<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'التوقيت العالمي';
$labels['tz:africa'] = 'أفريقيا';
$labels['tz:africa:abidjan'] = 'أبيدجان';
$labels['tz:africa:accra'] = 'آكر';
$labels['tz:africa:addis_ababa'] = 'أديس أبابا';
$labels['tz:africa:algiers'] = 'الجزائر';
$labels['tz:africa:asmara'] = 'أسمرة';
$labels['tz:africa:bamako'] = 'باماكو';
$labels['tz:africa:bangui'] = 'بانغي';
$labels['tz:africa:banjul'] = 'بانجول';
$labels['tz:africa:bissau'] = 'بيساو';
$labels['tz:africa:blantyre'] = 'بلانتير';
$labels['tz:africa:brazzaville'] = 'برازافيل';
$labels['tz:africa:bujumbura'] = 'بوجمبورا';
$labels['tz:africa:cairo'] = 'القاهرة';
$labels['tz:africa:casablanca'] = 'الدار البيضاء';
$labels['tz:africa:ceuta'] = 'سبتة';
$labels['tz:africa:conakry'] = 'كوناكري';
$labels['tz:africa:dakar'] = 'داكار';
$labels['tz:africa:dar_es_salaam'] = 'دار السلام';
$labels['tz:africa:djibouti'] = 'جيبوتي';
$labels['tz:africa:douala'] = 'دوالا';
$labels['tz:africa:el_aaiun'] = 'العيون';
$labels['tz:africa:freetown'] = 'فريتاون';
$labels['tz:africa:gaborone'] = 'جابورون';
$labels['tz:africa:harare'] = 'هراري';
$labels['tz:africa:johannesburg'] = 'جوهانسبرج';
$labels['tz:africa:juba'] = 'جوبا';
$labels['tz:africa:kampala'] = 'كمبالا';
$labels['tz:africa:khartoum'] = 'الخرطوم';
$labels['tz:africa:kigali'] = 'كيغالي';
$labels['tz:africa:kinshasa'] = 'كينشاسا';
$labels['tz:africa:lagos'] = 'لاغوس';
$labels['tz:africa:libreville'] = 'ليبرفيل';
$labels['tz:africa:lome'] = 'لومي';
$labels['tz:africa:luanda'] = 'لواندا';
$labels['tz:africa:lubumbashi'] = 'لوبومباشي';
$labels['tz:africa:lusaka'] = 'لوساكا';
$labels['tz:africa:malabo'] = 'مالابو';
$labels['tz:africa:maputo'] = 'مابوتو';
$labels['tz:africa:maseru'] = 'ماسيرو';
$labels['tz:africa:mbabane'] = 'مبابان';
$labels['tz:africa:mogadishu'] = 'مقديشو';
$labels['tz:africa:monrovia'] = 'مونروفيا';
$labels['tz:africa:nairobi'] = 'نيروبي';
$labels['tz:africa:ndjamena'] = 'نجامينا';
$labels['tz:africa:niamey'] = 'نيامي';
$labels['tz:africa:nouakchott'] = 'نواكشوط';
$labels['tz:africa:ouagadougou'] = 'واغادوغو';
$labels['tz:africa:porto-novo'] = 'بورتو نوفو';
$labels['tz:africa:sao_tome'] = 'ساو تومي';
$labels['tz:africa:tripoli'] = 'طرابلس';
$labels['tz:africa:tunis'] = 'تونس';
$labels['tz:africa:windhoek'] = 'ويندهوك';
$labels['tz:america'] = 'أمريكا';
$labels['tz:america:adak'] = 'أداك';
$labels['tz:america:anchorage'] = 'أنكوريج';
$labels['tz:america:anguilla'] = 'أنغيلا';
$labels['tz:america:antigua'] = 'أنتيغوا';
$labels['tz:america:araguaina'] = 'أراغوينا';
$labels['tz:america:argentina'] = 'الأرجنتين';
$labels['tz:america:argentina:buenos_aires'] = 'بوينس ايرس';
$labels['tz:america:argentina:catamarca'] = 'كاتاماركا';
$labels['tz:america:argentina:cordoba'] = 'قرطبة';
$labels['tz:america:argentina:jujuy'] = 'جوجوي';
$labels['tz:america:argentina:la_rioja'] = 'لاريوخا';
$labels['tz:america:argentina:mendoza'] = 'مندوزا';
$labels['tz:america:argentina:rio_gallegos'] = 'ريو جاليجوس';
$labels['tz:america:argentina:salta'] = 'سالتا';
$labels['tz:america:argentina:san_juan'] = 'سان خوان';
$labels['tz:america:argentina:san_luis'] = 'سان لويس';
$labels['tz:america:argentina:tucuman'] = 'توكومان';
$labels['tz:america:argentina:ushuaia'] = 'أوشوايا';
$labels['tz:america:aruba'] = 'أروبا';
$labels['tz:america:asuncion'] = 'أسونسيون';
$labels['tz:america:atikokan'] = 'أتيكوكان';
$labels['tz:america:bahia'] = 'باهيا';
$labels['tz:america:bahia_banderas'] = 'باهيا بانديراس';
$labels['tz:america:barbados'] = 'بربادوس';
$labels['tz:america:belem'] = 'بيليم';
$labels['tz:america:belize'] = 'بليز';
$labels['tz:america:blanc-sablon'] = 'بلانك-سابلون';
$labels['tz:america:boa_vista'] = 'بوا فيستا';
$labels['tz:america:bogota'] = 'بوغوتا';
$labels['tz:america:boise'] = 'بويسي';
$labels['tz:america:cambridge_bay'] = 'خليج كامبريدج';
$labels['tz:america:campo_grande'] = 'كامبو غراندي';
$labels['tz:america:cancun'] = 'كانكون';
$labels['tz:america:caracas'] = 'كاراكاس';
$labels['tz:america:cayenne'] = 'كايين';
$labels['tz:america:cayman'] = 'كايمان';
$labels['tz:america:chicago'] = 'شيكاغو';
$labels['tz:america:chihuahua'] = 'تشيواوا';
$labels['tz:america:costa_rica'] = 'كوستاريكا';
$labels['tz:america:creston'] = 'كريستون';
$labels['tz:america:cuiaba'] = 'كويابا';
$labels['tz:america:curacao'] = 'كوراساو';
$labels['tz:america:danmarkshavn'] = 'دانماركسهافن';
$labels['tz:america:dawson'] = 'داوسون';
$labels['tz:america:dawson_creek'] = 'داوسون كريك';
$labels['tz:america:denver'] = 'دنفر';
$labels['tz:america:detroit'] = 'ديترويت';
$labels['tz:america:dominica'] = 'دومينيكا';
$labels['tz:america:edmonton'] = 'إدمونتون';
$labels['tz:america:eirunepe'] = 'إيرونيبي';
$labels['tz:america:el_salvador'] = 'السلفادور';
$labels['tz:america:fort_nelson'] = 'فورت نيلسون';
$labels['tz:america:fortaleza'] = 'فورتاليزا';
$labels['tz:america:glace_bay'] = 'غلاس باي';
$labels['tz:america:godthab'] = 'غودثاب';
$labels['tz:america:goose_bay'] = 'غوس باي';
$labels['tz:america:grand_turk'] = 'غراند ترك';
$labels['tz:america:grenada'] = 'غرينادا';
$labels['tz:america:guadeloupe'] = 'غوادلوب';
$labels['tz:america:guatemala'] = 'غواتيمالا';
$labels['tz:america:guayaquil'] = 'غواياكيل';
$labels['tz:america:guyana'] = 'غيانا';
$labels['tz:america:halifax'] = 'هاليفاكس';
$labels['tz:america:havana'] = 'هافانا';
$labels['tz:america:hermosillo'] = 'هيرموسيو';
$labels['tz:america:indiana'] = 'إنديانا';
$labels['tz:america:indiana:indianapolis'] = 'إنديانابوليس';
$labels['tz:america:indiana:knox'] = 'نوكس';
$labels['tz:america:indiana:marengo'] = 'مارينغو';
$labels['tz:america:indiana:petersburg'] = 'بطرسبورغ';
$labels['tz:america:indiana:tell_city'] = 'تل سيتي';
$labels['tz:america:indiana:vevay'] = 'فيفاي';
$labels['tz:america:indiana:vincennes'] = 'فنسنس';
$labels['tz:america:indiana:winamac'] = 'وينا ماك';
$labels['tz:america:inuvik'] = 'إينوفيك';
$labels['tz:america:iqaluit'] = 'إيكالويت';
$labels['tz:america:jamaica'] = 'جامايكا';
$labels['tz:america:juneau'] = 'جونو';
$labels['tz:america:kentucky'] = 'كنتاكي';
$labels['tz:america:kentucky:louisville'] = 'لويفيل';
$labels['tz:america:kentucky:monticello'] = 'مونتيتشيلو';
$labels['tz:america:kralendijk'] = 'كرالينديك';
$labels['tz:america:la_paz'] = 'لاباز';
$labels['tz:america:lima'] = 'ليما';
$labels['tz:america:los_angeles'] = '"لوس أنجلوس';
$labels['tz:america:lower_princes'] = 'لاور برينسز';
$labels['tz:america:maceio'] = 'ماسيو';
$labels['tz:america:managua'] = 'ماناغوا';
$labels['tz:america:manaus'] = 'ماناوس';
$labels['tz:america:marigot'] = 'ماريغو';
$labels['tz:america:martinique'] = 'مارتينيك';
$labels['tz:america:matamoros'] = 'ماتاموروس';
$labels['tz:america:mazatlan'] = 'مازاتلان';
$labels['tz:america:menominee'] = 'مينوميني';
$labels['tz:america:merida'] = 'ميريدا';
$labels['tz:america:metlakatla'] = 'ميتلاكاتلا';
$labels['tz:america:mexico_city'] = 'مكسيكو سيتي';
$labels['tz:america:miquelon'] = 'ميكيلون';
$labels['tz:america:moncton'] = 'مونكتون';
$labels['tz:america:monterrey'] = 'مونتيري';
$labels['tz:america:montevideo'] = 'مونتيفيديو';
$labels['tz:america:montserrat'] = 'مونتسرات';
$labels['tz:america:nassau'] = 'ناساو';
$labels['tz:america:new_york'] = 'نيويورك';
$labels['tz:america:nipigon'] = 'نيبيغون';
$labels['tz:america:nome'] = 'نوم';
$labels['tz:america:noronha'] = 'نورونيا';
$labels['tz:america:north_dakota'] = 'نورث داكوتا';
$labels['tz:america:north_dakota:beulah'] = 'بيولا';
$labels['tz:america:north_dakota:center'] = 'سنتر';
$labels['tz:america:north_dakota:new_salem'] = 'نيو سالم';
$labels['tz:america:ojinaga'] = 'أوجيناغا';
$labels['tz:america:panama'] = 'بنما';
$labels['tz:america:pangnirtung'] = 'بانجنيرتونج';
$labels['tz:america:paramaribo'] = 'باراماريبو';
$labels['tz:america:phoenix'] = 'فينيكس';
$labels['tz:america:port-au-prince'] = 'بورت أو برنس';
$labels['tz:america:port_of_spain'] = 'ميناء إسبانيا';
$labels['tz:america:porto_velho'] = 'بورتو فيلهو';
$labels['tz:america:puerto_rico'] = 'بورتوريكو';
$labels['tz:america:rainy_river'] = 'رايني ريفر';
$labels['tz:america:rankin_inlet'] = 'رانكين إنلت';
$labels['tz:america:recife'] = 'ريسيفي';
$labels['tz:america:regina'] = 'ريجينا';
$labels['tz:america:resolute'] = 'ريزيلوت';
$labels['tz:america:rio_branco'] = 'ريو برانكو';
$labels['tz:america:santarem'] = 'سانتاريم';
$labels['tz:america:santiago'] = 'سانتياغو';
$labels['tz:america:santo_domingo'] = 'سانتو دومينغو';
$labels['tz:america:sao_paulo'] = 'ساو باولو';
$labels['tz:america:scoresbysund'] = 'سكورسبيسوند';
$labels['tz:america:sitka'] = 'سيتكا';
$labels['tz:america:st_barthelemy'] = 'سان بارتيليمي';
$labels['tz:america:st_johns'] = "سانت جون";
$labels['tz:america:st_kitts'] = 'سانت كيتس';
$labels['tz:america:st_lucia'] = 'سانت لوسيا';
$labels['tz:america:st_thomas'] = 'ساينت توماس';
$labels['tz:america:st_vincent'] = 'سانت فنسنت';
$labels['tz:america:swift_current'] = 'التيار السريع';
$labels['tz:america:tegucigalpa'] = 'تيغوسيغالبا';
$labels['tz:america:thule'] = 'ثولي';
$labels['tz:america:thunder_bay'] = 'ثاندر باي';
$labels['tz:america:tijuana'] = 'تيخوانا';
$labels['tz:america:toronto'] = 'تورنتو';
$labels['tz:america:tortola'] = 'تورتولا';
$labels['tz:america:vancouver'] = 'فانكوفر';
$labels['tz:america:whitehorse'] = 'وايتهورس';
$labels['tz:america:winnipeg'] = 'وينيبيغ';
$labels['tz:america:yakutat'] = 'ياكوتات';
$labels['tz:america:yellowknife'] = 'يلو نايف';
$labels['tz:antarctica'] = 'القطب الجنوبي';
$labels['tz:antarctica:casey'] = 'كيسي';
$labels['tz:antarctica:davis'] = 'ديفيس';
$labels['tz:antarctica:dumontdurville'] = "دومون دورفيل";
$labels['tz:antarctica:macquarie'] = 'ماكواري';
$labels['tz:antarctica:mawson'] = 'ماوسون';
$labels['tz:antarctica:mcmurdo'] = 'ماكموردو';
$labels['tz:antarctica:palmer'] = 'بالمر';
$labels['tz:antarctica:rothera'] = 'روثيرا';
$labels['tz:antarctica:syowa'] = 'سيوا';
$labels['tz:antarctica:troll'] = 'ترول';
$labels['tz:antarctica:vostok'] = 'فوستوك';
$labels['tz:arctic'] = 'القطب الشمالي';
$labels['tz:arctic:longyearbyen'] = 'لونجييربين';
$labels['tz:asia'] = 'آسيا';
$labels['tz:asia:aden'] = 'عدن';
$labels['tz:asia:almaty'] = 'ألماتي';
$labels['tz:asia:amman'] = 'عمّان';
$labels['tz:asia:anadyr'] = 'أنادير';
$labels['tz:asia:aqtau'] = 'أكتاو';
$labels['tz:asia:aqtobe'] = 'أكتوبي';
$labels['tz:asia:ashgabat'] = 'عشق آباد';
$labels['tz:asia:atyrau'] = 'أتيراو';
$labels['tz:asia:baghdad'] = 'بغداد';
$labels['tz:asia:bahrain'] = 'البحرين';
$labels['tz:asia:baku'] = 'باكو';
$labels['tz:asia:bangkok'] = 'بانكوك';
$labels['tz:asia:barnaul'] = 'بارناول';
$labels['tz:asia:beirut'] = 'بيروت';
$labels['tz:asia:bishkek'] = 'بيشكيك';
$labels['tz:asia:brunei'] = 'بروناي';
$labels['tz:asia:chita'] = 'تشيتا';
$labels['tz:asia:choibalsan'] = 'تشويبالسان';
$labels['tz:asia:colombo'] = 'كولومبو';
$labels['tz:asia:damascus'] = 'دمشق';
$labels['tz:asia:dhaka'] = 'دكا';
$labels['tz:asia:dili'] = 'ديلي';
$labels['tz:asia:dubai'] = 'دبي';
$labels['tz:asia:dushanbe'] = 'دوشانبي';
$labels['tz:asia:famagusta'] = 'فاماغوستا';
$labels['tz:asia:gaza'] = 'غزة';
$labels['tz:asia:hebron'] = 'الخليل';
$labels['tz:asia:ho_chi_minh'] = 'هو تشي منه';
$labels['tz:asia:hong_kong'] = 'هونغ كونغ';
$labels['tz:asia:hovd'] = 'هوفد';
$labels['tz:asia:irkutsk'] = 'إيركوتسك';
$labels['tz:asia:jakarta'] = 'جاكرتا';
$labels['tz:asia:jayapura'] = 'جايابورا';
$labels['tz:asia:jerusalem'] = 'القدس';
$labels['tz:asia:kabul'] = 'كابول';
$labels['tz:asia:kamchatka'] = 'كامتشاتكا';
$labels['tz:asia:karachi'] = 'كراتشي';
$labels['tz:asia:kathmandu'] = 'كاتماندو';
$labels['tz:asia:khandyga'] = 'خانديغا';
$labels['tz:asia:kolkata'] = 'كولكاتا';
$labels['tz:asia:krasnoyarsk'] = 'كراسنويارسك';
$labels['tz:asia:kuala_lumpur'] = 'كوالا لمبور';
$labels['tz:asia:kuching'] = 'كوتشينغ';
$labels['tz:asia:kuwait'] = 'الكويت';
$labels['tz:asia:macau'] = 'ماكاو';
$labels['tz:asia:magadan'] = 'ماجادان';
$labels['tz:asia:makassar'] = 'ماكاسار';
$labels['tz:asia:manila'] = 'مانيلا';
$labels['tz:asia:muscat'] = 'مسقط';
$labels['tz:asia:nicosia'] = 'نيقوسيا';
$labels['tz:asia:novokuznetsk'] = 'نوفوكوزنتسك';
$labels['tz:asia:novosibirsk'] = 'نوفوسيبيرسك';
$labels['tz:asia:omsk'] = 'أومسك';
$labels['tz:asia:oral'] = 'أورال';
$labels['tz:asia:phnom_penh'] = 'بنوم بنه';
$labels['tz:asia:pontianak'] = 'بونتياناك';
$labels['tz:asia:pyongyang'] = 'بيونغيانغ';
$labels['tz:asia:qatar'] = 'قطر';
$labels['tz:asia:qyzylorda'] = 'كيزيلوردا';
$labels['tz:asia:riyadh'] = 'الرياض';
$labels['tz:asia:sakhalin'] = 'سخالين';
$labels['tz:asia:samarkand'] = 'سمرقند';
$labels['tz:asia:seoul'] = 'سيول';
$labels['tz:asia:shanghai'] = 'شنغهاي';
$labels['tz:asia:singapore'] = 'سنغافورة';
$labels['tz:asia:srednekolymsk'] = 'سريدنيكوليمسك';
$labels['tz:asia:taipei'] = 'تايبيه';
$labels['tz:asia:tashkent'] = 'طاشقند';
$labels['tz:asia:tbilisi'] = 'تبليسي';
$labels['tz:asia:tehran'] = 'طهران';
$labels['tz:asia:thimphu'] = 'تيمفو';
$labels['tz:asia:tokyo'] = 'طوكيو';
$labels['tz:asia:tomsk'] = 'تومسك';
$labels['tz:asia:ulaanbaatar'] = 'أولان باتور';
$labels['tz:asia:urumqi'] = 'أورومتشي';
$labels['tz:asia:ust-nera'] = 'أوست-نيرا';
$labels['tz:asia:vientiane'] = 'فيينتيان';
$labels['tz:asia:vladivostok'] = 'فلاديفوستوك';
$labels['tz:asia:yakutsk'] = 'ياكوتسك';
$labels['tz:asia:yangon'] = 'يانغون';
$labels['tz:asia:yekaterinburg'] = 'يكاترينبورغ';
$labels['tz:asia:yerevan'] = 'يريفان';
$labels['tz:atlantic'] = 'الأطلسي';
$labels['tz:atlantic:azores'] = 'جزر الأزور';
$labels['tz:atlantic:bermuda'] = 'برمودا';
$labels['tz:atlantic:canary'] = 'كناري';
$labels['tz:atlantic:cape_verde'] = 'الرأس الأخضر';
$labels['tz:atlantic:faroe'] = 'فارو';
$labels['tz:atlantic:madeira'] = 'ماديرا';
$labels['tz:atlantic:reykjavik'] = 'ريكيافيك';
$labels['tz:atlantic:south_georgia'] = 'جورجيا الجنوبية';
$labels['tz:atlantic:st_helena'] = 'سانت هيلينا';
$labels['tz:atlantic:stanley'] = 'ستانلي';
$labels['tz:australia'] = 'أستراليا';
$labels['tz:australia:adelaide'] = 'أديلايد';
$labels['tz:australia:brisbane'] = 'بريسبان';
$labels['tz:australia:broken_hill'] = 'بروكن هيل';
$labels['tz:australia:currie'] = 'كوري ';
$labels['tz:australia:darwin'] = 'داروين';
$labels['tz:australia:eucla'] = 'يوكلا';
$labels['tz:australia:hobart'] = 'هوبارت';
$labels['tz:australia:lindeman'] = 'ليندمان';
$labels['tz:australia:lord_howe'] = 'لورد هاو';
$labels['tz:australia:melbourne'] = 'ملبورن';
$labels['tz:australia:perth'] = 'بيرث';
$labels['tz:australia:sydney'] = 'سيدني';
$labels['tz:europe'] = 'أوروبا';
$labels['tz:europe:amsterdam'] = 'أمستردام';
$labels['tz:europe:andorra'] = 'أندورا';
$labels['tz:europe:astrakhan'] = 'أستراخان';
$labels['tz:europe:athens'] = 'أثينا';
$labels['tz:europe:belgrade'] = 'بلغراد';
$labels['tz:europe:berlin'] = 'برلين';
$labels['tz:europe:bratislava'] = 'براتيسلافا';
$labels['tz:europe:brussels'] = 'بروكسل';
$labels['tz:europe:bucharest'] = 'بوخارست';
$labels['tz:europe:budapest'] = 'بودابست';
$labels['tz:europe:busingen'] = 'بوزنجن';
$labels['tz:europe:chisinau'] = 'كيشيناو';
$labels['tz:europe:copenhagen'] = 'كوبنهاجن';
$labels['tz:pacific:gambier'] = 'غامبير';
$labels['tz:pacific:guadalcanal'] = 'غوادالكانال';
$labels['tz:pacific:guam'] = 'غوام';
$labels['tz:pacific:honolulu'] = 'هونولولو';
$labels['tz:pacific:johnston'] = 'جونستون';
$labels['tz:pacific:kiritimati'] = 'كيريتيماتي';
$labels['tz:pacific:kosrae'] = 'كسرى';
$labels['tz:pacific:kwajalein'] = 'كواجالين';
$labels['tz:pacific:majuro'] = 'ماجورو';
$labels['tz:pacific:marquesas'] = 'ماركيساس';
$labels['tz:pacific:midway'] = 'ميدواي';
$labels['tz:pacific:nauru'] = 'ناورو';
$labels['tz:pacific:niue'] = 'نيو';
$labels['tz:pacific:norfolk'] = 'نورفولك';
$labels['tz:pacific:noumea'] = 'نوميا';
$labels['tz:pacific:pago_pago'] = 'باغو باغو';
$labels['tz:pacific:palau'] = 'بالاو';
$labels['tz:pacific:pitcairn'] = 'بيتكيرن';
$labels['tz:pacific:pohnpei'] = 'بوهنباي';
$labels['tz:pacific:port_moresby'] = 'مرفئ مويسبي';
$labels['tz:pacific:rarotonga'] = 'راروتونجا';
$labels['tz:pacific:saipan'] = 'سايبان';
$labels['tz:pacific:tahiti'] = 'تاهيتي';
$labels['tz:pacific:tarawa'] = 'تاراوا';
$labels['tz:pacific:tongatapu'] = 'تونغاتابو';
$labels['tz:pacific:wake'] = 'واكه';
$labels['tz:pacific:wallis'] = 'واليس';
