<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Presentar notificationes de navigator quando un nove message arriva';
$labels['desktop'] = 'Presentar notificationes de scriptorio quando un nove message arriva';
$labels['sound'] = 'Facer sonar un sono quando un nove message arriva';
$labels['test'] = 'Test';
$labels['title'] = 'Nove e-mail!';
$labels['body'] = 'Tu ha recipite un nove message.';
$labels['testbody'] = 'Iste es un notification de test.';
$labels['desktopdisabled'] = 'Le notificationes de scriptorio ha essite disactivate in tu navigator.';
$labels['desktopunsupported'] = 'Tu navigator non supporta le notificationes de scriptorio.';
$labels['desktoptimeout'] = 'Clauder notification de scriptorio';
