<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['loginfailed']  = 'लागईन हुन पाएन';
$messages['cookiesdisabled'] = 'तपाईको ब्राऊसरले कुकी स्वीकार गारिरहेको छैन';
$messages['sessionerror'] = 'सत्र समाप्त वा अवैद्य';
$messages['storageerror'] = 'सर्वर संग सम्पर्क हुन पाएन';
$messages['nomessagesfound'] = 'यो मेलबक्स मा कुनै मेल छैन';
$messages['loading'] = 'लोड भईरहेको छ...';
$messages['loadingdata'] = 'डाटा लोड भईरहेको छै...';
$messages['checkingmail'] = 'नया मेलको खोजी भईरहेको छ...';
$messages['sendingmessage'] = 'मेल पठाईदै रहेको छ...';
$messages['messagesent'] = 'मेल सफल्तापूर्वक पठाईयो';
$messages['savingmessage'] = 'मेल जोगाईदै छ...';
$messages['messagesaved'] = 'मेल ड्राफ्ट फोल्डरमा जोगाईयो';
$messages['successfullysaved'] = 'सफल्तापूर्वक जोगाईयो';
$messages['addedsuccessfully'] = 'सम्पर्क पुस्तिकामा सफल्तापूर्वक सम्पर्क प्रविष्ट गारियो';
$messages['blockedimages'] = 'तपाईको प्राईवेसी को लागि तथा अन्य स्पामबाट बच्नकोलागि यो मेलमा चित्रहुरु देखाईएका छैनन्।';
$messages['encryptedmessage'] = 'माफ गर्नुहोसे, यो मेल ईन्क्रिफ्ट गरिएको रूपमा छ, त्यसैले देखाउन सकिदैन!';
$messages['nocontactsfound'] = 'कुनै सम्पर्क भेटिएन';
$messages['contactnotfound'] = 'अनुरोध गारिएको सम्पर्क भेटिएन';
$messages['sendingfailed'] = 'मेल पठाउन सकिएन';
$messages['errormoving'] = 'मेल सार्न सकिएन';
$messages['errordeleting'] = 'मेल मेटाउन सकिएन';
$messages['deletecontactconfirm']  = 'तापाईले छान्नुभएको सम्पर्कहरु, साँचै मेट्न चहानुहुन्छ?';
$messages['deletemessagesconfirm'] = 'तापाईले छान्नु भएको मेलहरु, साँचै मेट्न चहानुहुन्छ?';
$messages['deletefolderconfirm']  = 'तापाईले साँचै यो फोल्डर मेट्न चहानु हुन्छ?';
$messages['purgefolderconfirm']  = 'तापाईले साँचै यो फोल्डरमा भएका सबै मेलहरु मेट्न चहानुहुन्छ?';
$messages['formincomplete'] = 'फर्म पूर्ण रुपमा भरिएको छैन';
$messages['noemailwarning'] = 'कृपया वैद्य ई-मेल भर्नुहोस';
$messages['nonamewarning']  = 'कृपया नाम भर्नुहोस';
$messages['nopagesizewarning'] = 'कृपया पन्नाको नाप भर्नुहोस';
$messages['norecipientwarning'] = 'कृपया कम-से-कम एउटा प्रापकको विवरण भर्नुहोस';
$messages['nosubjectwarning']  = 'मेलको कुनै विषय तोकिएको छैनै। केहि तोक्न चहानुहुन्छ ?';
$messages['nobodywarning'] = 'बिना केहि लेखि पठाउने?';
$messages['nosearchname'] = 'कृपया सम्पर्कको नाम या ई-मेल भर्नुहोस';
$messages['searchsuccessful'] = '$nr मेलहरु पाइयो';
$messages['searchnomatch'] = 'खोज असफल रहयो';
$messages['searching'] = 'खोजि भईरहेको छ...';
$messages['checking'] = 'जाँच भईरहेको छ...';
$messages['nospellerrors'] = 'कुनै गलत हिज्जे फेला परेनन्';
$messages['folderdeleted'] = 'फोल्डर सफल्तापूर्वक मेटियो';
$messages['deletedsuccessfully'] = 'सफल्तापूर्वक मेटियो';
$messages['converting'] = 'मेलबाट फोर्माटिङ हटाईदै छ...';
$messages['messageopenerror'] = 'सर्वरबाट मेल लोड हुन सकेन';
$messages['fileuploaderror'] = 'फाईल अपलोड हुन असफल';
$messages['filesizeerror'] = 'अपलोड गरिएको फाईल हद $size भन्दा ठूलो छ';
$messages['sourceisreadonly'] = 'यो ठेगाना को श्रोत पढ्नको लागि मात्र उपलब्ध छ';
$messages['errorsavingcontact'] = 'स्मपर्कको ठेगाना जोगाउन सकिएन';
