<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Siloù';
$labels['managefilters'] = 'Ardeiñ siloù ar posteloù o tont tre';
$labels['filtername'] = 'Anv ar sil';
$labels['newfilter'] = 'Sil nevez';
$labels['filteradd'] = 'Ouzhpennañ ur sil';
$labels['filterdel'] = 'Dilemel ar sil';
$labels['scope'] = 'Ledennad';
$labels['moveup'] = 'Dilec\'hiañ da grec\'h ';
$labels['movedown'] = 'Dilec\'hiañ d\'an traoñ';
$labels['filterallof'] = 'o kenglotañ gant an holl reolennoù da heul';
$labels['filteranyof'] = 'o kenglotañ gant unan eus ar reolennoù da heul';
$labels['filterany'] = 'An holl posteloù';
$labels['filtercontains'] = 'a endalc\'h';
$labels['filternotcontains'] = 'na endalc\'h ket';
$labels['filteris'] = 'a zo kevatal da';
$labels['filterisnot'] = 'n\'eo ket kevatal da';
$labels['filterexists'] = 'a zo dioutañ/diouti';
$labels['filternotexists'] = 'n\'eus ket dioutañ/diouti';
$labels['filtermatches'] = 'a genglot gant ar riñvenn';
$labels['filternotmatches'] = 'ne genglot ket gant ar riñvenn';
$labels['filterregex'] = 'a genglot gant ar bomm reol';
$labels['filternotregex'] = 'ne genglot ket gant ar bomm reol';
$labels['filterunder'] = 'dindan';
$labels['filterover'] = 'a-us';
$labels['addrule'] = 'Ouzhpennañ ur reolenn';
$labels['delrule'] = 'Dilemel ar reolenn';
$labels['messagemoveto'] = 'Dilec\'hiañ ar gemennadenn da';
$labels['messageredirect'] = 'Adheñchañ ar gemennadenn da';
$labels['messagecopyto'] = 'Eilañ ar postel e';
$labels['messagesendcopy'] = 'Kas un eilenn da';
$labels['messagereply'] = 'Respont gant ur gemennadenn';
$labels['messagedelete'] = 'Dilemel ar postel';
$labels['messagediscard'] = 'Dilezel gant ur gemennadenn';
$labels['messagekeep'] = 'Mirout ar gemennadenn er voest degemer';
$labels['messagesrules'] = 'Evit ar postel o tont-tre:';
$labels['messagesactions'] = '...erounit ar gweredoù da heul:';
$labels['add'] = 'Ouzhpennañ';
$labels['del'] = 'Dilemel';
$labels['sender'] = 'Kaser';
$labels['recipient'] = 'Degemerer';
$labels['vacationaddr'] = 'Ma chomlec\'hioù postel';
$labels['vacationdays'] = 'Feur kas ar c\'hemennadennoù (e devezhioù):';
$labels['vacationinterval'] = 'Feur kas ar c\'hemennadennoù:';
$labels['vacationreason'] = 'Korf ar gemennadenn (abeg an ezvezañs):';
$labels['vacationfrom'] = 'Chomlec\'h kaser ar respont:';
$labels['vacationsubject'] = 'Danvez';
$labels['days'] = 'a zevezhioù';
$labels['seconds'] = 'eilenn';
$labels['rulestop'] = 'Paouez da briziañ ar reolennoù';
$labels['enable'] = '(Di)weredekaat';
$labels['filtersets'] = 'Strolladoù sil';
$labels['filterdef'] = 'Despizadur ar sil';
$labels['active'] = 'gweredekaet';
$labels['none'] = 'hini ebet';
$labels['fromset'] = 'eus ar strollad';
$labels['fromfile'] = 'eus ur restr';
$labels['filterdisabled'] = 'Sil diweredekaet';
$labels['countisgreaterthan'] = 'an niver a zo ouzhpenn';
$labels['countisgreaterthanequal'] = 'an niver a zo ouzhpenn pe kevatal da';
$labels['countislessthan'] = 'An niver a zo nebeutoc\'h eget';
$labels['countislessthanequal'] = 'an niver a zo nebeutoc\'h pe kevatal da';
$labels['countequals'] = 'an niver a zo kevatal da';
$labels['countnotequals'] = 'an niver a zo dishenvel diouzh';
$labels['valueisgreaterthan'] = 'ar werzh a zo brasoc\'h eget';
$labels['valueisgreaterthanequal'] = 'ar gwerzh a zo brasoc\'h pe kevatal da';
$labels['valueislessthan'] = 'ar gwerzh a zo nebeutoc\'h eget';
$labels['valueislessthanequal'] = 'ar gwerzh a zo nebeutoc\'h pe kevatal da';
$labels['valueequals'] = 'ar gwerzh a zo kevatal da';
$labels['valuenotequals'] = 'ar gwerzh n\'eo ket kevatal da';
$labels['setflags'] = 'Lakaat bannieloù d\'ar gemennadenn';
$labels['addflags'] = 'Ouzhpennañ bannieloù d\'ar gemennadenn';
$labels['removeflags'] = 'Dilemel bannieloù diouzh ar gemennaenn';
$labels['flagread'] = 'Lennet';
$labels['flagdeleted'] = 'Dilamet';
$labels['flaganswered'] = 'Repsontet';
$labels['flagflagged'] = 'Bannielet';
$labels['flagdraft'] = 'Brouilhed';
$labels['setvariable'] = 'Lakaat un argemenn';
$labels['setvarname'] = 'Anv an argemenn';
$labels['setvarvalue'] = 'Gwerzh an argemenn';
$labels['setvarmodifiers'] = 'Daskemmerien:';
$labels['varlower'] = 'lizherennoù munut';
$labels['varupper'] = 'pennlizherennoù';
$labels['varlowerfirst'] = 'lizherenn gentañ munut';
$labels['varupperfirst'] = 'lizherenn gentañ bras';
$labels['varquotewildcard'] = 'menegiñ arouezennoù dibar';
$labels['varlength'] = 'hirder';
$labels['notify'] = 'Kas ur rebuziñ';
$labels['notifytarget'] = 'Bukenn ar rebuziñ:';
$labels['notifymessage'] = 'Kemennadenn rebuziñ (diret):';
$labels['notifyoptions'] = 'Dibarzhioù rebuziñ (diret):';
$labels['notifyfrom'] = 'Kaser rebuzi (diret):';
$labels['notifyimportance'] = 'Pouezusted:';
$labels['notifyimportancelow'] = 'izel';
$labels['notifyimportancenormal'] = 'reoliek';
$labels['notifyimportancehigh'] = 'uhel';
$labels['notifymethodmailto'] = 'Chomlec\'h postel';
$labels['notifymethodtel'] = 'Pellgomz';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Krouiñ ur sil';
$labels['usedata'] = 'Ober gant ar roadennoù da heul er sil';
$labels['nextstep'] = 'Pazenn da heul';
$labels['...'] = '...';
$labels['currdate'] = 'Deiziad bremanel';
$labels['datetest'] = 'Deiziad';
$labels['dateheader'] = 'talbenn:';
$labels['year'] = 'bloavezh';
$labels['month'] = 'miz';
$labels['day'] = 'devezh';
$labels['date'] = 'deiziad (bbbb-mm-dd)';
$labels['julian'] = 'deiziad (julian)';
$labels['hour'] = 'eur';
$labels['minute'] = 'munutenn';
$labels['second'] = 'eilenn';
$labels['time'] = 'eur (eur:miz:eilennoù)';
$labels['iso8601'] = 'deiziad (ISO8601)';
$labels['std11'] = 'deiziad (RFC2822)';
$labels['zone'] = 'gwerzhid-eur';
$labels['weekday'] = 'devezh ar sizhun (0-6)';
$labels['advancedopts'] = 'Dibarzhioù kempleshoc\'h';
$labels['body'] = 'Korf';
$labels['address'] = 'chomlec\'h';
$labels['envelope'] = 'golo-lizher';
$labels['modifier'] = 'dazkemmer:';
$labels['text'] = 'testenn';
$labels['undecoded'] = 'dienboneget (diaoz)';
$labels['contenttype'] = 'rizh an endalc\'had';
$labels['modtype'] = 'rizh:';
$labels['allparts'] = 'an holl';
$labels['domain'] = 'domani';
$labels['localpart'] = 'lodenn lec\'hel';
$labels['user'] = 'arveriad';
$labels['detail'] = 'munud';
$labels['comparator'] = 'keñverier';
$labels['default'] = 'dre ziouer';
$labels['octet'] = 'strizh (eizhbit)';
$labels['asciicasemap'] = 'chom hep teurel evezh ouzh an direnneg (ascii-casemap)';
$labels['asciinumeric'] = 'niverel (ascii-numeric)';
$labels['index'] = 'ibil:';
$labels['indexlast'] = 'war-gil';
$labels['spamtestequals'] = 'a zo kevatal da';
$labels['spamtestnotequals'] = 'n\'eo ket kevatal da';
$labels['vacation.reply'] = 'Kemennadenn respont';
$labels['vacation.advanced'] = 'Arventennoù kempleshoc\'h';
$labels['vacation.from'] = 'Chomlec\'h kaser ar respont';
$labels['vacation.subject'] = 'Danvez';
$labels['vacation.body'] = 'Korf';
$labels['vacation.status'] = 'Stad';
$labels['vacation.on'] = 'Ya';
$labels['vacation.off'] = 'Ket';
$labels['vacation.addresses'] = 'Ma chomlec\'hioù postel';
$labels['vacation.interval'] = 'Etremez respont';
$labels['vacation.saving'] = 'Oc\'h enrollañ ar roadennoù';
$labels['vacation.action'] = 'Gwered kemennadenn o tont-tre';
$labels['vacation.keep'] = 'Mirout';
$labels['vacation.discard'] = 'Dilezel';
$labels['vacation.redirect'] = 'Adheñchañ da';
$labels['vacation.copy'] = 'Kas un eilenn da';
$labels['forward.redirect'] = 'Adheñchañ da';
$labels['forward.copy'] = 'Kas un eilenn da';
$labels['forward.on'] = 'Ya';
$labels['forward.off'] = 'Ket';
$labels['forward.saving'] = 'Oc\'h enrollañ ar roadennoù';
$labels['filladdresses'] = 'Leuniañ gant ma holl chomlec\'hioù';
$labels['arialabelfiltersetactions'] = 'Gweredeoù ar strollad siloù';
$labels['arialabelfilteractions'] = 'Gweredoù ar sil';
$labels['arialabelfilterform'] = 'Perzhioù ar sil';
$labels['ariasummaryfilterslist'] = 'Roll ar siloù';
$labels['ariasummaryfiltersetslist'] = 'Roll ar strolladoù siloù';
$labels['filterstitle'] = 'Embann ar siloù posteloù o tont-tre';
$labels['vacationtitle'] = 'Embann ar reolenn maez-ar-burev';
$labels['message'] = 'Kemennadenn';
$labels['duplicate'] = 'a zo un eilad';
$labels['notduplicate'] = 'n\'eo ket un eilad';
$labels['duplicate.handle'] = 'merañ:';
$labels['duplicate.header'] = 'talbenn:';
$labels['duplicate.uniqueid'] = 'naoudi:';
$labels['duplicate.seconds'] = 'diamzeret (eilennoù):';
$labels['duplicate.last'] = 'daveel d\'an erounezadur kent';
$messages['filterunknownerror'] = 'Fazi dafariad dianav.';
$messages['filterconnerror'] = 'N\'haller ket kennaskañ d\'an dafariad';
$messages['filterdeleteerror'] = 'N\'haller ket dilemel ar sil. Ur fazi dafariad a zo c\'hoavezet.';
$messages['filterdeleted'] = 'Sil dilamet gant berzh.';
$messages['filtersaved'] = 'Sil enrollet gant berzh.';
$messages['filtersaveerror'] = 'N\'haller ket enrollañ ar sil. Ur fazi dafariad a zo c\'hoarvezet.';
$messages['filterformerror'] = 'Fazio a zo e furmskrid ar sil.';
$messages['filterdeleteconfirm'] = 'Fellout a ra deoc\'h dilemel ar sil dibabet?';
$messages['ruledeleteconfirm'] = 'Fellout a ra deoc\'h dilemel ar reolenn diuzet?';
$messages['actiondeleteconfirm'] = 'Fellout a ra deoc\'h dilemel ar gwered diuzet?';
$messages['forbiddenchars'] = 'Arouezennoù difennet er vaezienn.';
$messages['cannotbeempty'] = 'N\'hall ket ar vaezienn bezañ goullo.';
$messages['ruleexist'] = 'Ur sil gant an anv erspizet an zo dioutañ endeo.';
$messages['activateerror'] = 'N\'haller ket gweredekaat ar sil(où) diuzet. Ur fazi dafariad a zo c\'hoarvezet.';
$messages['deactivateerror'] = 'N\'haller ket diweredekaat ar sil(où) diuzet. Ur fazi dafariad a zo c\'hoarvezet.';
$messages['deactivated'] = 'Sil(où) diweredekaet gant berzh.';
$messages['activated'] = 'Sil(où) diweredekaet gant berzh.';
$messages['moved'] = 'Sil(où) dilec\'hiet gant berzh.';
$messages['moveerror'] = 'N\'haller ket dilec\'hiañ ar sil diuzet. Ur fazi dafariad a zo c\'hoarvezet.';
$messages['nametoolong'] = 'Re hir eo an anv.';
$messages['namereserved'] = 'Miret eo an anv.';
$messages['setexist'] = 'Ar strollad a zo anezhañ endeo.';
$messages['nodata'] = 'Ul lec\'hiadur a rank bezañ diuzet d\'an nebeutañ!';
$messages['invaliddateformat'] = 'Mentrezh deiziad pe lodenn deiziad didalvoudek';
$messages['saveerror'] = 'N\'haller ket enrollañ ar roadennoù. Ur fazi dafariad a zo c\'hoarvezet.';
$messages['emptyvacationbody'] = 'Dleet eo korf ar gemennadenn ezvezañs!';
$messages['duplicate.conflict.err'] = 'Un talbenn hag un naoudi unel n\'int ket aotreet.';
