<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Φίλτρα';
$labels['managefilters'] = 'Διαχείριση φίλτρων εισερχόμενων';
$labels['filtername'] = 'Ονομασία φίλτρου';
$labels['newfilter'] = 'Δημιουργία φίλτρου';
$labels['filteradd'] = 'Προσθήκη φίλτρου';
$labels['filterdel'] = 'Διαγραφή φίλτρου';
$labels['rules'] = 'Κανόνες';
$labels['actions'] = 'Ενέργειες';
$labels['scope'] = 'Εύρος';
$labels['moveup'] = 'Μετακίνηση πάνω';
$labels['movedown'] = 'Μετακίνηση κάτω';
$labels['filterallof'] = 'ταιριάζουν με όλους τους παρακάτω κανόνες';
$labels['filteranyof'] = 'ταιριάζουν με οποιονδήποτε από τους παρακάτω κανόνες';
$labels['filterany'] = 'όλα τα μηνύματα';
$labels['filtercontains'] = 'περιέχει';
$labels['filternotcontains'] = 'δεν περιέχει';
$labels['filteris'] = 'είναι ίσο με';
$labels['filterisnot'] = 'δεν είναι ίσο με';
$labels['filterexists'] = 'υπάρχει';
$labels['filternotexists'] = 'δεν υπάρχει';
$labels['filtermatches'] = 'ταιριάζει με την έκφραση ';
$labels['filternotmatches'] = 'Δεν ταιριάζει με την έκφραση';
$labels['filterregex'] = 'ταιριάζει με κανονική έκφραση';
$labels['filternotregex'] = 'δεν ταιριάζει με κανονική έκφραση';
$labels['filterunder'] = 'κάτω';
$labels['filterover'] = 'πάνω';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME part:';
$labels['mime-message'] = 'μήνυμα';
$labels['mime-anychild'] = 'όλα';
$labels['mime-type'] = 'τύπος';
$labels['mime-subtype'] = 'υποκατηγορία';
$labels['mime-contenttype'] = 'content-type';
$labels['mime-param'] = 'παράμετρος';
$labels['addrule'] = 'Προσθήκη κανόνα';
$labels['delrule'] = 'Διαγραφή κανόνα';
$labels['messagemoveto'] = 'Μετακίνηση μηνύματος στο';
$labels['messageredirect'] = 'Προώθηση μηνύματος στο';
$labels['messagecopyto'] = 'Αντιγραφη μυνηματος σε';
$labels['messagesendcopy'] = 'Αποστολη της αντιγραφης μυνηματος σε';
$labels['messagereply'] = 'Απάντηση με μήνυμα';
$labels['messagedelete'] = 'Διαγραφή μηνύματος';
$labels['messagediscard'] = 'Απόρριψη με μήνυμα';
$labels['messagekeep'] = 'Διατήρηση μηνύματος στα Εισερχόμενα';
$labels['messagesrules'] = 'Για εισερχόμενα μηνύματα που:';
$labels['messagesactions'] = '...εκτέλεση των παρακάτω ενεργειών:';
$labels['add'] = 'Προσθήκη';
$labels['del'] = 'Διαγραφή';
$labels['sender'] = 'Αποστολέας';
$labels['recipient'] = 'Παραλήπτης';
$labels['vacationaddr'] = 'Οι e-mail διευθύνσεις μου:';
$labels['vacationdays'] = 'Συχνότητα αποστολής μηνυμάτων (σε ημέρες):';
$labels['vacationinterval'] = 'Συχνότητα αποστολής μηνυμάτων:';
$labels['vacationreason'] = 'Σώμα μηνύματος (λόγος απουσίας):';
$labels['vacationfrom'] = 'Διεύθυνση απάντησης στον αποστολέα:';
$labels['vacationsubject'] = 'Θέμα μηνύματος: ';
$labels['days'] = 'ημέρες';
$labels['seconds'] = 'δευτερόλεπτα';
$labels['rulestop'] = 'Παύση επαλήθευσης κανόνων';
$labels['enable'] = 'Ενεργοποίηση/Απενεργοποίηση';
$labels['filterset'] = 'Σετ φίλτρων';
$labels['filtersets'] = 'Φίλτρο';
$labels['filtersetadd'] = 'Προσθήκη ομάδας φίλτρων';
$labels['filtersetdel'] = 'Διαγραφή ομάδας φίλτρων';
$labels['filtersetact'] = 'Ενεργοποίηση τρέχουσας ομάδας φίλτρων';
$labels['filtersetdeact'] = 'Απενεργοποίηση τρέχουσας ομάδας φίλτρων';
$labels['filterseteditraw'] = 'Επεξεργασία ομάδας φίλτρων';
$labels['filtersetswitch'] = '(Απ-)ενεργοποίηση ομάδας φίλτρων';
$labels['filterdef'] = 'Ορισμος φιλτρου';
$labels['filtersetname'] = 'Ονομασία ομάδας φίλτρων';
$labels['newfilterset'] = 'Νέα ομάδα φίλτρων';
$labels['active'] = 'ενεργο';
$labels['none'] = 'κανένα';
$labels['fromset'] = 'από το σύνολο ';
$labels['fromfile'] = 'απο αρχειο';
$labels['filterdisabled'] = 'Απενεργοποιημένο φίλτρο';
$labels['filterenabled'] = 'Ενεργό φίλτρο';
$labels['countisgreaterthan'] = 'αρίθμηση είναι μεγαλύτερη από';
$labels['countisgreaterthanequal'] = 'η μετρηση είναι μεγαλύτερη ή ίση προς';
$labels['countislessthan'] = 'η μετρηση είναι μικρότερη απο';
$labels['countislessthanequal'] = 'η μετρηση είναι μικρότερη ή ίση προς';
$labels['countequals'] = 'η μέτρηση είναι ίση προς ';
$labels['countnotequals'] = 'η μέτρηση δεν είναι ίση προς ';
$labels['valueisgreaterthan'] = 'η τιμη είναι μεγαλύτερη από';
$labels['valueisgreaterthanequal'] = 'η τιμη είναι μεγαλύτερη ή ίση προς';
$labels['valueislessthan'] = 'η τιμη είναι μικρότερη απο';
$labels['valueislessthanequal'] = 'η τιμη είναι μικρότερη ή ίση προς';
$labels['valueequals'] = 'η τιμη είναι ίση με';
$labels['valuenotequals'] = 'η τιμη δεν είναι ίση με';
$labels['setflags'] = 'Ορισμός σημαίων στο μήνυμα';
$labels['addflags'] = 'Προσθήκη σημαίων στο μήνυμα';
$labels['removeflags'] = 'Αφαιρέση σημαίων από το μήνυμα';
$labels['flagread'] = 'Αναγνωση';
$labels['flagdeleted'] = 'Διεγραμμένο';
$labels['flaganswered'] = 'Απαντήθηκε ';
$labels['flagflagged'] = 'Σημειωμένο';
$labels['flagdraft'] = 'Πρόχειρα';
$labels['addheader'] = 'Προσθήκη κεφαλίδας στο μήνυμα';
$labels['deleteheader'] = 'Αφαίρεση κεφαλίδας από το μήνυμα';
$labels['headername'] = 'Όνομα κεφαλίδας';
$labels['headervalue'] = 'Τιμή κεφαλίδας';
$labels['headerpos'] = 'Θέση κεφαλίδας';
$labels['headeratstart'] = 'στην αρχή';
$labels['headeratend'] = 'στο τέλος';
$labels['headeroccurrence'] = 'Εμφανίσεις/θέση της κεφαλίδας';
$labels['headerfromstart'] = 'από την αρχή';
$labels['headerfromend'] = 'από το τέλος';
$labels['headerpatterns'] = 'Μοτίβα τιμών κεφαλίδας';
$labels['headermatchtype'] = 'τύπος αντιστοιχίας:';
$labels['setvariable'] = 'Ορισμός μεταβλητής';
$labels['setvarname'] = 'Όνομα μεταβλητης:';
$labels['setvarvalue'] = 'Τιμη μεταβλητης:';
$labels['setvarmodifiers'] = 'Τροποποιητές: ';
$labels['varlower'] = 'Μικρογράμματη γραφή';
$labels['varupper'] = 'κεφαλαία γράμματα ';
$labels['varlowerfirst'] = 'πρώτος χαρακτήρας πεζός ';
$labels['varupperfirst'] = 'πρώτος χαρακτήρας κεφαλαία γράμματα';
$labels['varquotewildcard'] = 'παραθέση ειδικων χαρακτήρων';
$labels['varlength'] = 'Μήκος';
$labels['varencodeurl'] = 'τοις-εκατό κωδικοποίηση (για URL)';
$labels['notify'] = 'Αποστολή ειδοποίησης ';
$labels['notifytarget'] = 'Παραλήπτης ειδοποίησης:';
$labels['notifymessage'] = 'Μήνυμα ειδοποίησης (προαιρετικά):';
$labels['notifyoptions'] = 'Επιλογές ειδοποίησης (προαιρετικά):';
$labels['notifyfrom'] = 'Αποστολέας ειδοποίησης (προαιρετικά):';
$labels['notifyimportance'] = 'Σημασία: ';
$labels['notifyimportancelow'] = 'Χαμηλή';
$labels['notifyimportancenormal'] = 'Κανονική';
$labels['notifyimportancehigh'] = 'Υψηλή';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Τηλέφωνο';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Δημιουργία φίλτρου';
$labels['usedata'] = 'Χρησιμοποιηση ακολουθων δεδομενων στο φιλτρο:';
$labels['nextstep'] = 'Επομενο βημα';
$labels['...'] = '...';
$labels['string'] = 'Συμβολοσειρά';
$labels['currdate'] = 'Τρέχουσα ημερομηνία';
$labels['datetest'] = 'Ημερομηνία';
$labels['dateheader'] = 'επικεφαλίδα:';
$labels['year'] = 'χρονος';
$labels['month'] = 'μηνας';
$labels['day'] = 'ημερα';
$labels['date'] = 'ημερομηνία (yyyy-mm-dd)';
$labels['julian'] = 'ημερομηνία (Ιουλιανό ημ/γιο)';
$labels['hour'] = 'ωρα';
$labels['minute'] = 'λεπτο';
$labels['second'] = 'δευτερόλεπτο';
$labels['time'] = 'ωρα (hh:mm:ss)';
$labels['iso8601'] = 'ημερομηνία (ISO8601)';
$labels['std11'] = 'ημερομηνία (RFC2822)';
$labels['zone'] = 'Ζώνη Ώρας';
$labels['weekday'] = 'ημέρα της εβδομάδας (0-6)';
$labels['advancedopts'] = 'Προχωρημένες ρυθμίσεις';
$labels['body'] = 'Κείμενο';
$labels['address'] = 'Διεύθυνση';
$labels['envelope'] = 'φάκελος';
$labels['modifier'] = 'Τροποποιηση: ';
$labels['text'] = 'κειμενο';
$labels['undecoded'] = 'αποκωδικοποιημένο (raw)';
$labels['contenttype'] = 'Τύπος περιεχομένου ';
$labels['modtype'] = 'τυπος:';
$labels['allparts'] = 'Όλα';
$labels['domain'] = 'τομέας';
$labels['localpart'] = 'τοπικό τμήμα ';
$labels['user'] = 'χρηστης';
$labels['detail'] = 'λεπτομερειες';
$labels['comparator'] = 'σύγκριση:';
$labels['default'] = 'προεπιλογή';
$labels['octet'] = 'αυστηρή (οκτάδα) ';
$labels['asciicasemap'] = 'πεζά ή κεφαλαία (ascii-casemap)';
$labels['asciinumeric'] = 'αριθμητικό (ascii-αριθμητικο)';
$labels['index'] = 'ευρετήριο:';
$labels['indexlast'] = 'προς τα πίσω';
$labels['spamtest'] = 'Επίπεδο spam';
$labels['spamtestisgreaterthan'] = 'είναι μεγαλύτερο από';
$labels['spamtestisgreaterthanequal'] = 'είναι μεγαλύτερο ή μικρότερο από';
$labels['spamtestislessthan'] = 'είναι μικρότερο από';
$labels['spamtestislessthanequal'] = 'είναι μικρότερο ή μεγαλύτερο από';
$labels['spamtestequals'] = 'είναι ίσο με';
$labels['spamtestnotequals'] = 'δεν είναι ίσο με';
$labels['spamtestisunknown'] = 'είναι άγνωστο';
$labels['vacation'] = 'Εκτός γραφείου';
$labels['vacation.reply'] = 'Μήνυμα απάντησης';
$labels['vacation.advanced'] = 'Προηγμένες ρυθμίσεις';
$labels['vacation.from'] = 'Διεύθυνση απάντησης αποστολέα';
$labels['vacation.subject'] = 'Θέμα';
$labels['vacation.body'] = 'Σώμα';
$labels['vacation.start'] = 'Ώρα έναρξης';
$labels['vacation.end'] = 'Ώρα λήξης';
$labels['vacation.status'] = 'Κατάσταση';
$labels['vacation.on'] = 'Ενεργό';
$labels['vacation.off'] = 'Ανενεργό';
$labels['vacation.addresses'] = 'Οι e-mail διευθύνσεις μου';
$labels['vacation.interval'] = 'Διάστημα απάντησης';
$labels['vacation.after'] = 'Τοποθέτηση του κανόνα «εκτός-γραφείου» μετά από';
$labels['vacation.saving'] = 'Αποθήκευση δεδομένων...';
$labels['vacation.action'] = 'Ενέργεια εισερχόμενου μηνύματος';
$labels['vacation.keep'] = 'Διατήρηση';
$labels['vacation.discard'] = 'Διαγραφή';
$labels['vacation.redirect'] = 'Ανακατεύθυνση σε';
$labels['vacation.copy'] = 'Αποστολή αντιγράφου σε';
$labels['forward'] = 'Προώθηση';
$labels['forward.redirect'] = 'Ανακατεύθυνση σε';
$labels['forward.copy'] = 'Αποστολή αντιγράφου σε';
$labels['forward.on'] = 'Ενεργό';
$labels['forward.off'] = 'Ανενεργό';
$labels['forward.status'] = 'Κατάσταση:';
$labels['forward.action'] = 'Για τα εισερχόμενα μηνύματα να εκτελείται η ακόλουθη ενέργεια:';
$labels['forward.saving'] = 'Αποθήκευση δεδομένων...';
$labels['filladdresses'] = 'Συμπλήρωση με όλες τις email διευθύνσεις μου';
$labels['arialabelfiltersetactions'] = 'Ενέργειες ομάδας φίλτρων';
$labels['arialabelfilteractions'] = 'Ενέργειες φίλτρων';
$labels['arialabelfilterform'] = 'Ιδιότητες φίλτρων';
$labels['ariasummaryfilterslist'] = 'Λίστα φίλτρων';
$labels['ariasummaryfiltersetslist'] = 'Λίστα ομάδων φίλτρων';
$labels['filterstitle'] = 'Επεξεργασία φίλτρων εισερχόμενης αλληλογραφίας';
$labels['vacationtitle'] = 'Επεξεργασία κανόνα εκτός-γραφείου';
$labels['forwardtitle'] = 'Επεξεργασία κανόνα προώθησης';
$labels['message'] = 'Μήνυμα';
$labels['duplicate'] = 'είναι διπλότυπο';
$labels['notduplicate'] = 'δεν είναι διπλότυπο';
$labels['duplicate.handle'] = 'λαβή:';
$labels['duplicate.header'] = 'κεφαλίδα:';
$labels['duplicate.uniqueid'] = 'αναγνωριστικό:';
$labels['duplicate.seconds'] = 'λήξη χρόνου (δευτερόλεπτα):';
$labels['duplicate.last'] = 'σχετικό με την τελευταία εκτέλεση';
$messages['filterunknownerror'] = 'Άγνωστο σφάλμα διακομιστή';
$messages['filterconnerror'] = 'Αδυναμία σύνδεσης στον διακομιστή.';
$messages['filterdeleteerror'] = 'Αδυναμία διαγραφής φίλτρου. Προέκυψε σφάλμα στον διακομιστή.';
$messages['filterdeleted'] = 'Το φίλτρο διαγράφηκε επιτυχώς.';
$messages['filtersaved'] = 'Το φίλτρο αποθηκεύτηκε επιτυχώς.';
$messages['filtersaveerror'] = 'Αδυναμία αποθήκευσης φίλτρου. Προέκυψε σφάλμα στον διακομιστή.';
$messages['filterformerror'] = 'Η φόρμα των φίλτρων περιέχει σφάλματα.';
$messages['filterdeleteconfirm'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε το επιλεγμένο φίλτρο? ';
$messages['ruledeleteconfirm'] = 'Θέλετε όντως να διαγράψετε τον επιλεγμένο κανόνα;';
$messages['actiondeleteconfirm'] = 'Θέλετε όντως να διαγράψετε την επιλεγμένη ενέργεια;';
$messages['forbiddenchars'] = 'Μη επιτρεπτοί χαρακτήρες στο πεδίο.';
$messages['cannotbeempty'] = 'Το πεδίο δεν μπορεί να είναι κενό.';
$messages['ruleexist'] = 'Φιλτρο με αυτο το όνομα υπάρχει ήδη. ';
$messages['setactivateerror'] = 'Αδυναμία ενεργοποίησης της επιλεγμένης ομάδας φίλτρων. Προέκυψε σφάλμα στο διακομιστή.';
$messages['setdeactivateerror'] = 'Αδυναμία απενεργοποίησης της επιλεγμένης ομάδας φίλτρων. Προέκυψε σφάλμα στο διακομιστή.';
$messages['setdeleteerror'] = 'Αδυναμία διαγραφής της επιλεγμένης ομάδας φίλτρων. Προέκυψε σφάλμα στο διακομιστή.';
$messages['setactivated'] = 'Η ομάδα φίλτρων ενεργοποιήθηκε επιτυχώς.';
$messages['setdeactivated'] = 'Η ομάδα φίλτρων απενεργοποιήθηκε επιτυχώς.';
$messages['setdeleted'] = 'Η ομάδα φίλτρων διαγράφηκε επιτυχώς.';
$messages['setupdated'] = 'Η ομάδα φίλτρων ενημερώθηκε επιτυχώς.';
$messages['setdeleteconfirm'] = 'Θέλετε σίγουρα να διαγράψετε την επιλεγμένη ομάδα φίλτρων φίλτρων;';
$messages['setcreateerror'] = 'Αδυναμία δημιουργίας ομάδας φίλτρων. Προέκυψε σφάλμα στο διακομιστή.';
$messages['setcreated'] = 'Η ομάδα φίλτρων δημιουργήθηκε επιτυχώς.';
$messages['activateerror'] = 'Αδυναμία ενεργοποίησης επιλεγμένου φίλτρου(ων). Προέκυψε σφάλμα στον διακομιστή.';
$messages['deactivateerror'] = 'Αδυναμία απενεργοποίησης επιλεγμένου φίλτρου(ων). Προέκυψε σφάλμα στον διακομιστή.';
$messages['deactivated'] = 'Το φιλτρο(α) απενεργοποιηθηκαν επιτυχως.';
$messages['activated'] = 'Το φίλτρο(α) ενεργοποιηθηκαν επιτυχώς.';
$messages['moved'] = 'Το φίλτρο μετακινηθηκε επιτυχώς.';
$messages['moveerror'] = 'Αδυναμία μετακίνησης επιλεγμένου φίλτρου. Προέκυψε σφάλμα στον διακομιστή.';
$messages['nametoolong'] = 'Το όνομα είναι πολύ μεγάλο.';
$messages['namereserved'] = 'Δεσμευμένο όνομα. ';
$messages['setexist'] = 'Η ομάδα υπάρχει ήδη. ';
$messages['nodata'] = 'Πρέπει να επιλεγεί τουλάχιστον μία θέση!';
$messages['invaliddateformat'] = 'Μη έγκυρη ημερομηνία ή η ημερομηνία μορφής τμήμα';
$messages['saveerror'] = 'Αδύνατη η αποθήκευση δεδομένων. Προέκυψε σφάλμα στον διακομιστή';
$messages['vacationsaved'] = 'Τα δεδομένα «εκτός-γραφείου» αποθηκεύτηκαν επιτυχώς.';
$messages['forwardsaved'] = 'Τα δεδομένα προώθησης αποθηκεύτηκαν επιτυχώς';
$messages['emptyvacationbody'] = 'Απαιτείται κείμενο για το μήνυμα διακοπών!';
$messages['duplicate.conflict.err'] = 'Το μοναδικό αναγνωριστικό και το αναγνωριστικό κεφαλίδας δεν επιτρέπονται.';
$messages['disabledaction'] = 'Μη επιτρεπόμενη ενέργεια.';
$messages['lastindexempty'] = 'Ο δείκτης απαιτείται κατά την αρίθμηση από το τέλος';
$messages['noflagset'] = 'Πρέπει να επιλεγεί τουλάχιστον μία «σημαία»!';
