<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = '공유';
$labels['myrights'] = '접근 권한';
$labels['username'] = '사용자:';
$labels['advanced'] = '고급 모드';
$labels['add'] = '추가';
$labels['newuser'] = '입력내용 추가';
$labels['editperms'] = '권한 수정';
$labels['actions'] = '접근 권한 동작...';
$labels['anyone'] = '모든 사용자 (아무나)';
$labels['anonymous'] = '방문자 (익명)';
$labels['identifier'] = '식별자';
$labels['acll'] = '조회';
$labels['aclr'] = '읽은 메시지';
$labels['acls'] = '읽은 상태 유지';
$labels['aclw'] = '쓰기 깃발';
$labels['acli'] = '삽입 (복사할 위치)';
$labels['aclp'] = '게시';
$labels['aclc'] = '하위 폴더 생성';
$labels['aclk'] = '하위 폴더 생성';
$labels['acld'] = '메시지 삭제';
$labels['aclt'] = '메시지 삭제';
$labels['acle'] = '영구 제거';
$labels['aclx'] = '폴더 삭제';
$labels['acla'] = '관리';
$labels['acln'] = '메시지에 주석 추가';
$labels['aclfull'] = '전체 제어 권한';
$labels['aclother'] = '기타';
$labels['aclread'] = '읽음';
$labels['aclwrite'] = '쓰기';
$labels['acldelete'] = '삭제';
$labels['shortacll'] = '조회';
$labels['shortaclr'] = '읽음';
$labels['shortacls'] = '보관';
$labels['shortaclw'] = '쓰기';
$labels['shortacli'] = '삽입';
$labels['shortaclp'] = '게시';
$labels['shortaclc'] = '생성';
$labels['shortaclk'] = '생성';
$labels['shortacld'] = '삭제';
$labels['shortaclt'] = '삭제';
$labels['shortacle'] = '지움';
$labels['shortaclx'] = '폴더 삭제';
$labels['shortacla'] = '관리';
$labels['shortacln'] = '주석 추가';
$labels['shortaclother'] = '기타';
$labels['shortaclread'] = '읽기';
$labels['shortaclwrite'] = '쓱';
$labels['shortacldelete'] = '삭제';
$labels['longacll'] = '폴더가 목록에 나타나고 다음 사용자가 구독할 수 있음:';
$labels['longaclr'] = '읽기 위해 폴더를 열 수 있음';
$labels['longacls'] = '읽은 메시지 깃발이 변경될 수 있음';
$labels['longaclw'] = '메시지 깃발 및 키워드를 변경할 수 있음, 다만 읽음 및 삭제됨은 제외됨';
$labels['longacli'] = '메시지를 폴더에 복사하거나 작성할 수 있음';
$labels['longaclp'] = '메시지가 이 폴더에 게시될 수 있음';
$labels['longaclc'] = '이 폴더의 바로 아래에 폴더를 생성(또는 이름 변경)할 수 있음';
$labels['longaclk'] = '이 폴더의 바로 아래에 폴더를 생성(또는 이름 변경)할 수 있음';
$labels['longacld'] = '메시지 삭제 깃발이 변경될 수 있음';
$labels['longaclt'] = '메시지 삭제 깃발이 변경될 수 있음';
$labels['longacle'] = '메시지가 영구 제거될 수 있음';
$labels['longaclx'] = '폴더를 삭제하거나 이름을 변경 할 수 있음';
$labels['longacla'] = '폴더의 접근 권한을 변경할 수 있음';
$labels['longacln'] = '공유된 메타데이터(주석)은 변경될 수 있습니다';
$labels['longaclfull'] = '폴더 관리를 포함한 전체 제어 권한';
$labels['longaclread'] = '폴더를 열어 읽을 수 있음';
$labels['longaclwrite'] = '메시지를 표시하거나, 폴더로 이동 또는 복사할 수 있음';
$labels['longacldelete'] = '메시지를 삭제할 수 있음';
$labels['longaclother'] = '기타 접근 권한';
$labels['ariasummaryacltable'] = '접근 권한 목록';
$labels['arialabelaclactions'] = '목록 동작';
$labels['arialabelaclform'] = '접근 권한 양식';
$messages['deleting'] = '접근 권한을 삭제하는 중...';
$messages['saving'] = '접근 권한을 저장하는 중...';
$messages['updatesuccess'] = '접근 권한을 성공적으로 변경함';
$messages['deletesuccess'] = '접근 권한을 성공적으로 삭제함.';
$messages['createsuccess'] = '접근 권한을 성공적으로 추가함.';
$messages['updateerror'] = '접근 권한을 업데이트 할 수 없음';
$messages['deleteerror'] = '접근 권한을 삭제할 수 없음';
$messages['createerror'] = '접근 권한을 추가할 수 없음';
$messages['deleteconfirm'] = '정말로 선택한 사용자의 접근 권한을 삭제하시겠습니까?';
$messages['norights'] = '지정된 권한이 없음!';
$messages['nouser'] = '지정된 사용자명이 없음!';
