<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels = [];
$labels['editor_icon_alt'] = 'Markdown editor';
$labels['editor_button_title'] = 'Compose message in Markdown and have it sent as HTML';
$labels['toolbar_button_quit'] = 'Back to plain text editor';
$labels['toolbar_button_help'] = 'Open a markdown syntax guide in a new window';
$labels['toolbar_button_preview'] = 'Preview HTML as it would be sent';
$labels['toolbar_button_bold'] = 'Bold';
$labels['toolbar_button_italic'] = 'Italic';
$labels['toolbar_button_strike'] = 'Strike through';
$labels['toolbar_button_h1'] = 'Heading level 1';
$labels['toolbar_button_h2'] = 'Heading level 2';
$labels['toolbar_button_h3'] = 'Heading level 3';
$labels['toolbar_button_h4'] = 'Heading level 4';
$labels['toolbar_button_h5'] = 'Heading level 5';
$labels['toolbar_button_h6'] = 'Heading level 6';
$labels['toolbar_button_blockquote'] = 'Blockquote';
$labels['toolbar_button_unordered_list'] = 'Unordered list';
$labels['toolbar_button_ordered_list'] = 'Ordered list';
$labels['toolbar_button_link'] = 'Link';
$labels['toolbar_button_image'] = 'Image';
$labels['toolbar_button_undo'] = 'Undo';
$labels['toolbar_button_redo'] = 'Redo';
