<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Wyświetlaj powiadomienia o nadejściu nowej wiadomości w przeglądarce';
$labels['desktop'] = 'Wyświetlaj powiadomienia o nadejściu nowej wiadomości na pulpicie';
$labels['sound'] = 'Odtwarzaj dźwięk o nadejściu nowej wiadomości';
$labels['test'] = 'Testuj powiadomienie';
$labels['title'] = 'Nowa wiadomość!';
$labels['body'] = 'Nadeszła nowa wiadomość.';
$labels['testbody'] = 'To jest testowe powiadomienie.';
$labels['desktopdisabled'] = 'Powiadomienia na pulpicie zostały zablokowane w twojej przeglądarce.';
$labels['desktopunsupported'] = 'Twoja przeglądarka nie obsługuje powiadomień na pulpicie.';
$labels['desktoptimeout'] = 'Zamknij powiadomienie pulpitu';
