<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['changepasswd']  = 'Променете лозинка';
$labels['curpasswd']  = 'Сегашна лозинка';
$labels['newpasswd']  = 'Нова лозинка';
$labels['confpasswd']  = 'Потврдете ја вашата лозинка';
$messages['nopassword'] = 'Ве молиме внесете нова лозинка';
$messages['nocurpassword'] = 'Ве молиме внесете ја вашата сегашна лозинка.';
$messages['passwordincorrect'] = 'Сегашната лозинка е неточна.';
$messages['passwordinconsistency'] = 'Лозинките не се совпаѓаат, ве молиме обидете се повторно.';
$messages['crypterror'] = 'Новата лозинка не е зачувана. функцијата за енкрипција недостига.';
$messages['connecterror'] = 'Сегашната лозинка неможе да се зачува. Грешка при поврзувањето. ';
$messages['internalerror'] = 'Сегашната лозинка неможе да се зачува.';
$messages['passwordshort'] = 'Лозинката мора да биде минимум $length карактери.';
$messages['passwordweak'] = 'Лозинката мора да содржи барем една бројка и еден интерпункциски знак.';
$messages['passwordforbidden'] = 'Лозинката содржи забранети карактери.';
$messages['firstloginchange'] = 'Ова е вашето последно логирање. Ве молиме променете ја вашата лозинка.';
$messages['disablednotice'] = 'Системот се ажурира и не е возможна промена на лозинка во моментов. Ве молиме обидете се покасно. Се извинуваме за непријатностите. ';
$messages['passwinhistory'] = 'Лозинката е предходно употребувана.';
$messages['samepasswd'] = 'Новата лозинка мора да биде различна од старата.';
$messages['passwdexpirewarning'] = 'Предупредување ! Вашата лозинка наскоро истекува, ве молиме изменете ја пред $expirationdatetime.';
$messages['passwdexpired'] = 'Вашата лозинка е истечена, морате да ја промените ! ';
$messages['passwdconstraintviolation'] = 'Пасвордот е наришен. Пасвордот веројатно е слаб';
