<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Ar­chi­vie­ren';
$labels['buttontitle'] = 'Nachricht archivieren';
$labels['archived'] = 'Nachricht erfolgreich archiviert';
$labels['archivedreload'] = 'Erfolgreich archiviert. Bitte die Seite aktualisieren, um die neuen Archivordner zu sehen.';
$labels['archiveerror'] = 'Einige Nachrichten konnten nicht archiviert werden';
$labels['archivefolder'] = 'Archiv';
$labels['settingstitle'] = 'Archiv';
$labels['archivetype'] = 'Archiv aufteilen nach';
$labels['archivetypeyear'] = 'Jahr (z.B. Archiv/2012)';
$labels['archivetypemonth'] = 'Monat (z.B. Archiv/2012/06)';
$labels['archivetypetbmonth'] = 'Monat - Thunderbird-kompatibel (z.B. Archiv/2012/2012-06)';
$labels['archivetypefolder'] = 'Originalordner';
$labels['archivetypefolderyear'] = 'Jahr und der Originalordner (z.B. Archiv/2012/...)';
$labels['archivetypefoldermonth'] = 'Jahr, Monat und der Originalordner (z.B. Archiv/2012/06/...)';
$labels['archivetypesender'] = 'Absender-E-Mail';
$labels['unkownsender'] = 'unbekannt';
$labels['readonarchive'] = 'Nachricht im Archiv als gelesen markieren';
