<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Archiválás';
$labels['buttontitle'] = 'Üzenet archiválása';
$labels['archived'] = 'Sikeres archiválás';
$labels['archivedreload'] = 'Az archiválás sikeres. Frissítsd az oldalt, hogy lásd a létrejött archívum mappákat.';
$labels['archiveerror'] = 'Néhány üzenetet nem sikerült archiválni';
$labels['archivefolder'] = 'Archiválás';
$labels['settingstitle'] = 'Archiválás';
$labels['archivetype'] = 'Archívum tovább bontása a következő szerint';
$labels['archivetypeyear'] = 'Év (pl. Archívum/2012)';
$labels['archivetypemonth'] = 'Hónap (pl. Archívum/2012/06)';
$labels['archivetypetbmonth'] = 'Hónap - Thunderbird kompatibilis (pl. Archívum/2012/2012-06)';
$labels['archivetypefolder'] = 'Eredeti mappa';
$labels['archivetypefolderyear'] = 'Év és az eredeti mappa (pl. Archív/2012/...)';
$labels['archivetypefoldermonth'] = 'Év, hónap és az eredeti mappa  (pl. Archív/2012/06/...)';
$labels['archivetypesender'] = 'Feladó';
$labels['unkownsender'] = 'ismeretlen';
$labels['readonarchive'] = 'Üzenet olvasottként jelölése archiváláskor';
