<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'ئەرشیف';
$labels['buttontitle'] = 'ئەم نامەیە ئەرشیف بکە';
$labels['archived'] = 'بەسەرکەوتوویی ئەرشیف کرا';
$labels['archivedreload'] = 'بەسەرکەوتوویی ئەرشیف کرا، دووبارە پەڕەکە بکەرەوە بۆ بینینی بوخچە نوێیەکانی ئەرشیف.';
$labels['archiveerror'] = 'نەتوانرا هەندێک لە نامەکان ئەرشیف بکرێن';
$labels['archivefolder'] = 'ئەرشیف';
$labels['settingstitle'] = 'ئەرشیف';
$labels['archivetype'] = 'ئەرشیف دابەشبکە بەپێی';
$labels['archivetypeyear'] = 'ساڵ (بۆ نموونە ئەرشیف/2012)';
$labels['archivetypemonth'] = 'مانگ (بۆ نموونە ئەرشیف/06/2012)';
$labels['archivetypetbmonth'] = 'مانگ - گوونجاو لەگەڵ سەندەربێرد (بۆ نموونە ئەرشیف2012/2012-06)';
$labels['archivetypefolder'] = 'بوخچەی ڕەسەن';
$labels['archivetypefolderyear'] = 'ساڵ و بوخچە ڕەسەنەکە (بۆ نموونە ئەرشیف/2012/...)';
$labels['archivetypefoldermonth'] = 'ساڵ، مانگ و بوخچە ڕەسەنەکە (بۆ نموونە ئەرشیف/2012/06/...)';
$labels['archivetypesender'] = 'پۆستی ئەلیکترۆنیی نێردەر';
$labels['unkownsender'] = 'نەناسراو';
$labels['readonarchive'] = 'لە ئەرشیفدا نامەکە وەکو خوێنراوە دیاریبکە';
