<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['Anniversary'] = 'anniversary';
$map['Assistant\'s Name'] = 'assistant';
$map['Assistant\'s Phone'] = 'phone:assistant';
$map['Birthday'] = 'birthday';
$map['Ciudad de trabajo'] = 'locality:work';
$map['Provincia o estado de trabajo'] = 'country:work';
$map['Business Fax'] = 'phone:workfax';
$map['Teléfono del trabajo'] = 'phone:work';
$map['Business Phone 2'] = 'phone:work2';
$map['Código postal del trabajo'] = 'zipcode:work';
$map['País o región del trabajo'] = 'region:work';
$map['Calle del trabajo'] = 'street:work';
$map['Car Phone'] = 'phone:car';
$map['Categorías'] = 'groups';
$map['Organización'] = 'organization';
$map['Department'] = 'department';
$map['E-mail Address'] = 'email:other';
$map['Dirección de correo electrónico 2'] = 'email:other';
$map['Dirección del correo electrónico 3'] = 'email:other';
$map['Nombre'] = 'firstname';
$map['Género'] = 'gender';
$map['Home City'] = 'locality:home';
$map['País o región del domicilio'] = 'country:home';
$map['Home Fax'] = 'phone:homefax';
$map['Particular'] = 'phone:home';
$map['Home Phone 2'] = 'phone:home2';
$map['Home Postal Code'] = 'zipcode:home';
$map['Home State'] = 'region:home';
$map['Home Street'] = 'street:home';
$map['Puesto'] = 'jobtitle';
$map['Apellidos'] = 'surname';
$map['Nombre del director'] = 'manager';
$map['Segundo nombre'] = 'middlename';
$map['Mobile Phone'] = 'phone:mobile';
$map['Notes'] = 'notes';
$map['Otra ciudad'] = 'locality:other';
$map['Otra provincia o estado'] = 'country:other';
$map['Otro fax'] = 'phone:other';
$map['Otro teléfono'] = 'phone:other';
$map['Otro código postal'] = 'zipcode:other';
$map['Otro país o región'] = 'region:other';
$map['Otra calle'] = 'street:other';
$map['Pager'] = 'phone:pager';
$map['Teléfono principal'] = 'phone:main';
$map['Spouse'] = 'spouse';
$map['Suffix'] = 'suffix';
$map['Title'] = 'prefix';
$map['Página web'] = 'website:homepage';
$map['Día de nacimiento'] = 'birthday-d';
$map['Mes de nacimiento'] = 'birthday-m';
$map['Año de nacimiento'] = 'birthday-y';
$map['Nombre en pantalla'] = 'name';
$map['Fax'] = 'phone:homefax';
$map['Dirección personal'] = 'street:home';
$map['País de residencia'] = 'country:home';
$map['Código postal'] = 'zipcode:home';
$map['Teléfono móvil'] = 'phone:mobile';
$map['Apodo'] = 'nickname';
$map['Organización'] = 'organization';
$map['Buscapersonas'] = 'phone:pager';
$map['Dirección de correo electrónico principal'] = 'email:home';
$map['Dirección de correo electrónico secundaria'] = 'email:other';
$map['Página web 1'] = 'website:homepage';
$map['Página web 2'] = 'website:other';
$map['Teléfono (Trabajo)'] = 'phone:work';
$map['Dirección de trabajo'] = 'street:work';
$map['País (Trabajo)'] = 'country:work';
$map['Código postal (Trabajo)'] = 'zipcode:work';
$map['Date of Birth'] = 'birthday';
$map['Email'] = 'email:home';
$map['Home Mobile'] = 'phone:mobile';
$map['Home Zip'] = 'zipcode:home';
$map['Info'] = 'notes';
$map['User Photo'] = 'photo';
$map['URL'] = 'website:homepage';
$map['Work City'] = 'locality:work';
$map['Work Company'] = 'organization';
$map['Work Dept'] = 'department';
$map['Work Fax'] = 'phone:workfax';
$map['Work Mobile'] = 'phone:other';
$map['Work State'] = 'region:work';
$map['Work Title'] = 'jobtitle';
$map['Work Zip'] = 'zipcode:work';
