<?php

/*
 +-----------------------------------------------------------------------+
 | localization/it_IT/csv2vcard.inc                                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2014, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['Anniversario'] = 'anniversary';
$map['Nome dell\'assistente'] = 'assistant';
$map['Telefono dell\'assistente'] = 'phone:assistant';
$map['Compleanno'] = 'birthday';
$map['Città di lavoro'] = 'locality:work';
$map['Nazione/Regione di lavoro'] = 'country:work';
$map['Fax di Lavoro'] = 'phone:workfax';
$map['Telefono di Lavoro'] = 'phone:work';
$map['Telefono di Lavoro 2'] = 'phone:work2';
$map['CAP di Lavoro'] = 'zipcode:work';
$map['Provincia di lavoro'] = 'region:work';
$map['Indirizzo di lavoro'] = 'street:work';
$map['Telefono dell\'Auto'] = 'phone:car';
$map['Categorie'] = 'groups';
$map['Società'] = 'organization';
$map['Reparto'] = 'department';
$map['Indirizzo E-mail'] = 'email:other';
$map['Indirizzo E-mail 2'] = 'email:other';
$map['Indirizzo E-mail 3'] = 'email:other';
$map['Nome'] = 'firstname';
$map['Genere'] = 'gender';
$map['Città di residenza'] = 'locality:home';
$map['Nazione/Regione di casa'] = 'country:home';
$map['Fax di casa'] = 'phone:homefax';
$map['Telefono di casa'] = 'phone:home';
$map['Telefono di casa 2'] = 'phone:home2';
$map['CAP di casa'] = 'zipcode:home';
$map['Provincia di residenza'] = 'region:home';
$map['Indirizzo di casa'] = 'street:home';
$map['Qualifica'] = 'jobtitle';
$map['Cognome'] = 'surname';
$map['Nome del Responsabile'] = 'manager';
$map['Secondo Nome'] = 'middlename';
$map['Telefono Mobile'] = 'phone:mobile';
$map['Note'] = 'notes';
$map['Città Altro'] = 'locality:other';
$map['Nazione/Regione Altro'] = 'country:other';
$map['Fax Altro'] = 'phone:other';
$map['Phone Altro'] = 'phone:other';
$map['CAP Postale Altro'] = 'zipcode:other';
$map['Stato Altro'] = 'region:other';
$map['Via Altro'] = 'street:other';
$map['Numero cercapersone'] = 'phone:pager';
$map['Telefono Principale'] = 'phone:main';
$map['Coniuge'] = 'spouse';
$map['Suffisso'] = 'suffix';
$map['Titolo'] = 'prefix';
$map['Pagina Web'] = 'website:homepage';
$map['Giorno di nascita'] = 'birthday-d';
$map['Mese di nascita'] = 'birthday-m';
$map['Anno di nascita'] = 'birthday-y';
$map['Nome visualizzato'] = 'name';
$map['Numero fax'] = 'phone:homefax';
$map['Indirizzo di casa 2'] = 'street:home';
$map['Nazione di residenza'] = 'country:home';
$map['CAP di residenza'] = 'zipcode:home';
$map['Numero cellulare'] = 'phone:mobile';
$map['Soprannome'] = 'nickname';
$map['Organizzazione'] = 'organization';
$map['Numero Pager'] = 'phone:pager';
$map['Email principale'] = 'email:home';
$map['Email secondaria'] = 'email:other';
$map['Pagina web 1'] = 'website:homepage';
$map['Pagina web 2'] = 'website:other';
$map['Telefono lavoro'] = 'phone:work';
$map['Indirizzo di lavoro 2'] = 'street:work';
$map['Nazione di lavoro'] = 'country:work';
$map['CAP di lavoro'] = 'zipcode:work';
$map['Data di Nascita'] = 'birthday';
$map['Email'] = 'email:home';
$map['Cellulare di Casa'] = 'phone:mobile';
$map['CAP di casa'] = 'zipcode:home';
$map['Info'] = 'notes';
$map['Foto'] = 'photo';
$map['URL'] = 'website:homepage';
$map['Città di Lavoro'] = 'locality:work';
$map['Società di lavoro'] = 'organization';
$map['Reparto di lavoro'] = 'department';
$map['Fax di lavoro'] = 'phone:workfax';
$map['Cellulare di lavoro'] = 'phone:other';
$map['Nazione/Regione di lavoro'] = 'region:work';
$map['Titolo di lavoro'] = 'jobtitle';
$map['CAP di lavoro'] = 'zipcode:work';
