<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['scope'] = 'Viloyat';
$labels['messagedelete'] = 'Savatga';
$labels['add'] = 'Qo`shish';
$labels['del'] = 'O`chirish';
$labels['sender'] = 'Jo`natuvchi';
$labels['flagread'] = 'O`qilgan';
$labels['flagdeleted'] = 'O`chirilgan';
$labels['flagflagged'] = 'Belgilangan';
$labels['notifymethodmailto'] = 'E-Mail';
$labels['notifymethodtel'] = 'Telefon';
$labels['datetest'] = 'Sana';
$labels['advancedopts'] = 'Qo`shimcha xossalar';
$labels['body'] = 'Xat tarkibi';
$labels['vacation.subject'] = 'Mavzu';
$labels['vacation.body'] = 'Xat tarkibi';
