<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2015, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Pekka Nurmi <peknur@gmail.com>                                |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['Näyttönimi'] = 'name';
$map['Etunimi'] = 'firstname';
$map['Sukunimi'] = 'surname';
$map['Kotipuhelin'] = 'phone:home';
$map['Kotikaupunki'] = 'locality:home';
$map['Kodin lääni'] = 'region:home';
$map['Työpaikan kaupunki'] = 'locality:work';
$map['Työpaikan lääni'] = 'region:work';
$map['Ammattinimi'] = 'jobtitle';
$map['Osasto'] = 'department';
$map['Muistiinpanot'] = 'notes';
$map['Syntymäpäivä'] = 'birthday-d';
$map['Syntymäkuukausi'] = 'birthday-m';
$map['Syntymävuosi'] = 'birthday-y';
$map['Näytettävä nimi'] = 'name';
$map['Faksin numero'] = 'phone:homefax';
$map['Lempinimi'] = 'nickname';
$map['Ensisijainen sähköposti'] = 'email:home';
$map['Toissijainen sähköposti'] = 'email:other';
$map['Työpuhelin'] = 'phone:work';
$map['Hakulaitteen numero'] = 'phone:pager';
$map['Matkapuhelinnumero'] = 'phone:mobile';
$map['Kotiosoite'] = 'street:home';
$map['Kodin postinumero'] = 'zipcode:home';
$map['Kotimaa'] = 'country:home';
$map['Työosoite'] = 'street:work';
$map['Työpaikan postinumero'] = 'zipcode:work';
$map['Työpaikan maa'] = 'country:work';
$map['Järjestö'] = 'organization';
$map['Verkkosivu 1'] = 'website:homepage';
$map['Verkkosivu 2'] = 'website:other';
