<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Birta tilkynningu í vafra þegar ný skilaboð berast';
$labels['desktop'] = 'Birta tilkynningu á skjáborði þegar ný skilaboð berast';
$labels['sound'] = 'Spila hljóðið þegar ný skilaboð berast';
$labels['test'] = 'Prófa';
$labels['title'] = 'Nýr tölvupóstur!';
$labels['body'] = 'Þú hefur fengið ný skilaboð.';
$labels['testbody'] = 'Þetta er prufutilkynning.';
$labels['desktopdisabled'] = 'Tilkynningar á skjáborði eru ekki virkar í vafranum þínum.';
$labels['desktopunsupported'] = 'Vafrinn þinn styður ekki tilkynningar á skjáborði.';
$labels['desktoptimeout'] = 'Loka tilkynningu á skjáborði';
