<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Có lỗi xảy ra.';
$messages['loginfailed']  = 'Không đăng nhập được';
$messages['cookiesdisabled'] = 'Trình duyệt không hỗ trợ cookies';
$messages['sessionerror'] = 'Phiên làm việc không hợp lệ hoặc đã hết hạn';
$messages['storageerror'] = 'Không kết nối được với máy chủ.';
$messages['servererror'] = 'Lỗi máy chủ';
$messages['servererrormsg'] = 'Lỗi máy chủ: $msg';
$messages['connerror'] = 'Lỗi kết nối (không kết nối được đến máy chủ)';
$messages['dberror'] = 'Lỗi cơ sở dữ liệu';
$messages['windowopenerror'] = 'Cửa sổ thông tin bật lên bị chặn';
$messages['requesttimedout'] = 'Yêu cầu hết  hạn';
$messages['errorreadonly'] = 'Không thể thực hiện thao tác. Thư mục chỉ cho phép đọc.';
$messages['errornoperm'] = 'Bạn không đủ quyền hạn để thực hiện thao tác này.';
$messages['erroroverquota'] = 'Không thể thực hiện thao tác do không còn đủ chỗ trống trên ổ đĩa.';
$messages['erroroverquotadelete'] = 'Không còn dư chỗ trống trên ổ đĩa. Sử dụng tổ hợp phím SHIFT+DEL để xoá thư.';
$messages['invalidrequest'] = 'Yêu cầu không hợp lệ! Không có dữ liệu nào được lưu.';
$messages['invalidhost'] = 'Sai thông tin tên máy chủ';
$messages['nomessagesfound'] = 'Không thấy có thư nào trong hộp thư này.';
$messages['mailboxempty'] = 'Hộp thư rỗng';
$messages['nomessages'] = 'Không có thư nào';
$messages['refreshing'] = 'Nạp lại dữ liệu...';
$messages['loading'] = 'Đang tải...';
$messages['uploading'] = 'Đang tải tập tin lên...';
$messages['uploadingmany'] = 'Đang tải các tập tin lên...';
$messages['loadingdata'] = 'Đang nạp dữ liệu...';
$messages['checkingmail'] = 'Kiểm tra thư mới...';
$messages['sendingmessage'] = 'Đang gửi thư...';
$messages['messagesent'] = 'Thư đã được gửi thành công.';
$messages['savingmessage'] = 'Đang lưu thư...';
$messages['messagesaved'] = 'Thư đã được lưu lại vào hộp thư Nháp.';
$messages['successfullysaved'] = 'Đã lưu thành công';
$messages['savingresponse'] = 'Đang lưu thông tin...';
$messages['deleteresponseconfirm'] = 'Bạn có thực sự muốn xoá thông tin này?';
$messages['addedsuccessfully'] = 'Liên hệ đã được thêm vào sổ địa chỉ thành công.';
$messages['contactnameexists'] = 'Đã có một liên hệ có tên như thế này.';
$messages['blockedimages'] = 'Để bảo vệ tính riêng tư, chức năng hiện ảnh từ xa bị cấm trong thư này.';
$messages['encryptedmessage'] = 'Thư này được mã hóa, không thể xem. Rất tiếc!';
$messages['nocontactsfound'] = 'Không tìm thấy liên hệ.';
$messages['contactnotfound'] = 'Không tìm thấy liên lạc được yêu cầu';
$messages['sendingfailed'] = 'Không gửi được thư';
$messages['senttooquickly'] = 'Xin đợi vài giây trước khi gửi thư này';
$messages['errorsavingsent'] = 'Có lỗi xảy ra khi lưu lại thư đã gửi.';
$messages['errorsaving'] = 'Lỗi trong quá trình lưu.';
$messages['errormoving'] = 'Không thể chuyển được thư';
$messages['errorcopying'] = 'Không thể sao chép thư';
$messages['errordeleting'] = 'Không thể xóa được thư';
$messages['errormarking'] = 'Không thể đánh dấu (các) thư';
$messages['deletecontactconfirm']  = 'Bạn có thực sự muốn xoá liên hệ đã chọn?';
$messages['deletegroupconfirm']  = 'Bạn có thực sự muốn xóa nhóm đã chọn?';
$messages['deletemessagesconfirm'] = 'Bạn thực sự có muốn xóa (các) thư đã chọn?';
$messages['deletefolderconfirm']  = 'Bạn có thực sự muốn xóa giữ liệu này?';
$messages['purgefolderconfirm']  = 'Bạn có thực sự muốn xóa toàn bộ thư trong giữ liệu này?';
$messages['contactdeleting'] = 'Đang xóa (các) liên lạc...';
$messages['groupdeleting'] = 'Đang xóa nhóm...';
$messages['folderdeleting'] = 'Đang xóa thư mục dữ liệu...';
$messages['foldermoving'] = 'Đang chuyển thư mục dữ liệu..';
$messages['foldersubscribing'] = 'Đăng ký vào thư mục...';
$messages['folderunsubscribing'] = 'Bỏ đăng ký thư mục...';
$messages['formincomplete'] = 'Mẫu đơn chưa được hoàn toàn điền xong.';
$messages['noemailwarning'] = 'Xin nhập địa chỉ email hợp lệ.';
$messages['nonamewarning']  = 'Xin nhập tên.';
$messages['nopagesizewarning'] = 'Xin nhập kích cỡ của trang.';
$messages['nosenderwarning'] = 'Vui lòng nhập địa chỉ email của người gửi';
$messages['recipientsadded'] = 'Thông tin người nhận đã được thêm thành công';
$messages['norecipientwarning'] = 'Vui lòng nhập ít nhất 1 người nhận.';
$messages['disclosedrecipwarning'] = 'Tất cả người nhận sẽ nhìn được địa chỉ email của người khác. Để tránh việc này, bạn có thể dùng trường địa chỉ Bcc.';
$messages['disclosedreciptitle'] = 'Có quá nhiều người nhận';
$messages['nosubjectwarning']  = 'Mục "Tiêu đề" vẫn còn trống. Bạn có muốn nhập tiêu đề bây giờ không?';
$messages['nosubjecttitle']  = 'Không có tiêu đề';
$messages['nobodywarning'] = 'Gửi thư không có nội dung?';
$messages['restoresavedcomposedata'] = 'Tìm thấy một thư đã được soạn trước nhưng chưa gửi.\n\nTiêu đề: $subject\nLưu ngày: $date\n\nBạn có muốn khôi phục lại thư này?';
$messages['nosearchname'] = 'Nhập liên hệ hoặc địa chỉ email.';
$messages['notuploadedwarning'] = 'Tất cả các đính kèm vẫn chưa được tải lên hết. Xin đợi hoặc hủy việc tải lên.';
$messages['searchsuccessful'] = '$nr thư đã tìm được.';
$messages['contactsearchsuccessful'] = '$nr liên hệ đã tìm được.';
$messages['searchnomatch'] = 'Không tìm thấy sự trùng hợp nào.';
$messages['searching'] = 'Đang tìm kiếm...';
$messages['checking'] = 'Đang kiểm tra...';
$messages['stillsearching'] = 'Đang tiếp tục tìm kiếm...';
$messages['nospellerrors'] = 'Không tìm thấy lỗi chính tả.';
$messages['folderdeleted'] = 'Giữ liệu đã được xóa thành công.';
$messages['foldersubscribed'] = 'Giữ liệu được nhập vào thành công.';
$messages['folderunsubscribed'] = 'Giữ liệu không nhập vào thành công.';
$messages['deletedsuccessfully'] = 'Đã xóa thành công';
$messages['converting'] = 'Loại bỏ định dạng...';
$messages['messageopenerror'] = 'Không thể tải thư từ máy chủ';
$messages['filelinkerror'] = 'Đính kèm file bị lỗi.';
$messages['fileuploaderror'] = 'Tải tập tin lên thất bại';
$messages['filesizeerror'] = 'Tập tin được tải lên vượt quá dung lượng tối đa....';
$messages['copysuccess'] = 'Sao chép thành công $nr địa chỉ.';
$messages['movesuccess'] = 'Đã chuyển thành công $nr địa chỉ liên hệ.';
$messages['copyerror'] = 'Không thể sao chép địa chỉ liên hệ nào.';
$messages['moveerror'] = 'Không thể chuyển địa chỉ liên hệ nào.';
$messages['sourceisreadonly'] = 'Nguồn địa chỉ này chỉ cho đọc';
$messages['errorsavingcontact'] = 'Không thể lưu địa chỉ liên lạc';
$messages['movingmessage'] = 'Đang chuyển thư...';
$messages['copyingmessage'] = 'Đang sao chép thư...';
$messages['copyingcontact'] = 'Đang sao chép liên lạc...';
$messages['movingcontact'] = 'Đang chuyển (các) địa chỉ liên hệ...';
$messages['deletingmessage'] = 'Đang xóa thư...';
$messages['markingmessage'] = 'Đánh dấu thư...';
$messages['addingmember'] = 'Đang thêm liên lạc vào nhóm...';
$messages['removingmember'] = 'Đang xóa liên lạc từ nhóm...';
$messages['receiptsent'] = 'Biên nhận đọc đã được gửi thành công.';
$messages['errorsendingreceipt'] = 'Không thể gửi ghi nhận';
$messages['deleteidentityconfirm'] = 'Bạn có thực sự muốn xóa nhận diện này?';
$messages['nodeletelastidentity'] = 'Bạn không thể xóa nhận diện này, đó là cái cuối cùng của bạn.';
$messages['forbiddencharacter'] = 'Tên giữ liệu chứa một ký tự bị cấm.';
$messages['selectimportfile'] = 'Xin chọn hồ sơ để tải lên.';
$messages['addresswriterror'] = 'Sổ địa chỉ đã chọn không thể viết lại được';
$messages['contactaddedtogroup'] = 'Thêm liên lạc vào nhóm này thành công';
$messages['contactremovedfromgroup'] = 'Xóa liên lạc khỏi nhóm này thành công';
$messages['nogroupassignmentschanged'] = 'Không quy nhóm nào đả được thay đổi';
$messages['importwait'] = 'Đang nhập, xin chờ...';
$messages['importformaterror'] = 'Nhập dữ liệu lỗi. Tệp tin vừa tải lên không phải tệp dữ liệu chính xác.';
$messages['importconfirm'] = 'Đã nhập $inserted liên hệ đã chèn vào thành công.';
$messages['importmessagesuccess'] = 'Đã nhập thành công $nr thư.';
$messages['importmessageerror'] = 'Nhập dữ liệu bị lỗi. Tệp tin vừa tải lên không có định dạng chính xác của tệp cấu hình hòm thư hoặc một thư đơn lẻ.';
$messages['opnotpermitted'] = 'Thao tác không được cho phép!';
$messages['editorwarning'] = 'Việc chuyển công cụ soạn thảo có thể làm mất định dạng dữ liệu. Bạn có muốn tiếp tục không?';
$messages['httpreceivedencrypterror'] = 'Xuất hiện một lỗi cấu hình  tai hại. Hãy liên hệ với người quản trị ngay. <b> Thư của bạn không thể gửi được </b>';
$messages['smtpconnerror'] = 'Lỗi SMTP ($code): Kết nỗi tới máy chủ bị lỗi.';
$messages['smtpautherror'] = 'Lỗi SMTP ($code): Xác thực thất bại.';
$messages['smtpfromerror'] = 'Lỗi SMTP ($code):  Không thể bố trí người gửi "$from" ($msg).';
$messages['smtptoerror'] = 'Lỗi SMTP ($code):  Không thể bố trí người nhận "$to" ($msg).';
$messages['smtprecipientserror'] = 'Lỗi SMTP: không thể phân loại danh sách người nhận';
$messages['smtperror'] = 'Lỗi SMTP: $msg';
$messages['toomanyrecipients'] = 'Quá nhiều người nhận. Hãy giảm số lượng người nhận xuống tối đa là $max.';
$messages['maxgroupmembersreached'] = 'Số lượng thành viên trong nhóm vượt quá mức tối đa là $max.';
$messages['internalerror'] = 'Xuất hiện một lỗi nội bộ. Xin hãy thử lại';
$messages['contactdelerror'] = 'Không thể xóa liên lạc';
$messages['contactdeleted'] = 'Liên lạc được xóa thành công';
$messages['contactrestoreerror'] = 'Không thể khôi phục liên lạc đã xóa';
$messages['contactrestored'] = 'Liên lạc được khôi phục thành công';
$messages['groupdeleted'] = 'Nhóm được xóa thành công';
$messages['grouprenamed'] = 'Nhóm được đặt tên lại thành công';
$messages['groupcreated'] = 'Nhóm được tạo thành công';
$messages['savedsearchdeleted'] = 'Tìm kiếm đã lưu được xóa thành công';
$messages['savedsearchdeleteerror'] = 'Không thể xóa tìm kiếm đã lưu';
$messages['savedsearchcreated'] = 'Tìm kiếm đã lưu được tạo thành công';
$messages['savedsearchcreateerror'] = 'Không thể tạo tìm kiếm đã lưu';
$messages['messagedeleted'] = 'Thư được xóa thành công';
$messages['messagemoved'] = 'Thư được chuyển đi thành công';
$messages['messagecopied'] = 'Thư được sao chép thành công';
$messages['messagemarked'] = 'Thư được đánh dấu thành công';
$messages['autocompletechars'] = 'Phải nhập ít nhất $min ký tự để năng tự động gõ';
$messages['autocompletemore'] = 'Nhiều dữ liệu phù hợp hơn được tìm thấy. Hãy gõ thêm  ký tự.';
$messages['namecannotbeempty'] = 'Tên không được để trống';
$messages['nametoolong'] = 'Tên quá dài';
$messages['folderupdated'] = 'Giữ liệu được cập nhật thành công';
$messages['foldercreated'] = 'Giữ liệu được tạo thành công';
$messages['invalidimageformat'] = 'Không phải là định dạng ảnh hợp lệ.';
$messages['mispellingsfound'] = 'Lỗi chính tả được phát hiện trong thư';
$messages['parentnotwritable'] = 'Không thể tạo/chuyển folder vào folder gốc đã chọn. Không có quyền truy cập.';
$messages['messagetoobig'] = 'Một phần thư quá lớn để xử lý nó.';
$messages['noscriptwarning'] = 'Cảnh báo: Dịch vụ webmail này yêu cầu sử dụng Javascript. Để sử dụng, bạn cần kích hoạt hỗ trợ Javascript trong cấu hình trình duyệt Internet đang sử dụng.';
