<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'フィルター';
$labels['managefilters'] = '受信メールのフィルターを管理';
$labels['filtername'] = 'フィルター名';
$labels['newfilter'] = '新しいフィルター';
$labels['filteradd'] = 'フィルターを追加';
$labels['filterdel'] = 'フィルターを削除';
$labels['rules'] = '規則';
$labels['actions'] = '操作';
$labels['scope'] = 'スコープ';
$labels['moveup'] = '上に移動';
$labels['movedown'] = '下に移動';
$labels['filterallof'] = '次の規則のすべてに一致';
$labels['filteranyof'] = '次の規則のいずれかに一致';
$labels['filterany'] = 'すべてのメッセージ';
$labels['filtercontains'] = '含む';
$labels['filternotcontains'] = '含まない';
$labels['filteris'] = '次に等しい';
$labels['filterisnot'] = '次に等しくない';
$labels['filterexists'] = 'が存在';
$labels['filternotexists'] = 'が存在しない';
$labels['filtermatches'] = '次の式に一致';
$labels['filternotmatches'] = '次の式に一致しない';
$labels['filterregex'] = '次の正規表現に一致';
$labels['filternotregex'] = '次の正規表現に一致しない';
$labels['filterunder'] = 'より下';
$labels['filterover'] = 'より上';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIMEのパート:';
$labels['mime-message'] = 'メッセージ';
$labels['mime-anychild'] = '任意';
$labels['mime-type'] = 'タイプ';
$labels['mime-subtype'] = 'サブタイプ';
$labels['mime-contenttype'] = 'コンテントタイプ';
$labels['mime-param'] = 'パラメーター';
$labels['addrule'] = '規則を追加';
$labels['delrule'] = '規則を削除';
$labels['messagemoveto'] = '次にメッセージを移動';
$labels['messageredirect'] = '次のメールアドレスに転送';
$labels['messagecopyto'] = '次にメッセージをコピー';
$labels['messagesendcopy'] = '次にメッセージのコピーを送信';
$labels['messagereply'] = 'メッセージを返信';
$labels['messagedelete'] = 'メッセージを削除';
$labels['messagediscard'] = 'メッセージを破棄';
$labels['messagekeep'] = 'メッセージを受信箱に保持';
$labels['messagesrules'] = '受信したメールの処理:';
$labels['messagesactions'] = '以下の操作を実行:';
$labels['add'] = '追加';
$labels['del'] = '削除';
$labels['sender'] = '送信者';
$labels['recipient'] = '宛先';
$labels['vacationaddr'] = '私の電子メールアドレス:';
$labels['vacationdays'] = 'メッセージを(1日に)送信する頻度:';
$labels['vacationinterval'] = 'メッセージを送信する頻度:';
$labels['vacationreason'] = 'メッセージ本体(休暇の理由):';
$labels['vacationfrom'] = '返信する送信者のアドレス:';
$labels['vacationsubject'] = 'メッセージの件名:';
$labels['days'] = '日';
$labels['seconds'] = '秒';
$labels['rulestop'] = '規則の評価を停止';
$labels['enable'] = '有効/無効';
$labels['filterset'] = 'フィルターセット';
$labels['filtersets'] = 'フィルターセット';
$labels['filtersetadd'] = 'フィルターセットを追加';
$labels['filtersetdel'] = 'フィルターセットを削除';
$labels['filtersetact'] = '現在のフィルターセットを有効化';
$labels['filtersetdeact'] = '現在のフィルターセットを無効化';
$labels['filterseteditraw'] = 'フィルターセットを編集';
$labels['filtersetswitch'] = 'フィルターセットを有効・無効';
$labels['filterdef'] = 'フィルターの定義';
$labels['filtersetname'] = 'フィルターセットの名前';
$labels['newfilterset'] = '新しいフィルターセット';
$labels['active'] = '有効';
$labels['none'] = 'なし';
$labels['fromset'] = 'セットから';
$labels['fromfile'] = 'ファイルから';
$labels['filterdisabled'] = 'フィルターは無効';
$labels['filterenabled'] = 'フィルターは有効';
$labels['countisgreaterthan'] = 'より大きい回数';
$labels['countisgreaterthanequal'] = '以上の回数';
$labels['countislessthan'] = '未満の回数';
$labels['countislessthanequal'] = '以下の回数';
$labels['countequals'] = '次と等しい回数';
$labels['countnotequals'] = '次と等しくない回数';
$labels['valueisgreaterthan'] = 'より大きい値';
$labels['valueisgreaterthanequal'] = '以上の値';
$labels['valueislessthan'] = '未満の値';
$labels['valueislessthanequal'] = '以下の値';
$labels['valueequals'] = '次と等しい値';
$labels['valuenotequals'] = '次と等しくない値';
$labels['setflags'] = 'メッセージにフラグを設定';
$labels['addflags'] = 'メッセージにフラグを追加';
$labels['removeflags'] = 'メッセージからフラグを削除';
$labels['flagread'] = '既読';
$labels['flagdeleted'] = '削除済み';
$labels['flaganswered'] = '返信済み';
$labels['flagflagged'] = 'フラグ付き';
$labels['flagdraft'] = '下書き';
$labels['addheader'] = 'メッセージにヘッダーを追加';
$labels['deleteheader'] = 'メッセージからヘッダーを削除';
$labels['headername'] = 'ヘッダーの名前';
$labels['headervalue'] = 'ヘッダーの値';
$labels['headerpos'] = 'ヘッダーの位置';
$labels['headeratstart'] = '最初';
$labels['headeratend'] = '最後';
$labels['headeroccurrence'] = 'ヘッダーの存在・位置';
$labels['headerfromstart'] = '開始';
$labels['headerfromend'] = '終了';
$labels['headerpatterns'] = 'ヘッダーの値のパターン';
$labels['headermatchtype'] = '一致タイプ:';
$labels['setvariable'] = '変数を設定';
$labels['setvarname'] = '変数の名前:';
$labels['setvarvalue'] = '変数の値:';
$labels['setvarmodifiers'] = '修飾子:';
$labels['varlower'] = '小文字';
$labels['varupper'] = '大文字';
$labels['varlowerfirst'] = '最初の文字を小文字';
$labels['varupperfirst'] = '最初の文字を大文字';
$labels['varquotewildcard'] = '特殊文字を引用処理';
$labels['varlength'] = '長さ';
$labels['varencodeurl'] = '(URLを)パーセント・エンコード';
$labels['notify'] = '通知を送信';
$labels['notifytarget'] = '通知の対象:';
$labels['notifymessage'] = '通知のメッセージ(任意):';
$labels['notifyoptions'] = '通知のオプション(任意):';
$labels['notifyfrom'] = '通知の送信者(任意):';
$labels['notifyimportance'] = '重要度:';
$labels['notifyimportancelow'] = '低';
$labels['notifyimportancenormal'] = '通常';
$labels['notifyimportancehigh'] = '高';
$labels['notifymethodmailto'] = '電子メール';
$labels['notifymethodtel'] = '電話';
$labels['notifymethodsms'] = 'ショートメッセージ';
$labels['filtercreate'] = 'フィルターを作成';
$labels['usedata'] = 'フィルターで次のデータを使用';
$labels['nextstep'] = '次の段階';
$labels['...'] = '...';
$labels['string'] = '文字列';
$labels['currdate'] = '現在の日付';
$labels['datetest'] = '日付';
$labels['dateheader'] = 'ヘッダー:';
$labels['year'] = '年';
$labels['month'] = '月';
$labels['day'] = '日';
$labels['date'] = '日付(年-月-日)';
$labels['julian'] = '日付(ユリウス歴)';
$labels['hour'] = '時';
$labels['minute'] = '分';
$labels['second'] = '秒';
$labels['time'] = '時刻 (時:分:秒)';
$labels['iso8601'] = '日付(ISO8601)';
$labels['std11'] = '日付(RFC2822)';
$labels['zone'] = 'タイムゾーン';
$labels['weekday'] = '平日(0-6)';
$labels['advancedopts'] = '高度なオプション';
$labels['body'] = '本文';
$labels['address'] = 'メールアドレス';
$labels['envelope'] = 'エンベロープ';
$labels['modifier'] = '修正:';
$labels['text'] = 'テキスト';
$labels['undecoded'] = '未デコード(そのまま)';
$labels['contenttype'] = 'コンテント・タイプ';
$labels['modtype'] = '種類:';
$labels['allparts'] = 'すべて';
$labels['domain'] = 'ドメイン';
$labels['localpart'] = 'ローカルパート';
$labels['user'] = 'ユーザー';
$labels['detail'] = '詳細';
$labels['comparator'] = '比較器:';
$labels['default'] = '初期値';
$labels['octet'] = '厳密(オクテット)';
$labels['asciicasemap'] = '大文字小文字を区別しない(ascii-casemap)';
$labels['asciinumeric'] = '数値(ascii-numeric)';
$labels['index'] = 'インデックス:';
$labels['indexlast'] = '後方';
$labels['spamtest'] = 'SPAMのレベル';
$labels['spamtestisgreaterthan'] = 'より大きい';
$labels['spamtestisgreaterthanequal'] = '以上';
$labels['spamtestislessthan'] = 'より小さい';
$labels['spamtestislessthanequal'] = '以下';
$labels['spamtestequals'] = '次に等しい';
$labels['spamtestnotequals'] = '次に等しくない';
$labels['spamtestisunknown'] = '不明';
$labels['vacation'] = '事務所に不在';
$labels['vacation.reply'] = '返信のメッセージ';
$labels['vacation.advanced'] = '詳細な設定';
$labels['vacation.from'] = '送信者のアドレスに返信';
$labels['vacation.subject'] = '件名';
$labels['vacation.body'] = '本文';
$labels['vacation.start'] = '開始時刻';
$labels['vacation.end'] = '終了時刻';
$labels['vacation.status'] = '状態';
$labels['vacation.on'] = 'オン';
$labels['vacation.off'] = 'オフ';
$labels['vacation.addresses'] = '私の電子メールアドレス';
$labels['vacation.interval'] = '返信の間隔';
$labels['vacation.after'] = '事務所不在のルールを後に配置';
$labels['vacation.saving'] = 'データを保存中...';
$labels['vacation.action'] = '届いたメッセージの操作';
$labels['vacation.keep'] = '保持';
$labels['vacation.discard'] = '破棄';
$labels['vacation.redirect'] = '次のメールアドレスに転送';
$labels['vacation.copy'] = '次にメッセージを送信';
$labels['forward'] = '転送';
$labels['forward.redirect'] = '次のメールアドレスに転送';
$labels['forward.copy'] = '次にメッセージを送信';
$labels['forward.on'] = 'オン';
$labels['forward.off'] = 'オフ';
$labels['forward.status'] = '状態:';
$labels['forward.action'] = '到着したメールに以下の操作を実行:';
$labels['forward.saving'] = 'データを保存中...';
$labels['filladdresses'] = 'すべてのアドレスで満たす';
$labels['arialabelfiltersetactions'] = 'フィルターセットの動作';
$labels['arialabelfilteractions'] = 'フィルターの動作';
$labels['arialabelfilterform'] = 'フィルターの特性';
$labels['ariasummaryfilterslist'] = 'フィルターの一覧';
$labels['ariasummaryfiltersetslist'] = 'フィルターセットの一覧';
$labels['filterstitle'] = '届いたメールのフィルターを編集';
$labels['vacationtitle'] = '勤務時間外の規則を編集';
$labels['forwardtitle'] = 'メールの転送の規則を編集';
$labels['message'] = 'メッセージ';
$labels['duplicate'] = 'は重複';
$labels['notduplicate'] = 'は非重複';
$labels['duplicate.handle'] = 'ハンドル:';
$labels['duplicate.header'] = 'ヘッダー:';
$labels['duplicate.uniqueid'] = '識別子:';
$labels['duplicate.seconds'] = '時間切れ(秒):';
$labels['duplicate.last'] = '最後の実行から相対的';
$messages['filterunknownerror'] = '不明なサーバーのエラーです。';
$messages['filterconnerror'] = 'サーバに接続できません。';
$messages['filterdeleteerror'] = 'フィルターを削除できません。サーバーでエラーが発生しました。';
$messages['filterdeleted'] = 'フィルターを削除しました。';
$messages['filtersaved'] = 'フィルターを保存しました。';
$messages['filtersaveerror'] = 'フィルターの保存できません。サーバーでエラーが発生しました。';
$messages['filterformerror'] = 'フィルターのフォームにエラーがあります。';
$messages['filterdeleteconfirm'] = '本当に選択したフィルターを削除しますか?';
$messages['ruledeleteconfirm'] = '本当に選択した規則を削除しますか?';
$messages['actiondeleteconfirm'] = '本当に選択した動作を削除しますか?';
$messages['forbiddenchars'] = '項目に禁止している文字が含まれています。';
$messages['cannotbeempty'] = '項目は空欄にできません。';
$messages['ruleexist'] = '指定した名前のフィルターが既に存在します。';
$messages['setactivateerror'] = '選択したフィルターセットを有効にできませんでした。サーバーでエラーが発生しました。';
$messages['setdeactivateerror'] = '選択したフィルターセットを無効にできませんでした。サーバーでエラーが発生しました。';
$messages['setdeleteerror'] = '選択したフィルターセットを削除できませんでした。サーバーでエラーが発生しました。';
$messages['setactivated'] = 'フィルターセットを有効にしました。';
$messages['setdeactivated'] = 'フィルターセットを無効にしました。';
$messages['setdeleted'] = 'フィルターセットを削除しました。';
$messages['setupdated'] = 'フィルターセットを更新しました。';
$messages['setdeleteconfirm'] = '本当に削除したフィルターセットを削除しますか?';
$messages['setcreateerror'] = 'フィルターセットを作成できませんでした。サーバーでエラーが発生しました。';
$messages['setcreated'] = 'フィルターセットを作成しました。';
$messages['activateerror'] = '選択したフィルターを有効にできません。サーバーでエラーが発生しました。';
$messages['deactivateerror'] = '選択したフィルターを無効にできません。サーバーでエラーが発生しました。';
$messages['deactivated'] = 'フィルターを無効にしました。';
$messages['activated'] = 'フィルターを有効にしました。';
$messages['moved'] = 'フィルターを移動しました。';
$messages['moveerror'] = '選択したフィルターを移動できません。サーバーでエラーが発生しました。';
$messages['nametoolong'] = '名前が長すぎます。';
$messages['namereserved'] = '予約されている名前です。';
$messages['setexist'] = 'フィルターセットが既に存在します。';
$messages['nodata'] = '少なくとも場所を1つ選択しなければなりません!';
$messages['invaliddateformat'] = '無効な日付または日付部分の書式';
$messages['saveerror'] = 'フィルターの保存できません。サーバーでエラーが発生しました。';
$messages['vacationsaved'] = '事務所不在のデータを保存しました。';
$messages['forwardsaved'] = '転送のデータを保存しました。';
$messages['emptyvacationbody'] = '休暇のメッセージの本文が必要です!';
$messages['duplicate.conflict.err'] = 'ヘッダーと一意な識別子の両方は同時に使用できません。';
$messages['disabledaction'] = '許可されていない動作です。';
$messages['lastindexempty'] = '最後から数える時はインデックスが必要';
$messages['noflagset'] = '少なくともフラッグを1つ選択しなければなりません。';
$messages['saving.actionordererror'] = '\'$previous\'の処理は\'$current\'の処理の後でなければなりません。';
