<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'اشتراک‌گذاری';
$labels['myrights'] = 'حقوق دسترسی';
$labels['username'] = 'کاربر:';
$labels['advanced'] = 'حالت پیشرفته';
$labels['add'] = 'افزودن';
$labels['newuser'] = 'افزودن ورودی';
$labels['editperms'] = 'ویرایش مجوزها';
$labels['actions'] = 'فعالیت‌های حق دسترسی...';
$labels['anyone'] = 'همه‌ی کاربران (هر کسی)';
$labels['anonymous'] = 'مهمان‌ها (ناشناس)';
$labels['identifier'] = 'شناساگر';
$labels['acll'] = 'یافتن';
$labels['aclr'] = 'پیام‌های خوانده شده';
$labels['acls'] = 'نگه داشتن حالت بازدید';
$labels['aclw'] = 'پرچم‌های نوشتن';
$labels['acli'] = 'وارد کردن (رونوشت در)';
$labels['aclp'] = 'نوشته';
$labels['aclc'] = 'ایجاد زیرپوشه‌ها';
$labels['aclk'] = 'ایجاد زیرپوشه‌ها';
$labels['acld'] = 'حذف پیام‌ها';
$labels['aclt'] = 'حذف پیام‌ها';
$labels['acle'] = 'پاک کردن';
$labels['aclx'] = 'حذف پوشه';
$labels['acla'] = 'اداره کردن';
$labels['acln'] = 'حاشیه نویسی پیام ها';
$labels['aclfull'] = 'کنترل کامل';
$labels['aclother'] = 'دیگر';
$labels['aclread'] = 'خواندن';
$labels['aclwrite'] = 'نوشتن';
$labels['acldelete'] = 'حذف کردن';
$labels['shortacll'] = 'یافتن';
$labels['shortaclr'] = 'خواندن';
$labels['shortacls'] = 'نگه داشتن';
$labels['shortaclw'] = 'نوشتن';
$labels['shortacli'] = 'جاگذارى';
$labels['shortaclp'] = 'پست کردن';
$labels['shortaclc'] = 'ایجاد';
$labels['shortaclk'] = 'ایجاد';
$labels['shortacld'] = 'حذف';
$labels['shortaclt'] = 'حذف';
$labels['shortacle'] = 'پاک کردن';
$labels['shortaclx'] = 'حذف پوشه';
$labels['shortacla'] = 'اداره کردن';
$labels['shortacln'] = 'حاشیه نویسی';
$labels['shortaclother'] = 'دیگر';
$labels['shortaclread'] = 'خواندن';
$labels['shortaclwrite'] = 'نوشتن';
$labels['shortacldelete'] = 'حذف کردن';
$labels['longacll'] = 'پوشه در فهرست‌ها قابل مشاهده است و می‌تواند مشترک آن شد';
$labels['longaclr'] = 'پوشه می‌تواند برای خواندن باز شود';
$labels['longacls'] = 'پرچم بازدید پیام‌ها می‌تواند تغییر داده شود';
$labels['longaclw'] = 'پرچم و کلیدواژه پیام‌ها می‌تواند تغییر داده شود، به غیر از بازدید و حذف';
$labels['longacli'] = 'پیام‌ها می‌توانند کپی یا نوشته شوند به پوشه';
$labels['longaclp'] = 'پیام‌ها می‌توانند پست شوند به این پوشه';
$labels['longaclc'] = 'پوشه‌ها می‌توانند ایجاد شوند (تغییر نام داد شوند) به طور مستقیم در این پوشه';
$labels['longaclk'] = 'پوشه‌ها می‌توانند ایجاد شوند (تغییر نام داد شوند) به طور مستقیم در این پوشه';
$labels['longacld'] = 'پرچم حذف پیام‌ها می‌تواند تغییر داده شود';
$labels['longaclt'] = 'پرچم حذف پیام‌ها می‌تواند تغییر داده شود';
$labels['longacle'] = 'پیام‌ها می‌توانند حذف شوند';
$labels['longaclx'] = 'پوشه می‌تواند حذف یا تغییر نام داده شود';
$labels['longacla'] = 'حقوق دسترسی پوشه می‌تواند تغییر داده شود';
$labels['longacln'] = 'اطلاعات متا اشتراک گذاشته شده پیام‌ها (حاشیه‌ها) می‌تواند تغییر داده شوند';
$labels['longaclfull'] = 'کنترل کامل شما مدیریت پوشه';
$labels['longaclread'] = 'پوشه می‌تواند برای خواندن باز شود';
$labels['longaclwrite'] = 'پیام‌ها می‌توانند علامتگذاری، نوشته و یا کپی شوند در پوشه';
$labels['longacldelete'] = 'پیام‌ها می‌توانند حذف شوند';
$labels['longaclother'] = 'قوانین دسترسی دیگر';
$labels['ariasummaryacltable'] = 'فهرست قوانین دسترسی';
$labels['arialabelaclactions'] = 'فهرست کنش‌ها';
$labels['arialabelaclform'] = 'فرم قوانین دسترسی';
$messages['deleting'] = 'حذف کردن حقوق دسترسی...';
$messages['saving'] = 'ذخیره حقوق دسترسی...';
$messages['updatesuccess'] = 'حقوق دسترسی با کام‌یابی تغییر کردند';
$messages['deletesuccess'] = 'حقوق دسترسی با کام‌یابی حذف شدند';
$messages['createsuccess'] = 'حقوق دسترسی با کام‌یابی اضافه شدند';
$messages['updateerror'] = 'ناتوانی در روزآمد کردن حقوق دسترسی';
$messages['deleteerror'] = 'ناتوانی در حذف حقوق دسترسی';
$messages['createerror'] = 'ناتوانی در اضافه کردن حقوق دسترسی';
$messages['deleteconfirm'] = 'آیا شما مطمئن هستید که می‌خواهید حقوق دسترسی را برای کاربر(ان) انتخاب شده حذف نمایید؟';
$messages['norights'] = 'هیچ حقی مشخص نشده است!';
$messages['nouser'] = 'هیج نام‌کاربری‌ای مشخص نشده است!';
