<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtri';
$labels['managefilters'] = 'Uredi filtre za dohodno pošto';
$labels['filtername'] = 'Ime filtra';
$labels['newfilter'] = 'Nov filter';
$labels['filteradd'] = 'Dodaj filter';
$labels['filterdel'] = 'Izbriši filter';
$labels['rules'] = 'Pravila';
$labels['actions'] = 'Možnosti';
$labels['scope'] = 'Obseg';
$labels['moveup'] = 'Pomakni se navzgor';
$labels['movedown'] = 'Pomakni se navzdol';
$labels['filterallof'] = 'izpolnjeni morajo biti vsi pogoji';
$labels['filteranyof'] = 'izpolnjen mora biti vsaj eden od navedenih pogojev';
$labels['filterany'] = 'pogoj velja za vsa sporočila';
$labels['filtercontains'] = 'vsebuje';
$labels['filternotcontains'] = 'ne vsebuje';
$labels['filteris'] = 'je enak/a';
$labels['filterisnot'] = 'ni enak/a';
$labels['filterexists'] = 'obstaja';
$labels['filternotexists'] = 'ne obstaja';
$labels['filtermatches'] = 'ustreza izrazu';
$labels['filternotmatches'] = 'ne ustreza izrazu';
$labels['filterregex'] = 'ustreza regularnemu izrazu';
$labels['filternotregex'] = 'ne ustreza regularnemu izrazu';
$labels['filterunder'] = 'pod';
$labels['filterover'] = 'nad';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Del MIME:';
$labels['mime-message'] = 'sporočilo';
$labels['mime-anychild'] = 'katerikoli';
$labels['mime-type'] = 'tip';
$labels['mime-subtype'] = 'podtip';
$labels['mime-contenttype'] = 'tip vsebine';
$labels['mime-param'] = 'parameter';
$labels['addrule'] = 'Dodaj pravilo';
$labels['delrule'] = 'Izbriši pravilo';
$labels['messagemoveto'] = 'Premakni sporočilo v';
$labels['messageredirect'] = 'Preusmeri sporočilo v';
$labels['messagecopyto'] = 'Kopiraj sporočila na';
$labels['messagesendcopy'] = 'Pošlji kopijo sporočila na';
$labels['messagereply'] = 'Odgovori s sporočilom';
$labels['messagedelete'] = 'Izbriši sporočilo';
$labels['messagediscard'] = 'Zavrži s sporočilom';
$labels['messagekeep'] = 'Ohrani sporočila v mapi Prejeto';
$labels['messagesrules'] = 'Določi pravila za dohodno pošto:';
$labels['messagesactions'] = '...izvrši naslednja dejanja:';
$labels['add'] = 'Dodaj';
$labels['del'] = 'Izbriši';
$labels['sender'] = 'Pošiljatelj';
$labels['recipient'] = 'Prejemnik';
$labels['vacationaddr'] = 'Moji elektronski naslovi:';
$labels['vacationdays'] = 'Kako pogosto naj bodo sporočila poslana (v dnevih):';
$labels['vacationinterval'] = 'Sporočila pošlji na:';
$labels['vacationreason'] = 'Vsebina sporočila (vzrok za odsotnost):';
$labels['vacationfrom'] = 'Naslov za odgovor:';
$labels['vacationsubject'] = 'Zadeva sporočila';
$labels['days'] = 'dni';
$labels['seconds'] = 'sekund';
$labels['rulestop'] = 'Prekini z izvajanjem pravil';
$labels['enable'] = 'Omogoči/Onemogoči';
$labels['filterset'] = 'Nastavitev filtra';
$labels['filtersets'] = 'Nastavitve filtrov';
$labels['filtersetadd'] = 'Dodaj nabor filtrov';
$labels['filtersetdel'] = 'Izbriši nabor filtrov';
$labels['filtersetact'] = 'Aktiviraj trenutni nabor filtrov';
$labels['filtersetdeact'] = 'Deaktiviraj trenutni nabor filtrov';
$labels['filterseteditraw'] = 'Uredi nabor filtrov';
$labels['filtersetswitch'] = 'Vklopi/izklopi nabor filtrov';
$labels['filterdef'] = 'Opis filtra';
$labels['filtersetname'] = 'Ime nabora filtrov';
$labels['newfilterset'] = 'Nov nabor filtrov';
$labels['active'] = 'aktiven';
$labels['none'] = 'brez';
$labels['fromset'] = 'iz nastavitve';
$labels['fromfile'] = 'iz dokumenta';
$labels['filterdisabled'] = 'Filter onemogočen';
$labels['filterenabled'] = 'Filter omogočen';
$labels['countisgreaterthan'] = 'seštevek je večji od';
$labels['countisgreaterthanequal'] = 'seštevek je večji ali enak';
$labels['countislessthan'] = 'seštevek je manjši od';
$labels['countislessthanequal'] = 'seštevel je manjši ali enak';
$labels['countequals'] = 'seštevek je enak';
$labels['countnotequals'] = 'vsota ne ustreza';
$labels['valueisgreaterthan'] = 'vrednost je večja od';
$labels['valueisgreaterthanequal'] = 'vrednost je večja ali enaka';
$labels['valueislessthan'] = 'vrednost je manjša od';
$labels['valueislessthanequal'] = 'vrednost je manjša ali enaka';
$labels['valueequals'] = 'vrednost je enaka';
$labels['valuenotequals'] = 'vrednost ni enaka';
$labels['setflags'] = 'Označi sporočilo';
$labels['addflags'] = 'Označi sporočilo';
$labels['removeflags'] = 'Odstrani zaznamke s sporočil';
$labels['flagread'] = 'Prebrano';
$labels['flagdeleted'] = 'Izbrisano';
$labels['flaganswered'] = 'Odgovorjeno';
$labels['flagflagged'] = 'Označeno';
$labels['flagdraft'] = 'Osnutek';
$labels['addheader'] = 'Dodaj glavo sporočilu';
$labels['deleteheader'] = 'Odstrani glavo iz sporočila';
$labels['headername'] = 'Ime glave sporočila';
$labels['headervalue'] = 'Vrednost glave sporočila';
$labels['headerpos'] = 'Položaj glave';
$labels['headeratstart'] = 'na začetku';
$labels['headeratend'] = 'na koncu';
$labels['headeroccurrence'] = 'Položaj glave';
$labels['headerfromstart'] = 'od začetka';
$labels['headerfromend'] = 'od konca';
$labels['headerpatterns'] = 'Vzorci vrednosti glave';
$labels['headermatchtype'] = 'način ujemanja:';
$labels['setvariable'] = 'Nastavi spremenljivko';
$labels['setvarname'] = 'Ime spremenljivke:';
$labels['setvarvalue'] = 'Vrednost spremenljivke:';
$labels['setvarmodifiers'] = 'Modifikator:';
$labels['varlower'] = 'majhne črke';
$labels['varupper'] = 'velike črke';
$labels['varlowerfirst'] = 'prvi znak velika začetnica';
$labels['varupperfirst'] = 'prvi znak velika začetnica';
$labels['varquotewildcard'] = 'citiraj posebne znake';
$labels['varlength'] = 'dolžina';
$labels['varencodeurl'] = 'odstotno kodirano (za URL-je)';
$labels['notify'] = 'Poštlji obvestilo';
$labels['notifytarget'] = 'Cilj obvestila:';
$labels['notifymessage'] = 'Besedilo obvestila (ni obvezno):';
$labels['notifyoptions'] = 'Možnosti obvestila (ni obvezno):';
$labels['notifyfrom'] = 'Pošiljatelj obvestila (ni obvezno):';
$labels['notifyimportance'] = 'Pomembnost:';
$labels['notifyimportancelow'] = 'nizko';
$labels['notifyimportancenormal'] = 'običajno';
$labels['notifyimportancehigh'] = 'visoko';
$labels['notifymethodmailto'] = 'E-Pošta';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Ustvari filter';
$labels['usedata'] = 'Pri stvarjanju filtra uporabi naslednje podatke';
$labels['nextstep'] = 'Naslednji korak';
$labels['...'] = '...';
$labels['string'] = 'Niz';
$labels['currdate'] = 'Današnji datum';
$labels['datetest'] = 'Datum';
$labels['dateheader'] = 'glava:';
$labels['year'] = 'leto';
$labels['month'] = 'mesec';
$labels['day'] = 'dan';
$labels['date'] = 'datum(yyyy-mm-dd)';
$labels['julian'] = 'datum (julijanski)';
$labels['hour'] = 'ura';
$labels['minute'] = 'minuta';
$labels['second'] = 'sekunda';
$labels['time'] = 'čas';
$labels['iso8601'] = 'datum (ISO8601)';
$labels['std11'] = 'datum (RFC2822)';
$labels['zone'] = 'časovni pas';
$labels['weekday'] = 'dan v tednu (0-6)';
$labels['advancedopts'] = 'Dodatne možnosti';
$labels['body'] = 'Vsebina';
$labels['address'] = 'naslov';
$labels['envelope'] = 'ovojnica';
$labels['modifier'] = 'modifikator';
$labels['text'] = 'besedilo';
$labels['undecoded'] = 'neobdelano';
$labels['contenttype'] = 'tip vsebine';
$labels['modtype'] = 'tip';
$labels['allparts'] = 'vse';
$labels['domain'] = 'domena';
$labels['localpart'] = 'lokalni del';
$labels['user'] = 'uporabnik';
$labels['detail'] = 'podrobnosti';
$labels['comparator'] = 'primerjalnik';
$labels['default'] = 'privzeto';
$labels['octet'] = 'strict (octet)';
$labels['asciicasemap'] = 'ni občutljiv na velike/male črke (ascii-casemap)';
$labels['asciinumeric'] = 'numerično (ascii-numeric)';
$labels['index'] = 'indeks:';
$labels['indexlast'] = 'obraten vrstni red';
$labels['spamtest'] = 'Nivo nezaželene pošte';
$labels['spamtestisgreaterthan'] = 'je večji od';
$labels['spamtestisgreaterthanequal'] = 'je večji ali enak';
$labels['spamtestislessthan'] = 'je manjši od';
$labels['spamtestislessthanequal'] = 'je manjši ali enak';
$labels['spamtestequals'] = 'je enak/a';
$labels['spamtestnotequals'] = 'ni enak/a';
$labels['spamtestisunknown'] = 'je neznan';
$labels['vacation'] = 'Sporočilo o odsotnosti';
$labels['vacation.reply'] = 'Sporočilo za odgovor';
$labels['vacation.advanced'] = 'Napredne nastavitve';
$labels['vacation.from'] = 'Naslov za odgovor';
$labels['vacation.subject'] = 'Zadeva';
$labels['vacation.body'] = 'Vsebina';
$labels['vacation.start'] = 'Začetek';
$labels['vacation.end'] = 'Konec';
$labels['vacation.status'] = 'Status';
$labels['vacation.on'] = 'Vključeno';
$labels['vacation.off'] = 'Izključeno';
$labels['vacation.addresses'] = 'Moji elektronski naslovi';
$labels['vacation.interval'] = 'Interval za odgovor';
$labels['vacation.after'] = 'Postavi pravilo o odsotnosti za';
$labels['vacation.saving'] = 'Shranjevanje podatkov...';
$labels['vacation.action'] = 'Operacije za dohodna sporočila';
$labels['vacation.keep'] = 'Ohrani';
$labels['vacation.discard'] = 'Zavrži';
$labels['vacation.redirect'] = 'Preusmeri na';
$labels['vacation.copy'] = 'Pošlji kopijo na';
$labels['forward'] = 'Posredovanje';
$labels['forward.redirect'] = 'Preusmeri na';
$labels['forward.copy'] = 'Pošlji kopijo na';
$labels['forward.on'] = 'Vključeno';
$labels['forward.off'] = 'Izključeno';
$labels['forward.status'] = 'Status:';
$labels['forward.action'] = 'Za dohodna sporočila izvrši naslednje operacije';
$labels['forward.saving'] = 'Shranjevanje podatkov...';
$labels['filladdresses'] = 'Dopolni z mojimi naslovi';
$labels['arialabelfiltersetactions'] = 'Nastavitve operacij filtrov';
$labels['arialabelfilteractions'] = 'Operacije filtrov';
$labels['arialabelfilterform'] = 'Lastnosti filtra';
$labels['ariasummaryfilterslist'] = 'Seznam filtrov';
$labels['ariasummaryfiltersetslist'] = 'Seznam filtrov';
$labels['filterstitle'] = 'Uredi filtre za dohodno pošto';
$labels['vacationtitle'] = 'Uredi sporočilo o odsotnosti';
$labels['forwardtitle'] = 'Uredi pravilo posredovanja pošte';
$labels['message'] = 'Sporočilo';
$labels['duplicate'] = 'je podvojen';
$labels['notduplicate'] = 'ni podvojen';
$labels['duplicate.handle'] = 'ukrep:';
$labels['duplicate.header'] = 'glava sporočila:';
$labels['duplicate.uniqueid'] = 'označevalnik:';
$labels['duplicate.seconds'] = 'časovna omejitev (sekunde):';
$labels['duplicate.last'] = 'relativno glede na zadnjo izvedbo';
$messages['filterunknownerror'] = 'Prišlo je do neznane napake.';
$messages['filterconnerror'] = 'Povezave s strežnikom (managesieve) ni bilo mogoče vzpostaviti';
$messages['filterdeleteerror'] = 'Pravila ni bilo mogoče izbrisati. Prišlo je do napake.';
$messages['filterdeleted'] = 'Pravilo je bilo uspešno izbrisano.';
$messages['filtersaved'] = 'Pravilo je bilo uspešno shranjeno';
$messages['filtersaveerror'] = 'Pravila ni bilo mogoče shraniti. Prišlo je do napake.';
$messages['filterformerror'] = 'Filter vsebuje napake.';
$messages['filterdeleteconfirm'] = 'Ste prepričani, da želite izbrisati izbrano pravilo?';
$messages['ruledeleteconfirm'] = 'Ste prepričani, da želite izbrisati izbrano pravilo?';
$messages['actiondeleteconfirm'] = 'Ste prepričani, da želite izbrisati izbrano dejanje?';
$messages['forbiddenchars'] = 'V polju so neveljavni znaki';
$messages['cannotbeempty'] = 'Polje ne sme biti prazno';
$messages['ruleexist'] = 'Filer s tem imenom že obstaja';
$messages['setactivateerror'] = 'Izbranega nabora filtrov ni bilo mogoče vključiti. Prišlo je do napake na strežniku.';
$messages['setdeactivateerror'] = 'Izbranega nabora filtrov ni bilo mogoče izključiti. Prišlo je do napake na strežniku.';
$messages['setdeleteerror'] = 'Izbranega nabora filtrov ni bilo mogoče izbrisati. Prišlo je do napake na strežniku.';
$messages['setactivated'] = 'Nabor filtrov je bil uspešno vključen.';
$messages['setdeactivated'] = 'Nabor filtrov je bil uspešno izključen.';
$messages['setdeleted'] = 'Nabor filtrov je bil uspešno izbrisan.';
$messages['setupdated'] = 'Nabor filtrov je bil uspešno posodobljen.';
$messages['setdeleteconfirm'] = 'Ste prepričani, da želite izbrisati izbrani nabor filtrov?';
$messages['setcreateerror'] = 'Nabora filtrov ni bilo mogoče ustvariti. Prišlo je do napake na strežniku.';
$messages['setcreated'] = 'Nabor filtrov je bil uspešno ustvarjen.';
$messages['activateerror'] = 'Izbranega/ih filtra/ov ni bilo mogoče vključiti. Prišlo je do napake na strežniku.';
$messages['deactivateerror'] = 'Izbranega/ih fitra/ov ni bilo mogoče izključiti. Prišlo je do napake na strežniku.';
$messages['deactivated'] = 'Filtri so bili uspešno omogočeni.';
$messages['activated'] = 'Filtri so bili uspešno onemogočeni.';
$messages['moved'] = 'Filter je bil uspešno premaknjen.';
$messages['moveerror'] = 'Izbranega filtra ni bilo mogoče premakniti. Prišlo je do napake na strežniku.';
$messages['nametoolong'] = 'Ime je predolgo.';
$messages['namereserved'] = 'Rezervirano ime.';
$messages['setexist'] = 'Nastavitev filtra že obstaja.';
$messages['nodata'] = 'Izbrana mora biti vsaj ena nastavitev!';
$messages['invaliddateformat'] = 'Neveljaven datum ali oblika zapisa datuma';
$messages['saveerror'] = 'Podatkov ni bilo mogoče shraniti. Prišlo je do napake na strežniku.';
$messages['vacationsaved'] = 'Sporočilo o odsotnosti je bilo uspešno shranjeno.';
$messages['forwardsaved'] = 'Posredovanje podatkov je bilo uspešno shranjeno.';
$messages['emptyvacationbody'] = 'Zahtevana je vsebina sporočila o odsotnosti';
$messages['duplicate.conflict.err'] = 'Tako glava sporočila kot enoličen označevalnik nista dovoljena.';
$messages['disabledaction'] = 'Operacija ni dovoljena.';
$messages['lastindexempty'] = 'Indeks je obvezen pri štetju od konca';
$messages['noflagset'] = 'Izbrana mora biti vsaj ena zastavica.';
