<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Markdownエディター';
$labels['editor_button_title'] = 'Markdownでメッセージを作成してHTMLとして送信';
$labels['toolbar_button_quit'] = 'テキスト形式の エディターに戻す';
$labels['toolbar_button_help'] = 'Markdownの文法のガイドを新しいウィンドウに開く';
$labels['toolbar_button_preview'] = 'HTMLとして送信する内容をプレビュー';
$labels['toolbar_button_bold'] = '太文字';
$labels['toolbar_button_italic'] = '斜体';
$labels['toolbar_button_strike'] = '取り消し線';
$labels['toolbar_button_h1'] = '見出しレベル1';
$labels['toolbar_button_h2'] = '見出しレベル2';
$labels['toolbar_button_h3'] = '見出しレベル3';
$labels['toolbar_button_h4'] = '見出しレベル4';
$labels['toolbar_button_h5'] = '見出しレベル5';
$labels['toolbar_button_h6'] = '見出しレベル6';
$labels['toolbar_button_blockquote'] = 'バッククオート';
$labels['toolbar_button_unordered_list'] = '順序のないリスト';
$labels['toolbar_button_ordered_list'] = '順序のあるリスト';
$labels['toolbar_button_link'] = 'リンク';
$labels['toolbar_button_image'] = '画像';
$labels['toolbar_button_undo'] = '取り消し';
$labels['toolbar_button_redo'] = 'やり直し';
