<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'Āfrika';
$labels['tz:africa:abidjan'] = 'Abidžana';
$labels['tz:africa:accra'] = 'Akra';
$labels['tz:africa:addis_ababa'] = 'Adisabeba';
$labels['tz:africa:algiers'] = 'Alžīra';
$labels['tz:africa:asmara'] = 'Asmara';
$labels['tz:africa:bamako'] = 'Bamako';
$labels['tz:africa:bangui'] = 'Bangi';
$labels['tz:africa:banjul'] = 'Bandžula';
$labels['tz:africa:bissau'] = 'Bisava';
$labels['tz:africa:blantyre'] = 'Blantaira';
$labels['tz:africa:brazzaville'] = 'Brazavila';
$labels['tz:africa:bujumbura'] = 'Bužumbura';
$labels['tz:africa:cairo'] = 'Kaira';
$labels['tz:africa:casablanca'] = 'Kasablanka';
$labels['tz:africa:ceuta'] = 'Ceuta';
$labels['tz:africa:conakry'] = 'Konakri';
$labels['tz:africa:dakar'] = 'Dakāra';
$labels['tz:africa:dar_es_salaam'] = 'Dāresalāma';
$labels['tz:africa:djibouti'] = 'Džibuti';
$labels['tz:africa:kampala'] = 'Kampala';
$labels['tz:africa:kigali'] = 'Kigali';
$labels['tz:africa:lagos'] = 'Lagosa';
$labels['tz:africa:luanda'] = 'Luanda';
$labels['tz:africa:maputo'] = 'Maputu';
$labels['tz:africa:tripoli'] = 'Tripole';
$labels['tz:america'] = 'Amerika';
$labels['tz:america:argentina'] = 'Argentīna';
$labels['tz:america:argentina:buenos_aires'] = 'Buenosairesa';
$labels['tz:america:argentina:salta'] = 'Salta';
$labels['tz:america:argentina:san_luis'] = 'Sanluisa';
$labels['tz:america:barbados'] = 'Barbadosa';
$labels['tz:america:bogota'] = 'Bogota';
$labels['tz:america:chicago'] = 'Čikāga';
$labels['tz:america:detroit'] = 'Detroita';
$labels['tz:america:dominica'] = 'Dominika';
$labels['tz:america:el_salvador'] = 'Salvadora';
$labels['tz:america:grenada'] = 'Grenāda';
$labels['tz:america:guatemala'] = 'Gvatemala';
$labels['tz:america:halifax'] = 'Helifeksa';
$labels['tz:america:havana'] = 'Havana';
$labels['tz:america:indiana:indianapolis'] = 'Indianapolisa';
$labels['tz:america:indiana:petersburg'] = 'Pēterburga';
$labels['tz:america:jamaica'] = 'Jamaika';
$labels['tz:america:kentucky'] = 'Kentuki';
$labels['tz:america:kentucky:louisville'] = 'Lūivila';
$labels['tz:america:lima'] = 'Lima';
$labels['tz:america:los_angeles'] = 'Losandželosa';
$labels['tz:america:merida'] = 'Merida';
$labels['tz:america:mexico_city'] = 'Mehiko';
$labels['tz:america:monterrey'] = 'Monterreja';
$labels['tz:america:montevideo'] = 'Montevideo';
$labels['tz:america:nassau'] = 'Nassau';
$labels['tz:america:new_york'] = 'Ņujorka';
$labels['tz:america:panama'] = 'Panama';
$labels['tz:america:phoenix'] = 'Fēniksa';
$labels['tz:america:puerto_rico'] = 'Puerto Riko';
$labels['tz:america:santiago'] = 'Santjago';
$labels['tz:america:santo_domingo'] = 'Santodomingo';
$labels['tz:america:sao_paulo'] = 'Sanpaulu';
$labels['tz:america:sitka'] = 'Sitka';
$labels['tz:america:st_lucia'] = 'Sentlūsija';
$labels['tz:america:toronto'] = 'Toronto';
$labels['tz:america:vancouver'] = 'Vankūvera';
$labels['tz:america:winnipeg'] = 'Vinipega';
$labels['tz:antarctica'] = 'Antarktika';
$labels['tz:arctic'] = 'Arktika';
$labels['tz:asia'] = 'Āzija';
$labels['tz:asia:baghdad'] = 'Bagdāde';
$labels['tz:asia:bahrain'] = 'Bahreina';
$labels['tz:asia:baku'] = 'Baku';
$labels['tz:asia:bangkok'] = 'Bankoka';
$labels['tz:asia:beirut'] = 'Beiruta';
$labels['tz:asia:brunei'] = 'Bruneja';
$labels['tz:asia:chita'] = 'Čita';
$labels['tz:asia:colombo'] = 'Kolombo';
$labels['tz:asia:dubai'] = 'Dubaja';
$labels['tz:asia:dushanbe'] = 'Dušanbe';
$labels['tz:asia:gaza'] = 'Gaza';
$labels['tz:asia:hong_kong'] = 'Honkonga';
$labels['tz:asia:irkutsk'] = 'Irkutska';
$labels['tz:asia:jakarta'] = 'Jakarta';
$labels['tz:asia:jerusalem'] = 'Jeruzaleme';
$labels['tz:asia:kabul'] = 'Kabula';
$labels['tz:asia:kamchatka'] = 'Kamčatka';
$labels['tz:asia:karachi'] = 'Karāči';
$labels['tz:asia:kuwait'] = 'Kuveita';
$labels['tz:asia:macau'] = 'Makau';
$labels['tz:asia:manila'] = 'Manila';
$labels['tz:asia:muscat'] = 'Muskata';
$labels['tz:asia:nicosia'] = 'Nikosija';
$labels['tz:asia:novosibirsk'] = 'Novosibirska';
$labels['tz:asia:omsk'] = 'Omska';
$labels['tz:asia:qatar'] = 'Kvatara';
$labels['tz:asia:seoul'] = 'Seula';
$labels['tz:asia:shanghai'] = 'Šanhaja';
$labels['tz:asia:singapore'] = 'Singapūra';
$labels['tz:asia:taipei'] = 'Taipeja';
$labels['tz:asia:tashkent'] = 'Taškenta';
$labels['tz:asia:tbilisi'] = 'Tbilisi';
$labels['tz:asia:tehran'] = 'Teherāna';
$labels['tz:asia:tokyo'] = 'Tokija';
$labels['tz:asia:tomsk'] = 'Tomska';
$labels['tz:asia:vladivostok'] = 'Vladivostoka';
$labels['tz:asia:yakutsk'] = 'Jakutska';
$labels['tz:asia:yekaterinburg'] = 'Jekaterenburga';
$labels['tz:atlantic:bermuda'] = 'Bermuda';
$labels['tz:atlantic:canary'] = 'Kanārijas';
$labels['tz:atlantic:madeira'] = 'Madeira';
$labels['tz:atlantic:reykjavik'] = 'Reikjavika';
$labels['tz:atlantic:south_georgia'] = 'Dienviddžordžija';
$labels['tz:atlantic:stanley'] = 'Stenli';
$labels['tz:australia'] = 'Austrālija';
$labels['tz:australia:adelaide'] = 'Adelaide';
$labels['tz:australia:melbourne'] = 'Melburna';
$labels['tz:australia:sydney'] = 'Sidneja';
$labels['tz:europe'] = 'Eiropa';
$labels['tz:europe:amsterdam'] = 'Amsterdama';
$labels['tz:europe:andorra'] = 'Andora';
$labels['tz:europe:athens'] = 'Atēnas';
$labels['tz:europe:belgrade'] = 'Belgrada';
$labels['tz:europe:berlin'] = 'Berlīne';
$labels['tz:europe:bratislava'] = 'Bratislava';
$labels['tz:europe:brussels'] = 'Brisele';
$labels['tz:europe:bucharest'] = 'Buhareste';
$labels['tz:europe:budapest'] = 'Budapešta';
$labels['tz:europe:copenhagen'] = 'Kopenhāgena';
$labels['tz:europe:dublin'] = 'Dublina';
$labels['tz:europe:gibraltar'] = 'Gibraltārs';
$labels['tz:europe:helsinki'] = 'Helsinki';
$labels['tz:europe:isle_of_man'] = 'Mana sala';
$labels['tz:europe:istanbul'] = 'Stambula';
$labels['tz:europe:jersey'] = 'Džersija';
$labels['tz:europe:kaliningrad'] = 'Kaļiņingrada';
$labels['tz:europe:kiev'] = 'Kijeva';
$labels['tz:europe:kirov'] = 'Kirova';
$labels['tz:europe:lisbon'] = 'Lisabona';
$labels['tz:europe:ljubljana'] = 'Lubļana';
$labels['tz:europe:london'] = 'Londona';
$labels['tz:europe:luxembourg'] = 'Luksemburga';
$labels['tz:europe:madrid'] = 'Madride';
$labels['tz:europe:malta'] = 'Malta';
$labels['tz:europe:minsk'] = 'Minska';
$labels['tz:europe:monaco'] = 'Monako';
$labels['tz:europe:moscow'] = 'Maskava';
$labels['tz:europe:oslo'] = 'Oslo';
$labels['tz:europe:paris'] = 'Parīze';
$labels['tz:europe:prague'] = 'Prāga';
$labels['tz:europe:riga'] = 'Rīga';
$labels['tz:europe:rome'] = 'Roma';
$labels['tz:europe:samara'] = 'Samāra';
$labels['tz:europe:san_marino'] = 'San Marino';
$labels['tz:europe:sarajevo'] = 'Sarajeva';
$labels['tz:europe:saratov'] = 'Saratova';
$labels['tz:europe:simferopol'] = 'Simferopole';
$labels['tz:europe:skopje'] = 'Skopje';
$labels['tz:europe:sofia'] = 'Sofija';
$labels['tz:europe:stockholm'] = 'Stokholma';
$labels['tz:europe:tallinn'] = 'Tallina';
$labels['tz:europe:vatican'] = 'Vatikāns';
$labels['tz:europe:vienna'] = 'Vīne';
$labels['tz:europe:vilnius'] = 'Viļņa';
$labels['tz:europe:volgograd'] = 'Volgograda';
$labels['tz:europe:warsaw'] = 'Varšava';
$labels['tz:europe:zagreb'] = 'Zagreba';
$labels['tz:europe:zurich'] = 'Cīrihe';
$labels['tz:indian'] = 'Indiana';
$labels['tz:indian:comoro'] = 'Komoro';
$labels['tz:indian:maldives'] = 'Maldivas';
$labels['tz:indian:mauritius'] = 'Maurīcija';
$labels['tz:pacific'] = 'Klusā okeāna valstis';
$labels['tz:pacific:fiji'] = 'Fidži';
$labels['tz:pacific:honolulu'] = 'Honolulu';
$labels['tz:pacific:palau'] = 'Palau';
$labels['tz:pacific:port_moresby'] = 'Portmorsbija';
$labels['tz:pacific:saipan'] = 'Spānija';
$labels['tz:pacific:tahiti'] = 'taiti';
