<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'به اين پروژه خوش امديد';
$labels['username'] = 'نام کاربر';
$labels['password'] = 'شفر';
$labels['server'] = 'سرور';
$labels['login'] = 'داخل شدن';
$labels['logout'] = 'خروج';
$labels['mail'] = 'ايميل';
$labels['settings'] = 'تنظیمات شخصی';
$labels['addressbook'] = 'کتاب ادرس';
$labels['inbox'] = 'نامه های ارسالي';
$labels['drafts'] = 'نامه های ناتکمیل';
$labels['sent'] = 'ارسال شده';
$labels['trash'] = 'اشغال دانی';
$labels['junk'] = 'بیکاره';
$labels['show_real_foldernames'] = 'نمایش نام واقعی برای فولدرهای خاص';
$labels['subject'] = 'مضمون';
$labels['from'] = 'ارسال کننده';
$labels['sender'] = 'فرستنده';
$labels['to'] = 'ګيرينده';
$labels['cc'] = 'تکثیر';
$labels['bcc'] = 'تکثیر پنهان';
$labels['replyto'] = 'جواب نامه';
$labels['date'] = 'تاريخ';
$labels['size'] = 'اندازه';
$labels['priority'] = 'اولویت';
$labels['organization'] = 'تنظیمات';
$labels['readstatus'] = 'خواندن وضعیت';
$labels['listoptions'] = 'لیست کردن آپشن ها...';
$labels['mailboxlist'] = 'پوشه ها';
$labels['messagesfromto'] = 'از  مقدار پيغام به مقدار حساب شده';
$labels['messagenrof'] = 'از شمار پيغام های حساب شده';
$labels['copy'] = 'تکثیر';
$labels['move'] = 'انتقال';
$labels['moveto'] = 'انتقال بدهید به ...';
$labels['copyto'] = 'کپی کردن به...';
$labels['download'] = 'داونلود کردن';
$labels['open'] = 'باز کردن';
$labels['showattachment'] = 'نمایش';
$labels['filename'] = 'نام فايل';
$labels['filesize'] = 'اندازه فايل';
$labels['addtoaddressbook'] = 'در کتاب ادرس علاوه نماييد';
$labels['sun'] = 'يکشنپبه';
$labels['mon'] = 'دوشنبه';
$labels['tue'] = 'سه شنبه';
$labels['wed'] = 'چهارشنبه';
$labels['thu'] = 'پنج شنبه';
$labels['fri'] = 'جمعه';
$labels['sat'] = 'شنبه';
$labels['sunday'] = 'يکشنبه';
$labels['monday'] = 'دوشنبه';
$labels['tuesday'] = 'سه شنبه';
$labels['wednesday'] = 'چهارشنبه';
$labels['thursday'] = 'پنج شنبه';
$labels['friday'] = 'جمعه';
$labels['saturday'] = 'شنبه';
$labels['jan'] = 'جنوری';
$labels['feb'] = 'فبروری';
$labels['mar'] = 'مارچ';
$labels['apr'] = 'اپریل';
$labels['may'] = 'می';
$labels['jun'] = 'جون';
$labels['jul'] = 'جولایی';
$labels['aug'] = 'آگست';
$labels['sep'] = 'سپتمبر';
$labels['oct'] = 'اکتوبر';
$labels['nov'] = 'نومبر';
$labels['dec'] = 'دسمبر';
$labels['longjan'] = 'جنوری';
$labels['longfeb'] = 'فبروری';
$labels['longmar'] = 'مارچ';
$labels['longapr'] = 'اپریل';
$labels['longmay'] = 'می';
$labels['longjun'] = 'جون';
$labels['longjul'] = 'جولایی';
$labels['longaug'] = 'آگست';
$labels['longsep'] = 'سپتمبر';
$labels['longoct'] = 'اکتوبر';
$labels['longnov'] = 'نومبر';
$labels['longdec'] = 'دسمبر';
$labels['today'] = 'امروز';
$labels['refresh'] = 'رفرش';
$labels['checkmail'] = 'بررسي کردن پيغام های جديد';
$labels['compose'] = 'نوشتن پیام حدید';
$labels['writenewmessage'] = 'ساختن پيغام جديد';
$labels['reply'] = 'پاسخ';
$labels['replytomessage'] = 'جواب دادن به پيغام';
$labels['replytoallmessage'] = 'به فرستنده و تمام گيرينده ها جواب بدهيد';
$labels['replyall'] = 'پاسخ به همه';
$labels['replylist'] = 'لیست پاسخ';
$labels['forward'] = 'فوروارد';
$labels['forwardmessage'] = 'فرستادن این پیام به دیگران / فارورد';
$labels['deletemessage'] = 'حذف کردن پيغام';
$labels['movemessagetotrash'] = 'پيغام را به اشيآيي حذف شده منتقل نماييد';
$labels['printmessage'] = 'اين پيغام را چاپ کنيد';
$labels['previousmessage'] = 'پيغام قبلي را نشان دهيد';
$labels['firstmessage'] = 'پيغام اولي را نشان دهيد';
$labels['nextmessage'] = 'پيغام بعدي رانشان دهيد';
$labels['lastmessage'] = 'پيغام اخير را نشان دهيد';
$labels['backtolist'] = 'بازگشتن به لست پيغام';
$labels['viewsource'] = 'منبع / کود را نشان دهيد';
$labels['mark'] = 'نشانه گذاری';
$labels['markmessages'] = 'پيغام ها را نشاني کنيد';
$labels['markread'] = 'مانند خوانده شده';
$labels['markunread'] = 'مانند خوانده نشده';
$labels['markflagged'] = 'مانند نشانی شده';
$labels['markunflagged'] = 'مانند نشانی ناشده';
$labels['more'] = 'بیشتر';
$labels['back'] = 'بازگشت';
$labels['options'] = 'انتخاب ها';
$labels['first'] = 'اول';
$labels['last'] = 'انتها';
$labels['previous'] = 'قبلی';
$labels['next'] = 'بعدی';
$labels['select'] = 'انتخاب کردن';
$labels['all'] = 'تمام';
$labels['none'] = 'هيچ کدام';
$labels['isread'] = 'خواندن';
$labels['unread'] = 'ناخوانده';
$labels['flagged'] = 'نشانی شده';
$labels['unanswered'] = 'پیامهای جواب نداده شده';
$labels['deleted'] = 'حذف شد';
$labels['filter'] = 'تصفیه کردن';
$labels['list'] = 'لیست';
$labels['attachment'] = 'الصاق';
$labels['nonesort'] = 'هيچ کدام';
$labels['sentdate'] = 'تاریخ ارسال';
$labels['arrival'] = 'تاریخ دریافت';
$labels['asc'] = 'صعودی';
$labels['desc'] = 'نزولی';
$labels['layoutlist'] = 'لیست';
$labels['compact'] = 'خلاصه';
$labels['empty'] = 'خالي';
$labels['quota'] = '‌طريقه استعمال ديسک';
$labels['unknown'] = 'نامعلوم';
$labels['unlimited'] = 'نامعين/ نامحدود';
$labels['quicksearch'] = 'جستجوی سریع';
$labels['resetsearch'] = 'بازنشاندن جستجو';
$labels['body'] = 'متن پیام';
$labels['openinextwin'] = 'در پینجره ای جدید باز کنید';
$labels['sendmessage'] = 'پيغام را همين حالا ارسال کنيد';
$labels['savemessage'] = 'این پیش نویس را حفظ نمایید';
$labels['addattachment'] = 'ضميمه نمودن يک فايل';
$labels['charset'] = 'ست کرکتر ها';
$labels['editortype'] = 'روش تصحیح کننده / نوشتاری';
$labels['returnreceipt'] = 'رسید برای مراجعت نامه';
$labels['recipient'] = 'گیرنده';
$labels['checkspelling'] = 'املا را بررسي کنيد';
$labels['resumeediting'] = 'ادامه / بازگشت به تصحیی کردن / نوشتن';
$labels['revertto'] = 'رجوع کردن به';
$labels['attachments'] = 'ضميمه ها';
$labels['upload'] = 'اپلود کردن';
$labels['close'] = 'بستن';
$labels['low'] = 'کم';
$labels['lowest'] = 'کمترین';
$labels['normal'] = 'عادی';
$labels['high'] = 'عالي';
$labels['highest'] = 'عاليترين';
$labels['nosubject'] = 'مضمون ندارد';
$labels['showimages'] = 'نمايش دادن تصاوير';
$labels['alwaysshow'] = 'همیشه نشان بده تصاویر را از این فرسیتنده﷼';
$labels['htmltoggle'] = 'ایچ تی ام ایل';
$labels['plaintoggle'] = 'متن ساده';
$labels['savesentmessagein'] = 'پیام ارسال شده را ذخیره کن در';
$labels['dontsave'] = 'ذخیره نکنید';
$labels['maxuploadsize'] = '$sizeزیاد ترین اندازه اجازه داده شده فایل عبارت است از';
$labels['addcc'] = 'نسخیه دوم  را علاوه کنید';
$labels['addbcc'] = 'نسخه پنهان را علاوه کنید';
$labels['addreplyto'] = 'علاوه کردن';
$labels['mdnrequest'] = 'فرستانده این پیام خواهش نموده زمانیکه شما نامه را خواندید براش آگاهی داده شود آيا شما ميخواهيد که فرستنده را آګاه سازيد';
$labels['receiptread'] = 'بازگشت رسید (خوانده شده)';
$labels['yourmessage'] = 'برای پيغام شما اين يک رسید بازگشت است';
$labels['receiptnote'] = 'يادداشت : اين رسيد شما را فقط اګاه ميسازد که پيغام به کامپیوتر گیرنده نمایش داده شده است  هیچ گارنتی وجود ندارد که گیرنده پیام این پیام را خوانده و یا مطالب آن را درک کرده باشد.';
$labels['name'] = 'نشان دادن نام';
$labels['firstname'] = 'اسم/ نام';
$labels['surname'] = 'اسم فاميلي / تخلص';
$labels['email'] = 'ايميل';
$labels['other'] = 'دیگر';
$labels['typeother'] = 'دیگر';
$labels['editcontact'] = 'آدرس جدید را تصحیح کنید';
$labels['edit'] = 'تصحيح کردن';
$labels['cancel'] = 'لغو کردن/ حذف کردن';
$labels['save'] = 'حفظ کردن';
$labels['delete'] = 'حذف کردن';
$labels['addphoto'] = 'افزودن';
$labels['deletecontact'] = 'آدرس های انتخاب شده را حذف کنيد';
$labels['composeto'] = 'ايمیل را نوشته کنيد به';
$labels['contactsfromto'] = 'از$count$to به $from آدرس ها از';
$labels['print'] = 'چاپ کردن';
$labels['export'] = 'صادر کردن';
$labels['exportvcards'] = 'صادر نماییدVcardآدرس ها را به فرمت';
$labels['previouspage'] = 'بسته قبلي را نشان دهيد';
$labels['firstpage'] = 'بسته اولي را نشان دهيد';
$labels['nextpage'] = 'بسته بعدي را نشان دهيد';
$labels['lastpage'] = 'بسته اخير را نشان دهيد';
$labels['groups'] = 'گروه ها';
$labels['personaladrbook'] = 'ادرس های شخصي';
$labels['import'] = 'وارد کردن';
$labels['importcontacts'] = 'آدرس ها را وارد نمایید';
$labels['importreplace'] = 'تمام کتاب آدرس ها را عوض نمایید';
$labels['done'] = 'اجرا شد';
$labels['settingsfor'] = 'تنظیمات برای';
$labels['about'] = 'درباره نرم افزار';
$labels['preferences'] = 'ترجيحات';
$labels['userpreferences'] = 'ترجيحات کاربر';
$labels['editpreferences'] = 'تصحيح کردن ترجيحات  کاربر';
$labels['identities'] = 'شناخت ها';
$labels['preferhtml'] = 'نشان دادن ايچ ټي ام ايل';
$labels['htmlmessage'] = 'پيغام ايچ ټي‌ام ايل';
$labels['prettydate'] = 'تاريخ های مهم';
$labels['setdefault'] = 'بطور همیشگی انتخاب نمایید';
$labels['autodetect'] = 'اتومات';
$labels['language'] = 'لسان';
$labels['timezone'] = 'ناحيه زمانی';
$labels['pagesize'] = 'تعداد سطر ها در صفحه';
$labels['signature'] = 'امضا';
$labels['dstactive'] = 'Daylight saving time';
$labels['htmleditor'] = 'پيغام ايچ ټي ام ايل رانوشته کنيد';
$labels['htmlsignature'] = 'امضای حساب ایمیل بشکل ایچ تی ام ال';
$labels['previewpane'] = 'چوکات پیشنما را نشان دهید';
$labels['skin'] = 'تمپلیت محیط کاربری';
$labels['logoutclear'] = 'Clear Trash on logout';
$labels['logoutcompact'] = 'Compact Inbox on logout';
$labels['uisettings'] = 'محیط کاربر';
$labels['serversettings'] = 'تنظیمات سرور';
$labels['mailboxview'] = 'طرز نمایش صندوق پستی';
$labels['mdnrequests'] = 'آگاهی های ارسال کننده';
$labels['askuser'] = 'از کاربر بپرسید';
$labels['autosend'] = 'پیام را بطور خودکار روان کنید';
$labels['readwhendeleted'] = 'در هنگام حفظ پیام را خوانده شده نشانی کنید';
$labels['flagfordeletion'] = 'Flag the message for deletion instead of delete';
$labels['skipdeleted'] = 'پیام های حذف شده را نمایش ندهید';
$labels['showremoteimages'] = 'Display remote inline images';
$labels['fromknownsenders'] = 'نامه های از آدرس های شناخته شده';
$labels['always'] = 'همیشه';
$labels['showinlineimages'] = 'تصاویر ضمیمه شده را در پایین پیام نشان دهید.';
$labels['autosavedraft'] = 'بصورت خودکار پیش نويس را حفظ کنيد';
$labels['everynminutes'] = 'دقیفه$n هر';
$labels['never'] = 'هیچگاه';
$labels['messagesdisplaying'] = 'نمایش دادن پیام ها';
$labels['messagescomposition'] = 'ایجاد کردن پیام جدید';
$labels['mimeparamfolding'] = 'نام های ضمیمه ها';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (دیگر ها)';
$labels['advancedoptions'] = 'انتخاب های پیشرفته';
$labels['focusonnewmessage'] = 'فوکس دادن پینجره مرورگر به پیام جدید';
$labels['checkallfolders'] = 'تمام پوشه ها را بخاطر پیام های جدید بررسی کنید';
$labels['allmessages'] = 'تمام پیام ها';
$labels['folder'] = 'پوشه';
$labels['folders'] = 'پوشه ها';
$labels['foldername'] = 'نام پوشه';
$labels['subscribed'] = 'مشترک';
$labels['messagecount'] = 'پيغام ها';
$labels['create'] = 'ایجاد کردن';
$labels['createfolder'] = 'ایجاد پوشه جدید';
$labels['managefolders'] = 'اداره کردن پوشه ها';
$labels['specialfolders'] = 'پوشه های مخصوص';
$labels['sortby'] = 'فهرست کردن توسط';
$labels['sortasc'] = 'فهرست کردن از طرف بالا به پايين';
$labels['sortdesc'] = 'فهرست کردن از طرف پايين به بالا';
$labels['license'] = 'حق نشر';
$labels['B'] = 'بایت';
$labels['KB'] = 'کیلو بایت';
$labels['MB'] = 'میگا بایت';
$labels['GB'] = 'گیگا بایت';
