<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Textformatering';
$labels['editor_button_title'] = 'Skapa meddelande med textformatering och skicka som HTML';
$labels['toolbar_button_quit'] = 'Återgå till ren textredigering';
$labels['toolbar_button_help'] = 'Öppna formateringsguiden i ett nytt fönster';
$labels['toolbar_button_preview'] = 'Förhandsvisa som meddelandet kommer skickas';
$labels['toolbar_button_bold'] = 'Fet';
$labels['toolbar_button_italic'] = 'Kursiv';
$labels['toolbar_button_strike'] = 'Överstruken';
$labels['toolbar_button_h1'] = 'Rubriknivå 1';
$labels['toolbar_button_h2'] = 'Rubriknivå 2';
$labels['toolbar_button_h3'] = 'Rubriknivå 3';
$labels['toolbar_button_h4'] = 'Rubriknivå 4';
$labels['toolbar_button_h5'] = 'Rubriknivå 5';
$labels['toolbar_button_h6'] = 'Rubriknivå 6';
$labels['toolbar_button_blockquote'] = 'Citatblock';
$labels['toolbar_button_unordered_list'] = 'Onumrerad lista';
$labels['toolbar_button_ordered_list'] = 'Numrerad lista';
$labels['toolbar_button_link'] = 'Länk';
$labels['toolbar_button_image'] = 'Bild';
$labels['toolbar_button_undo'] = 'Ångra';
$labels['toolbar_button_redo'] = 'Gör om';
