<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Comparteix';
$labels['myrights'] = 'Permisos d\'accés';
$labels['username'] = 'Usuari:';
$labels['advanced'] = 'Mode Avançat';
$labels['add'] = 'Afegeix';
$labels['newuser'] = 'Afegeix una entrada';
$labels['editperms'] = 'Edita Permisos';
$labels['actions'] = 'Accions dels permisos d\'accés...';
$labels['anyone'] = 'Tots els usuaris (qualsevol)';
$labels['anonymous'] = 'Convidats (anònim)';
$labels['identifier'] = 'Identificador';
$labels['acll'] = 'Cerca';
$labels['aclr'] = 'Llegeix missatges';
$labels['acls'] = 'Conserva\'l com a llegit';
$labels['aclw'] = 'Marques d\'escriptura';
$labels['acli'] = 'Insereix (Copia dins)';
$labels['aclp'] = 'Envia l\'entrada';
$labels['aclc'] = 'Crea subcarpetes';
$labels['aclk'] = 'Crea subcarpetes';
$labels['acld'] = 'Suprimeix missatges';
$labels['aclt'] = 'Suprimeix missatges';
$labels['acle'] = 'Buida';
$labels['aclx'] = 'Suprimeix carpeta';
$labels['acla'] = 'Administra';
$labels['acln'] = 'Anota missatges';
$labels['aclfull'] = 'Control total';
$labels['aclother'] = 'Un altre';
$labels['aclread'] = 'Lectura';
$labels['aclwrite'] = 'Escriptura';
$labels['acldelete'] = 'Suprimeix';
$labels['shortacll'] = 'Cerca';
$labels['shortaclr'] = 'Lectura';
$labels['shortacls'] = 'Conserva';
$labels['shortaclw'] = 'Escriptura';
$labels['shortacli'] = 'Insereix';
$labels['shortaclp'] = 'Envia l\'entrada';
$labels['shortaclc'] = 'Crea';
$labels['shortaclk'] = 'Crea';
$labels['shortacld'] = 'Suprimeix';
$labels['shortaclt'] = 'Suprimeix';
$labels['shortacle'] = 'Buida';
$labels['shortaclx'] = 'Suprimeix carpeta';
$labels['shortacla'] = 'Administra';
$labels['shortacln'] = 'Anota';
$labels['shortaclother'] = 'Un altre';
$labels['shortaclread'] = 'Lectura';
$labels['shortaclwrite'] = 'Escriptura';
$labels['shortacldelete'] = 'Suprimeix';
$labels['longacll'] = 'La carpeta és visible a les llistes i s\'hi pot subscriure';
$labels['longaclr'] = 'La carpeta pot ser oberta per llegir';
$labels['longacls'] = 'Els missatges marcats com a Llegit poden ser canviats';
$labels['longaclw'] = 'Les marques i les paraules clau dels missatges poden ser canviats, excepte els Llegit i Suprimit';
$labels['longacli'] = 'Els missatges poden ser escrits i copiats a la carpeta';
$labels['longaclp'] = 'Els missatges poden ser enviats a aquesta carpeta';
$labels['longaclc'] = 'Es poden crear (or reanomenar) carpetes directament sota aquesta carpeta';
$labels['longaclk'] = 'Es poden crear (or reanomenar) carpetes directament sota aquesta carpeta';
$labels['longacld'] = 'Els missatges amb l\'indicador Suprimit poden ser canviats';
$labels['longaclt'] = 'Els missatges amb l\'indicador Suprimit poden ser canviats';
$labels['longacle'] = 'Els missatges poden ser purgats';
$labels['longaclx'] = 'La carpeta pot ser suprimida o reanomenada';
$labels['longacla'] = 'Els permisos d\'accés a la carpeta poden ser canviats';
$labels['longacln'] = 'Les metadades compartides dels missatges (anotacions) poden ser canviades';
$labels['longaclfull'] = 'Control total fins i tot la gestió de carpetes';
$labels['longaclread'] = 'La carpeta pot ser oberta per llegir';
$labels['longaclwrite'] = 'Els missatges poden ser marcats, escrits o copiats a la carpeta';
$labels['longacldelete'] = 'Els missatges poden ser suprimits';
$labels['longaclother'] = 'Altres drets d\'accés';
$labels['ariasummaryacltable'] = 'Llista els drets d\'accés';
$labels['arialabelaclactions'] = 'Llista les accions';
$labels['arialabelaclform'] = 'Formulari de drets d\'accés';
$messages['deleting'] = 'S\'estan suprimint els permisos d\'accés...';
$messages['saving'] = 'S\'estan desant els permisos d\'accés...';
$messages['updatesuccess'] = 'Els permisos d\'accés han estat canviats correctament';
$messages['deletesuccess'] = 'Els permisos d\'accés han estat suprimits correctament';
$messages['createsuccess'] = 'Els permisos d\'accés han estat afegits correctament';
$messages['updateerror'] = 'No s\'han pogut actualitzar els permisos d\'accés';
$messages['deleteerror'] = 'No s\'han pogut suprimir els permisos d\'accés';
$messages['createerror'] = 'No s\'han pogut afegir els permisos d\'accés';
$messages['deleteconfirm'] = 'Esteu segur de voler suprimir els permisos d\'accés de l\'usuari o usuaris seleccionats?';
$messages['norights'] = 'No s\'ha especificat cap permís';
$messages['nouser'] = 'No s\'ha especificat cap nom d\'usuari';
