<?php

/*
 +-----------------------------------------------------------------------+
 | localization/zh_TW/csv2vcard.inc                                      |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2012, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['紀念日'] = 'anniversary';
$map['助理'] = 'assistant';
$map['助理電話'] = 'phone:assistant';
$map['生日'] = 'birthday';
$map['商務 - 市/鎮'] = 'locality:work';
$map['商務 - 國家/地區'] = 'country:work';
$map['商務傳真'] = 'phone:workfax';
$map['商務電話'] = 'phone:work';
$map['商務電話 2'] = 'phone:work2';
$map['商務 - 郵遞區號'] = 'zipcode:work';
$map['商務 - 縣市'] = 'region:work';
$map['商務 - 街'] = 'street:work';
$map['汽車電話'] = 'phone:car';
$map['類別'] = 'groups';
$map['公司'] = 'organization';
$map['部門'] = 'department';
$map['電子郵件地址'] = 'email:other';
$map['名字'] = 'firstname';
$map['性別'] = 'gender';
$map['住家 - 市/鎮'] = 'locality:home';
$map['住家 - 國家/地區'] = 'country:home';
$map['住家傳真'] = 'phone:homefax';
$map['住家電話'] = 'phone:home';
$map['住家電話 2'] = 'phone:home2';
$map['住家 - 郵遞區號'] = 'zipcode:home';
$map['住家 - 縣/市'] = 'region:home';
$map['住家 - 街'] = 'street:home';
$map['職稱'] = 'jobtitle';
$map['姓氏'] = 'surname';
$map['主管名稱'] = 'manager';
$map['中間名'] = 'middlename';
$map['行動電話'] = 'phone:mobile';
$map['記事'] = 'notes';
$map['其他 - 市/鎮'] = 'locality:other';
$map['其他 - 國家/地區'] = 'country:other';
$map['其他傳真'] = 'phone:other';
$map['其他電話'] = 'phone:other';
$map['其他 - 郵遞區號'] = 'zipcode:other';
$map['其他 - 縣/市'] = 'region:other';
$map['其他 - 街'] = 'street:other';
$map['呼叫器'] = 'phone:pager';
$map['代表電話'] = 'phone:main';
$map['配偶'] = 'spouse';
$map['稱謂'] = 'suffix';
$map['頭銜'] = 'prefix';
$map['網頁'] = 'website:homepage';
$map['姓'] = 'surname';
$map['名'] = 'firstname';
$map['生日 (日)'] = 'birthday-d';
$map['生日 (月)'] = 'birthday-m';
$map['生日 (年)'] = 'birthday-y';
$map['顯示名稱'] = 'name';
$map['傳真號碼'] = 'phone:homefax';
$map['住家住址'] = 'street:home';
$map['居住國家'] = 'country:home';
$map['住址郵遞區號'] = 'zipcode:home';
$map['手機號碼'] = 'phone:mobile';
$map['暱稱'] = 'nickname';
$map['Organization'] = 'organization';
$map['呼叫器號碼'] = 'phone:pager';
$map['主要 Email'] = 'email:home';
$map['次要 Email'] = 'email:other';
$map['網頁 1'] = 'website:homepage';
$map['網頁 2'] = 'website:other';
$map['商務電話'] = 'phone:work';
$map['商務地址'] = 'street:work';
$map['商務國家'] = 'country:work';
$map['商務郵遞區號'] = 'zipcode:work';
$map['商務市鎮'] = 'locality:work';
$map['商務縣市'] = 'region:work';
$map['居住市鎮'] = 'locality:home';
$map['居住縣市'] = 'region:home';
