<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Фильтры';
$labels['managefilters'] = 'Управление фильтрами для входящей почты';
$labels['filtername'] = 'Название фильтра';
$labels['newfilter'] = 'Новый фильтр';
$labels['filteradd'] = 'Добавить фильтр';
$labels['filterdel'] = 'Удалить фильтр';
$labels['rules'] = 'Правила';
$labels['actions'] = 'Действия';
$labels['scope'] = 'Область';
$labels['moveup'] = 'Сдвинуть вверх';
$labels['movedown'] = 'Сдвинуть вниз';
$labels['filterallof'] = 'соответствует всем указанным правилам';
$labels['filteranyof'] = 'соответствует любому из указанных правил';
$labels['filterany'] = 'все сообщения';
$labels['filtercontains'] = 'содержит';
$labels['filternotcontains'] = 'не содержит';
$labels['filteris'] = 'соответствует';
$labels['filterisnot'] = 'не соответствует';
$labels['filterexists'] = 'существует';
$labels['filternotexists'] = 'не существует';
$labels['filtermatches'] = 'совпадает с выражением';
$labels['filternotmatches'] = 'не совпадает с выражением';
$labels['filterregex'] = 'совпадает с регулярным выражением';
$labels['filternotregex'] = 'не совпадает с регулярным выражением';
$labels['filterunder'] = 'меньше';
$labels['filterover'] = 'больше';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME часть:';
$labels['mime-message'] = 'сообщение';
$labels['mime-anychild'] = 'любой';
$labels['mime-type'] = 'тип';
$labels['mime-subtype'] = 'подтип';
$labels['mime-contenttype'] = 'тип содержимого';
$labels['mime-param'] = 'параметр';
$labels['addrule'] = 'Добавить правило';
$labels['delrule'] = 'Удалить правило';
$labels['messagemoveto'] = 'Переместить сообщение в';
$labels['messageredirect'] = 'Перенаправить сообщение на';
$labels['messagecopyto'] = 'Скопировать сообщение в';
$labels['messagesendcopy'] = 'Отправить копию сообщения на';
$labels['messagereply'] = 'Ответить с сообщением';
$labels['messagedelete'] = 'Удалить сообщение';
$labels['messagediscard'] = 'Не принимать и ответить:';
$labels['messagekeep'] = 'Оставить сообщение во Входящих';
$labels['messagesrules'] = 'Для входящей почты:';
$labels['messagesactions'] = '...выполнить следующие действия:';
$labels['add'] = 'Добавить';
$labels['del'] = 'Удалить';
$labels['sender'] = 'Отправитель';
$labels['recipient'] = 'Получатель';
$labels['vacationaddr'] = 'Мои адреса эл. почты:';
$labels['vacationdays'] = 'Как часто отправлять сообщения (в днях):';
$labels['vacationinterval'] = 'Как часто отправлять сообщения:';
$labels['vacationreason'] = 'Текст сообщения (причина отсутствия):';
$labels['vacationfrom'] = 'Обратный адрес отправителя:';
$labels['vacationsubject'] = 'Тема сообщения:';
$labels['days'] = 'дней';
$labels['seconds'] = 'секунд';
$labels['rulestop'] = 'Закончить выполнение';
$labels['enable'] = 'Включить/Выключить';
$labels['filterset'] = 'Набор фильтров';
$labels['filtersets'] = 'Наборы фильтров';
$labels['filtersetadd'] = 'Добавить набор фильтров';
$labels['filtersetdel'] = 'Удалить набор фильтров';
$labels['filtersetact'] = 'Включить текущий набор фильтров';
$labels['filtersetdeact'] = 'Отключить текущий набор фильтров';
$labels['filterseteditraw'] = 'Изменить набор фильтров';
$labels['filtersetswitch'] = 'Включить/выключить набор фильтров';
$labels['filterdef'] = 'Описание фильтра';
$labels['filtersetname'] = 'Название набора фильтров';
$labels['newfilterset'] = 'Новый набор фильтров';
$labels['active'] = 'используется';
$labels['none'] = 'нет';
$labels['fromset'] = 'из набора';
$labels['fromfile'] = 'из файла';
$labels['filterdisabled'] = 'Отключить фильтр';
$labels['filterenabled'] = 'Фильтр включен';
$labels['countisgreaterthan'] = 'количество больше, чем';
$labels['countisgreaterthanequal'] = 'количество больше или равно';
$labels['countislessthan'] = 'количество меньше, чем';
$labels['countislessthanequal'] = 'количество меньше или равно';
$labels['countequals'] = 'количество равно';
$labels['countnotequals'] = 'количество не равно';
$labels['valueisgreaterthan'] = 'значение больше, чем';
$labels['valueisgreaterthanequal'] = 'значение больше или равно';
$labels['valueislessthan'] = 'значение меньше, чем';
$labels['valueislessthanequal'] = 'значение меньше или равно';
$labels['valueequals'] = 'значение равно';
$labels['valuenotequals'] = 'значение не равно';
$labels['setflags'] = 'Установить флаги на сообщение';
$labels['addflags'] = 'Добавить флаги к сообщению';
$labels['removeflags'] = 'Убрать флаги из сообщения';
$labels['flagread'] = 'Прочитано';
$labels['flagdeleted'] = 'Удалено';
$labels['flaganswered'] = 'Отвечено';
$labels['flagflagged'] = 'Помечено';
$labels['flagdraft'] = 'Черновик';
$labels['addheader'] = 'Добавить заголовок к сообщению';
$labels['deleteheader'] = 'Удалить заголовок из сообщения';
$labels['headername'] = 'Название заголовка';
$labels['headervalue'] = 'Значение заголовка';
$labels['headerpos'] = 'Положение заголовка';
$labels['headeratstart'] = 'в начале';
$labels['headeratend'] = 'в конце';
$labels['headeroccurrence'] = 'Появление/положение заголовка';
$labels['headerfromstart'] = 'с конца';
$labels['headerfromend'] = 'с начала';
$labels['headerpatterns'] = 'Шаблоны значений заголовков';
$labels['headermatchtype'] = 'тип соответствия:';
$labels['setvariable'] = 'Задать переменную';
$labels['setvarname'] = 'Имя переменной:';
$labels['setvarvalue'] = 'Значение переменной:';
$labels['setvarmodifiers'] = 'Модификаторы:';
$labels['varlower'] = 'нижний регистр';
$labels['varupper'] = 'верхний регистр';
$labels['varlowerfirst'] = 'первый символ в нижнем регистре';
$labels['varupperfirst'] = 'первый символ в верхнем регистре';
$labels['varquotewildcard'] = 'символ кавычек';
$labels['varlength'] = 'длина';
$labels['notify'] = 'Отправить уведомление';
$labels['notifytarget'] = 'Объект уведомления:';
$labels['notifymessage'] = 'Сообщение уведомления (не обязательно):';
$labels['notifyoptions'] = 'Параметры уведомления (не обязательно):';
$labels['notifyfrom'] = 'Отправитель уведомления (не обязательно):';
$labels['notifyimportance'] = 'Важность:';
$labels['notifyimportancelow'] = 'низкая';
$labels['notifyimportancenormal'] = 'нормальная';
$labels['notifyimportancehigh'] = 'высокая';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Телефон';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Создать фильтр';
$labels['usedata'] = 'Использовать следующие данные в фильтре:';
$labels['nextstep'] = 'Далее';
$labels['...'] = '...';
$labels['string'] = 'Строка';
$labels['currdate'] = 'Текущая дата';
$labels['datetest'] = 'Дата';
$labels['dateheader'] = 'заголовок:';
$labels['year'] = 'год';
$labels['month'] = 'месяц';
$labels['day'] = 'день';
$labels['date'] = 'дата (гггг-мм-дд)';
$labels['julian'] = 'дата (юлианская)';
$labels['hour'] = 'час';
$labels['minute'] = 'минута';
$labels['second'] = 'секунда';
$labels['time'] = 'время (чч:мм:сс)';
$labels['iso8601'] = 'дата (ISO8601)';
$labels['std11'] = 'дата (RFC2822)';
$labels['zone'] = 'часовой пояс';
$labels['weekday'] = 'день недели (0-6)';
$labels['advancedopts'] = 'Дополнительные параметры';
$labels['body'] = 'Тело письма';
$labels['address'] = 'адрес';
$labels['envelope'] = 'конверт';
$labels['modifier'] = 'модификатор области поиска:';
$labels['text'] = 'текст';
$labels['undecoded'] = 'необработанный (сырой)';
$labels['contenttype'] = 'тип содержимого';
$labels['modtype'] = 'поиск в адресах:';
$labels['allparts'] = 'везде';
$labels['domain'] = 'в имени домена';
$labels['localpart'] = 'только в имени пользователя, без домена';
$labels['user'] = 'в полном имени пользователя';
$labels['detail'] = 'в дополнительных сведениях';
$labels['comparator'] = 'способ сравнения:';
$labels['default'] = 'по умолчанию';
$labels['octet'] = 'Строгий (octet)';
$labels['asciicasemap'] = 'Регистронезависимый (ascii-casemap)';
$labels['asciinumeric'] = 'Числовой (ascii-numeric)';
$labels['index'] = 'индекс:';
$labels['indexlast'] = 'наоборот';
$labels['spamtest'] = 'Уровень спама';
$labels['spamtestisgreaterthan'] = 'больше, чем';
$labels['spamtestisgreaterthanequal'] = 'больше или равно';
$labels['spamtestislessthan'] = 'меньше чем';
$labels['spamtestislessthanequal'] = 'меньше или равно';
$labels['spamtestequals'] = 'соответствует';
$labels['spamtestnotequals'] = 'не соответствует';
$labels['spamtestisunknown'] = 'неизвестно';
$labels['vacation'] = 'Вне офиса';
$labels['vacation.reply'] = 'Ответное сообщение';
$labels['vacation.advanced'] = 'Дополнительные настройки';
$labels['vacation.from'] = 'Обратный адрес отправителя';
$labels['vacation.subject'] = 'Тема';
$labels['vacation.body'] = 'Тело письма';
$labels['vacation.start'] = 'Время начала';
$labels['vacation.end'] = 'Время окончания';
$labels['vacation.status'] = 'Состояние';
$labels['vacation.on'] = 'Вкл.';
$labels['vacation.off'] = 'Выкл.';
$labels['vacation.addresses'] = 'Мои адреса эл. почты';
$labels['vacation.interval'] = 'Интервал ответа';
$labels['vacation.after'] = 'Поместить правило отсутствия в офисе после';
$labels['vacation.saving'] = 'Сохранение данных...';
$labels['vacation.action'] = 'Действия с входящим сообщением';
$labels['vacation.keep'] = 'Оставить';
$labels['vacation.discard'] = 'Отменить';
$labels['vacation.redirect'] = 'Перенаправить на';
$labels['vacation.copy'] = 'Отправить копию на';
$labels['forward'] = 'Пересылка';
$labels['forward.redirect'] = 'Перенаправить на';
$labels['forward.copy'] = 'Отправить копию на';
$labels['forward.on'] = 'Вкл.';
$labels['forward.off'] = 'Выкл.';
$labels['forward.status'] = 'Статус:';
$labels['forward.action'] = 'Выполнить следующее действие для входящих сообщений:';
$labels['forward.saving'] = 'Сохранение данных...';
$labels['filladdresses'] = 'Заполнить всеми моими адресами';
$labels['arialabelfiltersetactions'] = 'Действия набора фильтров';
$labels['arialabelfilteractions'] = 'Действия фильтра';
$labels['arialabelfilterform'] = 'Свойства фильтра';
$labels['ariasummaryfilterslist'] = 'Список фильтров';
$labels['ariasummaryfiltersetslist'] = 'Список набора фильтров';
$labels['filterstitle'] = 'Редактировать фильтры для входящей почты';
$labels['vacationtitle'] = 'Изменить правило "Не в офисе"';
$labels['forwardtitle'] = 'Изменить правило пересылки';
$labels['message'] = 'Сообщение';
$labels['duplicate'] = 'дублируется';
$labels['notduplicate'] = 'не дублируется';
$labels['duplicate.handle'] = 'дескриптор:';
$labels['duplicate.header'] = 'заголовок:';
$labels['duplicate.uniqueid'] = 'идентификатор:';
$labels['duplicate.seconds'] = 'тайм-аут (секунд):';
$labels['duplicate.last'] = 'относительно последнего запуска';
$messages['filterunknownerror'] = 'Неизвестная ошибка сервера.';
$messages['filterconnerror'] = 'Невозможно подключиться к серверу.';
$messages['filterdeleteerror'] = 'Невозможно удалить фильтр. Ошибка сервера.';
$messages['filterdeleted'] = 'Фильтр успешно удалён.';
$messages['filtersaved'] = 'Фильтр успешно сохранён.';
$messages['filtersaveerror'] = 'Невозможно сохранить фильтр. Ошибка сервера.';
$messages['filterformerror'] = 'Форма фильтра содержит ошибки.';
$messages['filterdeleteconfirm'] = 'Вы действительно хотите удалить выделенный фильтр?';
$messages['ruledeleteconfirm'] = 'Вы уверенны, что хотите удалить выделенное правило?';
$messages['actiondeleteconfirm'] = 'Вы уверенны, что хотите удалить выделенное действие?';
$messages['forbiddenchars'] = 'Недопустимые символы в поле.';
$messages['cannotbeempty'] = 'Поле не может быть пустым.';
$messages['ruleexist'] = 'Фильтр с таким именем уже существует.';
$messages['setactivateerror'] = 'Невозможно включить выбранный набор фильтров. Ошибка сервера.';
$messages['setdeactivateerror'] = 'Невозможно отключить выбранный набор фильтров. Ошибка сервера.';
$messages['setdeleteerror'] = 'Невозможно удалить выбранный набор фильтров. Ошибка сервера.';
$messages['setactivated'] = 'Набор фильтров успешно включён.';
$messages['setdeactivated'] = 'Набор фильтров успешно отключён.';
$messages['setdeleted'] = 'Набор фильтров успешно удалён.';
$messages['setupdated'] = 'Набор фильтров успешно обновлён.';
$messages['setdeleteconfirm'] = 'Вы уверены в том, что хотите удалить выбранный набор фильтров?';
$messages['setcreateerror'] = 'Невозможно создать набор фильтров. Ошибка сервера.';
$messages['setcreated'] = 'Набор фильтров успешно создан.';
$messages['activateerror'] = 'Невозможно включить выбранный(е) фильтр(ы). Ошибка сервера.';
$messages['deactivateerror'] = 'Невозможно выключить выбранный(е) фильтр(ы). Ошибка сервера.';
$messages['deactivated'] = 'Фильтр(ы) успешно отключен(ы).';
$messages['activated'] = 'Фильтр(ы) успешно включен(ы).';
$messages['moved'] = 'Фильтр успешно перемещён.';
$messages['moveerror'] = 'Невозможно переместить фильтр. Ошибка сервера.';
$messages['nametoolong'] = 'Слишком длинное имя.';
$messages['namereserved'] = 'Зарезервированное имя.';
$messages['setexist'] = 'Набор уже существует.';
$messages['nodata'] = 'Нужно выбрать хотя бы одну позицию!';
$messages['invaliddateformat'] = 'Неверная дата или формат части даты';
$messages['saveerror'] = 'Невозможно сохранить данные. Ошибка сервера.';
$messages['vacationsaved'] = 'Данные об отсутствии успешно сохранены.';
$messages['forwardsaved'] = 'Данные о пересылке успешно сохранены.';
$messages['emptyvacationbody'] = 'Сообщение о причине отсутствия не может быть пустым!';
$messages['duplicate.conflict.err'] = 'Не разрешено использовать заголовок и уникальный идентификатор вместе.';
$messages['disabledaction'] = 'Действие не разрешено.';
$messages['lastindexempty'] = 'Индекс необходим при подсчете с конца';
$messages['noflagset'] = 'Нужно выбрать хотя бы один флаг.';
