<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Razmjena';
$labels['myrights'] = 'Prava pristupa';
$labels['username'] = 'Korisnik:';
$labels['advanced'] = 'Napredni mod';
$labels['add'] = 'Dodaj';
$labels['newuser'] = 'Dodaj unos';
$labels['editperms'] = 'Uredi dozvole';
$labels['actions'] = 'Akcije za prava pristupa...';
$labels['anyone'] = 'Svi korisnici (bilo ko)';
$labels['anonymous'] = 'Gosti (anonimno)';
$labels['identifier'] = 'Identifikator';
$labels['acll'] = 'Pronađi';
$labels['aclr'] = 'Pročitaj poruke';
$labels['acls'] = 'Zadrži stanje pregleda';
$labels['aclw'] = 'Oznake za pisanje';
$labels['acli'] = 'Umetni (Kopiraj u)';
$labels['aclp'] = 'Objavi';
$labels['aclc'] = 'Napravi podfoldere';
$labels['aclk'] = 'Napravi podfoldere';
$labels['acld'] = 'Obriši poruke';
$labels['aclt'] = 'Obriši poruke';
$labels['acle'] = 'Izbriši';
$labels['aclx'] = 'Obriši folder';
$labels['acla'] = 'Administracija';
$labels['acln'] = 'Obilježi poruke';
$labels['aclfull'] = 'Puna kontrola';
$labels['aclother'] = 'Ostalo';
$labels['aclread'] = 'Pročitano';
$labels['aclwrite'] = 'Piši';
$labels['acldelete'] = 'Obriši';
$labels['shortacll'] = 'Pronađi';
$labels['shortaclr'] = 'Pročitano';
$labels['shortacls'] = 'Zadrži';
$labels['shortaclw'] = 'Piši';
$labels['shortacli'] = 'Umetni';
$labels['shortaclp'] = 'Objavi';
$labels['shortaclc'] = 'Kreiraj';
$labels['shortaclk'] = 'Kreiraj';
$labels['shortacld'] = 'Obriši';
$labels['shortaclt'] = 'Obriši';
$labels['shortacle'] = 'Izbriši';
$labels['shortaclx'] = 'Brisanje foldera';
$labels['shortacla'] = 'Administracija';
$labels['shortacln'] = 'Obilježli';
$labels['shortaclother'] = 'Ostalo';
$labels['shortaclread'] = 'Pročitano';
$labels['shortaclwrite'] = 'Piši';
$labels['shortacldelete'] = 'Obriši';
$labels['longacll'] = 'Ovaj folder je vidljiv u listama i moguće je izvršiti pretplatu na njega';
$labels['longaclr'] = 'Folder je moguće otvoriti radi čitanja';
$labels['longacls'] = 'Oznaka čitanja za poruke se može promijeniti';
$labels['longaclw'] = 'Oznake za poruke i ključne riječi je moguće promijeniti, osim za pregledano i obrisano';
$labels['longacli'] = 'Moguće je kopirati i zapisivati poruke u folder';
$labels['longaclp'] = 'Moguće je objavljivati poruke u ovaj folder';
$labels['longaclc'] = 'Moguće je kreirati (ili preimenovati) foldere diretno ispod ovog foldera';
$labels['longaclk'] = 'Moguće je kreirati (ili preimenovati) foldere diretno ispod ovog foldera';
$labels['longacld'] = 'Oznaka za obrisane poruke se može mijenjati';
$labels['longaclt'] = 'Oznaka za obrisane poruke se može mijenjati';
$labels['longacle'] = 'Poruke je moguće obrisati';
$labels['longaclx'] = 'Folder je moguće obrisati ili preimenovati';
$labels['longacla'] = 'Pristupna prava foldera je moguće promijeniti';
$labels['longacln'] = 'Dijeljeni podaci (obilježavanja) poruka mogu se mijenjati';
$labels['longaclfull'] = 'Puna kontrola uključujući i administraciju foldera';
$labels['longaclread'] = 'Folder je moguće otvoriti radi čitanja';
$labels['longaclwrite'] = 'Moguće je označavati, zapisivati i kopirati poruke u folder';
$labels['longacldelete'] = 'Moguće je obrisati poruke';
$labels['longaclother'] = 'Ostala prava pristupa';
$labels['ariasummaryacltable'] = 'Lista prava pristupa';
$labels['arialabelaclactions'] = 'Lista akcija';
$labels['arialabelaclform'] = 'Obrazac za prava pristupa';
$messages['deleting'] = 'Brišem prava pristupa...';
$messages['saving'] = 'Snimam prava pristupa...';
$messages['updatesuccess'] = 'Prava pristupa su uspješno promijenjena';
$messages['deletesuccess'] = 'Prava pristupa su uspješno obrisana';
$messages['createsuccess'] = 'Prava pristupa su uspješno dodana';
$messages['updateerror'] = 'Nije moguće ažurirati prava pristupa';
$messages['deleteerror'] = 'Nije moguće obrisati prava pristupa';
$messages['createerror'] = 'Nije moguće dodati prava pristupa';
$messages['deleteconfirm'] = 'Jeste li sigurni da želite ukloniti prava pristupa za odabrane korisnike?';
$messages['norights'] = 'Niste odabrali prava pristupa!';
$messages['nouser'] = 'Niste odabrali korisničko ime!';
