<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'זמן בינלאומי סטנדרדי';
$labels['tz:africa'] = 'אפריקה';
$labels['tz:africa:abidjan'] = 'אבידג\'אן';
$labels['tz:africa:accra'] = 'אקרה';
$labels['tz:africa:addis_ababa'] = 'אדיס אבבה';
$labels['tz:africa:algiers'] = 'אלג\'יר';
$labels['tz:africa:asmara'] = 'אסמרה';
$labels['tz:africa:bamako'] = 'באמאקו';
$labels['tz:africa:bangui'] = 'באנגוי';
$labels['tz:africa:banjul'] = 'באנג\'ול';
$labels['tz:africa:bissau'] = 'ביסאו';
$labels['tz:africa:blantyre'] = 'בלאנטיר';
$labels['tz:africa:brazzaville'] = 'ברזוויל';
$labels['tz:africa:bujumbura'] = 'בוג\'ומבורה';
$labels['tz:africa:cairo'] = 'קהיר';
$labels['tz:africa:casablanca'] = 'קזבלנקה';
$labels['tz:africa:ceuta'] = 'סיוטה';
$labels['tz:africa:conakry'] = 'קונקרי';
$labels['tz:africa:dakar'] = 'דאקאר';
$labels['tz:africa:dar_es_salaam'] = 'דאר א סלאם';
$labels['tz:africa:djibouti'] = 'ג\'יבוטי';
$labels['tz:africa:douala'] = 'דואלה';
$labels['tz:africa:el_aaiun'] = 'אל עיון';
$labels['tz:africa:freetown'] = 'פריטאון';
$labels['tz:africa:gaborone'] = 'גבורון';
$labels['tz:africa:harare'] = 'האררה';
$labels['tz:africa:johannesburg'] = 'יוהנסבורג';
$labels['tz:africa:juba'] = 'ג\'ובה';
$labels['tz:africa:kampala'] = 'קמפלה';
$labels['tz:africa:khartoum'] = 'חרטום';
$labels['tz:africa:kigali'] = 'קיגאלי';
$labels['tz:africa:kinshasa'] = 'קינשאסה';
$labels['tz:africa:lagos'] = 'לאגוס';
$labels['tz:africa:libreville'] = 'ליברוויל';
$labels['tz:africa:lome'] = 'לומה';
$labels['tz:africa:luanda'] = 'לואנדה';
$labels['tz:africa:lubumbashi'] = 'לובומבאשי';
$labels['tz:africa:lusaka'] = 'לוסאקה';
$labels['tz:africa:malabo'] = 'מלאבו';
$labels['tz:africa:maputo'] = 'מפוטו';
$labels['tz:africa:maseru'] = 'מאסרו';
$labels['tz:africa:mbabane'] = 'מבאבאנה';
$labels['tz:africa:mogadishu'] = 'מוגדישו';
$labels['tz:africa:monrovia'] = 'מונרוביה';
$labels['tz:africa:nairobi'] = 'נאירובי';
$labels['tz:africa:ndjamena'] = 'נדג\'אמנה';
$labels['tz:africa:niamey'] = 'ניאמי';
$labels['tz:africa:nouakchott'] = 'נואקצ\'וט';
$labels['tz:africa:ouagadougou'] = 'אואגדוגו';
$labels['tz:africa:porto-novo'] = 'פורטו נובו';
$labels['tz:africa:sao_tome'] = 'סאו תומה';
$labels['tz:africa:tripoli'] = 'טריפולי';
$labels['tz:africa:tunis'] = 'תוניס';
$labels['tz:africa:windhoek'] = 'ווינדוק';
$labels['tz:america'] = 'אמריקה';
$labels['tz:america:adak'] = 'אדאק';
$labels['tz:america:anchorage'] = 'אנקורג\'';
$labels['tz:america:anguilla'] = 'אנגואייה';
$labels['tz:america:antigua'] = 'אנטיגואה';
$labels['tz:america:araguaina'] = 'אראגואינה';
$labels['tz:america:argentina'] = 'ארגנטינה';
$labels['tz:america:argentina:buenos_aires'] = 'בואנוס איירס';
$labels['tz:america:argentina:catamarca'] = 'קאטאמארקה';
$labels['tz:america:argentina:cordoba'] = 'קורדובה';
$labels['tz:america:argentina:jujuy'] = 'חוחואי';
$labels['tz:america:argentina:la_rioja'] = 'לה ריוחה';
$labels['tz:america:argentina:mendoza'] = 'מנדוסה';
$labels['tz:america:argentina:rio_gallegos'] = 'ריו קאיחוס';
$labels['tz:america:argentina:salta'] = 'סאלטה';
$labels['tz:america:argentina:san_juan'] = 'סן חואן';
$labels['tz:america:argentina:san_luis'] = 'סן לואיס';
$labels['tz:america:argentina:tucuman'] = 'טוקומן';
$labels['tz:america:argentina:ushuaia'] = 'אושואיה';
$labels['tz:america:aruba'] = 'ארובה';
$labels['tz:america:asuncion'] = 'אסונסיון';
$labels['tz:america:atikokan'] = 'אטיקוקן';
$labels['tz:america:bahia'] = 'באהיה';
$labels['tz:america:bahia_banderas'] = 'באהיה בנדראס';
$labels['tz:america:barbados'] = 'ברבדוס';
$labels['tz:america:belem'] = 'בלם';
$labels['tz:america:belize'] = 'בליז';
$labels['tz:america:blanc-sablon'] = 'בלאנק-סבלון';
$labels['tz:america:boa_vista'] = 'בואה ויסטה';
$labels['tz:america:bogota'] = 'בוגוטה';
$labels['tz:america:boise'] = 'בויזי';
$labels['tz:america:cambridge_bay'] = 'קמברידג\' ביי';
$labels['tz:america:campo_grande'] = 'קמפו גרנדה';
$labels['tz:america:cancun'] = 'קנקון';
$labels['tz:america:caracas'] = 'קראקאס';
$labels['tz:america:cayenne'] = 'קאיין';
$labels['tz:america:cayman'] = 'קיימן';
$labels['tz:america:chicago'] = 'שיקגו';
$labels['tz:america:chihuahua'] = 'צ\'יוואוואה';
$labels['tz:america:costa_rica'] = 'קוסטה ריקה';
$labels['tz:america:creston'] = 'קרסטון';
$labels['tz:america:cuiaba'] = 'קולאבה';
$labels['tz:america:curacao'] = 'קורסאו';
$labels['tz:america:danmarkshavn'] = 'דנמרקסהאבן';
$labels['tz:america:dawson'] = 'דוסון';
$labels['tz:america:dawson_creek'] = 'דוסון קריק';
$labels['tz:america:denver'] = 'דנבר';
$labels['tz:america:detroit'] = 'דטרויט';
$labels['tz:america:dominica'] = 'דומיניקה';
$labels['tz:america:edmonton'] = 'אדמונטון';
$labels['tz:america:eirunepe'] = 'איירונפה';
$labels['tz:america:el_salvador'] = 'אל סלבדור';
$labels['tz:america:fort_nelson'] = 'פורט נלסון';
$labels['tz:america:fortaleza'] = 'פורטלסה';
$labels['tz:america:glace_bay'] = 'גלייס ביי';
$labels['tz:america:godthab'] = 'גוטהאב';
$labels['tz:america:goose_bay'] = 'גוס ביי';
$labels['tz:america:grand_turk'] = 'גרנד טרק';
$labels['tz:america:grenada'] = 'גרנדה';
$labels['tz:america:guadeloupe'] = 'גואדלופ';
$labels['tz:america:guatemala'] = 'גואטמלה';
$labels['tz:america:guayaquil'] = 'גואיקיל';
$labels['tz:america:guyana'] = 'גויאנה';
$labels['tz:america:halifax'] = 'האליפקס';
$labels['tz:america:havana'] = 'הבאנה';
$labels['tz:america:hermosillo'] = 'הרמוסיו';
$labels['tz:america:indiana'] = 'אינדיאנה';
$labels['tz:america:indiana:indianapolis'] = 'אינדיאנאפוליס';
$labels['tz:america:indiana:knox'] = 'נוקס';
$labels['tz:america:indiana:marengo'] = 'מרנגו';
$labels['tz:america:indiana:petersburg'] = 'פטרסבורג';
$labels['tz:america:indiana:tell_city'] = 'טל סיטי';
$labels['tz:america:indiana:vevay'] = 'וובאי';
$labels['tz:america:indiana:vincennes'] = 'וויסנס';
$labels['tz:america:indiana:winamac'] = 'ווינמאק';
$labels['tz:america:inuvik'] = 'אינוביק';
$labels['tz:america:iqaluit'] = 'איקאלואיט';
$labels['tz:america:jamaica'] = 'ג\'מאיקה';
$labels['tz:america:juneau'] = 'ג\'ונו';
$labels['tz:america:kentucky'] = 'קנטאקי';
$labels['tz:america:kentucky:louisville'] = 'לואיוויל';
$labels['tz:america:kentucky:monticello'] = 'מונטיצ\'לו';
$labels['tz:america:kralendijk'] = 'קראלנדיק';
$labels['tz:america:la_paz'] = 'לה פס';
$labels['tz:america:lima'] = 'לימה';
$labels['tz:america:los_angeles'] = 'לוס אנג\'לס';
$labels['tz:america:lower_princes'] = 'לואר פרינסס';
$labels['tz:america:maceio'] = 'מסיאו';
$labels['tz:america:managua'] = 'מנאגואה';
$labels['tz:america:manaus'] = 'מנאוס';
$labels['tz:america:marigot'] = 'מאריגוט';
$labels['tz:america:martinique'] = 'מרטיניק';
$labels['tz:america:matamoros'] = 'מטאמורוס';
$labels['tz:america:mazatlan'] = 'מזאטלן';
$labels['tz:america:menominee'] = 'מנומיני';
$labels['tz:america:merida'] = 'מרידה';
$labels['tz:america:metlakatla'] = 'מטלקטלה';
$labels['tz:america:mexico_city'] = 'מקסיקו סיטי';
$labels['tz:america:miquelon'] = 'מיקלון';
$labels['tz:america:moncton'] = 'מונקטון';
$labels['tz:america:monterrey'] = 'מונטריי';
$labels['tz:america:montevideo'] = 'מונטוידיאו';
$labels['tz:america:montserrat'] = 'מונטסראט';
$labels['tz:america:nassau'] = 'נסאו';
$labels['tz:america:new_york'] = 'ניו יורק';
$labels['tz:america:nipigon'] = 'ניפיגון';
$labels['tz:america:nome'] = 'נום';
$labels['tz:america:noronha'] = 'מורוניה';
$labels['tz:america:north_dakota'] = 'נורת\' דקוטה';
$labels['tz:america:north_dakota:beulah'] = 'ביולה';
$labels['tz:america:north_dakota:center'] = 'סנטר';
$labels['tz:america:north_dakota:new_salem'] = 'ניו סיילם';
$labels['tz:america:ojinaga'] = 'אוחינגה';
$labels['tz:america:panama'] = 'פנמה';
$labels['tz:america:pangnirtung'] = 'פאנגנירטונג';
$labels['tz:america:paramaribo'] = 'פראמאריבו';
$labels['tz:america:phoenix'] = 'פיניקס';
$labels['tz:america:port-au-prince'] = 'פורט או פרינס';
$labels['tz:america:port_of_spain'] = 'פורט אוף ספיין';
$labels['tz:america:porto_velho'] = 'פורטו וולהו';
$labels['tz:america:puerto_rico'] = 'פוארטו ריקו';
$labels['tz:america:rainy_river'] = 'רייני ריבר';
$labels['tz:america:rankin_inlet'] = 'ראנקין אינלט';
$labels['tz:america:recife'] = 'רסיפה';
$labels['tz:america:regina'] = 'רגינה';
$labels['tz:america:resolute'] = 'רסולוטה';
$labels['tz:america:rio_branco'] = 'ריו בראנקו';
$labels['tz:america:santarem'] = 'סנטרם';
$labels['tz:america:santiago'] = 'סנטיאגו';
$labels['tz:america:santo_domingo'] = 'סנטו דומינגו';
$labels['tz:america:sao_paulo'] = 'סאו פאולו';
$labels['tz:america:scoresbysund'] = 'סקורסביסונד';
$labels['tz:america:sitka'] = 'סיטקה';
$labels['tz:america:st_barthelemy'] = 'סיינט ברתלמיי';
$labels['tz:america:st_johns'] = "סיינט ג'ונס";
$labels['tz:america:st_kitts'] = 'סיינט קיטס';
$labels['tz:america:st_lucia'] = 'סיינט לוסיה';
$labels['tz:america:st_thomas'] = 'סיינט תומאס';
$labels['tz:america:st_vincent'] = 'סיינט וינסנט';
$labels['tz:america:swift_current'] = 'סוויפט קארנט';
$labels['tz:america:tegucigalpa'] = 'טגוסיגאלפה';
$labels['tz:america:thule'] = 'תול';
$labels['tz:america:thunder_bay'] = 'תאנדר ביי';
$labels['tz:america:tijuana'] = 'טיחואנה';
$labels['tz:america:toronto'] = 'טורונטו';
$labels['tz:america:tortola'] = 'טורטולה';
$labels['tz:america:vancouver'] = 'ונקובר';
$labels['tz:america:whitehorse'] = 'ווייטהורס';
$labels['tz:america:winnipeg'] = 'וויניפג';
$labels['tz:america:yakutat'] = 'יקוטאט';
$labels['tz:america:yellowknife'] = 'יילוונייף';
$labels['tz:antarctica'] = 'אנטרטיקה';
$labels['tz:antarctica:casey'] = 'קייסי';
$labels['tz:antarctica:davis'] = 'דייביס';
$labels['tz:antarctica:dumontdurville'] = "דומון ד'אורויל";
$labels['tz:antarctica:macquarie'] = 'מקארי';
$labels['tz:antarctica:mawson'] = 'מוסון';
$labels['tz:antarctica:mcmurdo'] = 'מקמורדו';
$labels['tz:antarctica:palmer'] = 'פאלמר';
$labels['tz:antarctica:rothera'] = 'רותרה';
$labels['tz:antarctica:syowa'] = 'סאיווה';
$labels['tz:antarctica:troll'] = 'טרול';
$labels['tz:antarctica:vostok'] = 'ווסטוק';
$labels['tz:arctic'] = 'ארקטיק';
$labels['tz:arctic:longyearbyen'] = 'לונגיירביין';
$labels['tz:asia'] = 'אסיה';
$labels['tz:asia:aden'] = 'עדן';
$labels['tz:asia:almaty'] = 'אמאטי';
$labels['tz:asia:amman'] = 'עמאן';
$labels['tz:asia:anadyr'] = 'אנאדיר';
$labels['tz:asia:aqtau'] = 'אקטאו';
$labels['tz:asia:aqtobe'] = 'אקטובה';
$labels['tz:asia:ashgabat'] = 'אשגבאט';
$labels['tz:asia:atyrau'] = 'אטיראו';
$labels['tz:asia:baghdad'] = 'בגדד';
$labels['tz:asia:bahrain'] = 'בחריין';
$labels['tz:asia:baku'] = 'באקו';
$labels['tz:asia:bangkok'] = 'בנגקוק';
$labels['tz:asia:barnaul'] = 'במאול';
$labels['tz:asia:beirut'] = 'ביירות';
$labels['tz:asia:bishkek'] = 'בישקק';
$labels['tz:asia:brunei'] = 'ברוניי';
$labels['tz:asia:chita'] = 'צ\'יטה';
$labels['tz:asia:choibalsan'] = 'צ\'ויבלסן';
$labels['tz:asia:colombo'] = 'קולומבו';
$labels['tz:asia:damascus'] = 'דמשק';
$labels['tz:asia:dhaka'] = 'דאקה';
$labels['tz:asia:dili'] = 'דילי';
$labels['tz:asia:dubai'] = 'דובאי';
$labels['tz:asia:dushanbe'] = 'דושנבה';
$labels['tz:asia:famagusta'] = 'פמגוסטה';
$labels['tz:asia:gaza'] = 'עזה';
$labels['tz:asia:hebron'] = 'חברון';
$labels['tz:asia:ho_chi_minh'] = 'הו צ\'י מין';
$labels['tz:asia:hong_kong'] = 'הונג קונג';
$labels['tz:asia:hovd'] = 'חוווד';
$labels['tz:asia:irkutsk'] = 'אירקוצק';
$labels['tz:asia:jakarta'] = 'ג\'קארטה';
$labels['tz:asia:jayapura'] = 'ג\'איאפורה';
$labels['tz:asia:jerusalem'] = 'ירושלים';
$labels['tz:asia:kabul'] = 'קאבול';
$labels['tz:asia:kamchatka'] = 'קאמצ\'טקה';
$labels['tz:asia:karachi'] = 'קראצ\'י';
$labels['tz:asia:kathmandu'] = 'קתמנדו';
$labels['tz:asia:khandyga'] = 'קאנדיג\'ה';
$labels['tz:asia:kolkata'] = 'כולכתה';
$labels['tz:asia:krasnoyarsk'] = 'קראסנויארסק';
$labels['tz:asia:kuala_lumpur'] = 'קואלה לומפור';
$labels['tz:asia:kuching'] = 'קוצ\'ינג';
$labels['tz:asia:kuwait'] = 'כוויית';
$labels['tz:asia:macau'] = 'מקאו';
$labels['tz:asia:magadan'] = 'מאגאדן';
$labels['tz:asia:makassar'] = 'מקאסר';
$labels['tz:asia:manila'] = 'מנילה';
$labels['tz:asia:muscat'] = 'מוסקט';
$labels['tz:asia:nicosia'] = 'ניקוסיה';
$labels['tz:asia:novokuznetsk'] = 'נובוקוזנצק';
$labels['tz:asia:novosibirsk'] = 'נובוסיבירסק';
$labels['tz:asia:omsk'] = 'אומסק';
$labels['tz:asia:oral'] = 'אורל';
$labels['tz:asia:phnom_penh'] = 'פנום פן';
$labels['tz:asia:pontianak'] = 'פונטיאנאק';
$labels['tz:asia:pyongyang'] = 'פיונגיאנג';
$labels['tz:asia:qatar'] = 'קטאר';
$labels['tz:asia:qyzylorda'] = 'קיזילורדה';
$labels['tz:asia:riyadh'] = 'ריאד';
$labels['tz:asia:sakhalin'] = 'סאחלין';
$labels['tz:asia:samarkand'] = 'סמרקנד';
$labels['tz:asia:seoul'] = 'סיאול';
$labels['tz:asia:shanghai'] = 'שנגחאי';
$labels['tz:asia:singapore'] = 'סינגפור';
$labels['tz:asia:srednekolymsk'] = 'סרדנקולימסק';
$labels['tz:asia:taipei'] = 'טאיפה';
$labels['tz:asia:tashkent'] = 'טשקנט';
$labels['tz:asia:tbilisi'] = 'טביליסי';
$labels['tz:asia:tehran'] = 'טהרן';
$labels['tz:asia:thimphu'] = 'תימפו';
$labels['tz:asia:tokyo'] = 'טוקיו';
$labels['tz:asia:tomsk'] = 'טומסק';
$labels['tz:asia:ulaanbaatar'] = 'אולנבטאר';
$labels['tz:asia:urumqi'] = 'אורומקי';
$labels['tz:asia:ust-nera'] = 'אוסט-נרה';
$labels['tz:asia:vientiane'] = 'ווינטיאן';
$labels['tz:asia:vladivostok'] = 'וולאדיווסטוק';
$labels['tz:asia:yakutsk'] = 'יאקוצק';
$labels['tz:asia:yangon'] = 'יאנגון';
$labels['tz:asia:yekaterinburg'] = 'יקטרינבורג';
$labels['tz:asia:yerevan'] = 'ירוואן';
$labels['tz:atlantic'] = 'אטלנטיק';
$labels['tz:atlantic:azores'] = 'אזוריים';
$labels['tz:atlantic:bermuda'] = 'ברמודה';
$labels['tz:atlantic:canary'] = 'קנארי';
$labels['tz:atlantic:cape_verde'] = 'קייפ וורדה';
$labels['tz:atlantic:faroe'] = 'פארו';
$labels['tz:atlantic:madeira'] = 'מאדיירה';
$labels['tz:atlantic:reykjavik'] = 'רייקיאוויק';
$labels['tz:atlantic:south_georgia'] = 'סאות ג\'ורג\'יה';
$labels['tz:atlantic:st_helena'] = 'סט הלנה';
$labels['tz:atlantic:stanley'] = 'סטנלי';
$labels['tz:australia'] = 'אוסטרליה';
$labels['tz:australia:adelaide'] = 'אדלייד';
$labels['tz:australia:brisbane'] = 'בריסביין';
$labels['tz:australia:broken_hill'] = 'ברוקן היל';
$labels['tz:australia:currie'] = 'קארי';
$labels['tz:australia:darwin'] = 'דארווין';
$labels['tz:australia:eucla'] = 'יוקלה';
$labels['tz:australia:hobart'] = 'הובארט';
$labels['tz:australia:lindeman'] = 'לינדמאן';
$labels['tz:australia:lord_howe'] = 'לורד האווי';
$labels['tz:australia:melbourne'] = 'מלבורן';
$labels['tz:australia:perth'] = 'פרת';
$labels['tz:australia:sydney'] = 'סידני';
$labels['tz:europe'] = 'אירופה';
$labels['tz:europe:amsterdam'] = 'אמסטרדם';
$labels['tz:europe:andorra'] = 'אנדורה';
$labels['tz:europe:astrakhan'] = 'אסטרחאן';
$labels['tz:europe:athens'] = 'אתונה';
$labels['tz:europe:belgrade'] = 'בלגראד';
$labels['tz:europe:berlin'] = 'ברלין';
$labels['tz:europe:bratislava'] = 'ברטיסלאבה';
$labels['tz:europe:brussels'] = 'בריסל';
$labels['tz:europe:bucharest'] = 'בוקרשט';
$labels['tz:europe:budapest'] = 'בודפשט';
$labels['tz:europe:busingen'] = 'בוסינגן';
$labels['tz:europe:chisinau'] = 'קישינב';
$labels['tz:europe:copenhagen'] = 'קופנהאגן';
$labels['tz:europe:dublin'] = 'דבלין';
$labels['tz:europe:gibraltar'] = 'גיברלטר';
$labels['tz:europe:guernsey'] = 'גרנזי';
$labels['tz:europe:helsinki'] = 'הלסינקי';
$labels['tz:europe:isle_of_man'] = 'אייל אוף מאן';
$labels['tz:europe:istanbul'] = 'איסטנבול';
$labels['tz:europe:jersey'] = 'ג\'רזי';
$labels['tz:europe:kaliningrad'] = 'קאלינינגראד';
$labels['tz:europe:kiev'] = 'קייב';
$labels['tz:europe:kirov'] = 'קירוב';
$labels['tz:europe:lisbon'] = 'ליסבון';
$labels['tz:europe:ljubljana'] = 'ליובליאנה';
$labels['tz:europe:london'] = 'לונדון';
$labels['tz:europe:luxembourg'] = 'לוקסמבורג';
$labels['tz:europe:madrid'] = 'מדריד';
$labels['tz:europe:malta'] = 'מאלטה';
$labels['tz:europe:mariehamn'] = 'מריהאם';
$labels['tz:europe:minsk'] = 'מינסק';
$labels['tz:europe:monaco'] = 'מונאקו';
$labels['tz:europe:moscow'] = 'מוסקבה';
$labels['tz:europe:oslo'] = 'אוסלו';
$labels['tz:europe:paris'] = 'פריס';
$labels['tz:europe:podgorica'] = 'פודגוריצה';
$labels['tz:europe:prague'] = 'פראג';
$labels['tz:europe:riga'] = 'ריגה';
$labels['tz:europe:rome'] = 'רומא';
$labels['tz:europe:samara'] = 'סמארה';
$labels['tz:europe:san_marino'] = 'סן מרינו';
$labels['tz:europe:sarajevo'] = 'סראייבו';
$labels['tz:europe:saratov'] = 'סראטוב';
$labels['tz:europe:simferopol'] = 'סימפרופול';
$labels['tz:europe:skopje'] = 'סקופיה';
$labels['tz:europe:sofia'] = 'סופיה';
$labels['tz:europe:stockholm'] = 'סטוקהולם';
$labels['tz:europe:tallinn'] = 'טאלין';
$labels['tz:europe:tirane'] = 'טיראנה';
$labels['tz:europe:ulyanovsk'] = 'אוליאנובסק';
$labels['tz:europe:uzhgorod'] = 'אוז\'גורוד';
$labels['tz:europe:vaduz'] = 'ואדוז';
$labels['tz:europe:vatican'] = 'ותיקן';
$labels['tz:europe:vienna'] = 'וינה';
$labels['tz:europe:vilnius'] = 'וילניוס';
$labels['tz:europe:volgograd'] = 'וולגוגראד';
$labels['tz:europe:warsaw'] = 'ורשה';
$labels['tz:europe:zagreb'] = 'זאגרב';
$labels['tz:europe:zaporozhye'] = 'זאפורוז\'ייה';
$labels['tz:europe:zurich'] = 'ציריך';
$labels['tz:indian'] = 'אינדיאן';
$labels['tz:indian:antananarivo'] = 'אטננריבו';
$labels['tz:indian:chagos'] = 'צ\'אגוס';
$labels['tz:indian:christmas'] = 'כריסטמס';
$labels['tz:indian:cocos'] = 'קוקוס';
$labels['tz:indian:comoro'] = 'קומורו';
$labels['tz:indian:kerguelen'] = 'קרגואלן';
$labels['tz:indian:mahe'] = 'מאהה';
$labels['tz:indian:maldives'] = 'מלדיביים';
$labels['tz:indian:mauritius'] = 'מאוריציוס';
$labels['tz:indian:mayotte'] = 'מאיוט';
$labels['tz:indian:reunion'] = 'ראוניון';
$labels['tz:pacific'] = 'פסיפיק';
$labels['tz:pacific:apia'] = 'אפיה';
$labels['tz:pacific:auckland'] = 'אוקלנד';
$labels['tz:pacific:bougainville'] = 'בוגיינוויל';
$labels['tz:pacific:chatham'] = 'צ\'טהאם';
$labels['tz:pacific:chuuk'] = 'צ\'וק';
$labels['tz:pacific:easter'] = 'איסטר';
$labels['tz:pacific:efate'] = 'אפאטה';
$labels['tz:pacific:enderbury'] = 'אנדרבורי';
$labels['tz:pacific:fakaofo'] = 'פקאופו';
$labels['tz:pacific:fiji'] = 'פיג\'י';
$labels['tz:pacific:funafuti'] = 'פונאפוטי';
$labels['tz:pacific:galapagos'] = 'גלאפאגוס';
$labels['tz:pacific:gambier'] = 'גאמבייר';
$labels['tz:pacific:guadalcanal'] = 'גואדאלקנאל';
$labels['tz:pacific:guam'] = 'גואם';
$labels['tz:pacific:honolulu'] = 'הונולולו';
$labels['tz:pacific:johnston'] = 'ג\'ונסטון';
$labels['tz:pacific:kiritimati'] = 'קיריטימאטי';
$labels['tz:pacific:kosrae'] = 'קושאי';
$labels['tz:pacific:kwajalein'] = 'קוואז\'אליין';
$labels['tz:pacific:majuro'] = 'מאז\'ורו';
$labels['tz:pacific:marquesas'] = 'מארקסאס';
$labels['tz:pacific:midway'] = 'מידוויי';
$labels['tz:pacific:nauru'] = 'נאורו';
$labels['tz:pacific:niue'] = 'ניואיי';
$labels['tz:pacific:norfolk'] = 'נורפוק';
$labels['tz:pacific:noumea'] = 'נומיאה';
$labels['tz:pacific:pago_pago'] = 'פאגו פאגו';
$labels['tz:pacific:palau'] = 'פאלאו';
$labels['tz:pacific:pitcairn'] = 'פיטקרן';
$labels['tz:pacific:pohnpei'] = 'פונפיי';
$labels['tz:pacific:port_moresby'] = 'פורט מורסבי';
$labels['tz:pacific:rarotonga'] = 'רארוטונגה';
$labels['tz:pacific:saipan'] = 'סאיפאן';
$labels['tz:pacific:tahiti'] = 'טהיטי';
$labels['tz:pacific:tarawa'] = 'טאראווה';
$labels['tz:pacific:tongatapu'] = 'טונגטאפו';
$labels['tz:pacific:wake'] = 'ווייק';
$labels['tz:pacific:wallis'] = 'ווליס';
