<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Dalinimasis';
$labels['myrights'] = 'Prieigos teisės';
$labels['username'] = 'Vartotojas:';
$labels['advanced'] = 'Pažengusio vartotojo rėžimas';
$labels['add'] = 'Pridėti';
$labels['newuser'] = 'Pridėti įrašą';
$labels['editperms'] = 'Tvarkyti leidimus';
$labels['actions'] = 'Prieigos teisių veiksmai...';
$labels['anyone'] = 'Visi vartotojai (bet kas)';
$labels['anonymous'] = 'Svečias (anonimas)';
$labels['identifier'] = 'Identifikatorius';
$labels['acll'] = 'Paieška';
$labels['aclr'] = 'Perskaityti pranešimus';
$labels['acls'] = 'Palikti būseną "Žiūrėtas"';
$labels['aclw'] = 'Įrašyti vėliavėles';
$labels['acli'] = 'Įterpti (kopijuoti į)';
$labels['aclp'] = 'Įrašas';
$labels['aclc'] = 'Kurti poaplankius';
$labels['aclk'] = 'Kurti poaplankius';
$labels['acld'] = 'Ištrinti žinutes';
$labels['aclt'] = 'Ištrinti žinutes';
$labels['acle'] = 'Išbraukti';
$labels['aclx'] = 'Ištrinti aplanką';
$labels['acla'] = 'Valdyti';
$labels['acln'] = 'Anotuoti laiškus';
$labels['aclfull'] = 'Visiška kontrolė';
$labels['aclother'] = 'Kita';
$labels['aclread'] = 'Skaityti';
$labels['aclwrite'] = 'Įrašyti';
$labels['acldelete'] = 'Trinti';
$labels['shortacll'] = 'Paieška';
$labels['shortaclr'] = 'Skaityti';
$labels['shortacls'] = 'Palikti';
$labels['shortaclw'] = 'Įrašyti';
$labels['shortacli'] = 'Įterpti';
$labels['shortaclp'] = 'Įrašas';
$labels['shortaclc'] = 'Sukurti';
$labels['shortaclk'] = 'Sukurti';
$labels['shortacld'] = 'Trinti';
$labels['shortaclt'] = 'Trinti';
$labels['shortacle'] = 'Išbraukti';
$labels['shortaclx'] = 'Ištrinti aplanką';
$labels['shortacla'] = 'Valdyti';
$labels['shortacln'] = 'Anotuoti';
$labels['shortaclother'] = 'Kita';
$labels['shortaclread'] = 'Skaityti';
$labels['shortaclwrite'] = 'Įrašyti';
$labels['shortacldelete'] = 'Trinti';
$labels['longacll'] = 'Aplankas yra matomas sąrašuose ir gali būti prenumeruojamas';
$labels['longaclr'] = 'Aplanką galima peržiūrėti';
$labels['longacls'] = 'Pranešimų vėliavėlė "Matyta" gali būti pakeista';
$labels['longaclw'] = 'Pranešimų vėliavėlės ir raktažodžiai gali būti pakeisti, išskyrus "Matytas" ir "Ištrintas"';
$labels['longacli'] = 'Pranešimai gali būti įrašyti arba nukopijuoti į aplanką';
$labels['longaclp'] = 'Į šį aplanką galima dėti laiškus.';
$labels['longaclc'] = 'Nauji aplankai gali būti kuriami (arba pervadinami) šioje direktorijoje';
$labels['longaclk'] = 'Nauji aplankai gali būti kuriami (arba pervadinami) šioje direktorijoje';
$labels['longacld'] = 'Pranešimų vėliavėlė "Ištrintas" gali būti pakeista';
$labels['longaclt'] = 'Pranešimų vėliavėlė "Ištrintas" gali būti pakeista';
$labels['longacle'] = 'Pranešimai gali būti išbraukti';
$labels['longaclx'] = 'Aplankas gali būti pašalintas arba pervadintas';
$labels['longacla'] = 'Aplanko prieigos teisės gali būti pakeistos';
$labels['longacln'] = 'Bendrieji laiškų meta-duomenys (anotacijos) gali būti pakeisti';
$labels['longaclfull'] = 'Visiška kontrolė įskaitant aplanko administravimą';
$labels['longaclread'] = 'Aplanką galima peržiūrėti';
$labels['longaclwrite'] = 'Pranešimai gali būti pažymėti, įrašyti arba nukopijuoti į aplanką';
$labels['longacldelete'] = 'Pranešimai gali būti ištrinti';
$labels['longaclother'] = 'Kitos prieigos teisės';
$labels['ariasummaryacltable'] = 'Prieigos teisių sąrašas';
$labels['arialabelaclactions'] = 'Rodyti veiksmus';
$labels['arialabelaclform'] = 'Prieigos teisių forma';
$messages['deleting'] = 'Panaikinamos prieigos teisės';
$messages['saving'] = 'Išsaugomos prieigos teisės';
$messages['updatesuccess'] = 'Prieigos teisės sėkmingai pakeistos';
$messages['deletesuccess'] = 'Prieigos teisės sėkmingai panaikintos';
$messages['createsuccess'] = 'Prieigos teisės sėkmingai pridėtos';
$messages['updateerror'] = 'Nepavyko pakeisti prieigos teisių';
$messages['deleteerror'] = 'Neįmanoma panaikinti prieigos teises';
$messages['createerror'] = 'Neišeina pridėti prieigos teises';
$messages['deleteconfirm'] = 'Ar jūs esate įsitikinę, jog norite panaikinti prieigos teises pažymėtiems vartotojams(-ui)?';
$messages['norights'] = 'Nenurodytos jokios teisės!';
$messages['nouser'] = 'Nenurodytas joks vartotojas!';
