<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'اشتراک گذاری';
$labels['myrights'] = 'حقوق دسترسی';
$labels['username'] = 'کاربر:';
$labels['advanced'] = 'حالت پیشرفته';
$labels['add'] = 'افزودن';
$labels['newuser'] = 'افزودن مدخل';
$labels['editperms'] = 'ویرایش مجوزها';
$labels['actions'] = 'فعالیت‌های حق دسترسی...';
$labels['anyone'] = 'همه‌ی کاربران (هر کسی)';
$labels['anonymous'] = 'مهمان‌ها (ناشناس)';
$labels['identifier'] = 'شناسه';
$labels['acll'] = 'یافتن';
$labels['aclr'] = 'خواندن پیام';
$labels['acls'] = 'نگه داشتن حالت بازدید';
$labels['aclw'] = 'نوشتن نشانه ها';
$labels['acli'] = 'درج (رونوشت در)';
$labels['aclp'] = 'ارسال';
$labels['aclc'] = 'ایجاد زیرپوشه‌ها';
$labels['aclk'] = 'ایجاد زیرپوشه‌ها';
$labels['acla'] = 'مدیر';
$labels['aclfull'] = 'کنترل کامل';
$labels['aclother'] = 'دیگر';
$labels['aclread'] = 'خواندن';
$labels['acldelete'] = 'حذف';
$labels['shortacll'] = 'یافتن';
$labels['shortaclr'] = 'خواندن';
$labels['shortaclp'] = 'ارسال';
$labels['shortaclc'] = 'ایجاد کردن';
$labels['shortaclk'] = 'ایجاد کردن';
$labels['shortacld'] = 'حذف';
$labels['shortaclt'] = 'حذف';
$labels['shortacla'] = 'مدیر';
$labels['shortaclother'] = 'دیگر';
$labels['shortaclread'] = 'خواندن';
$labels['shortacldelete'] = 'حذف';
