<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Userinfo plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['userinfo'] = 'Infos utilisateur';
$labels['infoforuser'] = 'Renseignements pour $user';
$labels['created'] = 'Créé';
$labels['lastlogin'] = 'Dernière connexion';
$labels['defaultidentity'] = 'Identité par défaut';
$labels['userid'] = 'ID';
