<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'Африка';
$labels['tz:africa:abidjan'] = 'Абіджан';
$labels['tz:africa:accra'] = 'Аккра';
$labels['tz:africa:addis_ababa'] = 'Аддис-Абеба';
$labels['tz:africa:algiers'] = 'Алжир';
$labels['tz:africa:asmara'] = 'Асмера';
$labels['tz:africa:bamako'] = 'Бамако';
$labels['tz:africa:bangui'] = 'Бангі';
$labels['tz:africa:banjul'] = 'Банжул';
$labels['tz:africa:bissau'] = 'Бісау';
$labels['tz:africa:blantyre'] = 'Блантайр';
$labels['tz:africa:brazzaville'] = 'Браззавіль';
$labels['tz:africa:bujumbura'] = 'Бужумбура';
$labels['tz:africa:cairo'] = 'Каїр';
$labels['tz:africa:casablanca'] = 'Касабланка';
$labels['tz:africa:ceuta'] = 'Сеута';
$labels['tz:africa:conakry'] = 'Конакрі';
$labels['tz:africa:dakar'] = 'Дакар';
$labels['tz:africa:dar_es_salaam'] = 'Дар-ес-Салам';
$labels['tz:africa:djibouti'] = 'Джибуті';
$labels['tz:africa:douala'] = 'Дуала';
$labels['tz:africa:el_aaiun'] = 'Ель-Аюн';
$labels['tz:africa:freetown'] = 'Фрітаун';
$labels['tz:africa:gaborone'] = 'Ґабороне';
$labels['tz:africa:harare'] = 'Хараре';
$labels['tz:africa:johannesburg'] = 'Йоханнесбург';
$labels['tz:africa:juba'] = 'Джуба';
$labels['tz:africa:kampala'] = 'Кампала';
$labels['tz:africa:khartoum'] = 'Хартум';
$labels['tz:africa:kigali'] = 'Кіґалі';
$labels['tz:africa:kinshasa'] = 'Кіншаса';
$labels['tz:africa:lagos'] = 'Лаґос';
$labels['tz:africa:libreville'] = 'Лібревіль';
$labels['tz:africa:lome'] = 'Ломе';
$labels['tz:africa:luanda'] = 'Луанда';
$labels['tz:africa:lubumbashi'] = 'Лумумбаші';
$labels['tz:africa:lusaka'] = 'Лусака';
$labels['tz:africa:malabo'] = 'Малабо';
$labels['tz:africa:maputo'] = 'Мапуту';
$labels['tz:africa:maseru'] = 'Масеру';
$labels['tz:africa:mbabane'] = 'Мбабане';
$labels['tz:africa:mogadishu'] = 'Моґадішо';
$labels['tz:africa:monrovia'] = 'Монровія';
$labels['tz:africa:nairobi'] = 'Найробі';
$labels['tz:africa:ndjamena'] = 'Нджамена';
$labels['tz:africa:niamey'] = 'Ніамей';
$labels['tz:africa:nouakchott'] = 'Нуакшот';
$labels['tz:africa:ouagadougou'] = 'Уаґадуґу';
$labels['tz:africa:porto-novo'] = 'Порто-Ново';
$labels['tz:africa:sao_tome'] = 'Сан-Томе';
$labels['tz:africa:tripoli'] = 'Триполі';
$labels['tz:africa:tunis'] = 'Туніс';
$labels['tz:africa:windhoek'] = 'Віндгук';
$labels['tz:america'] = 'Америка';
$labels['tz:america:adak'] = 'Адак';
$labels['tz:america:anchorage'] = 'Анкоридж';
$labels['tz:america:anguilla'] = 'Анґілья';
$labels['tz:america:antigua'] = 'Антигуа';
$labels['tz:america:araguaina'] = 'Арагуаіна';
$labels['tz:america:argentina'] = 'Аргентина';
$labels['tz:america:argentina:buenos_aires'] = 'Буенос-Айрес';
$labels['tz:america:argentina:catamarca'] = 'Катамарка';
$labels['tz:america:argentina:cordoba'] = 'Кордова';
$labels['tz:america:argentina:jujuy'] = 'Джуджуй';
$labels['tz:america:argentina:la_rioja'] = 'Ла-Ріоха';
$labels['tz:america:argentina:mendoza'] = 'Мендоса';
$labels['tz:america:argentina:rio_gallegos'] = 'Ріо-Ґальєґос';
$labels['tz:america:argentina:salta'] = 'Сальта';
$labels['tz:america:argentina:san_juan'] = 'Сан-Хуан';
$labels['tz:america:argentina:san_luis'] = 'Сан-Луїс';
$labels['tz:america:argentina:tucuman'] = 'Тукуман';
$labels['tz:america:argentina:ushuaia'] = 'Ушуая';
$labels['tz:america:aruba'] = 'Аруба';
$labels['tz:america:asuncion'] = 'Асунсьйон';
$labels['tz:america:atikokan'] = 'Атікокан';
$labels['tz:america:bahia'] = 'Баїя';
$labels['tz:america:bahia_banderas'] = 'Баїя-де-Бандерас';
$labels['tz:america:barbados'] = 'Барбадос';
$labels['tz:america:belem'] = 'Белен';
$labels['tz:america:belize'] = 'Беліз';
$labels['tz:america:blanc-sablon'] = 'Блан-Саблон';
$labels['tz:america:boa_vista'] = 'Боа-Віста';
$labels['tz:america:bogota'] = 'Богота';
$labels['tz:america:boise'] = 'Бойсе';
$labels['tz:america:cambridge_bay'] = 'Кеймбрідж-Бей';
$labels['tz:america:campo_grande'] = 'Кампу-Гранде';
$labels['tz:america:cancun'] = 'Канкун';
$labels['tz:america:caracas'] = 'Каракас';
$labels['tz:america:cayenne'] = 'Каєнна';
$labels['tz:america:cayman'] = 'Кайманові Острови';
$labels['tz:america:chicago'] = 'Чикаго';
$labels['tz:america:chihuahua'] = 'Чихуахуа';
$labels['tz:america:costa_rica'] = 'Коста-Рика';
$labels['tz:america:creston'] = 'Крестон';
$labels['tz:america:cuiaba'] = 'Куяба';
$labels['tz:america:curacao'] = 'Кюрасао';
$labels['tz:america:danmarkshavn'] = 'Данмарксхавн';
$labels['tz:america:dawson'] = 'Довсон';
$labels['tz:america:dawson_creek'] = 'Довсон-Крік';
$labels['tz:america:denver'] = 'Денвер';
$labels['tz:america:detroit'] = 'Детройт';
$labels['tz:america:dominica'] = 'Домініка';
$labels['tz:america:edmonton'] = 'Едмонтон';
$labels['tz:america:eirunepe'] = 'Эйрунепе';
$labels['tz:america:el_salvador'] = 'Сальвадор';
$labels['tz:america:fort_nelson'] = 'Форт-Нельсон';
$labels['tz:america:fortaleza'] = 'Форталеза';
$labels['tz:america:glace_bay'] = 'Глейс-Бей';
$labels['tz:america:godthab'] = 'Готгоб';
$labels['tz:america:guadeloupe'] = 'Гваделупа';
$labels['tz:america:guatemala'] = 'Гватемала';
$labels['tz:america:guyana'] = 'Гаяна';
$labels['tz:america:havana'] = 'Гавана';
$labels['tz:america:indiana:indianapolis'] = 'Індіанаполіс';
$labels['tz:america:jamaica'] = 'Ямайка';
$labels['tz:america:kentucky'] = 'Кентуккі';
$labels['tz:america:los_angeles'] = 'Лос-Анджелес';
$labels['tz:america:new_york'] = 'Нью-Йорк';
$labels['tz:america:north_dakota'] = 'Північна Дакота';
$labels['tz:america:panama'] = 'Панама';
$labels['tz:america:santo_domingo'] = 'Санто-Домінго';
$labels['tz:america:vancouver'] = 'Ванкувер';
$labels['tz:antarctica'] = 'Антарктика';
$labels['tz:asia'] = 'Азія';
$labels['tz:asia:almaty'] = 'Алмати';
$labels['tz:asia:ashgabat'] = 'Ашгабат';
$labels['tz:asia:baghdad'] = 'Багдад';
$labels['tz:asia:bahrain'] = 'Бахрейн';
$labels['tz:asia:baku'] = 'Баку';
$labels['tz:asia:bangkok'] = 'Бангкок';
$labels['tz:asia:barnaul'] = 'Барнаул';
$labels['tz:asia:beirut'] = 'Бейрут';
$labels['tz:asia:bishkek'] = 'Бішкек';
$labels['tz:asia:dubai'] = 'Дубай';
$labels['tz:asia:dushanbe'] = 'Душанбе';
$labels['tz:asia:gaza'] = 'Газа';
$labels['tz:asia:hong_kong'] = 'Гонконг';
$labels['tz:asia:irkutsk'] = 'Іркутськ';
$labels['tz:asia:jakarta'] = 'Джакарта';
$labels['tz:asia:jerusalem'] = 'Єрусалим';
$labels['tz:asia:kabul'] = 'Кабул';
$labels['tz:asia:kathmandu'] = 'Катманду';
$labels['tz:asia:krasnoyarsk'] = 'Красноярськ';
$labels['tz:asia:kuwait'] = 'Кувейт';
$labels['tz:asia:magadan'] = 'Магадан';
$labels['tz:asia:novosibirsk'] = 'Новосибірськ';
$labels['tz:asia:omsk'] = 'Омськ';
$labels['tz:asia:qatar'] = 'Катар';
$labels['tz:asia:sakhalin'] = 'Сахалін';
$labels['tz:asia:seoul'] = 'Сеул';
$labels['tz:asia:shanghai'] = 'Шанхай';
$labels['tz:asia:tashkent'] = 'Ташкент';
$labels['tz:asia:tbilisi'] = 'Тбілісі';
$labels['tz:asia:tokyo'] = 'Токіо';
$labels['tz:asia:tomsk'] = 'Томськ';
$labels['tz:asia:vladivostok'] = 'Владивосток';
$labels['tz:asia:yekaterinburg'] = 'Єкатеринбург';
$labels['tz:asia:yerevan'] = 'Єреван';
$labels['tz:atlantic:reykjavik'] = 'Рейк\'явік';
$labels['tz:australia'] = 'Австралія';
$labels['tz:australia:sydney'] = 'Сідней';
$labels['tz:europe'] = 'Європа';
$labels['tz:europe:amsterdam'] = 'Амстердам';
$labels['tz:europe:astrakhan'] = 'Астрахань';
$labels['tz:europe:berlin'] = 'Берлін';
$labels['tz:europe:bratislava'] = 'Братислава';
$labels['tz:europe:bucharest'] = 'Бухарест';
$labels['tz:europe:budapest'] = 'Будапешт';
$labels['tz:europe:dublin'] = 'Дублін';
$labels['tz:europe:gibraltar'] = 'Гібралтар';
$labels['tz:europe:helsinki'] = 'Гельсінкі';
$labels['tz:europe:istanbul'] = 'Стамбул';
$labels['tz:europe:kaliningrad'] = 'Калінінград';
$labels['tz:europe:kiev'] = 'Київ';
$labels['tz:europe:london'] = 'Лондон';
$labels['tz:europe:madrid'] = 'Мадрид';
$labels['tz:europe:malta'] = 'Мальта';
$labels['tz:europe:minsk'] = 'Мінськ';
$labels['tz:europe:monaco'] = 'Монако';
$labels['tz:europe:moscow'] = 'Москва';
$labels['tz:europe:oslo'] = 'Осло';
$labels['tz:europe:paris'] = 'Париж';
$labels['tz:europe:prague'] = 'Прага';
$labels['tz:europe:riga'] = 'Рига';
$labels['tz:europe:simferopol'] = 'Сімферополь';
$labels['tz:europe:tallinn'] = 'Таллінн';
$labels['tz:europe:ulyanovsk'] = 'Ульяновськ';
$labels['tz:europe:uzhgorod'] = 'Ужгород';
$labels['tz:europe:vatican'] = 'Ватикан';
$labels['tz:europe:vilnius'] = 'Вільнюс';
$labels['tz:europe:zagreb'] = 'Загреб';
$labels['tz:europe:zaporozhye'] = 'Запоріжжя';
$labels['tz:europe:zurich'] = 'Цюрих';
$labels['tz:indian:maldives'] = 'Мальдіви';
$labels['tz:pacific:honolulu'] = 'Гонолулу';
