<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['changepasswd']  = 'Wijzig wachtwoord';
$labels['curpasswd']  = 'Huidig wachtwoord:';
$labels['newpasswd']  = 'Nieuw wachtwoord:';
$labels['confpasswd']  = 'Bevestig nieuw wachtwoord:';
$messages['nopassword'] = 'Voeg aub nieuw wachtwoord in.';
$messages['nocurpassword'] = 'Voeg aub huidig wachtwoord in.';
$messages['passwordincorrect'] = 'Huidig wachtwoord incorrect.';
$messages['passwordinconsistency'] = 'Wachtwoorden komen niet overeen, probeer nogmaals.';
$messages['crypterror'] = 'Nieuw wachtwoord niet bewaard. Encryptie-functie ontbreekt.';
$messages['connecterror'] = 'Nieuw wachtwoord niet bewaard. Verbindingsfout.';
$messages['internalerror'] = 'Nieuw wachtwoord niet bewaard.';
$messages['passwordshort'] = 'Wachtwoord moet ten minste $length tekens lang zijn.';
$messages['passwordweak'] = 'Wachtwoord moet ten minste één getal en één leesteken bevatten.';
$messages['passwordforbidden'] = 'Wachtwoord bevat ongeldige tekens.';
$messages['firstloginchange'] = 'Dit is uw eerste login. Gelieve uw wachtwoord te wijzigen.';
$messages['disablednotice'] = 'Het systeem is momenteel in onderhoud en het wijzigen van een wachtwoord is momenteel niet mogelijk. Alles zou binnenkort terug normaal moeten werken. We verontschuldigen ons voor het ongemak.';
