<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'ប័ណ្ណសារ';
$labels['buttontitle'] = 'ធ្វើ​សារ​នេះ​ជា​បណ្ណសារ';
$labels['archived'] = 'ធ្វើ​ជា​បណ្ណសារ​បាន​សម្រេច';
$labels['archivedreload'] = 'ធ្វើ​ជា​បណ្ណសារ​បាន​សម្រេច។ ផ្ទុក​ទំព័រ​ឡើង​វិញ ដើម្បី​មើល​ថត​បណ្ណសារ​ថ្មី។';
$labels['archiveerror'] = 'សារ​ខ្លះ​មិន​អាច​ត្រូវ​បាន​ធ្វើ​ជា​បណ្ណសារ​ទេ';
$labels['archivefolder'] = 'ប័ណ្ណសារ';
$labels['settingstitle'] = 'បណ្ណសារ';
$labels['archivetype'] = 'ចែក​បណ្ណសារ​តាម';
$labels['archivetypeyear'] = 'ឆ្នាំ (ឧទា. បណ្ណសារ/2012)';
$labels['archivetypemonth'] = 'ខែ (ឧទា. បណ្ណសារ/2012/06)';
$labels['archivetypefolder'] = 'ថត​ដើម';
$labels['archivetypesender'] = 'អ្នក​ផ្ញើ​អ៊ីមែល';
$labels['unkownsender'] = 'មិន​ស្គាល់';
