<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Enigma plugin              |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['encryption'] = 'Krüpteerimine';
$labels['enigmacerts'] = 'S/MIME sertifikaadid';
$labels['enigmakeys'] = 'PGP võtmed';
$labels['keyname'] = 'Nimi';
$labels['keyid'] = 'Võtme ID';
$labels['keyuserid'] = 'Kasutaja ID';
$labels['keytype'] = 'Võtme tüüp';
$labels['fingerprint'] = 'Sõrmejälg';
$labels['keyprops'] = 'Võtme omadused';
$labels['userids'] = 'Lisakasutajad';
$labels['typepublickey'] = 'avalik võti';
$labels['typekeypair'] = 'võtme paar';
$labels['keyattimport'] = 'Impordi võti';
$labels['typesign'] = 'Allkirjasta';
$labels['typeencrypt'] = 'Krüpti';
$labels['typecert'] = 'Sertifitseeri';
$labels['typeauth'] = 'Autentimine';
$labels['subkeyid'] = 'ID';
$labels['subkeyalgo'] = 'Algoritm';
$labels['subkeycreated'] = 'Loodud';
$labels['subkeyexpires'] = 'Aegub';
$labels['subkeyusage'] = 'Kasutus';
$labels['expiresnever'] = 'mitte kunagi';
$labels['unknown'] = 'teadmata';
$labels['uservalid'] = 'Kehtiv';
$labels['userid'] = 'ID';
$labels['valid'] = 'kehtiv';
$labels['nminutes'] = '$m minute(it)';
$labels['wholesession'] = 'kogu sessioon';
$labels['createkeys'] = 'Loo uus võtme paar';
$labels['importkeys'] = 'Impordi võti';
$labels['keyremove'] = 'Eemalda';
$labels['keydisable'] = 'Keela';
$labels['keychpass'] = 'Muuda parooli';
$labels['keyadd'] = 'Lisa võti';
$labels['newkeyident'] = 'Identiteet';
$labels['newkeypass'] = 'Parool';
$labels['newkeypassconfirm'] = 'Kinnita parooli';
$labels['newkeytype'] = 'Võtme tüüp';
$labels['rsa2048'] = 'RSA - 2048 bitti';
$labels['rsa4096'] = 'RSA - 4096 bitti';
$labels['ecckeypair'] = 'ECC (elliptiline kurv)';
$labels['keygenerating'] = 'Võtmete genereerimine...';
$labels['encryptionoptions'] = 'Krüpteerimise valikud...';
$labels['encryptmsg'] = 'Krüpteeri see sõnum';
$labels['attachpubkeymsg'] = 'Lisa minu avalik võti';
$labels['onlypubkeys'] = 'Ekspordi ainult avalikud võtmed';
$labels['withprivkeys'] = 'Ekspordi salavõtmed';
$labels['keyimportlabel'] = 'Impordi failist';
$labels['managekeys'] = 'Halda PGP võtmeid';
$labels['arialabelkeyoptions'] = 'Võtme valikud';
$messages['encrypterror'] = 'Krüpteerimine ebaõnnestus.';
$messages['nokeysfound'] = 'Võtmeid ei leitud';
$messages['keynotfound'] = 'Võtit ei leitud!';
$labels['newkeysize'] = 'Võtme suurus';
$labels['key2048'] = '2048 bitti - vailimisi';
$labels['key4096'] = '4096 bitti - turvalisem';
