<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Bir sorun çıktı!';
$messages['loginfailed']  = 'Oturum açılamadı.';
$messages['cookiesdisabled'] = 'Tarayıcınız tanımlama bilgilerini kabul etmiyor.';
$messages['sessionerror'] = 'Oturumunuzun süresi geçmiş ya da geçersiz.';
$messages['cookiesmismatch'] = 'Tanımlama bilgileri uyuşmuyor. Lütfen tarayıcınızın tanımlama bilgilerini silin.';
$messages['storageerror'] = 'IMAP sunucusu ile bağlantı kurulamadı.';
$messages['servererror'] = 'Sunucu sorunu!';
$messages['servererrormsg'] = 'Sunucu sorunu: $msg';
$messages['accountlocked'] = 'Çok fazla başarısız oturum açma girişimi yapıldı. Bir süre sonra yeniden deneyin.';
$messages['connerror'] = 'Bağlantı sorunu (sunucuya erişilemedi)!';
$messages['dberror'] = 'Veri tabanı sorunu!';
$messages['dbconnerror'] = 'Veri tabanı bağlantısı kurulamadı!';
$messages['windowopenerror'] = 'Açılan pencere engellendi!';
$messages['requesttimedout'] = 'İstek zaman aşımına uğradı';
$messages['errorreadonly'] = 'İşlem gerçekleştirilemedi. Klasör salt okunur.';
$messages['errornoperm'] = 'İşlem gerçekleştirilemedi. İzinler yetersiz.';
$messages['erroroverquota'] = 'Boş alan olmadığından işlem yapılamadı.';
$messages['erroroverquotadelete'] = 'Diskte boş alan kalmadı. SHIFT+DEL tuşlarına basarak iletiyi silin.';
$messages['invalidrequest'] = 'İstek geçersiz! Herhangi bir veri kaydedilmedi';
$messages['invalidhost'] = 'Sunucu adı geçersiz.';
$messages['nomessagesfound'] = 'Bu e-posta kutusunda bir ileti bulunamadı.';
$messages['loggedout'] = 'Oturumunuzu kapattınız. Hoşça kalın!';
$messages['mailboxempty'] = 'E-posta kutusu boş';
$messages['nomessages'] = 'Herhangi bir ileti yok';
$messages['refreshing'] = 'Yenileniyor...';
$messages['loading'] = 'Yükleniyor...';
$messages['uploading'] = 'Dosya yükleniyor...';
$messages['attaching'] = 'Dosya ekle...';
$messages['uploadingmany'] = 'Dosyalar yükleniyor...';
$messages['loadingdata'] = 'Veriler yükleniyor...';
$messages['checkingmail'] = 'Yeni iletiler denetleniyor...';
$messages['sendingmessage'] = 'İleti gönderiliyor...';
$messages['messagesent'] = 'İleti gönderildi.';
$messages['savingmessage'] = 'İleti kaydediliyor...';
$messages['messagesaved'] = 'İleti taslaklara kaydedildi.';
$messages['successfullysaved'] = 'Kaydedildi';
$messages['savingresponse'] = 'Yanıt içeriği kaydediliyor...';
$messages['deleteresponseconfirm'] = 'Bu yanıt içeriğini silmek istediğinize emin misiniz?';
$messages['nocontactselected'] = 'Henüz bir kişi seçmemişsiniz.';
$messages['addedsuccessfully'] = 'Kişi adres defterine eklendi';
$messages['contactexists'] = 'Bu e-posta adresi rehberde var.';
$messages['contactnameexists'] = 'Rehberde aynı adlı biri zaten var.';
$messages['blockedimages'] = 'Kişisel gizliliğinizi korumak amacıyla iletideki görseller engellendi.';
$messages['blockedresources'] = 'Kişisel gizliliğinizi korumak amacıyla iletideki uzak kaynaklar engellendi.';
$messages['suspiciousemail'] = 'Bu iletide sahte olabilecek şüpheli e-posta adresleri var.';
$messages['bccemail'] = 'İletilmiş iletilerde gizli alıcılar (Bcc) var.';
$messages['bouncehint'] = 'İleti herhangi bir değişiklik yapılmadan gönderilecek. Özgün içerik, üst bilgi ve alıcılar korunacak.';
$messages['encryptedmessage'] = 'Bu ileti şifrelenmiş olduğundan görüntülenemiyor.';
$messages['externalmessagedecryption'] = 'Bu ileti şifrelenmiş ve şifresi tarayıcınızın eklentileri ile çözülebilir.';
$messages['nopubkeyfor'] = '$email için geçerli bir herkese açık anahtar bulunamadı';
$messages['nopubkeyforsender'] = 'Göndericinin herkese açık anahtar kimliği bulunamadı. İletinin yalnızca alıcılar için şifrelenmesini ister misiniz?';
$messages['encryptnoattachments'] = 'Yüklediğiniz ek dosyalar şifrelenmemiş. Lütfen dosya eklerini yeniden şifreleme düzenleyicisine ekleyin.';
$messages['searchpubkeyservers'] = 'Kayıp anahtarları herkese açık anahtar sunucularında aramak ister misiniz?';
$messages['encryptpubkeysfound'] = 'Aşağıdaki herkese açık anahtarlar bulundu:';
$messages['keyservererror'] = 'Anahtar, anahtar sunucusundan alınamadı.';
$messages['keyimportsuccess'] = '$key herkese açık anahtarı, anahtarlığınızın içine aktarıldı.';
$messages['nocontactsfound'] = 'Uygun bir kişi bulunamadı';
$messages['contactnotfound'] = 'Aranan kişi bulunamadı';
$messages['contactsearchonly'] = 'Seçilmiş adres defterindeki kişileri görüntülemek için bir arama formunu kullanmalısınız.';
$messages['sendingfailed'] = 'İleti gönderilemedi.';
$messages['senttooquickly'] = 'Lütfen bu iletiyi göndermeden önce $sec saniye bekleyin.';
$messages['errorsavingsent'] = 'Gönderilen ileti kayıt edilirken bir sorun çıktı.';
$messages['errorsaving'] = 'Kayıt sırasında bir sorun çıktı.';
$messages['errormoving'] = 'İleti taşınamadı.';
$messages['errorcopying'] = 'İleti kopyalanamadı.';
$messages['errordeleting'] = 'İleti silinemedi';
$messages['errormarking'] = 'İleti işaretlenemedi';
$messages['alerttitle'] = 'Dikkat';
$messages['confirmationtitle'] = 'Emin misiniz...';
$messages['deletecontactconfirm']  = 'Seçilmiş kişileri silmek istediğinize emin misiniz?';
$messages['deletegroupconfirm']  = 'Seçilmiş grupları silmek istediğinize emin misiniz?';
$messages['deletemessagesconfirm'] = 'Seçilmiş iletileri silmek istediğinize emin misiniz?';
$messages['deletefolderconfirm']  = 'Bu klasörü silmek istediğinize emin misiniz?';
$messages['movefolderconfirm']  = 'Bu klasörü taşımak istediğinize emin misiniz?';
$messages['purgefolderconfirm']  = 'Bu klasördeki tüm iletileri silmek istediğinize emin misiniz?';
$messages['contactdeleting'] = 'Kişi(ler) siliniyor...';
$messages['groupdeleting'] = 'Grup siliniyor...';
$messages['folderdeleting'] = 'Klasör siliniyor...';
$messages['foldermoving'] = 'Klasör taşınıyor...';
$messages['foldersubscribing'] = 'Klasöre abone olunuyor...';
$messages['folderunsubscribing'] = 'Klasör aboneliği kaldırılıyor...';
$messages['formincomplete'] = 'Form tam olarak doldurulmamış.';
$messages['noemailwarning'] = 'Lütfen geçerli bir e-posta adresi yazın.';
$messages['nonamewarning']  = 'Lütfen bir ad yazın.';
$messages['nopagesizewarning'] = 'Lütfen bir sayfa boyutu yazın.';
$messages['nosenderwarning'] = 'Göndericinin e-posta adresini yazın.';
$messages['recipientsadded'] = 'Alıcı(lar) eklendi.';
$messages['norecipientwarning'] = 'Lütfen en az bir alıcı belirtin';
$messages['disclosedrecipwarning'] = 'Tüm alıcılar diğer alıcıların e-posta adreslerini görebilir. Bu durumu engellemek ve gizliliği korumak için Gizli kopya alanını kullanabilirsiniz.';
$messages['disclosedreciptitle'] = 'Herkese açık alıcı sayısı çok fazla';
$messages['nosubjectwarning']  = '"Konu" alanı boş bırakılmış. Şimdi bir konu yazmak ister misiniz?';
$messages['nosubjecttitle']  = 'Konu belirtilmemiş';
$messages['nobodywarning'] = 'İleti boş olarak gönderilsin mi?';
$messages['notsentwarning'] = 'İleti gönderilmedi ve yaptığınız değişiklikler kaydedilmedi. Değişiklikler silinsin mi?';
$messages['restoresavedcomposedata'] = 'Daha önce hazırlanmış ancak gönderilmemiş bir ileti bulundu.\n\nKonu: $subject\Kaydedilme zamanı: $date\n\nBu iletiyi geri yüklemek istiyor musunuz?';
$messages['nosearchname'] = 'Lütfen bir kişi adı ya da e-posta adresi yazın.';
$messages['notuploadedwarning'] = 'Henüz tüm ek dosyalar yüklenmedi. Lütfen bekleyin ya da yüklemeyi iptal edin.';
$messages['searchsuccessful'] = '$nr ileti bulundu';
$messages['contactsearchsuccessful'] = '$nr kişi bulundu.';
$messages['searchnomatch'] = 'Arama ifadenize uygun bir sonuç bulunamadı.';
$messages['searching'] = 'Aranıyor...';
$messages['checking'] = 'Denetleniyor...';
$messages['stillsearching'] = 'Hala aranıyor...';
$messages['nospellerrors'] = 'Herhangi bir yazım hatası bulunamadı.';
$messages['folderdeleted'] = 'Klasör silindi.';
$messages['foldersubscribed'] = 'Klasöre abone olundu.';
$messages['folderunsubscribed'] = 'Klasör aboneliği kaldırıldı.';
$messages['folderpurged'] = 'Klasör boşaltıldı.';
$messages['folderexpunged'] = 'Klasör sıkıştırıldı.';
$messages['deletedsuccessfully'] = 'Silindi.';
$messages['converting'] = 'Biçimlendirme kaldırılıyor...';
$messages['messageopenerror'] = 'İleti sunucudan yüklenemedi.';
$messages['filelinkerror'] = 'Dosya eklenemedi.';
$messages['fileuploaderror'] = 'Dosya yüklenemedi.';
$messages['csvfilemismatch'] = 'İçinde farklı alanlar bulunan bir kaç CSV dosyası içe aktarılamaz.';
$messages['filesizeerror'] = 'Dosya izin verilen en büyük değer olan $size boyutundan büyük.';
$messages['filecounterror'] = 'Bir kerede en fazla $count dosya yüklenebilir.';
$messages['msgsizeerror'] = 'Dosya eklenemedi. İzin verilen en büyük değer olan $size boyutundan büyük.';
$messages['msgsizeerrorfwd'] = 'Bir ileti için belirlenmiş en büyük boyut değeri ($size) aşıldığından $num ileti eklenmedi.';
$messages['copysuccess'] = '$nr kişi kopyalandı.';
$messages['movesuccess'] = '$nr kişi taşındı.';
$messages['copyerror'] = 'Herhangi bir kişi kopyalanamadı.';
$messages['moveerror'] = 'Herhangi bir kişi taşınamadı.';
$messages['sourceisreadonly'] = 'Adres kaynağı salt okunur durumda.';
$messages['errorsavingcontact'] = 'Kişi adresi kaydedilemedi.';
$messages['movingmessage'] = 'İleti(ler) taşınıyor...';
$messages['copyingmessage'] = 'İleti(ler) kopyalanıyor...';
$messages['copyingcontact'] = 'Kişile(ler) kopyalanıyor...';
$messages['movingcontact'] = 'Kişi(ler) taşınıyor...';
$messages['deletingmessage'] = 'İleti(ler) siliniyor...';
$messages['markingmessage'] = 'İleti(ler) işaretleniyor...';
$messages['addingmember'] = 'Gruba kişi(ler) ekleniyor...';
$messages['removingmember'] = 'Gruptan kişi(ler) çıkarılıyor...';
$messages['receiptsent'] = 'Okundu onayı gönderildi.';
$messages['errorsendingreceipt'] = 'Okundu onayı gönderilemedi.';
$messages['deleteidentityconfirm'] = 'Bu kimliği silmek istediğinize emin misiniz?';
$messages['nodeletelastidentity'] = 'Son kimliğiniz olduğu için bu kimliği silemezsiniz.';
$messages['forbiddencharacter'] = 'Klasör adında izin verilmeyen karakterler var.';
$messages['selectimportfile'] = 'Lütfen yüklenecek dosyayı seçin.';
$messages['addresswriterror'] = 'Seçilmiş adres defteri yazılabilir durumda değil.';
$messages['contactaddedtogroup'] = 'Kişiler bu gruba eklendi.';
$messages['contactremovedfromgroup'] = 'Kişiler bu gruptan çıkarıldı';
$messages['nogroupassignmentschanged'] = 'Grup atamalarında bir değişiklik yapılmadı.';
$messages['importwait'] = 'Lütfen içe aktarma sürerken bekleyin...';
$messages['importformaterror'] = 'İçe aktarılamadı. Yüklenen dosya geçerli bir içe aktarım dosyası değil.';
$messages['importconfirm'] = '<b>$inserted kişi aktarıldı</b>';
$messages['importconfirmskipped'] = '<b>Var olan $skipped kişi atlandı</b>';
$messages['importconfirminvalid'] = '<b>Geçersiz $invalid kişi atlandı</b>';
$messages['importconfirmerrors'] = '<b>Geçerli $errors kişi içe aktarılamadı</b>';
$messages['importmessagesuccess'] = '$nr ileti içe aktarıldı';
$messages['importmessageerror'] = 'İçe aktarılamadı. Yüklenen dosya geçerli bir ileti ya da e-posta kutusu dosyası değil';
$messages['opnotpermitted'] = 'Bu işleme izin verilmiyor!';
$messages['nofromaddress'] = 'Bu kimliğin e-posta adresi yok.';
$messages['editorwarning'] = 'Düzenleyici türünü değiştirmek, yazı biçimlendirmesinin kaybolmasına neden olabilir. İlerlemek istiyor musunuz?';
$messages['httpreceivedencrypterror'] = 'Ayarlarda bir sorun var. Sistem yöneticinizle görüşün. <b>İletiniz gönderilemedi</b>';
$messages['smtpconnerror'] = 'SMTP sorunu ($code): Sunucu bağlantısı kurulamadı.';
$messages['smtpautherror'] = 'SMTP sorunu ($code): Kimlik doğrulanamadı.';
$messages['smtpfromerror'] = 'SMTP sorunu ($code): Gönderici adresi "$from" olarak ayarlanamadı ($msg)';
$messages['smtptoerror'] = 'SMTP sorunu ($code): "$to" alıcısı eklenemedi ($msg)';
$messages['smtprecipientserror'] = 'SMTP sorunu: Alıcı listesi ayrıştırılamadı';
$messages['smtputf8error'] = 'SMTP sorunu: Sunucu e-posta adreslerinde unikod karakterleri desteklemiyor.';
$messages['smtpsizeerror'] = 'SMTP hatası: İleti boyutu sunucu sınırlamasını aşıyor ($limit)';
$messages['smtperror'] = 'SMTP sorunu: $msg';
$messages['emailformaterror'] = 'E-posta adresi geçersiz: $email';
$messages['toomanyrecipients'] = 'Çok fazla alıcı var. En fazla $max alıcı olabilir.';
$messages['maxgroupmembersreached'] = 'Grup üyelerinin sayısı $max sınırını aşıyor.';
$messages['internalerror'] = 'Sorun var! Lütfen yeniden deneyin.';
$messages['contactdelerror'] = 'Kişi(ler) silinemedi.';
$messages['contactdeleted'] = 'Kişi(ler) silindi.';
$messages['contactrestoreerror'] = 'Silinen kişi(ler) geri yüklenemiyor.';
$messages['contactrestored'] = 'Kişi(ler) geri yüklendi.';
$messages['groupdeleted'] = 'Grup silindi';
$messages['grouprenamed'] = 'Grup adı değiştirildi.';
$messages['groupcreated'] = 'Grup eklendi.';
$messages['savedsearchdeleted'] = 'Kayıtlı arama silindi.';
$messages['savedsearchdeleteerror'] = 'Kayıtlı arama silinemedi.';
$messages['savedsearchcreated'] = 'Kayıtlı arama eklendi.';
$messages['savedsearchcreateerror'] = 'Kayıtlı arama eklenemedi.';
$messages['messagedeleted'] = 'İleti(ler) silindi.';
$messages['messagemoved'] = 'İleti(ler) taşındı.';
$messages['messagemovedtotrash'] = 'İleti(ler) çöpe atıldı.';
$messages['messagecopied'] = 'İleti(ler) kopyalandı.';
$messages['messagemarked'] = 'İleti(ler) işaretlendi.';
$messages['autocompletechars'] = 'Otomatik tamamlama için en az $min karakter yazın.';
$messages['autocompletemore'] = 'Fazla sayıda eşleşen öge bulundu. Lütfen daha fazla karakter yazın.';
$messages['namecannotbeempty'] = 'Ad alanı boş olamaz.';
$messages['nametoolong'] = 'Ad çok uzun.';
$messages['namedotforbidden'] = 'Klasör adı nokta işareti ile başlayamaz.';
$messages['folderupdated'] = 'Klasör güncellendi';
$messages['foldercreated'] = 'Klasör eklendi.';
$messages['invalidimageformat'] = 'Geçerli bir görsel biçimi değil.';
$messages['mispellingsfound'] = 'İletide yazım hataları var.';
$messages['parentnotwritable'] = 'Klasör, seçilen üst klasöre eklenemiyor ya da taşınamıyor. Erişim izni yok.';
$messages['messagetoobig'] = 'Bu ileti parçası işlenemeyecek kadar büyük.';
$messages['attachmentvalidationerror'] = 'Ek dosya türü ileti içinde belirtilen tür ile aynı değil ve bu dosya şüpheli. Bu dosyada zararlı bir içerik bulunuyor olabilir. O nedenle göndericiyi tanımıyor ya da güvenmiyorsanız bu dosyayı tarayıcı içinden açmayın. <br/><br/><em>Beklenen: $expected; Bulunan: $detected</em>';
$messages['noscriptwarning'] = 'Uyarı: Bu internet e-posta hizmetinin kullanılabilmesi için JavaScript gereklidir! Hizmeti kullanabilmek için lütfen tarayıcınızın JavaScript ayarlarını etkinleştirin.';
$messages['messageissent'] = 'İleti zaten gönderilmiş ancak henüz kaydedilmemiş. Şimdi kaydetmek ister misiniz?';
$messages['errnotfound'] = 'Dosya bulunamadı.';
$messages['errnotfoundexplain'] = 'İstenen kaynak bulunamadı!..';
$messages['errfailedrequest'] = 'İstek yerine getirilemedi';
$messages['errauthorizationfailed'] = 'Kimlik doğrulanamadı';
$messages['errunauthorizedexplain'] = 'Bu hizmete erişme izniniz yok!';
$messages['errrequestcheckfailed'] = 'İstek denetlenemedi';
$messages['errcsrfprotectionexplain'] = "Güvenliğiniz için, CSRF tehditine karşı bu kaynağa erişim engellenmiştir.\nlfBu iletiyi görüyorsanız, büyük olasılıkla oturum kapatılmadan internet uygulamasından çıkılmıştır.\n\nİlerlemek için insan etkileşimi gereklidir.";
$messages['errcontactserveradmin'] = 'Sunucu yöneticinize başvurun.';
$messages['clicktoresumesession'] = 'Önceki oturumu sürdürmek için buraya tıklayın';
$messages['errcomposesession'] = 'Hazırlama oturumu hatası';
$messages['errcomposesessionexplain'] = 'İstenilen hazırlama oturumu bulunamadı.';
$messages['clicktocompose'] = 'Yeni bir ileti hazırlamak için buraya tıklayın.';
$messages['nosupporterror'] = 'Bu özellik tarayıcınız tarafından desteklenmiyor.';
$messages['siginserted'] = 'İmza eklendi.';
$messages['responseinserted'] = 'Yanıt eklendi.';
$messages['noresponsesavailable'] = 'Kullanılabilecek bir yanıt yok';
$messages['listempty'] = 'Liste boş.';
$messages['listusebutton'] = 'Yeni bir kayıt eklemek için Ekle düğmesine tıklayın.';
$messages['keypaircreatesuccess'] = '$identity için yeni bir anahtar çifti oluşturuldu.';
$messages['emptyattachment'] = 'Bu ek dosya boş gibi görünüyor.<br>Lütfen göndericiyle görüşün.';
$messages['oauthloginfailed'] = 'OAuth oturumu açılamadı. Lütfen yeniden deneyin.';
$messages['oauthinvalidrequest'] = 'Kimlik doğrulama isteği geçersiz ya da eksik.';
$messages['oauthaccessdenied'] = 'Kimlik doğrulama sunucusu ya da kullanıcı isteği reddetti.';
