<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = '새로운 메시지가 도착하면 브라우저 알림 표시';
$labels['desktop'] = '새로운 메시지가 도착하면 바탕화면 알림 표시';
$labels['sound'] = '새로운 메시지가 도착하면 소리 재생';
$labels['test'] = '테스트';
$labels['title'] = '새 이메일 도착!';
$labels['body'] = '새 메시지가 수신되었습니다.';
$labels['testbody'] = '이것은 테스트 알림입니다.';
$labels['desktopdisabled'] = ' 브라우저에서 바탕화면 알림이 비활성화되었습니다.';
$labels['desktopunsupported'] = '브라우저가 바탕화면 알림을 지원하지 않습니다.';
$labels['desktoptimeout'] = '바탕화면 알림 닫기';
