<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Bistaratu nabigatzailearen jakinarazpenak mezu berrian';
$labels['desktop'] = 'Bistaratu sistemaren jakinarazpenak mezu berrian';
$labels['sound'] = 'Jo soinu bat mezu berriarekin';
$labels['test'] = 'Testa';
$labels['title'] = 'E-posta berria';
$labels['body'] = 'Mezu berria jaso duzu';
$labels['testbody'] = 'Hau jakinarazpen proba bat da';
$labels['desktopdisabled'] = 'Sistemaren jakinarazpenak ezgaituak daude zure nabigatzailean';
$labels['desktopunsupported'] = 'Zure nabigatzaileak ez ditu sistemaren jakinarazpenak onartzen.';
$labels['desktoptimeout'] = 'Itxi mahaigaineko jakinarazpena';
