<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['loginfailed']  = 'ঢোকা গেল না';
$messages['cookiesdisabled'] = 'আপনার ব্রাউজার, কুকি গ্রহন করে না';
$messages['sessionerror'] = 'আপনার সেশন শেষ';
$messages['storageerror'] = 'মেইল সারভার এর সাথে যোগাযোগ করা গেল না';
$messages['nomessagesfound'] = 'এই মেইলবক্সে কোনো চিঠি নাই';
$messages['loading'] = 'কম্পুটার কাজ করতেছে . .';
$messages['loadingdata'] = 'কম্পুটার তথ্য আনছে আপনার জন্য..';
$messages['checkingmail'] = 'নতুন চিঠি আসছে কিনা তা দেখা হচ্ছে';
$messages['sendingmessage'] = 'চিঠি পাঠায় দেওয়া হচ্ছে';
$messages['messagesent'] = 'চিঠি ঠিকঠাকমতো পাঠানো শেষ';
$messages['savingmessage'] = 'চিঠি জমা করে রাখা হচ্ছে';
$messages['messagesaved'] = 'চিঠি খসড়া হিসাবে জমা করে রাখা হয়েছে';
$messages['successfullysaved'] = 'ঠিকঠাকমতো জমা হয়ে গিয়েছে';
$messages['addedsuccessfully'] = 'নতুন ঠিকানা ঠিকঠাক মতো ঢোকানো হয়ে গেছে';
$messages['blockedimages'] = 'আপনার গোপনীয়তা রক্ষার জন্য আমরা ছবি গুলো সরিয়ে রেখেছি';
$messages['encryptedmessage'] = 'এটা একটি গোপন (encrypted) চিঠি। এটা আপনাকে দেখানো যাবে না। দু্ঃখিত।';
$messages['nocontactsfound'] = 'কোনো ঠিকানা পাওয়া গেলনা। দু্ঃখিত।';
$messages['contactnotfound'] = 'আপনি যে ঠিকানা খুজছেন সেটা পাওয়া গেল না';
$messages['sendingfailed'] = 'চিঠি পাঠানো গেলনা';
$messages['senttooquickly'] = 'এই চিঠি পাঠানোর আগে, দয়া করে $sec সেকেন্ড';
$messages['errormoving'] = 'চিঠিটা সরানো গেলো না';
$messages['errordeleting'] = 'চিঠিটা ফেলানো গেলো না';
$messages['deletecontactconfirm']  = 'আপনি কি আসলেই এই ঠিকানা(গুলো) ফেলো দিতে চান?';
$messages['deletemessagesconfirm'] = 'আপনি কি আসলেই এই চিঠি(গুলো) ফেলো দিতে চান?';
$messages['deletefolderconfirm']  = 'আপনি কি আসলেই এই ফোল্ডার/মেইলবক্স ফেলো দিতে চান?';
$messages['purgefolderconfirm']  = 'আপনি কি আসলেই এই ফোল্ডার/মেইলবক্স এর সব চিঠি ফেলো দিতে চান?';
$messages['folderdeleting'] = 'ফোল্ডার/মেইলবক্স ফেলে দেওয়া হচ্ছে';
$messages['foldermoving'] = 'ফোল্ডার/মেইলবক্স সরানো হচ্ছে';
$messages['formincomplete'] = 'আপনি সবগুলো জিনিষ লেখেননি';
$messages['noemailwarning'] = 'একটি সঠিক ই-মেইল লিখুন';
$messages['nonamewarning']  = 'দয়া করে নামটি লিখুন';
$messages['nopagesizewarning'] = 'দয়া করে পৃষ্ঠার সাইজটি লিখুন';
$messages['norecipientwarning'] = 'দয়া করে একজন প্রাপক এর ই-মেইলটা লিখুন';
$messages['nosubjectwarning']  = 'বিষয় হিসাবে কিছু লেখা হয়নি, আপনি কি কিছু লিখবেন এখন বিষয় হিসাবে?';
$messages['nobodywarning'] = 'কোনো কিছু না লিখেই এই চিঠি পাঠিয়ে দেবেন?';
$messages['nosearchname'] = 'দয়া করে একজনের নাম অথবা ই-মেইল লিখুন';
$messages['searchsuccessful'] = '$nr টা চিঠি পাওয়া গেছে';
$messages['searchnomatch'] = 'খুজে কিছু পাওয়া গেলোনা';
$messages['searching'] = 'খুজছি ....';
$messages['checking'] = 'দেখছি ...';
$messages['nospellerrors'] = 'No spelling errors found';
$messages['folderdeleted'] = 'ফোল্ডার/মেইলবক্স ঠিকঠাকমতো ফেলানো হয়ে গেছে';
$messages['deletedsuccessfully'] = 'ঠিকঠাকমতো ফেলানো হয়ে গেছে';
$messages['converting'] = 'বিন্যাস (formatting) সরানো হচ্ছে ..';
$messages['messageopenerror'] = 'সারভার থেকে চিঠি আনা গেলোনা';
$messages['fileuploaderror'] = 'ফাইলটা সারভারে উঠানো গেলোনা';
$messages['filesizeerror'] = 'যে ফাইলটা উঠানোর চেষ্টা করলেন সেটি সর্বোচ্চ সাইজ $size এর থেকে বেশি';
$messages['sourceisreadonly'] = 'এইঠিকানাটা খালি পড়ার জন্যে';
$messages['errorsavingcontact'] = 'ঠিকানা জমা রাখা গেলোনা';
$messages['movingmessage'] = 'চিঠি সরানো হচ্ছে..';
$messages['receiptsent'] = 'ঠিকঠাক মতো ফিরতি রশিদ পাঠানো হয়েছে';
$messages['errorsendingreceipt'] = 'রশিদ পাঠানো গেলোনা';
$messages['nodeletelastidentity'] = 'আপনি এই পরিচিতি ফেলতে পারবেন না কারন এইটায় বর্তমানে আপনার একমাত্র পরিচিতি।';
$messages['forbiddencharacter'] = 'ফোল্ডার এর নামের মধ্যে নিষিদ্ধ অক্ষর আছে';
$messages['selectimportfile'] = 'একটা ফাইল বেছে নিন তোলার জন্য';
$messages['addresswriterror'] = 'বেছে নেওয়া ঠিকানার বইটিতে লেখাযায় না';
$messages['importwait'] = 'আমদানি করা হচ্ছে। একটু অপেক্ষা করুন...';
$messages['importconfirm'] = '<b>ঠিকমতো $inserted ঠিকানা আমদানি করা গেছে, $skipped ঠিকানা আগের থেকেই ছিলো বলে তাদের টা যা ছিলো তাই রাখা হয়েছে</b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'এই কাজটা করার অনুমতি নাই আপনার';
