<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = '아프리카';
$labels['tz:africa:abidjan'] = '아비장';
$labels['tz:africa:accra'] = '아크라';
$labels['tz:africa:addis_ababa'] = '아디스아바바';
$labels['tz:africa:algiers'] = '알제';
$labels['tz:africa:asmara'] = '아스마라';
$labels['tz:africa:bamako'] = '바마코';
$labels['tz:africa:bangui'] = '방기';
$labels['tz:africa:banjul'] = '반줄';
$labels['tz:africa:bissau'] = '비사우';
$labels['tz:africa:blantyre'] = '블랜타이어';
$labels['tz:africa:brazzaville'] = '브라자빌';
$labels['tz:africa:bujumbura'] = '부줌부라';
$labels['tz:africa:cairo'] = '카이로';
$labels['tz:africa:casablanca'] = '카사블랑카';
$labels['tz:africa:ceuta'] = '세우타';
$labels['tz:africa:conakry'] = '코나크리';
$labels['tz:africa:dakar'] = '다카르';
$labels['tz:africa:dar_es_salaam'] = '다르에스살람';
$labels['tz:africa:djibouti'] = '지부티';
$labels['tz:africa:douala'] = '두알라';
$labels['tz:africa:el_aaiun'] = '엘아이운';
$labels['tz:africa:freetown'] = '프리타운';
$labels['tz:africa:gaborone'] = '가보로네';
$labels['tz:africa:harare'] = '하라레';
$labels['tz:africa:johannesburg'] = '요하네스버그';
$labels['tz:africa:juba'] = '주바';
$labels['tz:africa:kampala'] = '캄팔라';
$labels['tz:africa:khartoum'] = '하르툼';
$labels['tz:africa:kigali'] = '키갈리';
$labels['tz:africa:kinshasa'] = '킨샤사';
$labels['tz:africa:lagos'] = '라고스';
$labels['tz:africa:libreville'] = '리브르빌';
$labels['tz:africa:lome'] = '로메';
$labels['tz:africa:luanda'] = '루안다';
$labels['tz:africa:lubumbashi'] = '루붐바시';
$labels['tz:africa:lusaka'] = '루사카';
$labels['tz:africa:malabo'] = '말라보';
$labels['tz:africa:maputo'] = '마푸토';
$labels['tz:africa:maseru'] = '마세루';
$labels['tz:africa:mbabane'] = '음바바네';
$labels['tz:africa:mogadishu'] = '모가디슈';
$labels['tz:africa:monrovia'] = '몬로비아';
$labels['tz:africa:nairobi'] = '나이로비';
$labels['tz:africa:ndjamena'] = '은자메나';
$labels['tz:africa:niamey'] = '니아메';
$labels['tz:africa:nouakchott'] = '뉴악쇼트';
$labels['tz:africa:ouagadougou'] = '와가두구';
$labels['tz:africa:porto-novo'] = '포르토노보';
$labels['tz:africa:sao_tome'] = '상투메';
$labels['tz:africa:tripoli'] = '트리폴리';
$labels['tz:africa:tunis'] = '튀니스';
$labels['tz:africa:windhoek'] = '빈트후크';
$labels['tz:america'] = '아메리카';
$labels['tz:america:adak'] = '에이댁';
$labels['tz:america:anchorage'] = '앵커리지';
$labels['tz:america:anguilla'] = '앙귈라';
$labels['tz:america:antigua'] = '안티과';
$labels['tz:america:araguaina'] = '아라구아이나';
$labels['tz:america:argentina'] = '아르헨티나';
$labels['tz:america:argentina:buenos_aires'] = '부에노스아이레스';
$labels['tz:america:argentina:catamarca'] = '카타마르카';
$labels['tz:america:argentina:cordoba'] = '코르도바';
$labels['tz:america:argentina:jujuy'] = '후후이';
$labels['tz:america:argentina:la_rioja'] = '라리오하';
$labels['tz:america:argentina:mendoza'] = '멘도자';
$labels['tz:america:argentina:rio_gallegos'] = '리오가제고스';
$labels['tz:america:argentina:salta'] = '살타';
$labels['tz:america:argentina:san_juan'] = '산후안';
$labels['tz:america:argentina:san_luis'] = '산루이';
$labels['tz:america:argentina:tucuman'] = '투쿠만';
$labels['tz:america:argentina:ushuaia'] = '우수아이아';
$labels['tz:america:aruba'] = '아루바';
$labels['tz:america:asuncion'] = '아순시온';
$labels['tz:america:atikokan'] = '아티코칸';
$labels['tz:america:bahia'] = '바이아';
$labels['tz:america:bahia_banderas'] = '바이아반데라스';
$labels['tz:america:barbados'] = '바베이도스';
$labels['tz:america:belem'] = '벨렘';
$labels['tz:america:belize'] = '벨리즈';
$labels['tz:america:blanc-sablon'] = '블랑사블롱';
$labels['tz:america:boa_vista'] = '보아비스타';
$labels['tz:america:bogota'] = '보고타';
$labels['tz:america:boise'] = '보이시';
$labels['tz:america:cambridge_bay'] = '케임브리지베이';
$labels['tz:america:campo_grande'] = '캄포그란데';
$labels['tz:america:cancun'] = '칸쿤';
$labels['tz:america:caracas'] = '카라카스';
$labels['tz:america:cayenne'] = '카옌';
$labels['tz:america:cayman'] = '케이맨';
$labels['tz:america:chicago'] = '시카고';
$labels['tz:america:chihuahua'] = '치와와';
$labels['tz:america:costa_rica'] = '코스타리카';
$labels['tz:america:creston'] = '크레스턴';
$labels['tz:america:cuiaba'] = '쿠이아바';
$labels['tz:america:curacao'] = '쿠라사우';
$labels['tz:america:danmarkshavn'] = '덴마크샤븐';
$labels['tz:america:dawson'] = '도슨';
$labels['tz:america:dawson_creek'] = '도슨크릭';
$labels['tz:america:denver'] = '덴버';
$labels['tz:america:detroit'] = '디트로이트';
$labels['tz:america:dominica'] = '도미니카';
$labels['tz:america:edmonton'] = '에드먼턴';
$labels['tz:america:eirunepe'] = '에이루네페';
$labels['tz:america:el_salvador'] = '엘살바도르';
$labels['tz:america:fort_nelson'] = '포트넬슨';
$labels['tz:america:fortaleza'] = '포르탈레자';
$labels['tz:america:glace_bay'] = '글레이스베이';
$labels['tz:america:godthab'] = '고드홉';
$labels['tz:america:goose_bay'] = '구스베이';
$labels['tz:america:grand_turk'] = '그랜드터크';
$labels['tz:america:grenada'] = '그레나다';
$labels['tz:america:guadeloupe'] = '과들루프';
$labels['tz:america:guatemala'] = '과테말라';
$labels['tz:america:guayaquil'] = '과야킬';
$labels['tz:america:guyana'] = '가이아나';
$labels['tz:america:halifax'] = '핼리팩스';
$labels['tz:america:havana'] = '아바나';
$labels['tz:america:hermosillo'] = '에르모시요';
$labels['tz:america:indiana'] = '인디애나';
$labels['tz:america:indiana:indianapolis'] = '인디애나폴리스';
$labels['tz:america:indiana:knox'] = '녹스';
$labels['tz:america:indiana:marengo'] = '마렝고';
$labels['tz:america:indiana:petersburg'] = '피터즈버그';
$labels['tz:america:indiana:tell_city'] = '텔시티';
$labels['tz:america:indiana:vevay'] = '베바이';
$labels['tz:america:indiana:vincennes'] = '빈센즈';
$labels['tz:america:indiana:winamac'] = '위너맥';
$labels['tz:america:inuvik'] = '이누빅';
$labels['tz:america:iqaluit'] = '이칼루이트';
$labels['tz:america:jamaica'] = '자메이카';
$labels['tz:america:juneau'] = '주노';
$labels['tz:america:kentucky'] = '켄터키';
$labels['tz:america:kentucky:louisville'] = '루이스빌';
$labels['tz:america:kentucky:monticello'] = '몬티셀로';
$labels['tz:america:kralendijk'] = '크랄렌데이크';
$labels['tz:america:la_paz'] = '라파스';
$labels['tz:america:lima'] = '리마';
$labels['tz:america:los_angeles'] = '로스앤젤레스';
$labels['tz:america:lower_princes'] = '로어 프린스';
$labels['tz:america:maceio'] = '마세이오';
$labels['tz:america:managua'] = '마나과';
$labels['tz:america:manaus'] = '마나우스';
$labels['tz:america:marigot'] = '마리고';
$labels['tz:america:martinique'] = '마르티니크';
$labels['tz:america:matamoros'] = '마타모로스';
$labels['tz:america:mazatlan'] = '마사틀란';
$labels['tz:america:menominee'] = '메노미니';
$labels['tz:america:merida'] = '메리다';
$labels['tz:america:metlakatla'] = '메틀라카틀라';
$labels['tz:america:mexico_city'] = '멕시코시티';
$labels['tz:america:miquelon'] = '미클롱';
$labels['tz:america:moncton'] = '몽크턴';
$labels['tz:america:monterrey'] = '몬테레이';
$labels['tz:america:montevideo'] = '몬테비데오';
$labels['tz:america:montserrat'] = '몬트세라트';
$labels['tz:america:nassau'] = '나소';
$labels['tz:america:new_york'] = '뉴욕';
$labels['tz:america:nipigon'] = '니피곤';
$labels['tz:america:nome'] = '놈';
$labels['tz:america:noronha'] = '노로냐';
$labels['tz:america:north_dakota'] = '노스다코타';
$labels['tz:america:north_dakota:beulah'] = '뷸라';
$labels['tz:america:north_dakota:center'] = '센터';
$labels['tz:america:north_dakota:new_salem'] = '뉴살렘';
$labels['tz:america:ojinaga'] = '오지나가';
$labels['tz:america:panama'] = '파나마';
$labels['tz:america:pangnirtung'] = '팽니텅';
$labels['tz:america:paramaribo'] = '파라마리보';
$labels['tz:america:phoenix'] = '피닉스';
$labels['tz:america:port-au-prince'] = '포르토프랭스';
$labels['tz:america:port_of_spain'] = '포트오브스페인';
$labels['tz:america:porto_velho'] = '포르토벨료';
$labels['tz:america:puerto_rico'] = '푸에르토리코';
$labels['tz:america:rainy_river'] = '레이니리버';
$labels['tz:america:rankin_inlet'] = '랭킨 인라잇';
$labels['tz:america:recife'] = '레시페';
$labels['tz:america:regina'] = '리자이나';
$labels['tz:america:resolute'] = '레졸루트';
$labels['tz:america:rio_branco'] = '리오브랑쿠';
$labels['tz:america:santarem'] = '산타렘';
$labels['tz:america:santiago'] = '산티아고';
$labels['tz:america:santo_domingo'] = '산토도밍고';
$labels['tz:america:sao_paulo'] = '상파울루';
$labels['tz:america:scoresbysund'] = '스코레스비순드';
$labels['tz:america:sitka'] = '시트카';
$labels['tz:america:st_barthelemy'] = '세인트바르텔레미';
$labels['tz:america:st_johns'] = "세인트존스";
$labels['tz:america:st_kitts'] = '세인트키츠';
$labels['tz:america:st_lucia'] = '세인트루시아';
$labels['tz:america:st_thomas'] = '세인트토머스';
$labels['tz:america:st_vincent'] = '세인트빈센트';
$labels['tz:america:swift_current'] = '스위프트커런트';
$labels['tz:america:tegucigalpa'] = '테구시갈파';
$labels['tz:america:thule'] = '툴레';
$labels['tz:america:thunder_bay'] = '선더베이';
$labels['tz:america:tijuana'] = '티화나';
$labels['tz:america:toronto'] = '토론토';
$labels['tz:america:tortola'] = '토르톨라';
$labels['tz:america:vancouver'] = '밴쿠버';
$labels['tz:america:whitehorse'] = '화이트호스';
$labels['tz:america:winnipeg'] = '위니페그';
$labels['tz:america:yakutat'] = '야쿠타트';
$labels['tz:america:yellowknife'] = '옐로나이프';
$labels['tz:antarctica'] = '남극';
$labels['tz:antarctica:casey'] = '케이시';
$labels['tz:antarctica:davis'] = '데이비스';
$labels['tz:antarctica:dumontdurville'] = "뒤몽뒤르빌";
$labels['tz:antarctica:macquarie'] = '맥코리';
$labels['tz:antarctica:mawson'] = '모손';
$labels['tz:antarctica:mcmurdo'] = '맥머도';
$labels['tz:antarctica:palmer'] = '팔머';
$labels['tz:antarctica:rothera'] = '로세라';
$labels['tz:antarctica:syowa'] = '쇼와';
$labels['tz:antarctica:troll'] = '트롤';
$labels['tz:antarctica:vostok'] = '보스토크';
$labels['tz:arctic'] = '북극';
$labels['tz:arctic:longyearbyen'] = '롱위에아르뷔엔';
$labels['tz:asia'] = '아시아';
$labels['tz:asia:aden'] = '아덴';
$labels['tz:asia:almaty'] = '알마티';
$labels['tz:asia:amman'] = '암만';
$labels['tz:asia:anadyr'] = '아나디리';
$labels['tz:asia:aqtau'] = '악타우';
$labels['tz:asia:aqtobe'] = '아크토베';
$labels['tz:asia:ashgabat'] = '아시가바트';
$labels['tz:asia:atyrau'] = '아티라우';
$labels['tz:asia:baghdad'] = '바그다드';
$labels['tz:asia:bahrain'] = '바레인';
$labels['tz:asia:baku'] = '바쿠';
$labels['tz:asia:bangkok'] = '방콕';
$labels['tz:asia:barnaul'] = '바르나울';
$labels['tz:asia:beirut'] = '베이루트';
$labels['tz:asia:bishkek'] = '비슈케크';
$labels['tz:asia:brunei'] = '브루나이';
$labels['tz:asia:chita'] = '치타';
$labels['tz:asia:choibalsan'] = '처이발상';
$labels['tz:asia:colombo'] = '콜롬보';
$labels['tz:asia:damascus'] = '다마스쿠스';
$labels['tz:asia:dhaka'] = '다카';
$labels['tz:asia:dili'] = '딜리';
$labels['tz:asia:dubai'] = '두바이';
$labels['tz:asia:dushanbe'] = '두샨베';
$labels['tz:asia:famagusta'] = '파마구스타';
$labels['tz:asia:gaza'] = '가자';
$labels['tz:asia:hebron'] = '헤브론';
$labels['tz:asia:ho_chi_minh'] = '호치민';
$labels['tz:asia:hong_kong'] = '홍콩';
$labels['tz:asia:hovd'] = '허브드';
$labels['tz:asia:irkutsk'] = '이르쿠츠크';
$labels['tz:asia:jakarta'] = '자카르타';
$labels['tz:asia:jayapura'] = '자야푸라';
$labels['tz:asia:jerusalem'] = '예루살렘';
$labels['tz:asia:kabul'] = '카불';
$labels['tz:asia:kamchatka'] = '캄차카';
$labels['tz:asia:karachi'] = '카라치';
$labels['tz:asia:kathmandu'] = '카트만두';
$labels['tz:asia:khandyga'] = '칸디가';
$labels['tz:asia:kolkata'] = '콜카타';
$labels['tz:asia:krasnoyarsk'] = '크라스노야르스크';
$labels['tz:asia:kuala_lumpur'] = '콸라룸푸르';
$labels['tz:asia:kuching'] = '쿠칭';
$labels['tz:asia:kuwait'] = '쿠웨이트';
$labels['tz:asia:macau'] = '마카오';
$labels['tz:asia:magadan'] = '마가단';
$labels['tz:asia:makassar'] = '마카사르';
$labels['tz:asia:manila'] = '마닐라';
$labels['tz:asia:muscat'] = '무스카트';
$labels['tz:asia:nicosia'] = '니코시아';
$labels['tz:asia:novokuznetsk'] = '노보쿠즈네츠크';
$labels['tz:asia:novosibirsk'] = '노보시비르스크';
$labels['tz:asia:omsk'] = '옴스크';
$labels['tz:asia:oral'] = '오랄';
$labels['tz:asia:phnom_penh'] = '프놈펜';
$labels['tz:asia:pontianak'] = '폰티아낙';
$labels['tz:asia:pyongyang'] = '평양';
$labels['tz:asia:qatar'] = '카타르';
$labels['tz:asia:qyzylorda'] = '키질로르다';
$labels['tz:asia:riyadh'] = '리야드';
$labels['tz:asia:sakhalin'] = '사할린';
$labels['tz:asia:samarkand'] = '사마르칸트';
$labels['tz:asia:seoul'] = '서울';
$labels['tz:asia:shanghai'] = '상하이';
$labels['tz:asia:singapore'] = '싱가포르';
$labels['tz:asia:srednekolymsk'] = '스레드네콜림스크';
$labels['tz:asia:taipei'] = '타이페이';
$labels['tz:asia:tashkent'] = '타슈켄트';
$labels['tz:asia:tbilisi'] = '트빌리시';
$labels['tz:asia:tehran'] = '테헤란';
$labels['tz:asia:thimphu'] = '팀부';
$labels['tz:asia:tokyo'] = '도쿄';
$labels['tz:asia:tomsk'] = '톰스크';
$labels['tz:asia:ulaanbaatar'] = '울란바토르';
$labels['tz:asia:urumqi'] = '우루무치';
$labels['tz:asia:ust-nera'] = '우스네라';
$labels['tz:asia:vientiane'] = '비엔티안';
$labels['tz:asia:vladivostok'] = '블라디보스토크';
$labels['tz:asia:yakutsk'] = '야쿠츠크';
$labels['tz:asia:yangon'] = '양곤';
$labels['tz:asia:yekaterinburg'] = '에카테린부르크';
$labels['tz:asia:yerevan'] = '예레반';
$labels['tz:atlantic'] = '대서양';
$labels['tz:atlantic:azores'] = '아조레스';
$labels['tz:atlantic:bermuda'] = '버뮤다';
$labels['tz:atlantic:canary'] = '카나리아';
$labels['tz:atlantic:cape_verde'] = '카보베르데';
$labels['tz:atlantic:faroe'] = '페로';
$labels['tz:atlantic:madeira'] = '마데이라';
$labels['tz:atlantic:reykjavik'] = '레이캬비크';
$labels['tz:atlantic:south_georgia'] = '사우스조지아';
$labels['tz:atlantic:st_helena'] = '세인트헬레나';
$labels['tz:atlantic:stanley'] = '스탠리';
$labels['tz:australia'] = '오스트레일리아';
$labels['tz:australia:adelaide'] = '애들레이드';
$labels['tz:australia:brisbane'] = '브리즈번';
$labels['tz:australia:broken_hill'] = '브로컨힐';
$labels['tz:australia:currie'] = '커리';
$labels['tz:australia:darwin'] = '다윈';
$labels['tz:australia:eucla'] = '유클라';
$labels['tz:australia:hobart'] = '호바트';
$labels['tz:australia:lindeman'] = '린드만';
$labels['tz:australia:lord_howe'] = '로드하우';
$labels['tz:australia:melbourne'] = '멜버른';
$labels['tz:australia:perth'] = '퍼스';
$labels['tz:australia:sydney'] = '시드니';
$labels['tz:europe'] = '유럽';
$labels['tz:europe:amsterdam'] = '암스테르담';
$labels['tz:europe:andorra'] = '안도라';
$labels['tz:europe:astrakhan'] = '아스트라칸';
$labels['tz:europe:athens'] = '아테네';
$labels['tz:europe:belgrade'] = '베오그라드';
$labels['tz:europe:berlin'] = '베를린';
$labels['tz:europe:bratislava'] = '브라티슬라바';
$labels['tz:europe:brussels'] = '브뤼셀';
$labels['tz:europe:bucharest'] = '부쿠레슈티';
$labels['tz:europe:budapest'] = '부다페스트';
$labels['tz:europe:busingen'] = '뷔징겐';
$labels['tz:europe:chisinau'] = '키시나우';
$labels['tz:europe:copenhagen'] = '코펜하겐';
$labels['tz:europe:dublin'] = '더블린';
$labels['tz:europe:gibraltar'] = '지브롤터';
$labels['tz:europe:guernsey'] = '건지';
$labels['tz:europe:helsinki'] = '헬싱키';
$labels['tz:europe:isle_of_man'] = '맨섬';
$labels['tz:europe:istanbul'] = '이스탄불';
$labels['tz:europe:jersey'] = '저지';
$labels['tz:europe:kaliningrad'] = '칼리닌그라드';
$labels['tz:europe:kiev'] = '키예프';
$labels['tz:europe:kirov'] = '키로프';
$labels['tz:europe:lisbon'] = '리스본';
$labels['tz:europe:ljubljana'] = '류블랴나';
$labels['tz:europe:london'] = '런던';
$labels['tz:europe:luxembourg'] = '룩셈부르크';
$labels['tz:europe:madrid'] = '마드리드';
$labels['tz:europe:malta'] = '몰타';
$labels['tz:europe:mariehamn'] = '마리에하먼';
$labels['tz:europe:minsk'] = '민스크';
$labels['tz:europe:monaco'] = '모나코';
$labels['tz:europe:moscow'] = '모스크바';
$labels['tz:europe:oslo'] = '오슬로';
$labels['tz:europe:paris'] = '파리';
$labels['tz:europe:podgorica'] = '포드고리차';
$labels['tz:europe:prague'] = '프라하';
$labels['tz:europe:riga'] = '리가';
$labels['tz:europe:rome'] = '로마';
$labels['tz:europe:samara'] = '사마라';
$labels['tz:europe:san_marino'] = '산마리노';
$labels['tz:europe:sarajevo'] = '사라예보';
$labels['tz:europe:saratov'] = '사라토프';
$labels['tz:europe:simferopol'] = '심페로폴리';
$labels['tz:europe:skopje'] = '스코페';
$labels['tz:europe:sofia'] = '소피아';
$labels['tz:europe:stockholm'] = '스톡홀름';
$labels['tz:europe:tallinn'] = '탈린';
$labels['tz:europe:tirane'] = '티라나';
$labels['tz:europe:ulyanovsk'] = '울리야노프스크';
$labels['tz:europe:uzhgorod'] = '우즈호로드';
$labels['tz:europe:vaduz'] = '파두츠';
$labels['tz:europe:vatican'] = '바티칸';
$labels['tz:europe:vienna'] = '비엔나';
$labels['tz:europe:vilnius'] = '빌뉴스';
$labels['tz:europe:volgograd'] = '볼고그라드';
$labels['tz:europe:warsaw'] = '바르샤바';
$labels['tz:europe:zagreb'] = '자그레브';
$labels['tz:europe:zaporozhye'] = '자포리자';
$labels['tz:europe:zurich'] = '취리히';
$labels['tz:indian'] = '인도양';
$labels['tz:indian:antananarivo'] = '안타나나리보';
$labels['tz:indian:chagos'] = '차고스';
$labels['tz:indian:christmas'] = '크리스마스';
$labels['tz:indian:cocos'] = '코코스';
$labels['tz:indian:comoro'] = '코모로';
$labels['tz:indian:kerguelen'] = '케르겔렌';
$labels['tz:indian:mahe'] = '마헤';
$labels['tz:indian:maldives'] = '몰디브';
$labels['tz:indian:mauritius'] = '모리셔스';
$labels['tz:indian:mayotte'] = '마요트';
$labels['tz:indian:reunion'] = '레위니옹';
$labels['tz:pacific'] = '태평양';
$labels['tz:pacific:apia'] = '아피아';
$labels['tz:pacific:auckland'] = '오클랜드';
$labels['tz:pacific:bougainville'] = '부겐빌';
$labels['tz:pacific:chatham'] = '채텀';
$labels['tz:pacific:chuuk'] = '축';
$labels['tz:pacific:easter'] = '이스터';
$labels['tz:pacific:efate'] = '에파테';
$labels['tz:pacific:enderbury'] = '엔더버리';
$labels['tz:pacific:fakaofo'] = '파카오포';
$labels['tz:pacific:fiji'] = '피지';
$labels['tz:pacific:funafuti'] = '푸나푸티';
$labels['tz:pacific:galapagos'] = '갈라파고스';
$labels['tz:pacific:gambier'] = '갬비어';
$labels['tz:pacific:guadalcanal'] = '과달카날';
$labels['tz:pacific:guam'] = '괌';
$labels['tz:pacific:honolulu'] = '호놀룰루';
$labels['tz:pacific:johnston'] = '존스톤';
$labels['tz:pacific:kiritimati'] = '키리티마티';
$labels['tz:pacific:kosrae'] = '코스라에';
$labels['tz:pacific:kwajalein'] = '콰잘렌';
$labels['tz:pacific:majuro'] = '마주로';
$labels['tz:pacific:marquesas'] = '마르키즈';
$labels['tz:pacific:midway'] = '미드웨이';
$labels['tz:pacific:nauru'] = '나우루';
$labels['tz:pacific:niue'] = '니우에';
$labels['tz:pacific:norfolk'] = '노퍽';
$labels['tz:pacific:noumea'] = '누메아';
$labels['tz:pacific:pago_pago'] = '파고파고';
$labels['tz:pacific:palau'] = '팔라우';
$labels['tz:pacific:pitcairn'] = '핏케언';
$labels['tz:pacific:pohnpei'] = '폰페이';
$labels['tz:pacific:port_moresby'] = '포트모레스비';
$labels['tz:pacific:rarotonga'] = '라로통가';
$labels['tz:pacific:saipan'] = '사이판';
$labels['tz:pacific:tahiti'] = '타히티';
$labels['tz:pacific:tarawa'] = '타라와';
$labels['tz:pacific:tongatapu'] = '통가타푸';
$labels['tz:pacific:wake'] = '웨이크';
$labels['tz:pacific:wallis'] = '월리스';
