<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Radās kļūda!';
$messages['loginfailed']  = 'Pieslēgties neizdevās';
$messages['cookiesdisabled'] = 'Jūsu pārlūkprogramma neatbalsta sīkdatnes (cookies)';
$messages['sessionerror'] = 'Jūsu sesija ir beigusies.';
$messages['cookiesmismatch'] = 'Konstatēta sīkfailu neatbilstība. Lūdzu, notīriet Jūsu interneta pārlūkprogrammas sīkfailus.';
$messages['storageerror'] = 'Neizdevās pieslēgties IMAP serverim';
$messages['servererror'] = 'Servera kļūda!';
$messages['servererrormsg'] = 'Servera kļūda: $msg';
$messages['accountlocked'] = 'Pārāk daudz neveiksmīgu autorizēšanās mēģinājumu. Mēģiniet atkārtoti vēlāk.';
$messages['connerror'] = 'Savienojuma kļūda - nav iespējams pieslēgties serverim!';
$messages['dberror'] = 'Datubāzes kļūda!';
$messages['dbconnerror'] = 'Neizdevās pieslēgties datubāzei!';
$messages['windowopenerror'] = 'Izlēcošais logs tika bloķēts!';
$messages['requesttimedout'] = 'Pieprasījumam iestājās noilgums';
$messages['errorreadonly'] = 'Neizdevās veikt darbību: mape ir tikai lasāma (read only)';
$messages['errornoperm'] = 'Neizdevās veikt darbību: piekļuve liegta';
$messages['erroroverquota'] = 'Operāciju veikt nav iespējams. Uz diska nav brīvas veitas.';
$messages['erroroverquotadelete'] = 'Uz diska nav brīvas vietas. Lai dzēstu vēstuli, lietojiet SHIFT+DEL.';
$messages['invalidrequest'] = 'Nederīgs pieprasījums! Dati netika saglabāti ...';
$messages['invalidhost'] = 'Nederīgs servera nosaukums';
$messages['nomessagesfound'] = 'Šajā pastkastē nav vēstuļu';
$messages['loggedout'] = 'Jūs veiksmīgi pārtraucāt sesiju. Uz redzēšanos!';
$messages['mailboxempty'] = 'Pastkaste ir tukša';
$messages['nomessages'] = 'Nav nevienas vēstules';
$messages['refreshing'] = 'Atjauno...';
$messages['loading'] = 'Notiek ielāde...';
$messages['uploading'] = 'Augšupielāde failu...';
$messages['attaching'] = 'Pievieno failu...';
$messages['uploadingmany'] = 'Augšupielādē failus...';
$messages['loadingdata'] = 'Ielādē datus...';
$messages['checkingmail'] = 'Notiek pasta pārbaude ...';
$messages['sendingmessage'] = 'Tiek sūtīta vēstule ...';
$messages['messagesent'] = 'Vēstule nosūtīta veiksmīgi';
$messages['savingmessage'] = 'Vēstule tiek saglabāta ...';
$messages['messagesaved'] = 'Vēstule saglabāta Uzmetumos';
$messages['successfullysaved'] = 'Veiksmīgi saglabāts.';
$messages['savingresponse'] = 'Tiek saglabāts atbildes teksts ...';
$messages['deleteresponseconfirm'] = 'Vai Jūs tiešām gribat dzēst šo atbildes tekstu?';
$messages['nocontactselected'] = 'Jūs vēl neesat norādījuši nevienu kontaktu.';
$messages['addedsuccessfully'] = 'Kontakts veiksmīgi pievienots adrešu grāmatai';
$messages['contactexists'] = 'Kontakts ar šādu e-pasta adresi jau eksistē';
$messages['contactnameexists'] = 'Kontakts ar šādu vārdu jau eksistē.';
$messages['blockedimages'] = 'Drošības nolūkos attēli, kuri tiek ielādēti no cita servera, šajā vēstulē ir bloķēti';
$messages['blockedresources'] = 'Lai aizsargātu Jūsu privātumu, attālinātie reursi tika nobloķēti.';
$messages['suspiciousemail'] = 'Šajā e-pasta ziņojumā ir aizdomīgas e-pasta adreses, kuras, iespējams, ir krāpnieciskas.';
$messages['bccemail'] = 'Pārsūtītajā (-os) ziņojumā (-os) ir konfidenciāli saņēmēji (BCC).';
$messages['bouncehint'] = 'Ziņojums tiks nosūtīts bez jebkādām izmaiņām, t.i., izmantojot sākotnējo pamattekstu, galvenes un adresātus.';
$messages['encryptedmessage'] = 'Atvainojiet - šī ir šifrēta vēstule un diemžēl nevar tikt parādīta ...';
$messages['externalmessagedecryption'] = 'Šis e-pasts ir šifrēts un var tikt atšifrēts izmantojot interneta pārlūka paplašinājumu.';
$messages['nopubkeyfor'] = 'E-pastam $email netika atrasta neviena publiskā atslēga';
$messages['nopubkeyforsender'] = 'Jūsu sūtīšanas identitātei nav iespējams atrast publisko atslēgu. Vai e-pastu šifrēt tikai saņēmējiem?';
$messages['encryptnoattachments'] = 'Jau augšupielādētu pielikumu nav iespējams nošifrēt. Lūdzu pievienojiet to atkārtoti, izmantojot šifrēšanas redakrotu.';
$messages['searchpubkeyservers'] = 'Vai Jūs gribat lai trūkstošās atslēgas tiek sameklēt publiskajos atslēgu serveros?';
$messages['encryptpubkeysfound'] = 'Tika atrastas sekojošās publiskās atslēgas:';
$messages['keyservererror'] = 'Neizdevās iegūt atslēgu no atslēgu servera.';
$messages['keyimportsuccess'] = 'Publiskā atslēga $key veiksmīgi ieimportēta Jūsu atslēgu sarakstā.';
$messages['nocontactsfound'] = 'Kontakti netika atrasti';
$messages['contactnotfound'] = 'Pieprasītais kontakts nav atrasts';
$messages['contactsearchonly'] = 'Lai atrastu kontaktus no atzīmētās adrešu grāmatas, Jums ir jāizmanto meklēšanas forma.';
$messages['sendingfailed'] = 'Vēstule netika nosūtīta';
$messages['senttooquickly'] = 'Lūdzu uzgaidiet $sec sekundi(-es) pirms sūtiet šo vēstuli';
$messages['errorsavingsent'] = 'Saglabājot nosūtīto vēstuli notika kļūda - vēstule netika saglabāta';
$messages['errorsaving'] = 'Saglabājot vēstuli notika kļūda - vēstule netika saglabāta';
$messages['errormoving'] = 'Vēstule(s) netika pārvietota(s)';
$messages['errorcopying'] = 'Vēstules pārkopēt neizdevās';
$messages['errordeleting'] = 'Vēstules izdzēst neizdevās';
$messages['errormarking'] = 'Iezīmēt vēstules nebija iespējams';
$messages['alerttitle'] = 'Uzmanību';
$messages['confirmationtitle'] = 'Vai Jūs esat pārliecināts...';
$messages['deletecontactconfirm']  = 'Vai tiešām vēlaties dzēst iezīmētās kontaktpersonas?';
$messages['deletegroupconfirm']  = 'Vai tiešām vēlaties dzēst atzīmēto grupu?';
$messages['deletemessagesconfirm'] = 'Vai tiešām vēlaties dzēst iezīmētās vēstules?';
$messages['deletefolderconfirm']  = 'Vai tiešām vēlaties dzēst šo mapi?';
$messages['movefolderconfirm']  = 'Vai Jūs tiešām gribat pārvietot šo mapi?';
$messages['purgefolderconfirm']  = 'Vai tiešām vēlaties dzēst visas vēstules, kuras atrodas šajā mapē?';
$messages['contactdeleting'] = 'Dzēš kontaktus...';
$messages['groupdeleting'] = 'Dzēš grupu...';
$messages['folderdeleting'] = 'Dzēš mapi...';
$messages['foldermoving'] = 'Pārvieto mapi...';
$messages['foldersubscribing'] = 'Pieslēdz mapi...';
$messages['folderunsubscribing'] = 'Atslēdz mapi...';
$messages['formincomplete'] = 'Forma nav pilnībā aizpildīta';
$messages['noemailwarning'] = 'Lūdzu ievadiet korektu e-pasta adresi';
$messages['nonamewarning']  = 'Lūdzu ievadiet vārdu';
$messages['nopagesizewarning'] = 'Lūdzu ievadiet lapas izmēru';
$messages['nosenderwarning'] = 'Lūdzu ievadiet sūtītāja e-pasta adresi';
$messages['recipientsadded'] = 'Adresāti pievienoti veiksmīgi.';
$messages['norecipientwarning'] = 'Lūdzu ievadiet vismaz vienu saņēmēju';
$messages['disclosedrecipwarning'] = 'Katrs adresāts redzēs pārējo adresātu e-pasta adreses. Lai to novērstu un nodrošinātu adresātu privātumu, Jūs varat izmantot Bcc lauku.';
$messages['disclosedreciptitle'] = 'Pārāk daudz publisku adresātu';
$messages['nosubjectwarning']  = 'Lauks "temats" ir tukšs. Vai vēlaties to aizpildīt tagad?';
$messages['nosubjecttitle']  = 'Bez tēmas';
$messages['nobodywarning'] = 'Sūtīt vēstuli bez teksta?';
$messages['notsentwarning'] = 'Vēstule netika nosūtīta un tā satur nesaglabātas izmaiņas. Vai gribat atcelt šīs izmaiņas?';
$messages['restoresavedcomposedata'] = 'Ir atrasta pirms kāda laika uzrakstīta, bet nenosūtīta vēstule.\n\nTēma: $subject\nSaglabāta:$date\n\nVai atjaunot šo vēstuli?';
$messages['nosearchname'] = 'Lūdzu ievadiet kontaktpersonas vārdu vai e-pasta adresi';
$messages['notuploadedwarning'] = 'Visi pielikumi vēl nav augšupielādēti - lūdzu uzgaidiet vai atceļiet augšupielādi';
$messages['searchsuccessful'] = 'Atrastas $nr vēstules';
$messages['contactsearchsuccessful'] = 'Atrasti $nr kontakti';
$messages['searchnomatch'] = 'Meklējot nekas netika atrasts';
$messages['searching'] = 'Meklē...';
$messages['checking'] = 'Pārbauda...';
$messages['stillsearching'] = 'Joprojām meklē ...';
$messages['nospellerrors'] = 'Pareizrakstības kļūdas netika atrastas';
$messages['folderdeleted'] = 'Mape veiksmīgi izdzēsta';
$messages['foldersubscribed'] = 'Mape veiksmīgi pieslēgta.';
$messages['folderunsubscribed'] = 'Mape veiksmīgi atslēgta.';
$messages['folderpurged'] = 'Mape veiksmīgi iztukšota.';
$messages['folderexpunged'] = 'Mape veiksmīgi saspiesta.';
$messages['deletedsuccessfully'] = 'Veiksmīgi izdzēsts';
$messages['converting'] = 'Tiek noņemts vēstules formatējums...';
$messages['messageopenerror'] = 'Nevarēja ielādēt vēstuli no servera';
$messages['filelinkerror'] = 'Neizdevās faila pievienošana.';
$messages['fileuploaderror'] = 'Faila augšupielāde neveiksmīga';
$messages['csvfilemismatch'] = 'Vairāku CSV failu importēšana ar dažādiem datu laukiem nav iespējama.';
$messages['filesizeerror'] = 'Augšupielādētais fails pārsniedz pieļaujamo $size izmēru.';
$messages['filecounterror'] = 'Vienā reizē Jūs varat augšupielādēt maksimums $count failus.';
$messages['msgsizeerror'] = 'Neizdevās pievienot failu. Vēstules izmērs nedrīkst pārsniegt maksimālo pieļaujamo - $size .';
$messages['msgsizeerrorfwd'] = 'Pārsniegts maksimālais ziņojuma izmērs ($size). $num ziņojumi netika pievienoti..';
$messages['copysuccess'] = '$nr kontakti tika veiksmīgi pārkopēti.';
$messages['movesuccess'] = '$nr kontakti tika veiksmīgi pārvietoti.';
$messages['copyerror'] = 'Kontaktus pārkopēt neizdevās.';
$messages['moveerror'] = 'Kontaktus pārvietot neizdevās.';
$messages['sourceisreadonly'] = 'Adreses avots ir lasīšanas režīmā tikai';
$messages['errorsavingcontact'] = 'Kontakta adresi nevarēja saglabāt.';
$messages['movingmessage'] = 'Pārvieto vēstules...';
$messages['copyingmessage'] = 'Kopē vēstules...';
$messages['copyingcontact'] = 'Kopē kontaktus...';
$messages['movingcontact'] = 'Pārvieto kontaktu(s)...';
$messages['deletingmessage'] = 'Dzēš vēstules...';
$messages['markingmessage'] = 'Atzīmē vēstules...';
$messages['addingmember'] = 'Kontaktus pievieno grupai...';
$messages['removingmember'] = 'Kontaktus atvieno no grupas...';
$messages['receiptsent'] = 'Saņemšanas apstiprinājums nosūtīts veiksmīgi.';
$messages['errorsendingreceipt'] = 'Neizdevās nosūtīt saņemšanas apstiprinājumu.';
$messages['deleteidentityconfirm'] = 'Vai Jūs tiešām vēlaties dzēst šo identitāti?';
$messages['nodeletelastidentity'] = 'Šo identitāti nav iespējams izdzēst, jo tā ir pati pēdējā.';
$messages['forbiddencharacter'] = 'Mapes nosaukums satur aizliegtus simbolus.';
$messages['selectimportfile'] = 'Lūdzu norādiet failu, kuru vēlaties augšupielādēt.';
$messages['addresswriterror'] = 'Izvēlētās adrešu grāmatas datus nav iespējams rediģēt.';
$messages['contactaddedtogroup'] = 'Kontakti tika veiksmīgi pievienoti šai grupai.';
$messages['contactremovedfromgroup'] = 'Kontakti tika veiksmīgi atvienoti no šīs grupas.';
$messages['nogroupassignmentschanged'] = 'Grupā nekas netika mainīts.';
$messages['importwait'] = 'Importēju, lūdzu uzgaidiet...';
$messages['importformaterror'] = 'Imports neizdevās! Augšupielādētais fails nav derīgs importam.';
$messages['importconfirm'] = '<b>Veiksmīgi ieimportēti $inserted kontakti</b>';
$messages['importconfirmskipped'] = '<b>Izlaida $skipped jau eksistējošus kontaktus</b>';
$messages['importconfirminvalid'] = '<b>Izlaida $invalid nederīgus kontaktus </b>';
$messages['importconfirmerrors'] = '<b>Neizdevās ieimportēt $errors derīgus kontaktus</b>';
$messages['importmessagesuccess'] = 'Veiksmīgi ieimportētas $nr vēstules';
$messages['importmessageerror'] = 'Importēšanas kļūda! Augšupielādētā datne satur nekorektus datus';
$messages['opnotpermitted'] = 'Darbība nav atļauta!';
$messages['nofromaddress'] = 'Izvēlētajai identitātei nav norādīta e-pasta adrese.';
$messages['editorwarning'] = 'Pārslēdzot redaktora veidus var tikt pazaudēts teksta formatējums. Vai turpināt?';
$messages['httpreceivedencrypterror'] = 'Notika kritiska kļūme. Lūdzu nekavējoties sazinieties ar Jūsu administratoru. <b>Jūsu vēstuli nosūtīt nav iespējams.</b>';
$messages['smtpconnerror'] = 'SMTP kļūme ($code): Neizdevās pieslēgties serverim';
$messages['smtpautherror'] = 'SMTP kļūda ($code): Neizdevās autorizēties.';
$messages['smtpfromerror'] = 'SMTP kļūda ($code): Neizdevās iestatīt sūtītāju "$from" ($msg).';
$messages['smtptoerror'] = 'SMTP kļūda ($code): Neizdevās pievienot saņēmēju "$to" ($msg).';
$messages['smtprecipientserror'] = 'SMTP kļūda: Nav iespējams aptrādāt saņēmēju sarakstu.';
$messages['smtputf8error'] = 'SMTP kļūda: serveris neatbalsta unikodu epasta adresē.';
$messages['smtpsizeerror'] = 'SMTP kļūda: Vēstules izmērs pārsniedz serverī noteikto limitu ($limit)';
$messages['smtperror'] = 'SMTP kļūda: $msg';
$messages['emailformaterror'] = 'Nepareiza e-pasta adrese: $email';
$messages['toomanyrecipients'] = 'Pārāk daudz saņēmēju. Samaziniet skaitu līdz $max.';
$messages['maxgroupmembersreached'] = 'Grupas dalībnieku skaits pārsniedz limitu $max.';
$messages['internalerror'] = 'Atgadījās servera iekšējā kļūda. Lūdzu mēģiniet vēlreiz.';
$messages['contactdelerror'] = 'Kontaktus izdzēst neizdevās.';
$messages['contactdeleted'] = 'Kontakti izdzēsti veiksmīgi.';
$messages['contactrestoreerror'] = 'Izdzēstos kontaktus atjaunot neizdevās.';
$messages['contactrestored'] = 'Kontakti atjaunoti veiksmīgi.';
$messages['groupdeleted'] = 'Grupa izdzēsta veiksmīgi.';
$messages['grouprenamed'] = 'Grupa pārdēvēta veiksmīgi.';
$messages['groupcreated'] = 'Grupa izveidota veiksmīgi.';
$messages['savedsearchdeleted'] = 'Saglabātais meklēšanas pieprasījums izdzēsts veiksmīgi.';
$messages['savedsearchdeleteerror'] = 'Saglabāto meklēšanas pieprasījumu izdzēst neizdevās.';
$messages['savedsearchcreated'] = 'Saglabātais meklēšanas pieprasījums saglabāts veiksmīgi.';
$messages['savedsearchcreateerror'] = 'Meklēšanas pieprasījumu izveidot neizdevās.';
$messages['messagedeleted'] = 'Vēstule(s) veiksmīgi izdzēsta(s).';
$messages['messagemoved'] = 'Vēstule(s) veiksmīgi pārvietota(s).';
$messages['messagemovedtotrash'] = 'Vēstule(s) veiksmīgi iemesta(s) papīrgrozā.';
$messages['messagecopied'] = 'Vēstule(s) veiksmīgi pārkopēta(s).';
$messages['messagemarked'] = 'Vēstule(s) veiksmīgi atzīmēta(s).';
$messages['autocompletechars'] = 'Lai automātiski meklētu, ievadiet vismaz $min burtus.';
$messages['autocompletemore'] = 'Atrasti vairāki ieraksti. Papildiniet meklēšanas kritēriju ar vairāk burtiem.';
$messages['namecannotbeempty'] = 'Lūdzu ievadiet vārdu.';
$messages['nametoolong'] = 'Vārds ir pārāk garš.';
$messages['namedotforbidden'] = 'Mapes nosaukums nedrīkst sākties ar punktu.';
$messages['folderupdated'] = 'Mape vieksmīgi atjaunota.';
$messages['foldercreated'] = 'Mape veiksmīgi izveidota.';
$messages['invalidimageformat'] = 'Nederīgs attēla formāts.';
$messages['mispellingsfound'] = 'Vēstulē atrastas pareizrakstības kļūdas.';
$messages['parentnotwritable'] = 'Neizdevās izveidot/pārvietot mapi atzīmētajā virsmapē. Nav piekļuves tiesību.';
$messages['messagetoobig'] = 'Vēstule daļa ir pārāk liela, lai to varētu apstrādāt.';
$messages['attachmentvalidationerror'] = 'Šis e-pasta pielikums ir aizdomīgs, jo tā tips neatbilst tam, kurš norādīts pašā epasta ziņojumā. Ja Jūs neuzticaties sūtītājam, vai tas ir nepazīstams, Jums labāk nevērt vaļā šo e-pasta pielikumu, jo tas var saturēt ļaundabīgu kodu. <br/><br/><em>Norādīts: $expected; Atrasts: $detected3</em>';
$messages['noscriptwarning'] = 'Uzmanību: lai lasītu e-pastus, Jūsu pārlūkprogrammā jābūt ieslēgtiem JavaScript.';
$messages['messageissent'] = 'E-pasts jau ir nosūtīts, bet nav saglabāts. Vai Jūs vēlaties to tagad saglabāt?';
$messages['errnotfound'] = 'Fails netika atrasts';
$messages['errnotfoundexplain'] = 'Pieprasītais avots netika atrasts!';
$messages['errfailedrequest'] = 'Pieprasījums neizdevās';
$messages['errauthorizationfailed'] = 'Neveiksmīga autorizācija';
$messages['errunauthorizedexplain'] = 'Nevar pārbaudīt vai Jūs esat autorizēts izmantot šo servisu!';
$messages['errrequestcheckfailed'] = 'Pieprasījuma pārbaude neizdevās.';
$messages['errcsrfprotectionexplain'] = "Jūsu drošībai pieeja šim resursam ir aizsargāta pret vairāku vietņu pieprasījuma viltošanu (CSRF ).\nJa Jūs redzat šo ziņojumu, iespējams Jūs iepriekš nebijāt izgājuši ārā no šī e-pasta pārlūka.\n\nLai turpinātu, ir nepieciešams veikt lietotāja darbības.";
$messages['errcontactserveradmin'] = 'Lūdzu kontaktējieties ar servera administratoru.';
$messages['clicktoresumesession'] = 'Lai atjaunotu Jūsu iepriekšējo sesiju, spiest šeit.';
$messages['errcomposesession'] = 'Rakstot vēstuli radās autorizācijas sesijas kļūda';
$messages['errcomposesessionexplain'] = 'Pieprasītā sesija, vēstules rakstīšanai, netika atrasta.';
$messages['clicktocompose'] = 'Lai rakstītu jaunu vēstuli, spiest šeit';
$messages['nosupporterror'] = 'Šī iespēja Jūsu interneta pārlūkā nav atbalstīta.';
$messages['siginserted'] = 'Paraksts ievietots veiksmīgi.';
$messages['responseinserted'] = 'Atbilde ievietota veiksmīgi.';
$messages['noresponsesavailable'] = 'Nav pieejama neviena atbilde.';
$messages['listempty'] = 'Saraksts ir tukšs.';
$messages['listusebutton'] = 'Lai pievienotu jaunu ierakstu, izmantojiet pogu "Izveidot".';
$messages['keypaircreatesuccess'] = 'Jauns atslēgu pāris identitātei $identity tika veiksmīgi izveidots.';
$messages['emptyattachment'] = 'Izskatās, ka šis pielikums ir tukšs.<br>Lūdzu, sazinaties ar personu, kura to nosūtīja.';
$messages['oauthloginfailed'] = 'OAuth autorizācija neizdevās. Lūdzu mēģiniet vēlreiz.';
$messages['oauthinvalidrequest'] = 'Autorizācijas pieprasījums bija kļūdains vai nepabeigts.';
$messages['oauthaccessdenied'] = 'Autorizācijas serveris vai lietotājs noraidīja pieprasījumu.';
