<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Markdown szerkesztő';
$labels['editor_button_title'] = 'Írd meg az üzeneted Markdown-ban, és küld el HTML formátumban';
$labels['toolbar_button_quit'] = 'Vissza az egyszerű szöveg szerkesztőbe';
$labels['toolbar_button_help'] = 'Markdown szintaxis útmutató megnyitása új ablakban';
$labels['toolbar_button_preview'] = 'HTML előnézet, ahogy el lesz küldve';
$labels['toolbar_button_bold'] = 'Félkövér';
$labels['toolbar_button_italic'] = 'Dölt';
$labels['toolbar_button_strike'] = 'Áthúzva';
$labels['toolbar_button_h1'] = 'Címsor 1';
$labels['toolbar_button_h2'] = 'Címsor 2';
$labels['toolbar_button_h3'] = 'Címsor 3';
$labels['toolbar_button_h4'] = 'Címsor 4';
$labels['toolbar_button_h5'] = 'Címsor 5';
$labels['toolbar_button_h6'] = 'Címsor 6';
$labels['toolbar_button_blockquote'] = 'Idézet';
$labels['toolbar_button_unordered_list'] = 'Listajeles lista';
$labels['toolbar_button_ordered_list'] = 'Számozott lista';
$labels['toolbar_button_link'] = 'Hivatkozás';
$labels['toolbar_button_image'] = 'Kép';
$labels['toolbar_button_undo'] = 'Visszavonás';
$labels['toolbar_button_redo'] = 'Újra';
