<roundcube:include file="includes/layout.html" />

<div class="frame-content <roundcube:var name="env:dialog_class" />">
	<roundcube:object name="dialogcontent" />
</div>

<roundcube:include file="includes/footer.html" />
