<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'ئۇ ت س';
$labels['tz:africa'] = 'ئافرىقا';
$labels['tz:africa:abidjan'] = 'ئابىدجان';
$labels['tz:africa:accra'] = 'ئاككىرا';
$labels['tz:africa:addis_ababa'] = 'ئاددىس ئابابا';
$labels['tz:africa:algiers'] = 'ئالجىر';
$labels['tz:africa:asmara'] = 'ئاسمارا';
$labels['tz:africa:bamako'] = 'باماكو';
$labels['tz:africa:bangui'] = 'بانگى';
$labels['tz:africa:banjul'] = 'بانجۇل';
$labels['tz:africa:bissau'] = 'بىسساۋ';
$labels['tz:africa:blantyre'] = 'بلانتىر';
$labels['tz:africa:brazzaville'] = 'برادزاۋىل';
$labels['tz:africa:bujumbura'] = 'بۇجۇمبۇرا';
$labels['tz:africa:cairo'] = 'قاھىرە';
$labels['tz:africa:casablanca'] = 'كاسابىلانكا';
$labels['tz:africa:ceuta'] = 'چۇتا';
$labels['tz:africa:conakry'] = 'كوناكرى';
$labels['tz:africa:dakar'] = 'داقار';
$labels['tz:africa:dar_es_salaam'] = 'دارېسسالام';
$labels['tz:africa:djibouti'] = 'جىبوتى';
$labels['tz:africa:douala'] = 'دۇئالا';
$labels['tz:africa:el_aaiun'] = 'ئال ئايۇن';
$labels['tz:africa:freetown'] = 'فرىتاۋىن';
$labels['tz:africa:gaborone'] = 'گابورون';
$labels['tz:africa:harare'] = 'ھارارە';
$labels['tz:africa:johannesburg'] = 'جوھانىسبۇرگ';
$labels['tz:africa:juba'] = 'جۇبا';
$labels['tz:africa:kampala'] = 'كامپالا';
$labels['tz:africa:khartoum'] = 'قارتۇم';
$labels['tz:africa:kigali'] = 'قىغالى';
$labels['tz:africa:kinshasa'] = 'كىنشاسا';
$labels['tz:africa:lagos'] = 'لاگوس';
$labels['tz:africa:libreville'] = 'لىبرېۋىل';
$labels['tz:africa:lome'] = 'لومې';
$labels['tz:africa:luanda'] = 'لۇئاندا';
$labels['tz:africa:lubumbashi'] = 'لۇبۇمباشى';
$labels['tz:africa:lusaka'] = 'لۇساكا';
$labels['tz:africa:malabo'] = 'مالابو';
$labels['tz:africa:maputo'] = 'ماپۇتو';
$labels['tz:africa:maseru'] = 'ماسېرۇ';
$labels['tz:africa:mbabane'] = 'بابانە';
$labels['tz:africa:mogadishu'] = 'موغادىشۇ';
$labels['tz:africa:monrovia'] = 'مونراۋىيە';
$labels['tz:africa:nairobi'] = 'نايروبى';
$labels['tz:africa:ndjamena'] = 'جامېنا';
$labels['tz:africa:niamey'] = 'نىئامى';
$labels['tz:africa:nouakchott'] = 'نوۋاكشوت';
$labels['tz:africa:ouagadougou'] = 'ئوۋاگادوگو';
$labels['tz:africa:porto-novo'] = 'پورتونوۋو';
$labels['tz:africa:sao_tome'] = 'ساۋتومى';
$labels['tz:africa:tripoli'] = 'ترىپولى';
$labels['tz:africa:tunis'] = 'تۇنىس';
$labels['tz:africa:windhoek'] = 'ۋىندوق';
$labels['tz:america'] = 'ئامىركا';
$labels['tz:america:adak'] = 'ئاداق';
$labels['tz:america:anchorage'] = 'ئانقورىج';
$labels['tz:america:anguilla'] = 'ئانگىللا';
$labels['tz:america:antigua'] = 'ئانتىگىيە';
$labels['tz:america:araguaina'] = 'ئاراگۇاينا';
$labels['tz:america:argentina'] = 'ئارگېنتىنا';
$labels['tz:america:argentina:buenos_aires'] = 'بونىس ئايرىس';
$labels['tz:america:argentina:catamarca'] = 'كاتاماركا';
$labels['tz:america:argentina:cordoba'] = 'كوردوبا';
$labels['tz:america:argentina:jujuy'] = 'جۇجۇي';
$labels['tz:america:argentina:la_rioja'] = 'لارىيوجا';
$labels['tz:america:argentina:mendoza'] = 'مېندوزا';
$labels['tz:america:argentina:rio_gallegos'] = 'رىيو گاللىگوس';
$labels['tz:america:argentina:salta'] = 'سالتا';
$labels['tz:america:argentina:san_juan'] = 'سان جۇۋان';
$labels['tz:america:argentina:san_luis'] = 'سان لۇئىت';
$labels['tz:america:argentina:tucuman'] = 'تۇكۇمان';
$labels['tz:america:argentina:ushuaia'] = 'ئۇشۇۋايە';
$labels['tz:america:aruba'] = 'ئارۇبا';
$labels['tz:america:asuncion'] = 'ئاسۇنسىئون';
$labels['tz:america:atikokan'] = 'ئاتىكوكان';
$labels['tz:america:bahia'] = 'باخىيە';
$labels['tz:america:bahia_banderas'] = 'باخىيە باندېراس';
$labels['tz:america:barbados'] = 'باربادوس';
$labels['tz:america:belem'] = 'بەلەم';
$labels['tz:america:belize'] = 'بەلىزە';
$labels['tz:america:blanc-sablon'] = 'بىلانك-سابلون';
$labels['tz:america:boa_vista'] = 'بوۋا ۋىستا';
$labels['tz:america:bogota'] = 'بوگوتا';
$labels['tz:america:boise'] = 'بوئىزە';
$labels['tz:america:cambridge_bay'] = 'كامبرىج قولتۇقى';
$labels['tz:america:campo_grande'] = 'كامپو گراندى';
$labels['tz:america:cancun'] = 'قانقۇن';
$labels['tz:america:caracas'] = 'قاراقاس';
$labels['tz:america:cayenne'] = 'قايەننە';
$labels['tz:america:cayman'] = 'قايمان';
$labels['tz:america:chicago'] = 'چىكاگو';
$labels['tz:america:chihuahua'] = 'چىخاخا';
$labels['tz:america:costa_rica'] = 'كوستارىكا';
$labels['tz:america:creston'] = 'كرىستون';
$labels['tz:america:cuiaba'] = 'كۇيابا';
$labels['tz:america:curacao'] = 'كۇراساۋ';
$labels['tz:america:danmarkshavn'] = 'دانمارقشاۋىن';
$labels['tz:america:dawson'] = 'داۋسون';
$labels['tz:america:dawson_creek'] = 'داۋسون كىرىك';
$labels['tz:america:denver'] = 'دەنۋە';
$labels['tz:america:detroit'] = 'دىتروئىت';
$labels['tz:america:dominica'] = 'دومىنىك';
$labels['tz:america:edmonton'] = 'ئەدمونتون';
$labels['tz:america:eirunepe'] = 'ئەيرۇنەپە';
$labels['tz:america:el_salvador'] = 'ئەل سالۋادور';
$labels['tz:america:fort_nelson'] = 'فورت نېلسۇن';
$labels['tz:america:fortaleza'] = 'فورتالىزا';
$labels['tz:america:glace_bay'] = 'گلائىس قولتۇقى';
$labels['tz:america:godthab'] = 'كاتخوپ';
$labels['tz:america:goose_bay'] = 'گوئۇس قولتۇقى';
$labels['tz:america:grand_turk'] = 'گرانىت تۈرك';
$labels['tz:america:grenada'] = 'گرېنادا';
$labels['tz:america:guadeloupe'] = 'گۇۋادەلۇپى';
$labels['tz:america:guatemala'] = 'گۋاتېمالا';
$labels['tz:america:guayaquil'] = 'گۋاياكىل';
$labels['tz:america:guyana'] = 'گۇيانا';
$labels['tz:america:halifax'] = 'خالىفاكىس';
$labels['tz:america:havana'] = 'ھاۋانا';
$labels['tz:america:hermosillo'] = 'ھېرموسىللو';
$labels['tz:america:indiana'] = 'ئىندىئانا';
$labels['tz:america:indiana:indianapolis'] = 'ئىندىئاناپولىس';
$labels['tz:america:indiana:knox'] = 'كىنوكىس';
$labels['tz:america:indiana:marengo'] = 'مارېنگو';
$labels['tz:america:indiana:petersburg'] = 'پىتسىبورگ';
$labels['tz:america:indiana:tell_city'] = 'تېل شەھىرى';
$labels['tz:america:indiana:vevay'] = 'ۋەۋەي';
$labels['tz:america:indiana:vincennes'] = 'ۋىنچېنىس';
$labels['tz:america:indiana:winamac'] = 'ۋىناماق';
$labels['tz:america:inuvik'] = 'ئىنۇۋىك';
$labels['tz:america:iqaluit'] = 'ئىقالۇئىت';
$labels['tz:america:jamaica'] = 'يامايكا';
$labels['tz:america:juneau'] = 'جۇنىئو';
$labels['tz:america:kentucky'] = 'كېنتاكى';
$labels['tz:america:kentucky:louisville'] = 'لۇئىسۋىل';
$labels['tz:america:kentucky:monticello'] = 'مونتىچېلو';
$labels['tz:america:kralendijk'] = 'كرالېندىجىك';
$labels['tz:america:la_paz'] = 'لاپاز';
$labels['tz:america:lima'] = 'لىما';
$labels['tz:america:los_angeles'] = 'لوس ئانجىلىس';
$labels['tz:america:lower_princes'] = 'لوۋىر پرىنسەس';
$labels['tz:america:maceio'] = 'ماچېئو';
$labels['tz:america:managua'] = 'ماناگۇۋا';
$labels['tz:america:manaus'] = 'مانائۇس';
$labels['tz:america:marigot'] = 'مارىگوت';
$labels['tz:america:martinique'] = 'مارتىنىقۇ';
$labels['tz:america:matamoros'] = 'ماتامورۇس';
$labels['tz:america:mazatlan'] = 'مازاتلان';
$labels['tz:america:menominee'] = 'مېنومىنىي';
$labels['tz:america:merida'] = 'مېرىدا';
$labels['tz:america:metlakatla'] = 'مەتلاقاتلا';
$labels['tz:america:mexico_city'] = 'مېكسىكا شەھىرى';
$labels['tz:america:miquelon'] = 'مىقۇئىلون';
$labels['tz:america:moncton'] = 'مونتون';
$labels['tz:america:monterrey'] = 'مونتېررى';
$labels['tz:america:montevideo'] = 'مونتېۋىدىئو';
$labels['tz:america:montserrat'] = 'مونسەررات';
$labels['tz:america:nassau'] = 'ناساۋ';
$labels['tz:america:new_york'] = 'نىيو-يورۇك';
$labels['tz:america:nipigon'] = 'نىپىگون';
$labels['tz:america:nome'] = 'نومى';
$labels['tz:america:noronha'] = 'نورونا';
$labels['tz:america:north_dakota'] = 'شىمالىي داكوتا';
$labels['tz:america:north_dakota:beulah'] = 'بىئۇلاخ';
$labels['tz:america:north_dakota:center'] = 'مەركەز';
$labels['tz:america:north_dakota:new_salem'] = 'يېڭى سەلىم';
$labels['tz:america:ojinaga'] = 'ئوجىناگا';
$labels['tz:america:panama'] = 'پاناما';
$labels['tz:america:pangnirtung'] = 'پاڭنىرتۇڭ';
$labels['tz:america:paramaribo'] = 'پارامارىبو';
$labels['tz:america:phoenix'] = 'فىنىكىس';
$labels['tz:america:port-au-prince'] = 'پورت-ئو-پرىنس';
$labels['tz:america:port_of_spain'] = 'ئىسپانىيە پورتى';
$labels['tz:america:porto_velho'] = 'پورتو ۋېلو';
$labels['tz:america:puerto_rico'] = 'پۇئېرتورىكو';
$labels['tz:america:rainy_river'] = 'رېينى دەرياسى';
$labels['tz:america:rankin_inlet'] = 'رەنكىن ئىنلەت';
$labels['tz:america:recife'] = 'رەچىفە';
$labels['tz:america:regina'] = 'رېجىنا';
$labels['tz:america:resolute'] = 'رېسولۇتى';
$labels['tz:america:rio_branco'] = 'رىئو برانكو';
$labels['tz:america:santarem'] = 'سانتارەم';
$labels['tz:america:santiago'] = 'سانتىياگو';
$labels['tz:america:santo_domingo'] = 'سانتا دومىنگو';
$labels['tz:america:sao_paulo'] = 'ساۋ پاۋلو';
$labels['tz:america:scoresbysund'] = 'سكورىسبىسۇند';
$labels['tz:america:sitka'] = 'سىتكا';
$labels['tz:america:st_barthelemy'] = 'سانت بارتېلىمى';
$labels['tz:america:st_johns'] = "سانت جونىس";
$labels['tz:america:st_kitts'] = 'سانت كىتىس';
$labels['tz:america:st_lucia'] = 'سانتا لۇچىيا';
$labels['tz:america:st_thomas'] = 'سانت توماس';
$labels['tz:america:st_vincent'] = 'سانت ۋىنچېنت';
$labels['tz:america:swift_current'] = 'سىۋىفت كارىنت';
$labels['tz:america:tegucigalpa'] = 'تېگۇچىگالفا';
$labels['tz:america:thule'] = 'تۇلى';
$labels['tz:america:thunder_bay'] = 'ساندىر قولتۇقى';
$labels['tz:america:tijuana'] = 'تىجۇۋانا';
$labels['tz:america:toronto'] = 'تورونتو';
$labels['tz:america:tortola'] = 'تورتولا';
$labels['tz:america:vancouver'] = 'ۋانكۇۋېر';
$labels['tz:america:whitehorse'] = 'ۋايىتخورس';
$labels['tz:america:winnipeg'] = 'ۋىننىپەگ';
$labels['tz:america:yakutat'] = 'ياقۇتات';
$labels['tz:america:yellowknife'] = 'يەلونايىف';
$labels['tz:antarctica'] = 'ئانتىراكتىكا';
$labels['tz:antarctica:casey'] = 'كاسىي';
$labels['tz:antarctica:davis'] = 'دەۋىس';
$labels['tz:antarctica:dumontdurville'] = "دۇمونت دۇرۋىل";
$labels['tz:antarctica:macquarie'] = 'ماقىۋارى';
$labels['tz:antarctica:mawson'] = 'ماۋسون';
$labels['tz:antarctica:mcmurdo'] = 'مىكمۇردو';
$labels['tz:antarctica:palmer'] = 'پالمىر';
$labels['tz:antarctica:rothera'] = 'روتېرا';
$labels['tz:antarctica:syowa'] = 'سىيوۋا';
$labels['tz:antarctica:troll'] = 'تىرول';
$labels['tz:antarctica:vostok'] = 'ۋوستوق';
$labels['tz:arctic'] = 'قۇتۇپ';
$labels['tz:arctic:longyearbyen'] = 'لوڭيىربىيەن';
$labels['tz:asia'] = 'ئاسىيا';
$labels['tz:asia:aden'] = 'ئادەن';
$labels['tz:asia:almaty'] = 'ئالمۇتا';
$labels['tz:asia:amman'] = 'ئاممان';
$labels['tz:asia:anadyr'] = 'ئانادىر';
$labels['tz:asia:aqtau'] = 'ئاقتاۋ';
$labels['tz:asia:aqtobe'] = 'ئاقتۆپە';
$labels['tz:asia:ashgabat'] = 'ئاشىغئابات';
$labels['tz:asia:atyrau'] = 'ئاتىراۋ';
$labels['tz:asia:baghdad'] = 'باغداد';
$labels['tz:asia:bahrain'] = 'باخرائىن';
$labels['tz:asia:baku'] = 'باقۇ';
$labels['tz:asia:bangkok'] = 'بانكوك';
$labels['tz:asia:barnaul'] = 'بارنائۇل';
$labels['tz:asia:beirut'] = 'بەيرۇت';
$labels['tz:asia:bishkek'] = 'بىشكەك';
$labels['tz:asia:brunei'] = 'بىرۇنىي';
$labels['tz:asia:chita'] = 'كىتا';
$labels['tz:asia:choibalsan'] = 'قويبالسان';
$labels['tz:asia:colombo'] = 'كولومبو';
$labels['tz:asia:damascus'] = 'دەمەشق';
$labels['tz:asia:dhaka'] = 'داخا';
$labels['tz:asia:dili'] = 'دىلى';
$labels['tz:asia:dubai'] = 'دۇبەي';
$labels['tz:asia:dushanbe'] = 'دۈشەنبە';
$labels['tz:asia:famagusta'] = 'فاماگۇستا';
$labels['tz:asia:gaza'] = 'غەززە';
$labels['tz:asia:hebron'] = 'خېبىروئىن';
$labels['tz:asia:ho_chi_minh'] = 'خوكىمىن';
$labels['tz:asia:hong_kong'] = 'شاڭگاڭ';
$labels['tz:asia:hovd'] = 'خوۋىد';
$labels['tz:asia:irkutsk'] = 'ئىركۇتسىك';
$labels['tz:asia:jakarta'] = 'جاكارتا';
$labels['tz:asia:jayapura'] = 'جاياپۇرا';
$labels['tz:asia:jerusalem'] = 'ئېرۇسالىم';
$labels['tz:asia:kabul'] = 'كابۇل';
$labels['tz:asia:kamchatka'] = 'كامچاتكا';
$labels['tz:asia:karachi'] = 'كاراچى';
$labels['tz:asia:kathmandu'] = 'كاتماندۇ';
$labels['tz:asia:khandyga'] = 'كاندىگا';
$labels['tz:asia:kolkata'] = 'كولكاتا';
$labels['tz:asia:krasnoyarsk'] = 'كراسنويارسىك';
$labels['tz:asia:kuala_lumpur'] = 'كۇلا-لامپۇر';
$labels['tz:asia:kuching'] = 'كۇچىڭ';
$labels['tz:asia:kuwait'] = 'كۇۋەيت';
$labels['tz:asia:macau'] = 'ئاۋمىن';
$labels['tz:asia:magadan'] = 'ماغادان';
$labels['tz:asia:makassar'] = 'ماكاسسار';
$labels['tz:asia:manila'] = 'مانىلا';
$labels['tz:asia:muscat'] = 'مۇسقات';
$labels['tz:asia:nicosia'] = 'نىكوسىيە';
$labels['tz:asia:novokuznetsk'] = 'نوۋوكۇزنەتسىك';
$labels['tz:asia:novosibirsk'] = 'نوۋوسىبىرسىك';
$labels['tz:asia:omsk'] = 'ئومسىق';
$labels['tz:asia:oral'] = 'ئورال';
$labels['tz:asia:phnom_penh'] = 'پىنوم پىن';
$labels['tz:asia:pontianak'] = 'پونتىياناق';
$labels['tz:asia:pyongyang'] = 'پيوڭياڭ';
$labels['tz:asia:qatar'] = 'قاتار';
$labels['tz:asia:qyzylorda'] = 'قىزىلئوردا';
$labels['tz:asia:riyadh'] = 'رىياد';
$labels['tz:asia:sakhalin'] = 'ساخالىن';
$labels['tz:asia:samarkand'] = 'سەمەرقەنت';
$labels['tz:asia:seoul'] = 'سىئول';
$labels['tz:asia:shanghai'] = 'شاڭخەي';
$labels['tz:asia:singapore'] = 'سىنگاپور';
$labels['tz:asia:srednekolymsk'] = 'سىرەدنەكولىسىك';
$labels['tz:asia:taipei'] = 'تەيبېي';
$labels['tz:asia:tashkent'] = 'تاشكەنت';
$labels['tz:asia:tbilisi'] = 'تىبىلىسى';
$labels['tz:asia:tehran'] = 'تېھران';
$labels['tz:asia:thimphu'] = 'تىمپۇ';
$labels['tz:asia:tokyo'] = 'توكيو';
$labels['tz:asia:tomsk'] = 'تومسىق';
$labels['tz:asia:ulaanbaatar'] = 'ئۇلانباتۇر';
$labels['tz:asia:urumqi'] = 'ئۈرۈمچى';
$labels['tz:asia:ust-nera'] = 'ئۇست-نېرا';
$labels['tz:asia:vientiane'] = 'ۋىئېنتىئانە';
$labels['tz:asia:vladivostok'] = 'ۋىلادىۋوستوق';
$labels['tz:asia:yakutsk'] = 'ياكۇتىسك';
$labels['tz:asia:yangon'] = 'يانگون';
$labels['tz:asia:yekaterinburg'] = 'ياكاتېرىنبۇرگ';
$labels['tz:asia:yerevan'] = 'يەرەۋان';
$labels['tz:atlantic'] = 'ئاتلانتىك';
$labels['tz:atlantic:azores'] = 'ئازورىس';
$labels['tz:atlantic:bermuda'] = 'بېرمۇدا';
$labels['tz:atlantic:canary'] = 'كانارىي';
$labels['tz:atlantic:cape_verde'] = 'كاپى ۋېردى';
$labels['tz:atlantic:faroe'] = 'فاروئە';
$labels['tz:atlantic:madeira'] = 'مادېيرا';
$labels['tz:atlantic:reykjavik'] = 'رەيجاۋىك';
$labels['tz:atlantic:south_georgia'] = 'جەنۇبىي گرۇزىيە';
$labels['tz:atlantic:st_helena'] = 'سانت ھەلەنا';
$labels['tz:atlantic:stanley'] = 'ستېيىنلى';
$labels['tz:australia'] = 'ئاۋىسترالىيە';
$labels['tz:australia:adelaide'] = 'ئادېلايدې';
$labels['tz:australia:brisbane'] = 'برىسبانە';
$labels['tz:australia:broken_hill'] = 'بىروۋكىن خىل';
$labels['tz:australia:currie'] = 'كۇررىي';
$labels['tz:australia:darwin'] = 'دارۋىن';
$labels['tz:australia:eucla'] = 'يۇكىلا';
$labels['tz:australia:hobart'] = 'خوبارت';
$labels['tz:australia:lindeman'] = 'لىندېمان';
$labels['tz:australia:lord_howe'] = 'لورد خوۋىي';
$labels['tz:australia:melbourne'] = 'مېلبورن';
$labels['tz:australia:perth'] = 'پېرىس';
$labels['tz:australia:sydney'] = 'سىدنى';
$labels['tz:europe'] = 'ياۋروپا';
$labels['tz:europe:amsterdam'] = 'ئامىستىردام';
$labels['tz:europe:andorra'] = 'ئاندوررا';
$labels['tz:europe:astrakhan'] = 'ئاستراخان';
$labels['tz:europe:athens'] = 'ئافىنا';
$labels['tz:europe:belgrade'] = 'بېلگرادى';
$labels['tz:europe:berlin'] = 'بېرلىن';
$labels['tz:europe:bratislava'] = 'براتىسلاۋىيە';
$labels['tz:europe:brussels'] = 'بىريۇكسىل';
$labels['tz:europe:bucharest'] = 'بۇچارىست';
$labels['tz:europe:budapest'] = 'بۇداپىشت';
$labels['tz:europe:busingen'] = 'بۇسىنجىن';
$labels['tz:europe:chisinau'] = 'كىسىناۋ';
$labels['tz:europe:copenhagen'] = 'كوپىنھاگىن';
$labels['tz:europe:dublin'] = 'دۇبلىن';
$labels['tz:europe:gibraltar'] = 'جىبرالتار';
$labels['tz:europe:guernsey'] = 'گېرنىزى';
$labels['tz:europe:helsinki'] = 'خېلسىنكى';
$labels['tz:europe:isle_of_man'] = 'مان ئارىلى';
$labels['tz:europe:istanbul'] = 'ئىستانبۇل';
$labels['tz:europe:jersey'] = 'جېرسى';
$labels['tz:europe:kaliningrad'] = 'كالىنىنگرات';
$labels['tz:europe:kiev'] = 'كىيىۋ';
$labels['tz:europe:kirov'] = 'كىروۋ';
$labels['tz:europe:lisbon'] = 'لىزبۇن';
$labels['tz:europe:ljubljana'] = 'لۇبىلىئانا';
$labels['tz:europe:london'] = 'لوندون';
$labels['tz:europe:luxembourg'] = 'لىيۇكسىنبۇرگ';
$labels['tz:europe:madrid'] = 'مادىرىد';
$labels['tz:europe:malta'] = 'مالتا';
$labels['tz:europe:mariehamn'] = 'مارىھامىن';
$labels['tz:europe:minsk'] = 'مىنسىق';
$labels['tz:europe:monaco'] = 'موناكو';
$labels['tz:europe:moscow'] = 'موسكىۋا';
$labels['tz:europe:oslo'] = 'ئوسلو';
$labels['tz:europe:paris'] = 'پارىژ';
$labels['tz:europe:podgorica'] = 'پودگورىكا';
$labels['tz:europe:prague'] = 'پىراگ';
$labels['tz:europe:riga'] = 'رىگا';
$labels['tz:europe:rome'] = 'رىم';
$labels['tz:europe:samara'] = 'سامارە';
$labels['tz:europe:san_marino'] = 'سان مارىنو';
$labels['tz:europe:sarajevo'] = 'ساراجېۋو';
$labels['tz:europe:saratov'] = 'ساراتوۋ';
$labels['tz:europe:simferopol'] = 'سىمفېروپول';
$labels['tz:europe:skopje'] = 'سىكوپىيە';
$labels['tz:europe:sofia'] = 'سوفىيە';
$labels['tz:europe:stockholm'] = 'ستوكخولىم';
$labels['tz:europe:tallinn'] = 'تاللىن';
$labels['tz:europe:tirane'] = 'تىرانە';
$labels['tz:europe:ulyanovsk'] = 'ئۇلىئانوۋىسك';
$labels['tz:europe:uzhgorod'] = 'ئۇزغوروت';
$labels['tz:europe:vaduz'] = 'ۋادۇز';
$labels['tz:europe:vatican'] = 'ۋاتىكان';
$labels['tz:europe:vienna'] = 'ۋىيېنا';
$labels['tz:europe:vilnius'] = 'ۋىلنىئۇس';
$labels['tz:europe:volgograd'] = 'ۋولگوگرات';
$labels['tz:europe:warsaw'] = 'ۋارشاۋا';
$labels['tz:europe:zagreb'] = 'زاگرىپ';
$labels['tz:europe:zaporozhye'] = 'زاپوروژى';
$labels['tz:europe:zurich'] = 'سيۇرىخ';
$labels['tz:indian'] = 'ھىندى';
$labels['tz:indian:antananarivo'] = 'ئانتانانارىۋو';
$labels['tz:indian:chagos'] = 'چاگوس';
$labels['tz:indian:christmas'] = 'روجىستىۋا';
$labels['tz:indian:cocos'] = 'كوكوس';
$labels['tz:indian:comoro'] = 'كومورو';
$labels['tz:indian:kerguelen'] = 'كېرگېلەن';
$labels['tz:indian:mahe'] = 'ماخې';
$labels['tz:indian:maldives'] = 'مولداۋا';
$labels['tz:indian:mauritius'] = 'ماۋرىتۇس';
$labels['tz:indian:mayotte'] = 'مايوتتى';
$labels['tz:indian:reunion'] = 'رىئۇنىئون';
$labels['tz:pacific'] = 'تىنچ ئوكيان';
$labels['tz:pacific:apia'] = 'ئاپىيا';
$labels['tz:pacific:auckland'] = 'ئاقلەندىيە';
$labels['tz:pacific:bougainville'] = 'بۇگانىۋىل';
$labels['tz:pacific:chatham'] = 'چاتام';
$labels['tz:pacific:chuuk'] = 'چۇك';
$labels['tz:pacific:easter'] = 'ئىستىر';
$labels['tz:pacific:efate'] = 'ئېفاتې';
$labels['tz:pacific:enderbury'] = 'ئەندەربۇرى';
$labels['tz:pacific:fakaofo'] = 'فاكاۋفو';
$labels['tz:pacific:fiji'] = 'فىجى';
$labels['tz:pacific:funafuti'] = 'فۇنافۇتى';
$labels['tz:pacific:galapagos'] = 'گالاپاگوس';
$labels['tz:pacific:gambier'] = 'گامبىيىر';
$labels['tz:pacific:guadalcanal'] = 'گۋادالقانال';
$labels['tz:pacific:guam'] = 'گۇئام';
$labels['tz:pacific:honolulu'] = 'ھونولو';
$labels['tz:pacific:johnston'] = 'جونسىتون';
$labels['tz:pacific:kiritimati'] = 'كىرىتىماتى';
$labels['tz:pacific:kosrae'] = 'كوسرائە';
$labels['tz:pacific:kwajalein'] = 'كۋاجالىن';
$labels['tz:pacific:majuro'] = 'ماجۇرو';
$labels['tz:pacific:marquesas'] = 'ماركىساس';
$labels['tz:pacific:midway'] = 'مىدۋاي';
$labels['tz:pacific:nauru'] = 'ناۋرۇ';
$labels['tz:pacific:niue'] = 'نىيۇئېي';
$labels['tz:pacific:norfolk'] = 'نورفولك';
$labels['tz:pacific:noumea'] = 'نۇمىئا';
$labels['tz:pacific:pago_pago'] = 'پاگو پاگو';
$labels['tz:pacific:palau'] = 'پالاۋ';
$labels['tz:pacific:pitcairn'] = 'پىتكارىن';
$labels['tz:pacific:pohnpei'] = 'پونپىي';
$labels['tz:pacific:port_moresby'] = 'مورېسبىي پورتى';
$labels['tz:pacific:rarotonga'] = 'راروتونگا';
$labels['tz:pacific:saipan'] = 'سايپەن';
$labels['tz:pacific:tahiti'] = 'تاخىتى';
$labels['tz:pacific:tarawa'] = 'تاراۋا';
$labels['tz:pacific:tongatapu'] = 'تونگاتاپۇ';
$labels['tz:pacific:wake'] = 'ۋېيك';
$labels['tz:pacific:wallis'] = 'ۋاللىس';
