<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Bi xêr hatî $product';
$labels['username'] = 'Navê bikarhêner';
$labels['password'] = 'Borînpeyv';
$labels['server'] = 'Rajegir';
$labels['login'] = 'Têkevê';
$labels['oauthlogin'] = 'Bi $provider re têkeve';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Derkeve';
$labels['mail'] = 'E-name';
$labels['settings'] = 'Sazkarî';
$labels['addressbook'] = 'Pirtûka navnîşanê';
$labels['darkmode'] = 'Awayê tarî';
$labels['lightmode'] = 'Awayê ronî';
$labels['inbox'] = 'Peyamdank';
$labels['drafts'] = 'Reşnivîs';
$labels['sent'] = 'Şandî';
$labels['trash'] = 'Jêbirdank';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Ji bo peldankên taybet navên rast nîşan bide';
$labels['subject'] = 'Mijar';
$labels['from'] = 'Ji';
$labels['sender'] = 'Şander';
$labels['to'] = 'Bo';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Bersivê bide';
$labels['date'] = 'Dîrok';
$labels['size'] = 'Mezinahî';
$labels['priority'] = 'Girîngî';
$labels['organization'] = 'Sazî';
$labels['readstatus'] = 'Rewşê bixwîne';
$labels['listoptions'] = 'Vebijêrkên rêzê...';
$labels['listoptionstitle'] = 'Vebijêrkên rêzê';
$labels['mailboxlist'] = 'Peldank';
$labels['messagesfromto'] = 'Peyam $ji bo $to ji $count';
$labels['threadsfromto'] = 'Mijar $ji bo $to ji $coun';
$labels['messagenrof'] = '$nr peyam ji $count';
$labels['fromtoshort'] = '$ji – $bo ji $count';
$labels['copy'] = 'Jê bigire';
$labels['move'] = 'Bilivîne';
$labels['moveto'] = 'Bilivîne bo...';
$labels['copyto'] = 'Jê bigire bo ...';
$labels['download'] = 'Daxîne';
$labels['open'] = 'Veke';
$labels['showattachment'] = 'Nîşan bide';
$labels['showanyway'] = 'Her çawa be nîşan bide';
$labels['filename'] = 'Navê pelê';
$labels['filesize'] = 'Mezinahiya pelê';
$labels['addtoaddressbook'] = 'Têxe lênûska navnîşanan';
$labels['sun'] = 'Yek';
$labels['mon'] = 'Duş';
$labels['tue'] = 'Sêş';
$labels['wed'] = 'Çar';
$labels['thu'] = 'Pên';
$labels['fri'] = 'Înî';
$labels['sat'] = 'Şem';
$labels['sunday'] = 'Yekşem';
$labels['monday'] = 'Duşem';
$labels['tuesday'] = 'Sêşem';
$labels['wednesday'] = 'Çarşem';
$labels['thursday'] = 'Pêncşem';
$labels['friday'] = 'Înî';
$labels['saturday'] = 'Şemî';
$labels['jan'] = 'Çil';
$labels['feb'] = 'Reş';
$labels['mar'] = 'Ada';
$labels['apr'] = 'Avr';
$labels['may'] = 'Gul';
$labels['jun'] = 'Pûş';
$labels['jul'] = 'Tîr';
$labels['aug'] = 'Teb';
$labels['sep'] = 'Îlo';
$labels['oct'] = 'Cot';
$labels['nov'] = 'Mij';
$labels['dec'] = 'Ber';
$labels['longjan'] = 'Çile';
$labels['longfeb'] = 'Reşemî';
$labels['longmar'] = 'Adar';
$labels['longapr'] = 'Avrêl';
$labels['longmay'] = 'Gulan';
$labels['longjun'] = 'Pûşper';
$labels['longjul'] = 'Tîrmeh';
$labels['longaug'] = 'Tebax';
$labels['longsep'] = 'Îlon';
$labels['longoct'] = 'Cotmeh';
$labels['longnov'] = 'Mijdar';
$labels['longdec'] = 'Berfanbar';
$labels['today'] = 'Îro';
$labels['refresh'] = 'Rojane bike';
$labels['checkmail'] = 'Ji bo peyamên nû kontrol bike';
$labels['compose'] = 'Peyamekê biafirîne';
$labels['writenewmessage'] = 'Peyameke nû biafirîne';
$labels['reply'] = 'Bersivê bide';
$labels['replytomessage'] = 'Bersivê bide şander';
$labels['replytoallmessage'] = 'Bersivê ji bo hemû kesên ku ev peyan standine bişîne';
$labels['replyall'] = 'Bersivê bide hemûyan';
$labels['replylist'] = 'Lîsteyê bibersivîne';
$labels['forward'] = 'Beralî bike';
$labels['forwardmessage'] = 'Bersivê bide peyamê';
$labels['bounce'] = 'Ji nû ve bişîne';
$labels['deletemessage'] = 'Peyamê jê bibe';
$labels['undeletemessage'] = 'Pêyamê jê nebe';
$labels['movemessagetotrash'] = 'Peyamê bilivîne jêbirdankê';
$labels['printmessage'] = 'Vê peyamê çap bike';
$labels['previousmessage'] = 'Peyama berê nîşan bide';
$labels['firstmessage'] = 'Peyama yekemîn nîşan bide';
$labels['nextmessage'] = 'Peyama di pêş de nîşan bide';
$labels['lastmessage'] = 'Peyama dawî nîşan bide';
$labels['backtolist'] = 'Vegere rêza peyaman';
$labels['viewsource'] = 'Çavkaniyê nîşan bide';
$labels['mark'] = 'Nîşan bike';
$labels['markmessages'] = 'Peyamê nîşan bike';
$labels['markread'] = 'Wekî xwendî';
$labels['markunread'] = 'Wekî nexwendî';
$labels['markflagged'] = 'Wekî nîşankirî';
$labels['markunflagged'] = 'Wekî nenişankirî';
$labels['markundeleted'] = 'Wekî ku nejêbirî';
$labels['markasread'] = 'Wekî xwendî nîşan bide';
$labels['markasunread'] = 'Wekî nexwendî nîşan bide';
$labels['markasflagged'] = 'Wekî nîşankirî nîşan bide';
$labels['markasunflagged'] = 'Wekî nenîşankirî nîşan bide';
$labels['moreactions'] = 'Bêtir çalakî...';
$labels['markallread'] = 'Hemûyan wekî xwendî nîşan bike';
$labels['folders-cur'] = 'Tenê peldanka hilbijartî';
$labels['folders-sub'] = 'Peldanka hilbijartî û binpeldankên wê';
$labels['folders-all'] = 'Hemû peldank';
$labels['more'] = 'Bêtir';
$labels['back'] = 'Paş';
$labels['options'] = 'Vebijêrk';
$labels['composeoptions'] = 'Vebijêrkên nivîsandinê';
$labels['optionsandattachments'] = 'Vebijêrk û pêvek';
$labels['actions'] = 'Çalakî';
$labels['first'] = 'Pêşîn';
$labels['last'] = 'Dawîn';
$labels['previous'] = 'Pêşde';
$labels['next'] = 'Piştde';
$labels['select'] = 'Hilbijêre';
$labels['selection'] = 'Hilbijartin';
$labels['all'] = 'Hemû';
$labels['none'] = 'Ne yek jî';
$labels['currpage'] = 'Rûpela niha';
$labels['isread'] = 'Bixwîne';
$labels['unread'] = 'Nexwendî';
$labels['flagged'] = 'Nîşankirî';
$labels['unflagged'] = 'Ne nîşankirî';
$labels['unanswered'] = 'Bersivnedayî';
$labels['withattachment'] = 'Bi pêvek';
$labels['deleted'] = 'Jêbirî';
$labels['undeleted'] = 'Nê jêbirî';
$labels['replied'] = 'Bersivdayî';
$labels['forwarded'] = 'Beralî bike';
$labels['filter'] = 'Parzûn';
$labels['list'] = 'Lîste';
$labels['threads'] = 'Mijar';
$labels['expand-all'] = 'Hemûyan fereh bike';
$labels['expand-unread'] = 'Ên nexwendî veke';
$labels['collapse-all'] = 'Hemûyan hilweşîne';
$labels['showunread'] = 'Peyamên nexwendî nîşan bide';
$labels['expand_only_unread'] = 'tenê bi peyamên nexwendî';
$labels['fromto'] = 'Ji/Jê re';
$labels['flag'] = 'Al';
$labels['attachment'] = 'Pêvek';
$labels['nonesort'] = 'Ne yek jî';
$labels['sentdate'] = 'Dema şandinê';
$labels['arrival'] = 'Dema hatinê';
$labels['asc'] = 'ber bi jor ve';
$labels['desc'] = 'ber bi jêr ve';
$labels['listcolumns'] = 'Stûnan lîste bike';
$labels['listsorting'] = 'Stûna parzûnkirinê';
$labels['listorder'] = 'Rêza parzûnkirinê';
$labels['listmode'] = 'Moda dîtina lîsteyê';
$labels['lmode'] = 'Moda lîsteyê';
$labels['layoutlist'] = 'Lîste';
$labels['folderactions'] = 'Tevgerên dosyeyê...';
$labels['compact'] = 'Kompakt';
$labels['empty'] = 'Vala bike';
$labels['mailimportdesc'] = 'Tu dikare nameyê bi riya barkirina pelan di formatên <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> an<a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> de bike.';
$labels['quota'] = 'Bikaranîna dîskê';
$labels['unknown'] = 'nenas';
$labels['unlimited'] = 'bêsînor';
$labels['quotatotal'] = 'Sînor';
$labels['quotaused'] = 'Bikarhatî';
$labels['quotastorage'] = 'Valahiya dîskê';
$labels['quotamessage'] = 'Hejmara peyaman';
$labels['shortheaderdate'] = 'Di $date de';
$labels['shortheaderto'] = 'Bo $to di $date de';
$labels['quicksearch'] = 'Lêgerîna bilez';
$labels['searchplaceholder'] = 'Bigere';
$labels['resetsearch'] = 'Lêgerînê ji nû ve saz bike';
$labels['msgtext'] = 'Hemû peyam';
$labels['type'] = 'Cûre';
$labels['namex'] = 'Nav';
$labels['currentfolder'] = 'Peldanka heyî';
$labels['subfolders'] = 'Ev û bindosye';
$labels['allfolders'] = 'Hemû dosye';
$labels['searchinterval-1W'] = 'ji hefteyekê kevntir';
$labels['searchinterval-1M'] = 'ji mehekê kevntir';
$labels['searchinterval-1Y'] = 'ji salekê kevntir';
$labels['searchinterval1W'] = 'ji hefteyekê biçûktir';
$labels['searchinterval1M'] = 'ji mehekê biçûktir';
$labels['searchinterval1Y'] = 'ji salekê biçûktir';
$labels['infolder'] = 'Peldank: $folder';
$labels['currentaddressbook'] = 'Pirtûka navnîşanên heyî';
$labels['alladdressbooks'] = 'Hemû pirtûkên navnîşanan';
$labels['openinextwin'] = 'Di pencereyeke nû de veke';
$labels['emlsave'] = 'Daxîne (.eml)';
$labels['changeformathtml'] = 'Di forma HTMLê de nîşan bide';
$labels['editasnew'] = 'Wek nû sererast bike';
$labels['send'] = 'Bişîne';
$labels['sendmessage'] = 'Peyamê niha bişîne';
$labels['savemessage'] = 'Wekî reşnivîs tomar bike';
$labels['addattachment'] = 'Pelekê lê zêde bike';
$labels['charset'] = 'Curetîp';
$labels['editortype'] = 'Cureyê serastkat';
$labels['returnreceipt'] = 'Rapora Vegerînê';
$labels['mailreplyintro'] = 'Di $date de, şandyar nivîsî:';
$labels['originalmessage'] = 'Peyama orîjînal';
$labels['selectimage'] = 'Wêne bibijêre';
$labels['addimage'] = 'Wêne tev bike';
$labels['selectmedia'] = 'Fîlmekê bibijêre';
$labels['addmedia'] = 'Fîlmekê tev bike';
$labels['keyid'] = 'ID a kilîtê';
$labels['bccinstead'] = 'Bcc bi kar bîne';
$labels['insert'] = 'Tev bike';
$labels['spellcheck'] = 'Bilêvkirin';
$labels['checkspelling'] = 'Kontrola rastnivîsê';
$labels['resumeediting'] = 'Serastkirinê bidomîne';
$labels['revertto'] = 'Şûnde bîne';
$labels['restore'] = 'Vegerîne';
$labels['restoremessage'] = 'Peyamê vegerîne?';
$labels['ignore'] = 'Paşguh bike';
$labels['responses'] = 'Bersivgel';
$labels['insertresponse'] = 'Bersivekê têxê';
$labels['manageresponses'] = 'Bersivan bi rê ve bibe';
$labels['newresponse'] = 'Bersiveke nê biafirîne';
$labels['addresponse'] = 'Bersivê tev bike';
$labels['editresponse'] = 'Bersivê sererast bike';
$labels['editresponses'] = 'Bersivan sererast bike';
$labels['responsename'] = 'Nav';
$labels['responsetext'] = 'Teksta Bersivê';
$labels['attach'] = 'Pêvek';
$labels['attachments'] = 'Pêvek';
$labels['upload'] = 'Bar bike';
$labels['uploadprogress'] = '$percent ($current ji $total)';
$labels['close'] = 'Bigire';
$labels['messageoptions'] = 'Vebijêrkên peyamê...';
$labels['low'] = 'Nizm';
$labels['lowest'] = 'Nizmtirîn';
$labels['normal'] = 'Asayî';
$labels['high'] = 'Bilind';
$labels['highest'] = 'Bilintirîn';
$labels['nosubject'] = '(bê mijar)';
$labels['showimages'] = 'Nîşandana wêneyan';
$labels['allow'] = 'Bihêle';
$labels['alwaysshow'] = 'Her tim dîmenên ji $sender nîşan bide';
$labels['andnmore'] = '$nr bêtir...';
$labels['details'] = 'Hûrgulî';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Deqa tazî';
$labels['savesentmessagein'] = 'Peyama şandî tomar bike di ';
$labels['dontsave'] = 'tomar neke';
$labels['addcc'] = 'Cc Têxê';
$labels['addbcc'] = 'Bcc Têxê';
$labels['addreplyto'] = 'Bibersivîne têxê';
$labels['mdnrequest'] = 'Şandyarê/a vê peyamê xwest dema ku tu vê peyamê bixwînî ew were agahdarkirin. Tu dixwazî wî/ê agahdar bikî?';
$labels['receiptread'] = 'Rapora Vegerînê (xwendî)';
$labels['yourmessage'] = 'Ev rapora vegerîna peyama te ye';
$labels['receiptnote'] = 'Nîşe: Ev dide zanîn ka peyama te şand hat xwendin an na. Naveroka peyamê bi mîgogerî nayê zanîn.';
$labels['name'] = 'Navê xuya dibe';
$labels['firstname'] = 'Nav';
$labels['surname'] = 'Paşnav';
$labels['middlename'] = 'Navê navîn';
$labels['nameprefix'] = 'Pêşgir';
$labels['namesuffix'] = 'Paşgir';
$labels['nickname'] = 'Nûçik';
$labels['jobtitle'] = 'Şana Kar';
$labels['department'] = 'Beş';
$labels['gender'] = 'Zayend';
$labels['email'] = 'E-Peyam';
$labels['phone'] = 'Telefon';
$labels['address'] = 'Navnîşan';
$labels['street'] = 'Kolan';
$labels['locality'] = 'Bajar';
$labels['zipcode'] = 'ZIP Code';
$labels['region'] = 'Parêzgeh';
$labels['country'] = 'Welat';
$labels['birthday'] = 'Rojbûn';
$labels['anniversary'] = 'Sersal';
$labels['website'] = 'Website';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Nîşegel';
$labels['male'] = 'mêr';
$labels['female'] = 'jin';
$labels['othergender'] = 'ên din';
$labels['manager'] = 'Birêvebir';
$labels['assistant'] = 'Alîkar';
$labels['spouse'] = 'Hevjîn';
$labels['allfields'] = 'Hemû qad';
$labels['search'] = 'Bigere';
$labels['searchresult'] = 'Encama lêgerînê';
$labels['advsearch'] = 'Lêgerîna pêşketî';
$labels['advanced'] = 'Pêşketî';
$labels['other'] = 'Ên din';
$labels['qrcode'] = 'Koda QR';
$labels['typehome'] = 'Mal';
$labels['typework'] = 'Kar';
$labels['typeother'] = 'Ên din';
$labels['typemobile'] = 'Mobîl';
$labels['typemain'] = 'Sereke';
$labels['typehomefax'] = 'Faksa Malê';
$labels['typeworkfax'] = 'Faksa Kar';
$labels['typecar'] = 'Otomobîl';
$labels['typevideo'] = 'Bînûdeng';
$labels['typeassistant'] = 'Alîkar';
$labels['typehomepage'] = 'Malper';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Berg';
$labels['addfield'] = 'Qadekî zêde bike';
$labels['addcontact'] = 'Kesekî zêde bike';
$labels['editcontact'] = 'Têkiliyê serast bike';
$labels['contacts'] = 'Têkîlî';
$labels['contactproperties'] = 'Taybetmendiyên Kesan';
$labels['contactnameandorg'] = 'Nav û rêxistin';
$labels['personalinfo'] = 'Agahiyên kesane';
$labels['personal'] = 'Kesane';
$labels['contactphoto'] = 'Wêneyê Kes';
$labels['edit'] = 'Serast bike';
$labels['cancel'] = 'Betal';
$labels['save'] = 'Tomar bike';
$labels['delete'] = 'Jê bibe';
$labels['continue'] = 'Bidomîne';
$labels['ok'] = 'Baş e';
$labels['rename'] = 'Navê biguherîne';
$labels['addphoto'] = 'Tevlî bike';
$labels['replacephoto'] = 'Dîsa bi cih bike';
$labels['uploadphoto'] = 'Wêneyê bar bike';
$labels['choosefile'] = 'Pelê hilbijêre...';
$labels['choosefiles'] = 'Pelekê hilbijêre....';
$labels['browse'] = 'Bigere';
$labels['newcontact'] = 'Kesekî nû biafirîne';
$labels['deletecontact'] = 'Têkiliyên hilbijartî jê bibe';
$labels['composeto'] = 'Ji têkiliya hilbijartî re peyam bişîne';
$labels['contactsfromto'] = 'Têkiliyên $count ên di navbera $from - $to de';
$labels['print'] = 'çap bike';
$labels['export'] = 'Derxe';
$labels['exportall'] = 'Hemûyan derxe';
$labels['exportsel'] = 'A bijartî derxe';
$labels['newgroup'] = 'Komeke nû çêke';
$labels['addgroup'] = 'Komek tev bike';
$labels['grouprename'] = 'Dîsa navekî li komê bike';
$labels['groupdelete'] = 'Komê rake';
$labels['groupremove'] = 'Ji komê rake';
$labels['uponelevel'] = 'Astek jor';
$labels['previouspage'] = 'Seta berê nîşan bide';
$labels['firstpage'] = 'Seta yekemîn nîşan bide';
$labels['nextpage'] = 'Seta di rêzê de nîşan bide';
$labels['lastpage'] = 'Seta dawî nîşan bide';
$labels['group'] = 'Kom';
$labels['groups'] = 'Kom';
$labels['personaladrbook'] = 'Navnîşanên Takekesî';
$labels['searchsave'] = 'Lêgerînê tomar bike';
$labels['searchdelete'] = 'Lêgerînê jê bibe';
$labels['import'] = 'Derxe';
$labels['done'] = 'Qediya';
$labels['settingsfor'] = 'Sazkarî ji bo';
$labels['about'] = 'Derbar';
$labels['preferences'] = 'Vebijêrk';
$labels['userpreferences'] = 'Vebijêrkên bikarhêner';
$labels['editpreferences'] = 'Vebijêrkên bikarhêner serast bike';
$labels['identities'] = 'Nasname';
$labels['identityencryption'] = 'Şîfrekirin';
$labels['preferhtml'] = 'Wekî HTML nîşan bide';
$labels['htmlmessage'] = 'Peyama HTML';
$labels['messagepart'] = 'Parçe';
$labels['digitalsig'] = 'Îmzeya Dîjîtal';
$labels['prettydate'] = 'Kurtenivîsa Dîrokê';
$labels['setdefault'] = 'Wekî standard tomar bike';
$labels['autodetect'] = 'Xweber';
$labels['language'] = 'Ziman';
$labels['timezone'] = 'Herêma demê';
$labels['pagesize'] = 'Hejmara peyamên her rûpelekê';
$labels['signature'] = 'Şanenav';
$labels['dstactive'] = 'Demjimêra havînî';
$labels['htmleditor'] = 'Peyameke HTML biafirîne';
$labels['htmlsignature'] = 'Şanenava HTML';
$labels['previewpane'] = 'Panela berê nîşan bide';
$labels['uisettings'] = 'Navrûya bikarhêner';
$labels['serversettings'] = 'Sazkariyên rajegir';
$labels['askuser'] = 'bipirse min';
$labels['skipdeleted'] = 'Peyamên jêbirî nîşan nede';
$labels['fromknownsenders'] = 'ji şanderên nas';
$labels['frommycontacts'] = 'ji têkiliyên min';
$labels['always'] = 'Her dem';
$labels['autosavedraft'] = 'Xweber hilîne';
$labels['everynminutes'] = 'Her $n xulek(an)';
$labels['never'] = 'qet';
$labels['immediately'] = 'a niha';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (ên din)';
$labels['advancedoptions'] = 'Vebijêrkên pêşketî';
$labels['mainoptions'] = 'Vebijêrkên sereke';
$labels['browseroptions'] = 'Vebijêrkên gerokê';
$labels['newmessage'] = 'Peyama nû';
$labels['newmessageonly'] = 'tenê peyamên nû';
$labels['afternseconds'] = 'Piştî  $n çirke';
$labels['editoroptions'] = 'Vebijêrkên edîtorê';
$labels['replyalldefault'] = 'bersiva hemûyan bide';
$labels['allmessages'] = 'hemû peyam';
$labels['folder'] = 'Peldank';
$labels['folders'] = 'Peldank';
$labels['foldername'] = 'Navê peldankê';
$labels['subscribed'] = 'Ni şanenav';
$labels['messagecount'] = 'Peyam';
$labels['create'] = 'Biafirîne';
$labels['createfolder'] = 'Peldankeke nû biafirîne';
$labels['managefolders'] = 'Rêveberiya peldankan';
$labels['properties'] = 'Taybetmendî';
$labels['location'] = 'Cih';
$labels['info'] = 'Zanyarî';
$labels['foldertype'] = 'Cûreya peldankê';
$labels['personalfolder'] = 'Peldanka taybet';
$labels['otherfolder'] = 'Peldanka bikarhênerê din';
$labels['sharedfolder'] = 'Peldanka giştî';
$labels['namespace.personal'] = 'Kesane';
$labels['namespace.other'] = 'Bikarhênerên din';
$labels['namespace.shared'] = 'Parvekirî';
$labels['dualusemail'] = 'Peyam';
$labels['dualusefolder'] = 'Peldank';
$labels['openmailvelopesettings'] = 'Sazkariyên Mailvelope veke';
$labels['encryption'] = 'Şîfrekirin';
$labels['mailvelopeenable'] = 'Çalak bike';
$labels['sortby'] = 'Şêweyê rêzkirinê';
$labels['sortasc'] = 'Wekî zêde dibe';
$labels['sortdesc'] = 'Wekî kêm dibe';
$labels['undo'] = 'Vegere';
$labels['version'] = 'Guherto';
$labels['source'] = 'Çavkanî';
$labels['license'] = 'Lîsans';
$labels['support'] = 'Piştgiriyê bistîne';
$labels['dateformatY'] = 'SSSS';
$labels['dateformaty'] = 'SS';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'RR';
$labels['dateformatj'] = 'R';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['english'] = 'Îngilîzî';
$labels['arabic'] = 'Erebî';
$labels['turkish'] = 'Tirkî';
$labels['arialabelsearchterms'] = 'Mercên lêgerîne';
$labels['arialabelimagetools'] = 'Alavên wêneyê';
