<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Адбылася памылка.';
$messages['loginfailed']  = 'Не ўдалося ўвайсці.';
$messages['cookiesdisabled'] = 'Ваш браўзер не падтрымлівае cookie.';
$messages['sessionerror'] = 'Ваш сеанс хібны або яго тэрмін дзеяння скончыўся.';
$messages['cookiesmismatch'] = 'Выяўлена неадпаведнасць файлаў cookie. Ачысціце файлы cookie вашага браўзера.';
$messages['storageerror'] = 'Не атрымалася злучыцца з серверам IMAP.';
$messages['servererror'] = 'Памылка сервера!';
$messages['servererrormsg'] = 'Памылка сервера: $msg';
$messages['accountlocked'] = 'Было занадта шмат няўдалых спробаў увайсці. Паспрабуйце пазней.';
$messages['connerror'] = 'Памылка злучэння (не атрымалася злучыцца з серверам)!';
$messages['dberror'] = 'Памылка базы даных!';
$messages['dbconnerror'] = 'Немагчыма падлучыцца да базы даных!';
$messages['windowopenerror'] = 'Выплыўное акно было заблакавана!';
$messages['requesttimedout'] = 'Час чакання адказу скончыўся';
$messages['errorreadonly'] = 'Не атрымалася выканаць аперацыю. Каталог даступны толькі для чытання.';
$messages['errornoperm'] = 'Не атрымалася выканаць аперацыю. Адмоўлена ў доступе.';
$messages['erroroverquota'] = 'Не атрымалася выканаць аперацыю. Не стае вольнага месца на дыску.';
$messages['erroroverquotadelete'] = 'Не стае вольнага месца на дыску. Націсніце SHIFT+DEL, каб выдаліць ліст.';
$messages['invalidrequest'] = 'Хібны запыт! Даныя не захаваныя.';
$messages['invalidhost'] = 'Хібная назва сервера.';
$messages['nomessagesfound'] = 'У гэтай скрыні няма паведамленняў.';
$messages['loggedout'] = 'Вы паспяхова спынілі сеанс. Да пабачэння!';
$messages['mailboxempty'] = 'Скрыня пустая';
$messages['nomessages'] = 'Няма лістоў';
$messages['refreshing'] = 'Абнаўленне...';
$messages['loading'] = 'Загрузка...';
$messages['uploading'] = 'Запампоўванне файла...';
$messages['attaching'] = 'Далучэнне файла...';
$messages['uploadingmany'] = 'Запампоўванне файлаў...';
$messages['loadingdata'] = 'Загрузка даных...';
$messages['checkingmail'] = 'Праверка наяўнасці новых лістоў...';
$messages['sendingmessage'] = 'Адпраўленне ліста...';
$messages['messagesent'] = 'Ліст паспяхова адпраўлены.';
$messages['savingmessage'] = 'Захаванне ліста...';
$messages['messagesaved'] = 'Ліст захаваны ў чарнавікі.';
$messages['successfullysaved'] = 'Паспяхова захавана.';
$messages['savingresponse'] = 'Захаванне тэксту адказу...';
$messages['deleteresponseconfirm'] = 'Сапраўды выдаліць тэкст адказу?';
$messages['nocontactselected'] = 'Вы яшчэ не абралі кантакт.';
$messages['addedsuccessfully'] = 'Кантакт паспяхова дададзены ў адрасную кнігу.';
$messages['contactexists'] = 'Кантакт з такім адрасам электроннай пошты ўжо існуе.';
$messages['contactnameexists'] = 'Кантакт з такім самым імем ужо існуе.';
$messages['blockedimages'] = 'Каб абараніць вашу прыватнасць, адлеглыя выявы ў гэтым лісце заблакаваныя.';
$messages['blockedresources'] = 'У мэтах бяспекі адлеглыя рэсурсы былі заблакаваныя.';
$messages['suspiciousemail'] = 'Гэты ліст змяшчае падазроныя адрасы электроннай пошты, якія могуць належаць ашуканцам.';
$messages['bccemail'] = 'Перасланы(ыя) ліст(ы) змяшчае(юць) канфідэнцыйных атрымальнікаў (схаваная копія).';
$messages['bouncehint'] = 'Ліст будзе адпраўлены без зменаў, г.зн. з зыходным целам, загалоўкамі і атрымальнікамі.';
$messages['encryptedmessage'] = 'Гэта зашыфраваны ліст. Яго немагчыма паказаць. Выбачайце!';
$messages['externalmessagedecryption'] = 'Гэта зашыфраваны ліст, яго можна расшыфраваць з дапамогай пашырэння вашага браўзера.';
$messages['nopubkeyfor'] = 'Для $email не знойдзена прыдатнага публічнага ключа';
$messages['nopubkeyforsender'] = 'Для вашых асобовых звестак не знойдзена прыдатнага публічнага ключа. Хочаце зашыфраваць ліст толькі для атрымальнікаў?';
$messages['encryptnoattachments'] = 'Ужо запампаваныя далучаныя файлы немагчыма зашыфраваць. Дадайце іх нанова ў рэдактары шыфравання.';
$messages['searchpubkeyservers'] = 'Хочаце пашукаць адсутныя ключы на ​​серверах публічных ключоў?';
$messages['encryptpubkeysfound'] = 'Знойдзены наступныя публічныя ключы:';
$messages['keyservererror'] = 'Не ўдалося атрымаць ключы з сервера.';
$messages['keyimportsuccess'] = 'Публічны ключ $key паспяхова імпартаваны ў вашую вязку ключоў.';
$messages['nocontactsfound'] = 'Кантактаў не знойдзена.';
$messages['contactnotfound'] = 'Запытаны кантакт не знойдзены.';
$messages['contactsearchonly'] = 'Каб убачыць кантакты з гэтай адраснай кнігі, неабходна выкарыстаць форму пошуку.';
$messages['sendingfailed'] = 'Не атрымалася адправіць ліст.';
$messages['senttooquickly'] = 'Пачакайце $sec секунд(ы) перад адпраўленнем гэтага ліста.';
$messages['errorsavingsent'] = 'Не атрымалася захаваць адпраўлены ліст.';
$messages['errorsaving'] = 'Не атрымалася захаваць.';
$messages['errormoving'] = 'Не атрымалася перамясціць ліст(ы).';
$messages['errorcopying'] = 'Не атрымалася скапіяваць ліст(ы).';
$messages['errordeleting'] = 'Не атрымалася выдаліць ліст(ы).';
$messages['errormarking'] = 'Не атрымалася пазначыць ліст(ы).';
$messages['alerttitle'] = 'Увага';
$messages['confirmationtitle'] = 'Сапраўды...';
$messages['deletecontactconfirm']  = 'Сапраўды выдаліць абраны(я) кантакт(ы)?';
$messages['deletegroupconfirm']  = 'Сапраўды выдаліць абраную групу?';
$messages['deletemessagesconfirm'] = 'Сапраўды выдаліць абраны(я) ліст(ы)?';
$messages['deletefolderconfirm']  = 'Сапраўды выдаліць гэты каталог?';
$messages['movefolderconfirm']  = 'Сапраўды перамясціць гэты каталог?';
$messages['purgefolderconfirm']  = 'Сапраўды выдаліць усе лісты з гэтага каталога?';
$messages['contactdeleting'] = 'Выдаленне кантакта(аў)...';
$messages['groupdeleting'] = 'Выдаленне групы...';
$messages['folderdeleting'] = 'Выдаленне каталога...';
$messages['foldermoving'] = 'Перамяшчэнне каталога...';
$messages['foldersubscribing'] = 'Падпісанне на каталог...';
$messages['folderunsubscribing'] = 'Адпісванне ад каталога...';
$messages['formincomplete'] = 'Форма запоўненая не поўнасцю.';
$messages['noemailwarning'] = 'Увядзіце прыдатны адрас электроннай пошты.';
$messages['nonamewarning']  = 'Увядзіце назву.';
$messages['nopagesizewarning'] = 'Увядзіце памер старонкі.';
$messages['nosenderwarning'] = 'Увядзіце адрас электроннай пошты адпраўніка.';
$messages['recipientsadded'] = 'Атрымальнік(і) паспяхова дададзены(ыя).';
$messages['norecipientwarning'] = 'Увядзіце прынамсі аднаго атрымальніка.';
$messages['disclosedreciptitle'] = 'Занадта шмат публічных атрымальнікаў';
$messages['nosubjectwarning']  = 'Тэма ліста пустая. Хочаце ўвесці?';
$messages['nosubjecttitle']  = 'Няма тэмы';
$messages['nobodywarning'] = 'Адправіць ліст без тэксту?';
$messages['notsentwarning'] = 'Ліст не быў адпраўлены і мае незахаваныя змены. Хочаце адкінуць змены?';
$messages['restoresavedcomposedata'] = 'Быў знойдзены створаны, але не адпраўлены ліст.\n\nТэма: $subject\nЗахавана: $date\n\nХочаце аднавіць яго?';
$messages['nosearchname'] = 'Увядзіце імя кантакта альбо адрас электроннай пошты.';
$messages['notuploadedwarning'] = 'Яшчэ не запампаваліся ўсе далучаныя файлы. Пачакайце альбо скасуйце аперацыю.';
$messages['searchsuccessful'] = 'Знойдзена $nr лістоў.';
$messages['contactsearchsuccessful'] = 'Знойдзена $nr кантактаў.';
$messages['searchnomatch'] = 'Пошук не даў выніку.';
$messages['searching'] = 'Пошук...';
$messages['checking'] = 'Праверка...';
$messages['stillsearching'] = 'Усё яшчэ выконваецца пошук...';
$messages['nospellerrors'] = 'Памылак не выяўлена.';
$messages['folderdeleted'] = 'Каталог паспяхова выдалены.';
$messages['foldersubscribed'] = 'Паспяхова падпісана на каталог.';
$messages['folderunsubscribed'] = 'Паспяхова адпісана ад каталога.';
$messages['folderpurged'] = 'Каталог паспяхова ачышчаны.';
$messages['folderexpunged'] = 'Каталог паспяхова сціснуты.';
$messages['deletedsuccessfully'] = 'Паспяхова выдалена.';
$messages['converting'] = 'Выдаленне фарматавання...';
$messages['messageopenerror'] = 'Не атрымалася загрузіць ліст з сервера.';
$messages['filelinkerror'] = 'Не атрымалася далучыць файл.';
$messages['fileuploaderror'] = 'Не атрымалася запампаваць файл.';
$messages['csvfilemismatch'] = 'Імпартаванне некалькіх файлаў CSV з адрознымі палямі не падтрымліваецца.';
$messages['filesizeerror'] = 'Запампаваны файл перавышае максімальна дазволены памер $size.';
$messages['filecounterror'] = 'Вы можаце запампаваць не больш за $count файлаў запар.';
$messages['msgsizeerror'] = 'Не атрымалася далучыць файл. Перавышаны максімальны памер ліста ($size).';
$messages['msgsizeerrorfwd'] = 'Перавышаны максімальны памер ліста ($size). $num ліст(оў) не было далучана.';
$messages['copysuccess'] = 'Паспяхова скапіявана $nr кантактаў.';
$messages['movesuccess'] = 'Паспяхова перамешчана $nr кантактаў.';
$messages['copyerror'] = 'Не атрымалася скапіяваць ніводнага кантакта.';
$messages['moveerror'] = 'Не атрымалася перамясціць ніводнага кантакта.';
$messages['sourceisreadonly'] = 'Гэтая адрасная кніга даступная толькі для чытання.';
$messages['errorsavingcontact'] = 'Не атрымалася захаваць адрас кантакта.';
$messages['movingmessage'] = 'Выдаленне ліста(оў)...';
$messages['copyingmessage'] = 'Капіяванне ліста(оў)...';
$messages['copyingcontact'] = 'Капіяванне кантакта(аў)...';
$messages['movingcontact'] = 'Перамяшчэнне кантакта(аў)...';
$messages['deletingmessage'] = 'Выдаленне ліста(оў)...';
$messages['markingmessage'] = 'Пазначэнне ліста(оў)...';
$messages['addingmember'] = 'Даданне кантакта(аў) у групу...';
$messages['removingmember'] = 'Выдаленне кантакта(аў) з групы...';
$messages['receiptsent'] = 'Пацвярджэнне аб прачытанні паспяхова адпраўлена.';
$messages['errorsendingreceipt'] = 'Не атрымалася адправіць пацвярджэнне.';
$messages['deleteidentityconfirm'] = 'Сапраўды выдаліць гэтыя асабовыя звесткі?';
$messages['nodeletelastidentity'] = 'Вы не можаце выдаліць гэтыя асабовыя звесткі, бо яны апошняя.';
$messages['forbiddencharacter'] = 'Назва каталога змяшчае забаронены сімвал.';
$messages['selectimportfile'] = 'Абярыце файл, які хочаце запампаваць.';
$messages['addresswriterror'] = 'Абраная адрасная кніга даступная толькі для чытання.';
$messages['contactaddedtogroup'] = 'Кантакты паспяхова дададзеныя ў групу.';
$messages['contactremovedfromgroup'] = 'Кантакты паспяхова выдаленыя з групы.';
$messages['nogroupassignmentschanged'] = 'Усе прызначэнні групы засталіся без зменаў.';
$messages['importwait'] = 'Імпартаванне...';
$messages['importformaterror'] = 'Не атрымалася імпартаваць! Запампаваны файл не змяшчае прыдатных даных.';
$messages['importconfirm'] = '<b>Паспяхова імпартаваны(а) $inserted кантакт(аў)</b>';
$messages['importmessagesuccess'] = 'Паспяхова імпартавана $nr лістоў';
$messages['importmessageerror'] = 'Не атрымалася імпартаваць! Загружаны файл не ёсць прыдатным лістом альбо файлам паштовай скрыні';
$messages['opnotpermitted'] = 'Аперацыя забароненая!';
$messages['nofromaddress'] = 'У абраных асабовых звестках няма адраса электроннай пошты.';
$messages['editorwarning'] = 'Змена тыпу рэдактара можа прывесці да страты фарматавання. Працягнуць?';
$messages['httpreceivedencrypterror'] = 'Крытычная памылка ў канфігурацыі. Неадкладна звяжыцеся з адміністратарам. <b>Ліст немагчыма адправіць.</b>';
$messages['smtpconnerror'] = 'Памылка SMTP ($code): Не атрымалася злучыцца з серверам.';
$messages['smtpautherror'] = 'Памылка SMTP ($code): не атрымалася выканаць аўтэнтыфікацыю.';
$messages['smtpfromerror'] = 'Памылка SMTP ($code): не атрымалася пазначыць адпраўніка "$from" ($msg).';
$messages['smtptoerror'] = 'Памылка STMP ($code): не атрымалася пазначыць атрымальніка "$to" ($msg).';
$messages['smtprecipientserror'] = 'Памылка STMP: не атрымалася прачытаць спіс атрымальнікаў.';
$messages['smtputf8error'] = 'Памылка SMTP: сервер не падтрымлівае Юнікод у адрасах электроннай пошты.';
$messages['smtpsizeerror'] = 'Памылка STMP: памер ліста перавышае ліміт сервера ($limit)';
$messages['smtperror'] = 'Памылка SMTP: $msg';
$messages['emailformaterror'] = 'Хібны адрас электроннай пошты: $email';
$messages['toomanyrecipients'] = 'Занадта шмат атрымальнікаў. Паменшыце колькасць атрымальнікаў да $max.';
$messages['maxgroupmembersreached'] = 'Колькасць удзельнікаў групы перавышае максімум — $max.';
$messages['internalerror'] = 'Унутраная памылка. Паспрабуйце яшчэ раз.';
$messages['contactdelerror'] = 'Не атрымалася выдаліць кантакт(ы).';
$messages['contactdeleted'] = 'Кантакт(ы) выдалены(ыя).';
$messages['contactrestoreerror'] = 'Не атрымалася аднавіць выдалены(ыя) кантакт(ы).';
$messages['contactrestored'] = 'Кантакт(ы) адноўлены(ыя).';
$messages['groupdeleted'] = 'Група паспяхова выдаленая.';
$messages['grouprenamed'] = 'Назва групы паспяхова змененая.';
$messages['groupcreated'] = 'Група паспяхова створаная.';
$messages['savedsearchdeleted'] = 'Захаваны запыт паспяхова выдалены.';
$messages['savedsearchdeleteerror'] = 'Не атрымалася выдаліць захаваны запыт пошуку.';
$messages['savedsearchcreated'] = 'Захаваны запыт пошуку паспяхова створаны.';
$messages['savedsearchcreateerror'] = 'Не атрымалася стварыць захаваны запыт.';
$messages['messagedeleted'] = 'Ліст(ы) паспяхова выдалены(ыя).';
$messages['messagemoved'] = 'Ліст(ы) паспяхова перамешчаны(ыя).';
$messages['messagemovedtotrash'] = 'Ліст(ы) паспяхова перамешчаны(ыя) у сметніцу.';
$messages['messagecopied'] = 'Ліст(ы) паспяхова скапіяваны(ыя).';
$messages['messagemarked'] = 'Ліст(ы) паспяхова пазначаны(ыя).';
$messages['autocompletechars'] = 'Увядзіце прынамсі $min знакаў для аўтадапаўнення.';
$messages['autocompletemore'] = 'Знойдзена занадта шмат адпаведных запісаў. Увядзіце больш знакаў.';
$messages['namecannotbeempty'] = 'Назва не можа быць пустой.';
$messages['nametoolong'] = 'Назва занадта доўгая.';
$messages['namedotforbidden'] = 'Назва каталога не можа пачынацца з кропкі.';
$messages['folderupdated'] = 'Каталог паспяхова абноўлены.';
$messages['foldercreated'] = 'Каталог паспяхова створаны.';
$messages['invalidimageformat'] = 'Няслушны фармат выявы.';
$messages['mispellingsfound'] = 'У лісце выяўленыя граматычныя памылкі.';
$messages['parentnotwritable'] = 'Не атрымалася стварыць/перамясціць каталог ў абраным бацькоўскім каталозе. Няма правоў доступу.';
$messages['messagetoobig'] = 'Гэтая частка ліста занадта вялікая, каб яе апрацаваць.';
$messages['attachmentvalidationerror'] = 'Гэты далучаны файл выглядае падазроным, бо яго тып не супадае з тыпам, пададзеным у лісце. Калі вы не давяраеце адпраўніку, вам не варта адкрываць яго ў браўзеры, бо ён можа змяшчаць шкоднае змесціва.<br/><br/><em>Чакаецца: $expected; знойдзена: $detected</em>';
$messages['noscriptwarning'] = 'Увага: паштовай службе патрэбны Javascript! Каб карыстацца ёй, у наладах браўзера трэба ўключыць Javascript.';
$messages['messageissent'] = 'Ліст ўжо адпраўлены, але яшчэ не захавана. Хочаце захаваць?';
$messages['errnotfound'] = 'Файл не знойдзены';
$messages['errnotfoundexplain'] = 'Запытаны рэсурс не знойдзены.';
$messages['errfailedrequest'] = 'Не атрымалася выканаць запыт';
$messages['errauthorizationfailed'] = 'Не атрымалася выканаць аўтарызацыю';
$messages['errunauthorizedexplain'] = 'Не ўдалося пацвердзіць, што вы маеце права на доступ да гэтай службы.';
$messages['errrequestcheckfailed'] = 'Не атрымалася праверыць запыт';
$messages['errcsrfprotectionexplain'] = "Каб абараніць вас, доступ да гэтага рэсурсу абаронены ад CSRF.\nКалі вы бачыце гэтае паведамленне, верагодна, вы не выходзілі з сістэмы, перш чым выйсці з вэб-праграмы.\n\nЗараз патрэбна ўзаемадзеянне з чалавекам.";
$messages['errcontactserveradmin'] = 'Звярніцеся да адміністратара сервера.';
$messages['clicktoresumesession'] = 'Націсніце сюды, каб аднавіць папярэдні сеанс';
$messages['errcomposesession'] = 'Не атрымалася пачаць сеанс';
$messages['errcomposesessionexplain'] = 'Запытаны сеанс стварэння не знойдзены.';
$messages['clicktocompose'] = 'Націсніце сюды, каб стварыць новы ліст';
$messages['nosupporterror'] = 'Гэтая функцыя не падтрымліваецца ў вэб-браўзера.';
$messages['siginserted'] = 'Подпіс паспяхова ўстаўлены.';
$messages['responseinserted'] = 'Адказ паспяхова ўстаўлены.';
$messages['noresponsesavailable'] = 'Няма даступных адказаў';
$messages['listempty'] = 'Спіс пусты.';
$messages['listusebutton'] = 'Каб дадаць новы запіс, скарыстайцеся кнопкай "Стварыць".';
$messages['keypaircreatesuccess'] = 'Новая пара ключоў паспяхова створаная для $identity.';
$messages['emptyattachment'] = 'Здаецца, гэты ліст пусты.<br> Магчыма, змесціва было выдалена антывіруснымі/антыспамавымі службамі. Удакладніце ў адпраўніка.';
$messages['oauthloginfailed'] = 'Не атрымалася ўвайсці з дапамогай OAuth. Паспрабуйце пазней.';
