<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Արխիվ';
$labels['buttontitle'] = 'Արխիվացնել այս հաղորդագրությունը';
$labels['archived'] = 'Բարեհաջող արխիվացվեց';
$labels['archivedreload'] = 'Բարեհաջող արխիվացվեց: Վերբեռնեք էջը նոր արխիվացված պանակները տեսնելու համար:';
$labels['archiveerror'] = 'Որոշ հաղորդագրություններ հնարավոր չէ արխիվացնել';
$labels['archivefolder'] = 'Արխիվ';
$labels['settingstitle'] = 'Արխիվ';
$labels['archivetype'] = 'Բաժանել արխիվը';
$labels['archivetypeyear'] = 'Տարեթիվ (օր.՝ Արխիվ/2012)';
$labels['archivetypemonth'] = 'Ամսաթիվ (օր.՝ Արխիվ/2012/06)';
$labels['archivetypefolder'] = 'Առաջին պանակը';
$labels['archivetypesender'] = 'Ուղարկողի էլ-փոստը';
$labels['unkownsender'] = 'անհայտ';
