<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Arhīvs';
$labels['buttontitle'] = 'Arhivēt šo vēstuli';
$labels['archived'] = 'Vēstule veiksmīgi arhivēta';
$labels['archivedreload'] = 'Arhīvs veiksmīgi izveidots. Lai redzētu jaunās arhīva mapes, pārlādējiet lapu.';
$labels['archiveerror'] = 'Dažas vēstules nebija iespējams arhivēt';
$labels['archivefolder'] = 'Arhīvs';
$labels['settingstitle'] = 'Arhīvs';
$labels['archivetype'] = 'Sadalīt arhīvu pa';
$labels['archivetypeyear'] = 'Gadiem (piem. Arhīvs/2012)';
$labels['archivetypemonth'] = 'Mēnešiem (piem. Arhīvs/2012/06)';
$labels['archivetypetbmonth'] = 'Mēnesis - Savietojams ar Thunderbird (piem. Arhīvs/2012/2012-06)';
$labels['archivetypefolder'] = 'Sākotnējā mape';
$labels['archivetypefolderyear'] = 'Gads un oriģinālā mapīte (oiem. Archive/2012/...)';
$labels['archivetypefoldermonth'] = 'Gads, mēnesis un oriģinālā mapīte (piem. Archive/2012/06/...)';
$labels['archivetypesender'] = 'Sūtītāja e-pasts';
$labels['unkownsender'] = 'nezināms';
$labels['readonarchive'] = 'Arhivējot, atzīmēt vēstuli kā izlasītu';
