<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Archivovať';
$labels['buttontitle'] = 'Archivovať túto správu';
$labels['archived'] = 'Úspešne uložené do archívu';
$labels['archivedreload'] = 'Archivovanie bolo úspešne dokončené. Ak si chcete prezrieť nové archívne priečinky, obnovte stránku.';
$labels['archiveerror'] = 'Niektoré správy nebolo možné archivovať';
$labels['archivefolder'] = 'Archivovať';
$labels['settingstitle'] = 'Archív';
$labels['archivetype'] = 'Rozdeliť archív po';
$labels['archivetypeyear'] = 'rokoch (napríklad Archív/2012)';
$labels['archivetypemonth'] = 'mesiacoch (napríklad Archív/2012/06)';
$labels['archivetypetbmonth'] = 'mesiacoch - kompatibilne s Thunderbird (napríklad Archív /2012/2012-06)';
$labels['archivetypefolder'] = 'Pôvodný priečinok';
$labels['archivetypefolderyear'] = 'Rok a pôvodný priečinok (napr.: Archive/2012/...)';
$labels['archivetypefoldermonth'] = 'Rok, mesiac a pôvodný priečinok (napr.: Archive/2012/06/...)';
$labels['archivetypesender'] = 'E-mailová adresa odosielateľa';
$labels['unkownsender'] = 'neznámy';
$labels['readonarchive'] = 'Pri archivovaní označiť správu ako prečítanú';
