<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'هاوبەشکردن';
$labels['username'] = 'بەکارهێنەر:';
$labels['advanced'] = 'شێوازی پێشکەوتوو';
$labels['acldelete'] = 'سڕینەوە';
$labels['shortaclc'] = 'دروستکردن';
$labels['shortaclk'] = 'دروستکردن';
$labels['shortacld'] = 'سڕینەوە';
$labels['shortaclt'] = 'سڕینەوە';
$labels['shortaclx'] = 'سڕینەوەی بوخچە';
$labels['shortacldelete'] = 'سڕینەوە';
