<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Показва известия в браузъра при ново писмо';
$labels['desktop'] = 'Показва известия на работния плот при ново писмо';
$labels['sound'] = 'Възпроизведи звук при ново писмо';
$labels['test'] = 'Тест';
$labels['title'] = 'Ново писмо!';
$labels['body'] = 'Получихте ново писмо.';
$labels['testbody'] = 'Това е тестово известие.';
$labels['desktopdisabled'] = 'Известията на работния плот са изключени за Вашия браузър.';
$labels['desktopunsupported'] = 'Вашият браузър не поддържа известия на работния плот.';
$labels['desktoptimeout'] = 'Затваряне на известие на работния плот';
