<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'A avut loc o EROARE!';
$messages['loginfailed']  = 'Autentificare eşuată';
$messages['cookiesdisabled'] = 'Browserul dumneavoastră nu acceptă cookies';
$messages['sessionerror'] = 'Sesiunea dumneavoastră este invalidă sau a expirat';
$messages['storageerror'] = 'Conectarea la serverul IMAP a eşuat';
$messages['servererror'] = 'Eroare de server!';
$messages['servererrormsg'] = 'Eroare Server: $msg';
$messages['accountlocked'] = 'Prea multe încercări de conectare nereușite. Încearcați mai târziu.';
$messages['connerror'] = 'Eroare de conexiune (Serverul nu a fost găsit)!';
$messages['dberror'] = 'Eroare bază de date!';
$messages['windowopenerror'] = 'Fereastra nouă a fost blocată!';
$messages['requesttimedout'] = 'Timpul alocat cererii a expirat';
$messages['errorreadonly'] = 'Nu se poate efectua operaţiunea. Dosarul este disponibil doar pentru citire.';
$messages['errornoperm'] = 'Nu se poate efectua operaţiunea. Acces interzis.';
$messages['erroroverquota'] = 'Nu se poate efectua operația. Nu există spațiu liber.';
$messages['erroroverquotadelete'] = 'Nu există spațiu liber. Folosiți SHIFT+DEL pentru a șterge un mesaj.';
$messages['invalidrequest'] = 'Solicitare invalidă! Datele nu au fost salvate.';
$messages['invalidhost'] = 'Nume server invalid.';
$messages['nomessagesfound'] = 'Nu a fost găsit nici un mesaj în această căsuţă poştală';
$messages['mailboxempty'] = 'Căsuţa poştală este goală';
$messages['nomessages'] = 'Nici un mesaj';
$messages['refreshing'] = 'Reîmprospătare...';
$messages['loading'] = 'Se încarcă...';
$messages['uploading'] = 'Fişierul se încarcă...';
$messages['attaching'] = 'Fișierul se atașează....';
$messages['uploadingmany'] = 'Încarc fişierele...';
$messages['loadingdata'] = 'Se încarcă informaţiile...';
$messages['checkingmail'] = 'Se verifică pentru mesaje noi...';
$messages['sendingmessage'] = 'Trimitere mesaj...';
$messages['messagesent'] = 'Mesajul a fost trimis cu succes!';
$messages['savingmessage'] = 'Salvare mesaj...';
$messages['messagesaved'] = 'Mesajul a fost salvat în Ciorne';
$messages['successfullysaved'] = 'Salvat cu succes.';
$messages['savingresponse'] = 'Se salvează textul pentru răspuns...';
$messages['deleteresponseconfirm'] = 'Chiar vrei să ștergi acest text pentru răspuns?';
$messages['addedsuccessfully'] = 'Contactul a fost adăugat cu succes în agendă';
$messages['contactexists'] = 'Există deja un contact cu aceeași adresă de e-mail.';
$messages['contactnameexists'] = 'Există deja un contact cu acelaşi nume.';
$messages['blockedimages'] = 'Pentru a vă proteja intimitatea, imaginile externe au fost blocate.';
$messages['encryptedmessage'] = 'Acesta este un mesaj criptat şi nu poate fi afişat. Ne pare rău.';
$messages['externalmessagedecryption'] = 'Acesta este un mesaj criptat și poate fi decriptat cu extensia dvs. de browser.';
$messages['nopubkeyfor'] = 'Nu a fost găsită nici o cheie publică validă pentru $email';
$messages['nopubkeyforsender'] = 'Nu a fost găsită nici o cheie publică validă pentru identitatea expeditorului dvs. Doriți să criptați mesajul doar pentru destinatari?';
$messages['encryptnoattachments'] = 'Atașamentele deja încărcate nu pot fi criptate. Vă rugăm re-adăugați-le în editorul de criptare.';
$messages['searchpubkeyservers'] = 'Doriți să căutați în servere de chei publice pentru cheile care lipsesc?';
$messages['encryptpubkeysfound'] = 'Au fost găsite următoarele chei publice:';
$messages['nocontactsfound'] = 'Nu s-a găsit nici un contact';
$messages['contactnotfound'] = 'Contactul solicitat nu a fost găsit.';
$messages['sendingfailed'] = 'Nu s-a reuşit trimiterea mesajului';
$messages['senttooquickly'] = 'Vă rugăm aşteptaţi $sec sec. înainte de a trimite acest mesaj';
$messages['errorsavingsent'] = 'A intervenit o eroare în timp ce se efectua salvarea mesajului trimis.';
$messages['errorsaving'] = 'A intervenit o eroare în timp ce se efectua salvarea.';
$messages['errormoving'] = 'Nu am putut muta mesajul (mesajele).';
$messages['errorcopying'] = 'Nu am putut copia mesajul (mesajele).';
$messages['errordeleting'] = 'Nu am putut şterge mesajul (mesajele).';
$messages['errormarking'] = 'Nu am putut marca mesajul (mesajele)';
$messages['deletecontactconfirm']  = 'Sunteţi sigur că doriţi să ştergeţi contactul/ele selectat(e)?';
$messages['deletegroupconfirm']  = 'Sunteţi sigur că doriţi să ştergeţi grupul selectat?';
$messages['deletemessagesconfirm'] = 'Sunteţi sigur că doriţi să ştergeţi mesajul (mesajele) selectate ?';
$messages['deletefolderconfirm']  = 'Sunteţi sigur că doriţi să ştergeţi acest dosar?';
$messages['purgefolderconfirm']  = 'Sunteţi sigur că doriţi să ştergeţi toate mesajele din acest dosar?';
$messages['contactdeleting'] = 'Şterg contactul (ele)...';
$messages['groupdeleting'] = 'Şterg grupul...';
$messages['folderdeleting'] = 'Se şterge dosarul...';
$messages['foldermoving'] = 'Se mută dosarul...';
$messages['foldersubscribing'] = 'Abonez dosarul...';
$messages['folderunsubscribing'] = 'Dezabonez dosarul...';
$messages['formincomplete'] = 'Formularul nu a fost completat corect';
$messages['noemailwarning'] = 'Vă rugăm să introduceţi o adresă de e-mail validă';
$messages['nonamewarning']  = 'Vă rugăm să introduceţi un nume';
$messages['nopagesizewarning'] = 'Vă rugăm să introduceţi mărimea paginii';
$messages['nosenderwarning'] = 'Vă rugăm introduceți adresa de e-mail a expeditorului.';
$messages['norecipientwarning'] = 'Vă rugăm să introduceţi cel puţin un destinatar';
$messages['disclosedreciptitle'] = 'Prea mulți destinatari';
$messages['nosubjectwarning']  = 'Mesajul nu are subiect. Vreţi să introduceţi unul acum?';
$messages['nosubjecttitle']  = 'Fără subiect';
$messages['nobodywarning'] = 'Trimiteţi acest mesaj fără text?';
$messages['notsentwarning'] = 'Mesajul nu a fost trimis și are modificări nesalvate. Doriți să renunțați la modificările dvs.?';
$messages['restoresavedcomposedata'] = 'Un mesaj compus anterior a fost găsit.\n\nSubiect:$subject\nSalvat: $date\n\nDoriţi restaurarea acestuia ?';
$messages['nosearchname'] = 'Vă rugăm să introduceţi un nume de contact sau adresă de e-mail';
$messages['notuploadedwarning'] = 'Nu toate fişierele au fost ataşate. Vă rugăm să aşteptaţi sau să anulaţi încărcarea acestora.';
$messages['searchsuccessful'] = '$nr mesaje găsite';
$messages['contactsearchsuccessful'] = '$nr contact(e) găsit(e).';
$messages['searchnomatch'] = 'Căutarea nu a returnat niciun rezultat';
$messages['searching'] = 'Se caută...';
$messages['checking'] = 'Se verifică...';
$messages['stillsearching'] = 'Se caută...';
$messages['nospellerrors'] = 'Nu s-a găsit nicio greşeală de ortografie';
$messages['folderdeleted'] = 'Dosarul a fost şters cu succes';
$messages['foldersubscribed'] = 'Dosarul a fost abonat cu succes.';
$messages['folderunsubscribed'] = 'Dosarul a fost dezabonat cu succes.';
$messages['deletedsuccessfully'] = 'Mesaj şters cu succes !';
$messages['converting'] = 'Resetez mesajul la parametrii iniţiali...';
$messages['messageopenerror'] = 'Nu s-a putut încărca mesajul din server';
$messages['filelinkerror'] = 'Atașarea fișierului a eșuat.';
$messages['fileuploaderror'] = 'Încărcarea pe server a eşuat';
$messages['filesizeerror'] = 'Fişierul încărcat depăşeşte dimensiunea de $size';
$messages['filecounterror'] = 'Puteți încărca maxim $count fișiere simultan.';
$messages['msgsizeerror'] = 'Nu s-a atașat un fișier. Dimensiunea maximă a unui mesaj ($size) a fost depășită.';
$messages['copysuccess'] = 'Am copiat cu succes $nr contacte.';
$messages['movesuccess'] = 'Am mutat cu succes $nr contacte.';
$messages['copyerror'] = 'Nu am putut copia nici un contact.';
$messages['moveerror'] = 'Nu am putut muta nici un contact.';
$messages['sourceisreadonly'] = 'Sursa acestei adrese este "read-only" (se poate doar citi)';
$messages['errorsavingcontact'] = 'Nu s-a putut salva adresa de contact';
$messages['movingmessage'] = 'Mutare mesaj....';
$messages['copyingmessage'] = 'Copiere mesaj...';
$messages['copyingcontact'] = 'Copiez contact(ele)...';
$messages['movingcontact'] = 'Se muta contactul (contactele) ...';
$messages['deletingmessage'] = 'Şterg mesaj(ele)...';
$messages['markingmessage'] = 'Marchez mesaj(ele)...';
$messages['addingmember'] = 'Adaug contact(ele) la grup...';
$messages['removingmember'] = 'Şterg contact(ele) din grup...';
$messages['receiptsent'] = 'Confirmarea de citire a fost trimisă cu succes';
$messages['errorsendingreceipt'] = 'Confirmarea nu a putut fi trimisă';
$messages['deleteidentityconfirm'] = 'Chiar vrei să ştergi aceasă identitate?';
$messages['nodeletelastidentity'] = 'Nu puteţi şterge această identitate, este ultima.';
$messages['forbiddencharacter'] = 'Numele dosarului conţine un caracter nepermis.';
$messages['selectimportfile'] = 'Va rugăm să selectaţi fişierul pentru încărcare';
$messages['addresswriterror'] = 'Agenda selectată nu poate fi actualizată, aceasta fiind disponibila doar pentru citire.';
$messages['contactaddedtogroup'] = 'Contactele au fost adăugate cu succes la acest grup';
$messages['contactremovedfromgroup'] = 'Contactele au fost şterse cu succes din acest grup';
$messages['nogroupassignmentschanged'] = 'Atribuirile la grupuri nu au fost modificate.';
$messages['importwait'] = 'Datele sunt importate, vă rugăm să aşteptaţi...';
$messages['importformaterror'] = 'Importul a eșuat! Fișierul încărcat nu este un fișier valid pentru import de date.';
$messages['importconfirm'] = '<b>$inserted contacte au fost importate cu succes, $skipped intrări au fost ignorate deoarece ele există deja: $names</b>';
$messages['importmessagesuccess'] = 'Am importat cu succes $nr mesaje.';
$messages['importmessageerror'] = 'Importarea a esuat. Fisierul incarca nu este un mesaj valid pentru email.';
$messages['opnotpermitted'] = 'Operaţiunea nu este permisă!';
$messages['nofromaddress'] = 'Lipsește adresa de email în identitatea selectată.';
$messages['editorwarning'] = 'Trecerea în mod text a editorului va cauza pierderea formatării textului. Doriţi să continuaţi?';
$messages['httpreceivedencrypterror'] = 'Vă rugăm să luaţi legătura cu administratorul serverului de mail, deoarece există o eroare în configuraţia acestuia. <b>Mesajul d-voastră nu a fost trimis.</b>';
$messages['smtpconnerror'] = 'Eroare SMTP ($code): Conexiunea cu serverul a eşuat';
$messages['smtpautherror'] = 'Eroare SMTP ($code): Autentificare eşuată';
$messages['smtpfromerror'] = 'Eroare SMTP ($code): Nu s-a putut seta expeditorul "$from" ($msg)';
$messages['smtptoerror'] = 'Eroare SMTP ($code): Nu s-a putut adăuga destinatarul "$to" ($msg)';
$messages['smtprecipientserror'] = 'Eroare SMTP: Nu s-a putut procesa lista cu destinatari';
$messages['smtperror'] = 'Eroare SMTP: $msg';
$messages['emailformaterror'] = 'Adresă email nevalidă: $email';
$messages['toomanyrecipients'] = 'Prea mulţi destinatari. Reduceţi numărul de destinatari la $max.';
$messages['maxgroupmembersreached'] = 'Numărul de membri ai grupului depăşeşte maximul de $max.';
$messages['internalerror'] = 'A avut loc o eroare internă. Te rog încearcă din nou.';
$messages['contactdelerror'] = 'Nu am putut şterge contact(ele).';
$messages['contactdeleted'] = 'Contact(ele) au fost şterse cu succes.';
$messages['contactrestoreerror'] = 'Nu am putut restaura contact(ele) şterse.';
$messages['contactrestored'] = 'Contact(ele) au fost restaurate cu succes.';
$messages['groupdeleted'] = 'Grupul a fost şters cu succes.';
$messages['grouprenamed'] = 'Grupul a fost redenumit cu succes.';
$messages['groupcreated'] = 'Grupul a fost creat cu succes.';
$messages['savedsearchdeleted'] = 'Căutarea salvată a fost ştearsă cu succes.';
$messages['savedsearchdeleteerror'] = 'Nu am putut şterge căutarea salvată.';
$messages['savedsearchcreated'] = 'Căutarea a fost salvată cu succes.';
$messages['savedsearchcreateerror'] = 'Nu am putut salva căutarea.';
$messages['messagedeleted'] = 'Mesajul (ele) a (u) fost şters (e) cu succes.';
$messages['messagemoved'] = 'Mesajul (ele) a (u) fost mutat (e) cu succes.';
$messages['messagemovedtotrash'] = 'Mesaj(e) mutat(e) cu succes în Coșul de Gunoi';
$messages['messagecopied'] = 'Mesajul (ele) a (u) fost copiat (e) cu succes.';
$messages['messagemarked'] = 'Mesajul (ele) a (u) fost marcat (e) cu succes.';
$messages['autocompletechars'] = 'Introdu măcar $min caractere pentru autocompletare.';
$messages['autocompletemore'] = 'Au fost găsite mai multe înregistrări. Introdu mai multe caractere.';
$messages['namecannotbeempty'] = '"Nume" nu poate fi gol.';
$messages['nametoolong'] = 'Numele este prea lung.';
$messages['namedotforbidden'] = 'Numele dosarului nu poate începe cu punct.';
$messages['folderupdated'] = 'Dosar actualizat cu succes.';
$messages['foldercreated'] = 'Dosar creat cu succes.';
$messages['invalidimageformat'] = 'Tip invalid de imagine.';
$messages['mispellingsfound'] = 'Au fost găsite greşeli de ortografie în mesaj.';
$messages['parentnotwritable'] = 'Nu pot crea/muta dosarul în dosarul părinte selectat. Fără drepturi de acces.';
$messages['messagetoobig'] = 'Partea de mesaj este prea mare pentru a o procesa.';
$messages['noscriptwarning'] = 'Atenție: Serviciul de webmail necesită Javascript! Pentru a-l utiliza vă rugăm activați Javascript în setările browserului.';
$messages['messageissent'] = 'Mesajul a fost deja trimis, dar încă nu a fost salvat.
Vreți să îl salvați acum?';
$messages['errnotfound'] = 'Fișierul nu a fost găsit';
$messages['errnotfoundexplain'] = 'Resursa solicitată nu a fost găsită!';
$messages['errfailedrequest'] = 'Solicitare eșuată';
$messages['errauthorizationfailed'] = 'Autorizarea nu a reușit';
$messages['errunauthorizedexplain'] = 'Nu s-a putut verifica dacă sunteți autorizat să accesați acest serviciu!';
$messages['errrequestcheckfailed'] = 'Verificarea solicitării a eșuat';
$messages['errcsrfprotectionexplain'] = "Pentru protecția dvs., accesul la această resursă este protejat împotriva CSRF.\nDacă vedeți acest lucru, probabil că nu v-ați deconectat înainte de a părăsi aplicația web.\n\nInteracțiunea umană este necesară acum pentru a continua.";
$messages['errcontactserveradmin'] = 'Vă rugăm contactați administratorul de server.';
$messages['clicktoresumesession'] = 'Faceți clic aici pentru a vă relua sesiunea anterioară';
$messages['errcomposesession'] = 'Eroare sesiune de compunere';
$messages['errcomposesessionexplain'] = 'Sesiunea de compunere solicitată nu a fost găsită.';
$messages['clicktocompose'] = 'Clic aici pentru a compune un mesaj nou';
