<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = '$product मा स्वागत छ';
$labels['username'] = 'प्रयोगकर्ताको नाम';
$labels['password'] = 'प्रवेश शब्द';
$labels['server'] = 'सर्भर';
$labels['login'] = 'लगइन गर्नुहोस्';
$labels['logout'] = 'लगआउट गर्नुहोस्';
$labels['mail'] = 'ई-मेल';
$labels['settings'] = 'व्यक्तिगत रोजाईहरु';
$labels['addressbook'] = 'ठेगाना पुस्तिका';
$labels['inbox'] = 'प्राप्ति मञ्जूषा';
$labels['drafts'] = 'ड्राफ्टहरू';
$labels['sent'] = 'पठईएका मेलहरु';
$labels['trash'] = 'रद्दी टोकरी';
$labels['junk'] = 'स्पाम';
$labels['subject'] = 'विषय';
$labels['from'] = 'प्रेषक';
$labels['to'] = 'प्रापक';
$labels['cc'] = 'बोधार्थ';
$labels['bcc'] = 'गुप्त बोधार्थ';
$labels['replyto'] = 'लाई-जवाफ';
$labels['followupto'] = 'यसलाई अनुसरण गर्नुहोस्';
$labels['date'] = 'तारिख';
$labels['size'] = 'नाप';
$labels['priority'] = 'प्राथमिकता';
$labels['organization'] = 'संस्था';
$labels['readstatus'] = 'पढेको अवस्था';
$labels['mailboxlist'] = 'फोल्डरहरु';
$labels['messagesfromto'] = 'मेलहरु $from बाट $to सम्म, $count मध्यबाट';
$labels['threadsfromto'] = 'थ्रेडहरु $from बाट $to सम्म, $count मध्यबाट';
$labels['messagenrof'] = '$nr नम्बर मेल, $count मध्यबाट';
$labels['fromtoshort'] = '$from - $to, $count मध्यबाट';
$labels['copy'] = 'प्रतिलिपि गर्नुहोस्';
$labels['move'] = 'सार्नुहोस';
$labels['moveto'] = 'यहाँ सार्नुहोस';
$labels['download'] = 'डाऊनलोड';
$labels['filename'] = 'फाईलको नाम';
$labels['filesize'] = 'फाईलको नाप';
$labels['addtoaddressbook'] = 'ठेगाना पुस्तिकामा भर्नुहोस';
$labels['sun'] = 'आइत';
$labels['mon'] = 'सोम';
$labels['tue'] = 'मंगल';
$labels['wed'] = 'बुध';
$labels['thu'] = 'विहि';
$labels['fri'] = 'शुक';
$labels['sat'] = 'शनि';
$labels['sunday'] = 'आइतवार';
$labels['monday'] = 'सोमवार';
$labels['tuesday'] = 'मंगलवार';
$labels['wednesday'] = 'बुधवार';
$labels['thursday'] = 'विहिवार';
$labels['friday'] = 'शुक्रवार';
$labels['saturday'] = 'शनिवार';
$labels['jan'] = 'जनवरी';
$labels['feb'] = 'फेब्रुवरी';
$labels['mar'] = 'मार्च';
$labels['apr'] = 'अप्रिल';
$labels['may'] = 'मई';
$labels['jun'] = 'जुन';
$labels['jul'] = 'जुलाई';
$labels['aug'] = 'अगस्ट';
$labels['sep'] = 'सेप्टेम्बर';
$labels['oct'] = 'अक्टोबर';
$labels['nov'] = 'नोभेम्बर';
$labels['dec'] = 'डिसेम्बर';
$labels['longjan'] = 'जनवरी';
$labels['longfeb'] = 'फेब्रुवरी';
$labels['longmar'] = 'मार्च';
$labels['longapr'] = 'अप्रिल';
$labels['longmay'] = 'मई';
$labels['longjun'] = 'जुन';
$labels['longjul'] = 'जुलाई';
$labels['longaug'] = 'अगस्ट';
$labels['longsep'] = 'सेप्टेम्बर';
$labels['longoct'] = 'अक्टोबर';
$labels['longnov'] = 'नोभेम्बर';
$labels['longdec'] = 'डिसेम्बर';
$labels['today'] = 'आज';
$labels['refresh'] = 'ताजा पार्नुहोस्';
$labels['checkmail'] = 'नया मेल खोज्नुहोस';
$labels['compose'] = 'रचना गर्नुहोस्';
$labels['writenewmessage'] = 'नया मेल लेख्नुहोस';
$labels['reply'] = 'जवाफ दिनुहोस्';
$labels['replytomessage'] = 'प्रेषकलाई जवाफ दिनुहोस';
$labels['replytoallmessage'] = 'प्रेषक लगायत सबैलाई जवाफ दिनुहोस';
$labels['replyall'] = 'सबैलाई जवाफ दिनुहोस';
$labels['replylist'] = 'जवाफ तालिका';
$labels['forward'] = 'फरवार्ड गर्नुहोस्';
$labels['forwardinline'] = 'आन्तरिक पंक्तिमा फरवार्ड गर्नुहोस';
$labels['forwardattachment'] = 'एट्याचमेन्ट जसरी फरवार्ड गर्नुहोस';
$labels['forwardmessage'] = 'मेल अगाडि पठाउनुहोस';
$labels['deletemessage'] = 'रद्दी टोकरीमा हाल्नुहोस';
$labels['movemessagetotrash'] = 'सन्देशलाई रद्दी टोकरीमा सार्नुहोस';
$labels['printmessage'] = 'यो सन्देशलाई मुद्रण गर्नुहोस्';
$labels['previousmessage'] = 'पछाडिको सन्देश देखाउनुहोस';
$labels['firstmessage'] = 'पहलो सन्देश देखाउनुहोस';
$labels['nextmessage'] = 'अगाडिको सन्देश देखाउनुहोस';
$labels['lastmessage'] = 'अन्तिम सन्देश देखाउनुहोस';
$labels['backtolist'] = 'सन्देश सूची देखाउनुहोस';
$labels['viewsource'] = 'श्रोत देखाउनुहोस';
$labels['mark'] = 'चिन्ह लगाउनुहोस्';
$labels['markmessages'] = 'सन्देशमा चिन्ह लगाउनुहोस्';
$labels['more'] = 'अझ धेरै';
$labels['back'] = 'पछाडि';
$labels['options'] = 'विकल्पहरू';
$labels['select'] = 'चयन गर्नुहोस्';
$labels['all'] = 'सबै';
$labels['none'] = 'हैन';
$labels['unread'] = 'नपढिएका |';
$labels['nonesort'] = 'हैन';
$labels['compact'] = 'छोटो गर्नुहोस';
$labels['empty'] = 'खाली गर्ने';
$labels['quota'] = 'डिस्कको उपभोग';
$labels['unknown'] = 'अज्ञात';
$labels['unlimited'] = 'अनगिन्ति';
$labels['quicksearch'] = 'स्फुर्ति खोज';
$labels['resetsearch'] = 'पन: खोज';
$labels['sendmessage'] = 'तुरुन्तै मेल पठाउनुहोस';
$labels['savemessage'] = 'ड्राफ्ट जोगाउनुहोस';
$labels['addattachment'] = 'फाइल टाँस्नुहोस';
$labels['charset'] = 'क्यारेक्टर सेट';
$labels['editortype'] = 'सम्पादकको प्रकार';
$labels['returnreceipt'] = 'फिर्ति रसीद';
$labels['checkspelling'] = 'हिज्जे जाँच';
$labels['resumeediting'] = 'पुन: सम्पादन गर्नुहोस';
$labels['revertto'] = 'पहिलेको स्थितीमा जानुहोस';
$labels['attachments'] = 'टाँसिएका फाईलहरु';
$labels['upload'] = 'अपलोड';
$labels['close'] = 'बन्द';
$labels['low'] = 'कम';
$labels['lowest'] = 'सबै भन्दा कम';
$labels['normal'] = 'साधारण';
$labels['high'] = 'उच्च';
$labels['highest'] = 'उच्चतम';
$labels['nosubject'] = '(बिना विषयको)';
$labels['showimages'] = 'चित्र देखाउनुहोस';
$labels['htmltoggle'] = 'ऐच-टी-ऐम-एल (HTML)';
$labels['plaintoggle'] = 'सादा अक्षर';
$labels['name'] = 'देखाउने नाम';
$labels['firstname'] = 'पहिलो नाम';
$labels['surname'] = 'थर';
$labels['email'] = 'ई-मेल';
$labels['editcontact'] = 'सम्पर्क सच्याउनुहोस';
$labels['edit'] = 'सच्याउनुहोस';
$labels['cancel'] = 'खारेज गर्नुहोस';
$labels['save'] = 'जोगाउनुहोस';
$labels['delete'] = 'मेटाउनुहोस';
$labels['deletecontact'] = 'छानिएका सम्पर्कहरु मेटाउनुहोस';
$labels['composeto'] = 'मेल लेखी पठाउनुहोस';
$labels['contactsfromto'] = 'सम्पर्कहरु $from बाट $to सम्म, $count मध्यबाट';
$labels['print'] = 'छाप्नुहोस';
$labels['export'] = 'ऐक्स्पोर्ट गर्नुहोस';
$labels['previouspage'] = 'पहिलेको सेट देखाउनुहोस';
$labels['firstpage'] = 'पहिलो सेट देखाउनुहोस';
$labels['nextpage'] = 'अर्को सेट देखाउनुहोस';
$labels['lastpage'] = 'अन्तिम सेट देखाउनुहोस';
$labels['groups'] = 'समूहहरु';
$labels['personaladrbook'] = 'व्यक्तिगत ठेगानाहरु';
$labels['settingsfor'] = 'तय';
$labels['preferences'] = 'रोजाइहरु';
$labels['userpreferences'] = 'यूसरका रोजाइहरु';
$labels['editpreferences'] = 'यूसरका रोजाइहर सम्पादन गर्नुहोस';
$labels['identities'] = 'पहिचानहरु';
$labels['preferhtml'] = 'ऐच-टी-ऐम-ऐल(HTML) देखाउनुहोस';
$labels['htmlmessage'] = 'ऐच-टी-ऐम-ऐल (HTML) रूपका मेल';
$labels['prettydate'] = 'सुन्दर तारिख';
$labels['setdefault'] = 'तय गर्नुहोस';
$labels['language'] = 'भाषा';
$labels['timezone'] = 'समय क्षेत्र';
$labels['pagesize'] = 'हरेक पन्नामा यति';
$labels['signature'] = 'हस्ताक्षर';
$labels['dstactive'] = 'प्रकाश बचाव';
$labels['htmleditor'] = 'ऐच-टी-ऐम-एल (HTML) मेल लखन गर्नुहोस';
$labels['htmlsignature'] = 'ऐच-टी-ऐम-एल (HTML) हस्ताक्षर';
$labels['previewpane'] = 'पूर्व दृष्य देखाउनुहोस';
$labels['autosavedraft'] = 'स्वत ड्राफ्ट जोगाउनुहोस';
$labels['never'] = 'काहिलै नहुने';
$labels['folder'] = 'फोल्डर';
$labels['folders'] = 'फोल्डरहरु';
$labels['foldername'] = 'फोल्डरको नाम';
$labels['subscribed'] = 'सबस्क्राईब गरियो';
$labels['create'] = 'बनाउनुहोस';
$labels['createfolder'] = 'नया फोलडर बनाउनुहोस';
$labels['managefolders'] = 'फोलडर व्यवस्थित गर्नुहोस';
$labels['sortby'] = 'यसरी तय गर्नुहोस';
$labels['sortasc'] = 'पहिलो देखि अन्तिम सम्म तय गर्नुहोस';
$labels['sortdesc'] = 'अन्तिम देखि पहिलो सम्म तय गर्नुहोस';
