<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Paylaşma';
$labels['myrights'] = 'Giriş hüququ';
$labels['username'] = 'İstifadəçi:';
$labels['advanced'] = 'Ekspert rejimi';
$labels['add'] = 'Əlavə et';
$labels['newuser'] = 'Sahə əlavə et';
$labels['editperms'] = 'Cavabları redaktə et';
$labels['actions'] = 'Giriş hüququ ilə hərəkət...';
$labels['anyone'] = 'Bütün istifadəçilər (istənilən)';
$labels['anonymous'] = 'Qonaqlar (anonimlər)';
$labels['identifier'] = 'İdentifikator';
$labels['acll'] = 'Baxış';
$labels['aclr'] = 'Məktubu oxu';
$labels['acls'] = 'Oxunulan kimi saxla';
$labels['aclw'] = 'Yazı bayrağı';
$labels['acli'] = 'Əlavə et (kopyala)';
$labels['aclp'] = 'Yazı';
$labels['aclc'] = 'Qovluqaltı yarat';
$labels['aclk'] = 'Qovluqaltı yarat';
$labels['acld'] = 'Məktubu sil';
$labels['aclt'] = 'Məktubu sil';
$labels['acle'] = 'Poz';
$labels['aclx'] = 'Qovluğu sil';
$labels['acla'] = 'İdarə';
$labels['acln'] = 'Mesajl şərh et';
$labels['aclfull'] = 'Tam idarə';
$labels['aclother'] = 'Digər';
$labels['aclread'] = 'Oxu';
$labels['aclwrite'] = 'Yaz';
$labels['acldelete'] = 'Sil';
$labels['shortacll'] = 'Baxış';
$labels['shortaclr'] = 'Oxu';
$labels['shortacls'] = 'Saxla';
$labels['shortaclw'] = 'Yaz';
$labels['shortacli'] = 'Yerləşdir';
$labels['shortaclp'] = 'Yazı';
$labels['shortaclc'] = 'Yarat';
$labels['shortaclk'] = 'Yarat';
$labels['shortacld'] = 'Sil';
$labels['shortaclt'] = 'Sil';
$labels['shortacle'] = 'Poz';
$labels['shortaclx'] = 'Qovluğun silinməsi';
$labels['shortacla'] = 'İdarə';
$labels['shortacln'] = 'Şərh';
$labels['shortaclother'] = 'Digər';
$labels['shortaclread'] = 'Oxu';
$labels['shortaclwrite'] = 'Yaz';
$labels['shortacldelete'] = 'Sil';
$labels['longacll'] = 'Qovluq siyahıda görünür və yazılmağa hazırdır';
$labels['longaclr'] = 'Bu qovluq oxunmaq üçün açıla bilər';
$labels['longacls'] = 'Oxunulan flaqı dəyişdirilə bilər';
$labels['longaclw'] = 'Oxunulan və silinənlərdən başqa flaqlar və açar sözləri dəyişdirilə bilər';
$labels['longacli'] = 'Məktub qovluğa yazıla və ya saxlanıla bilər';
$labels['longaclp'] = 'Məktub bu qovluğa göndərilə bilər';
$labels['longaclc'] = 'Qovluqaltları bu qovluqda yaradıla və ya adı dəyişdirilə bilər';
$labels['longaclk'] = 'Qovluqaltları bu qovluqda yaradıla və ya adı dəyişdirilə bilər';
$labels['longacld'] = 'Silinən flaqı dəyişdirilə bilər';
$labels['longaclt'] = 'Silinən flaqı dəyişdirilə bilər';
$labels['longacle'] = 'Məktublar pozula bilər';
$labels['longaclx'] = 'Bu qovluq silinə və ya adı dəyişdirilə bilər';
$labels['longacla'] = 'Bu qovluğa giriş hüququ dəyişdirilə bilər';
$labels['longacln'] = 'Müştərək metaməlumatlar (şərhlər) dəyişdirilə bilər';
$labels['longaclfull'] = 'Qovluğun idarəsi ilə birlikdə, tam giriş.';
$labels['longaclread'] = 'Bu qovluq oxunmaq üçün açıla bilər';
$labels['longaclwrite'] = 'Məktubu bu qovluğa qeyd etmək, yazmaq və kopyalamaq olar';
$labels['longacldelete'] = 'Məktubu silmək olar';
$labels['longaclother'] = 'Digər giriş hüquqları';
$labels['ariasummaryacltable'] = 'Giriş hüquqlarının siyahısı';
$labels['arialabelaclactions'] = 'Hərəkət siyahısı';
$labels['arialabelaclform'] = 'Giriş hüquqlarının forması';
$messages['deleting'] = 'Giriş hüququnun silinməsi...';
$messages['saving'] = 'Giriş hüququnun saxlanılması...';
$messages['updatesuccess'] = 'Giriş hüququ dəyişdirildi';
$messages['deletesuccess'] = 'Giriş hüququ silindi';
$messages['createsuccess'] = 'Giriş hüququ əlavə edildi';
$messages['updateerror'] = 'Hüquqları yeniləmək alınmadı';
$messages['deleteerror'] = 'Giriş hüququnu silmək mümkün deyil';
$messages['createerror'] = 'Giriş hüququnu əlavə etmək mümkün deyil';
$messages['deleteconfirm'] = 'Seçilmiş istifadəçilərin giriş hüququnu silməkdə əminsiniz?';
$messages['norights'] = 'Giriş hüquqları göstərilməyib!';
$messages['nouser'] = 'İstifadəçi adı təyin olunmayıb!';
