<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = '$product ಗೆ ಸ್ವಾಗತ ';
$labels['password'] = 'ರಹಸ್ಯ ಪದ';
$labels['addressbook'] = 'ವಿಳಾಸ ಪುಸ್ತಕ';
$labels['subject'] = 'ವಿಷಯ';
$labels['from'] = 'ಇಂದ';
$labels['to'] = 'ಗೆ';
$labels['date'] = 'ದಿನಾಂಕ ';
$labels['size'] = 'ಗಾತ್ರ';
$labels['priority'] = 'ಆದ್ಯತೆ';
$labels['organization'] = 'ಸಂಘಟನೆ';
$labels['showattachment'] = 'ತೋರಿಸು';
$labels['filename'] = 'ಫೈಲ್ ಹೆಸರು';
$labels['filesize'] = 'ಫೈಲ್ ಗಾತ್ರ';
$labels['addtoaddressbook'] = 'ಪುಸ್ತಕ ವಿಳಾಸ ಸೇರಿಸು ';
$labels['sun'] = 'ಭಾನು ';
$labels['mon'] = 'ಸೋಮ';
$labels['tue'] = 'ಮಂಗಳ';
$labels['wed'] = 'ಬುಧ';
$labels['thu'] = 'ಗುರು';
$labels['fri'] = 'ಶುಕ್ರ';
$labels['sat'] = 'ಶನಿ';
$labels['sunday'] = 'ಭಾನುವಾರ';
$labels['monday'] = 'ಸೋಮವಾರ';
$labels['tuesday'] = 'ಮಂಗಳವಾರ';
$labels['wednesday'] = 'ಬುಧವಾರ';
$labels['thursday'] = 'ಗುರುವಾರ';
$labels['friday'] = 'ಶುಕ್ರವಾರ';
$labels['saturday'] = 'ಶನಿವಾರ';
$labels['may'] = 'ಮೇ';
$labels['longjan'] = 'ಜನವರಿ';
$labels['longfeb'] = 'ಫೆಬ್ರುವರಿ';
$labels['longmar'] = 'ಮಾರ್ಚ್';
$labels['longapr'] = 'ಏಪ್ರಿಲ್';
$labels['longmay'] = 'ಮೇ';
$labels['longjun'] = 'ಜೂನ್';
$labels['longjul'] = 'ಜೂಲೈ';
$labels['longaug'] = 'ಆಗಸ್ಟ್ ';
$labels['longsep'] = 'ಸೆಪ್ಟೆಂಬರ';
$labels['longoct'] = 'ಅಕ್ಟೋಬರ';
$labels['longnov'] = 'ನವೆಂಬರ';
$labels['longdec'] = 'ಡಿಸೆಂಬರ';
$labels['today'] = 'ಇಂದು';
$labels['checkmail'] = 'ಹೊಸ ಸಂದೇಶಗಳಿಗಾಗಿ ಪರಿಶೀಲಿಸು';
$labels['writenewmessage'] = 'ಒಂದು ಹೊಸ ಸಂದೇಶವನ್ನು ರಚಿಸು';
$labels['reply'] = 'ಉತ್ತರಕೊಡು';
$labels['deletemessage'] = 'ಸಂದೇಶ ಅಳಿಸು';
$labels['printmessage'] = 'ಈ ಸಂದೇಶವನ್ನು ಮುದ್ರಿಸು';
$labels['previousmessage'] = 'ಹಿಂದಿನ ಸಂದೇಶವನ್ನು ತೋರಿಸು';
$labels['firstmessage'] = 'ಮೊದಲ ಸಂದೇಶವನ್ನು ತೋರಿಸು';
$labels['nextmessage'] = 'ಮುಂದಿನ ಸಂದೇಶವನ್ನು ತೋರಿಸು';
$labels['lastmessage'] = 'ಕೊನೆಯ ಸಂದೇಶವನ್ನು ತೋರಿಸು';
$labels['unlimited'] = 'ಅನಿಯಮಿತ';
$labels['namex'] = 'ಹೆಸರು';
$labels['send'] = 'ಕಳುಹಿಸು';
$labels['sendmessage'] = 'ಸಂದೇಶ ಕಳುಹಿಸು';
$labels['savemessage'] = 'ಡ್ರಾಫ್ಟ್ ಆಗಿ ಉಳಿಸಿ';
$labels['originalmessage'] = 'ಮೂಲ ಸಂದೇಶ';
$labels['responsename'] = 'ಹೆಸರು';
$labels['close'] = 'ಮುಚ್ಚು';
$labels['messageoptions'] = 'ಸಂದೇಶ ಆಯ್ಕೆಗಳು';
$labels['low'] = 'ಕಡಿಮೆ';
$labels['lowest'] = 'ಅತಿ ಕಡಿಮೆ';
$labels['normal'] = 'ಸಾಧಾರಣ';
$labels['high'] = 'ಜಾಸ್ತಿ';
$labels['highest'] = 'ಅತಿ ಜಾಸ್ತಿ ';
$labels['nosubject'] = '(ವಿಷಯ ಇಲ್ಲ)';
$labels['showimages'] = 'ಚಿತ್ರಗಳನ್ನು ತೋರಿಸು';
$labels['alwaysshow'] = '$sender ಇಂದ ಯಾವಾಗಲೂ ಚಿತ್ರಗಳನ್ನು ತೋರಿಸು';
$labels['htmltoggle'] = 'HTML';
$labels['dontsave'] = 'ಉಳಿಸಬೇಡ';
$labels['department'] = 'ವಿಭಾಗ';
$labels['gender'] = 'ಲಿಂಗ';
$labels['email'] = 'ಇಮೇಲ್';
$labels['phone'] = 'ದೂರವಾಣಿ';
$labels['address'] = 'ವಿಳಾಸ';
$labels['street'] = 'ರಸ್ತೆ';
$labels['locality'] = 'ನಗರ';
$labels['country'] = 'ದೇಶ';
$labels['birthday'] = 'ಜನ್ಮದಿನ';
$labels['manager'] = 'ವ್ಯವಸ್ಥಾಪಕ';
$labels['assistant'] = 'ಸಹಾಯಕ';
$labels['search'] = 'ಹುಡುಕು';
$labels['typehome'] = 'ಮನೆ';
$labels['typework'] = 'ಕೆಲಸ';
$labels['typecar'] = 'ಕಾರು';
$labels['typeassistant'] = 'ಸಹಾಯಕ';
$labels['editcontact'] = 'ಸಂಪರ್ಕ ತಿದ್ದು';
$labels['contacts'] = 'ಸಂಪರ್ಕಗಳು';
$labels['edit'] = 'ತಿದ್ದು';
$labels['addphoto'] = 'ಸೇರಿಸು';
$labels['replacephoto'] = 'ಬದಲಾಯಿಸು';
$labels['uploadphoto'] = 'ಫೋಟೋ ಅಪ್ಲೋಡ್ ಮಾಡು';
$labels['deletecontact'] = 'ಆಯ್ಕೆಮಾಡಿದ ಸಂಪರ್ಕಗಳನ್ನು ಅಳಿಸು';
$labels['print'] = 'ಮುದ್ರಿಸು';
$labels['previouspage'] = 'ಹಿಂದಿನ ಪುಟವನ್ನು ತೋರಿಸು';
$labels['firstpage'] = 'ಮೊದಲ ಪುಟ ತೋರಿಸು';
$labels['nextpage'] = 'ಮುಂದಿನ ಪುಟ ತೋರಿಸು';
$labels['lastpage'] = 'ಕೊನೆಯ ಪುಟ ತೋರಿಸು';
$labels['group'] = 'ಗುಂಪು';
$labels['groups'] = 'ಗುಂಪುಗಳು';
$labels['preferences'] = 'ಆಯ್ಕೆಗಳು';
$labels['userpreferences'] = 'ಬಳಕೆದಾರ ಆಯ್ಕೆಗಳು';
$labels['editpreferences'] = 'ಬಳಕೆದಾರನ  ಆಯ್ಕೆಗಳನನ್ನು ತಿದ್ದಿ';
$labels['preferhtml'] = 'HTML  ತೋರಿಸು';
$labels['htmlmessage'] = 'HTML ಸಂದೇಶ';
$labels['digitalsig'] = 'ಡಿಜಿಟಲ್ ಸಹಿ';
$labels['dateformat'] = 'ದಿನಾಂಕ ಸ್ವರೂಪ';
$labels['timeformat'] = 'ಸಮಯ ಸ್ವರೂಪ';
$labels['language'] = 'ಭಾಷೆ';
$labels['timezone'] = 'ಸಮಯ ವಲಯ';
$labels['pagesize'] = 'ಪ್ರತಿ ಪುಟಕ್ಕೆ ಸಾಲುಗಳು';
$labels['signature'] = 'ಸಹಿ';
$labels['showinextwin'] = 'ಹೊಸ ವಿಂಡೋದಲ್ಲಿ ಸಂದೇಶ ತೆರೆಯಿರಿ';
$labels['composeextwin'] = 'ಹೊಸ ವಿಂಡೋದಲ್ಲಿ ರಚಿಸು';
$labels['htmleditor'] = 'HTML ಸಂದೇಶಗಳನ್ನು ರಚಿಸು';
$labels['htmlsignature'] = 'HTML ಸಹಿ';
$labels['showemail'] = ' ಇಮೇಲ್ ವಿಳಾಸವನ್ನು ಹೆಸರಿನೊಂದಿಗೆ ತೋರಿಸು';
$labels['askuser'] = 'ನನನ್ನು  ಕೇಳು';
$labels['autosend'] = 'ರಸಿಟನ್ನು  ಕಳಿಸು';
$labels['skipdeleted'] = 'ಅಳಿಸಲಾಗಿರುವ  ಸಂದೇಶಗಳನ್ನು ತೋರಿಸಬೇಡ';
$labels['always'] = 'ಯಾವಾಗಲೂ';
$labels['everynminutes'] = 'ಪ್ರತಿ $n ನಿಮಿಷ (ಗಳು)';
$labels['refreshinterval'] = 'ರಿಫ್ರೆಶ್ (ಹೊಸ ಸಂದೇಶಗಳನ್ನು, ಇತ್ಯಾದಿಗಳನ್ನು ಪರಿಶೀಲಿಸು)';
$labels['immediately'] = 'ತತ್ಕ್ಷಣ ';
$labels['mainoptions'] = 'ಮುಖ್ಯ ಆಯ್ಕೆಗಳು';
$labels['section'] = 'ವಿಭಾಗ';
$labels['newmessage'] = 'ಹೊಸ ಸಂದೇಶ';
$labels['signatureoptions'] = 'ಸಹಿ ಆಯ್ಕೆಗಳು';
$labels['whenreplying'] = 'ಪ್ರತ್ಯುತ್ತರ ನೀಡುವಾಗ';
$labels['replyempty'] = 'ಮೂಲ ಸಂದೇಶವನ್ನು ಉಲ್ಲೇಖಿಸಬೇಡ';
$labels['replyremovesignature'] = ' ಪ್ರತ್ಯುತ್ತರ ನೀಡುವಾಗ ಸಂದೇಶದಿಂದ ಮೂಲಸಹಿಯನ್ನು ತೆಗೆದು ಹಾಕು';
$labels['newmessageonly'] = 'ಹೊಸ ಸಂದೇಶ ಮಾತ್ರ    ';
$labels['insertsignature'] = 'ಸಹಿ ಸೇರಿಸು';
$labels['afternseconds'] = '$n ಸೆಕೆಂಡುಗಳ ನಂತರ';
$labels['addtodict'] = 'ನಿಘಂಟಿಗೆ ಸೇರಿಸು';
$labels['messagecount'] = 'ಸಂದೇಶಗಳು';
$labels['create'] = 'ರಚಿಸು';
$labels['properties'] = 'ಗುಣಲಕ್ಷಣಗಳು';
$labels['location'] = 'ಸ್ಥಳ';
$labels['info'] = 'ಮಾಹಿತಿ';
$labels['source'] = 'ಮೂಲ';
$labels['license'] = 'ಪರವಾನಗಿ';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['english'] = 'ಇಂಗ್ಲೀಷ್';
$labels['westerneuropean'] = 'ಪಾಶ್ಚಾತ್ಯ ಯುರೋಪಿಯನ್';
$labels['easterneuropean'] = 'ಪೂರ್ವ ಯುರೋಪಿಯನ್';
