<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Editor Markdown';
$labels['editor_button_title'] = 'Vytvorte správu v jazyku Markdown a odošlite ju ako HTML';
$labels['toolbar_button_quit'] = 'Späť na editor čistého textu';
$labels['toolbar_button_help'] = 'Otvoriť sprievodcu syntaxou jazyka Markdown v novom okne';
$labels['toolbar_button_preview'] = 'Náhľad na HTML ako by bolo odoslané';
$labels['toolbar_button_bold'] = 'Tučné';
$labels['toolbar_button_italic'] = 'Kurzíva';
$labels['toolbar_button_strike'] = 'Prečiarknuté';
$labels['toolbar_button_h1'] = 'Nadpis 1. úrovne';
$labels['toolbar_button_h2'] = 'Nadpis 2. úrovne';
$labels['toolbar_button_h3'] = 'Nadpis 3. úrovne';
$labels['toolbar_button_h4'] = 'Nadpis 4. úrovne';
$labels['toolbar_button_h5'] = 'Nadpis 5. úrovne';
$labels['toolbar_button_h6'] = 'Nadpis 6. úrovne';
$labels['toolbar_button_blockquote'] = 'Bloková citácia';
$labels['toolbar_button_unordered_list'] = 'Nezoradený zoznam';
$labels['toolbar_button_ordered_list'] = 'Zoradený zoznam';
$labels['toolbar_button_link'] = 'Odkaz';
$labels['toolbar_button_image'] = 'Obrázok';
$labels['toolbar_button_undo'] = 'Späť';
$labels['toolbar_button_redo'] = 'Dopredu';
