<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'ფილტრები';
$labels['filtername'] = 'ფილტრის სახელი';
$labels['newfilter'] = 'ახალი ფილტრი';
$labels['filteradd'] = 'ფილტრის დამატება';
$labels['filterdel'] = 'ფილტრის წაშლა';
$labels['rules'] = 'წესები';
$labels['actions'] = 'ქმედებები';
$labels['scope'] = 'შუალედი';
$labels['moveup'] = 'აწევა';
$labels['movedown'] = 'ჩამოწევა';
$labels['filterany'] = 'ყველა შეტყობინება';
$labels['filtercontains'] = 'შეიცავს';
$labels['filternotcontains'] = 'არ შეიცავს';
$labels['filterexists'] = 'არსებობს';
$labels['filternotexists'] = 'არ არსებობს';
$labels['filtermatches'] = 'ემთხვევა გამოსახულებას';
$labels['filterunder'] = 'ქვეშ';
$labels['filterover'] = 'ზემოთ';
$labels['mime'] = 'MIME:';
$labels['mime-message'] = 'შეტყობინება';
$labels['mime-anychild'] = 'ნებისმიერი';
$labels['mime-type'] = 'ტიპი';
$labels['mime-subtype'] = 'ქვეტიპი';
$labels['mime-contenttype'] = 'content-type';
$labels['mime-param'] = 'პარამეტრი';
$labels['addrule'] = 'წესის დამატება';
$labels['delrule'] = 'წესის წაშლა';
$labels['messagedelete'] = 'წაშლა';
$labels['add'] = 'დამატება';
$labels['del'] = 'წაშლა';
$labels['sender'] = 'გამგზავნელი';
$labels['recipient'] = 'მიმღები';
$labels['vacationsubject'] = 'შეტყობინების თემა:';
$labels['days'] = 'დღე';
$labels['seconds'] = 'წამი';
$labels['enable'] = 'ჩართვა/გამორთვა';
$labels['filterset'] = 'ფილტრების ნაკრები';
$labels['filtersets'] = 'ფილტრის ნაკრებები';
$labels['filterdef'] = 'ფილტრის აღწერა';
$labels['active'] = 'აქტიური';
$labels['none'] = 'არცერთი';
$labels['fromset'] = 'ნაკრებიდან';
$labels['fromfile'] = 'ფაილიდან';
$labels['filterdisabled'] = 'ფილტრი გამორთულია';
$labels['flagread'] = 'წაკითხვა';
$labels['flagdeleted'] = 'წაშლილი';
$labels['flaganswered'] = 'პასუხგაცემული';
$labels['flagflagged'] = 'მონიშნული';
$labels['flagdraft'] = 'მონახაზი';
$labels['setvariable'] = 'ცვლადის დაყენება';
$labels['setvarname'] = 'ცვლადის სახელი:';
$labels['setvarvalue'] = 'ცვლადის მნიშვნელობა:';
$labels['setvarmodifiers'] = 'მოდიფიკატორები:';
$labels['varlower'] = 'პატარა ასოები';
$labels['varupper'] = 'დიდი ასოები';
$labels['varlength'] = 'სიგრძე';
$labels['notify'] = 'გაფრთხილების გაგზავნა';
$labels['notifytarget'] = 'გაფრთხილების სამიზნე:';
$labels['notifyimportance'] = 'მნიშვნელოვნობა:';
$labels['notifyimportancelow'] = 'დაბალი';
$labels['notifyimportancenormal'] = 'ნორმალური';
$labels['notifyimportancehigh'] = 'მაღალი';
$labels['notifymethodmailto'] = 'ელ–ფოსტა';
$labels['notifymethodtel'] = 'ტელეფონი';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'ფილტრის შექმნა';
$labels['nextstep'] = 'შემდეგი ნაბიჯი';
$labels['...'] = '...';
$labels['string'] = 'სტრიქონი';
$labels['currdate'] = 'მიმდინარე თარიღი';
$labels['datetest'] = 'თარიღი';
$labels['dateheader'] = 'თავსართი:';
$labels['year'] = 'წელი';
$labels['month'] = 'თვე';
$labels['day'] = 'დღე';
$labels['date'] = 'თარიღი (წწწწ-თთ-დდ)';
$labels['julian'] = 'თარიღი (იულიანეს)';
$labels['hour'] = 'საათი';
$labels['minute'] = 'წუთი';
$labels['second'] = 'წამი';
$labels['time'] = 'დრო (სთ:წთ:წმ)';
$labels['iso8601'] = 'თარიღი (ISO8601)';
$labels['std11'] = 'თარიღი (RFC2822)';
$labels['zone'] = 'დროის სარტყელი';
$labels['weekday'] = 'სამუშაო დღე (0-6)';
$labels['advancedopts'] = 'დამატებითი პარამეტრები';
$labels['body'] = 'შეტყობინების ტექსტი';
$labels['address'] = 'მისამართი';
$labels['envelope'] = 'კონვერტი';
$labels['modifier'] = 'მოდიფიკატორი:';
$labels['text'] = 'ტექსტი';
$labels['undecoded'] = 'დეკოდირების გარეშე (დაუმუშავებელი)';
$labels['contenttype'] = 'შემცველობის ტიპი';
$labels['modtype'] = 'ტიპი:';
$labels['allparts'] = 'ყველა';
$labels['domain'] = 'დომენი';
$labels['localpart'] = 'ლოკალური პორტი';
$labels['user'] = 'მომხმარებელი';
$labels['detail'] = 'დეტალები';
$labels['comparator'] = 'შემდარებელი:';
$labels['default'] = 'ნაგულისხმევი';
$labels['octet'] = 'მკაცრი (ოქტეტი)';
$labels['asciinumeric'] = 'რიცხვითი (ASCII-რიცხვითი)';
$labels['index'] = 'ინდექსი:';
$labels['indexlast'] = 'უკან';
$labels['vacation.reply'] = 'პასუხი შეტყობინება';
$labels['vacation.advanced'] = 'დამატებითი პარამეტრები';
$labels['vacation.subject'] = 'სათაური';
$labels['vacation.body'] = 'შეტყობინების ტექსტი';
$labels['vacation.status'] = 'სტატუსი';
$labels['vacation.on'] = 'ჩართული';
$labels['vacation.off'] = 'გამორთული';
$labels['vacation.interval'] = 'პასუხის ინტერვალი';
$labels['vacation.saving'] = 'მიმდინარეობს მონაცემების შენახვა...';
$labels['vacation.keep'] = 'შენარჩუნება';
$labels['vacation.discard'] = 'მოცილება';
$labels['vacation.redirect'] = 'გადამისამართება სად';
$labels['forward'] = 'გადაგზავნა';
$labels['forward.redirect'] = 'გადამისამართება სად';
$labels['forward.on'] = 'ჩართული';
$labels['forward.off'] = 'გამორთული';
$labels['forward.status'] = 'სტატუსი:';
$labels['forward.saving'] = 'მიმდინარეობს მონაცემების შენახვა...';
$labels['arialabelfilteractions'] = 'ფილტრის ქმედებები';
$labels['arialabelfilterform'] = 'ფილტრის თვისებები';
$labels['message'] = 'შეტყობინება';
$labels['duplicate.handle'] = 'დამუშავება:';
$labels['duplicate.header'] = 'თავსართი:';
$labels['duplicate.uniqueid'] = 'იდენტიფიკატორი:';
$messages['namereserved'] = 'დაცული სახელი.';
