<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'visualizza notifica nel browser per nuovi messaggi';
$labels['desktop'] = 'visualizza notifiche sul desktop per nuovi messaggi';
$labels['sound'] = 'riproduci il suono per nuovi messaggi';
$labels['test'] = 'Prova';
$labels['title'] = 'Nuovo Messaggio';
$labels['body'] = 'Hai ricevuto un nuovo messaggio';
$labels['testbody'] = 'Notifica di prova';
$labels['desktopdisabled'] = 'Le notifiche sul desktop sono disabilitate nel tuo browser';
$labels['desktopunsupported'] = 'il tuo browser non supporta le notifiche sul desktop';
$labels['desktoptimeout'] = 'Chiudi la notifica visualizzata sul desktop';
