<?php

/*
+-----------------------------------------------------------------------+
| localization/de_DE/csv2vcard.inc                                      |
|                                                                       |
| Localization file of the Roundcube Webmail client                     |
| Copyright (C) 2005-2014, The Roundcube Dev Team                       |
|                                                                       |
| Licensed under the GNU General Public License version 3 or            |
| any later version with exceptions for skins & plugins.                |
| See the README file for a full license statement.                     |
|                                                                       |
+-----------------------------------------------------------------------+
| Author: Aleksander Machniak <alec@alec.pl>                            |
+-----------------------------------------------------------------------+
*/
$map = array();
$map['Jahrestag'] = 'anniversary';
$map['Name Assistent'] = 'assistant';
$map['Telefon Assistent'] = 'phone:assistant';
$map['Geburtstag'] = 'birthday';
$map['Ort geschäftlich'] = 'locality:work';
$map['Region geschäftlich'] = 'country:work';
$map['Fax geschäftlich'] = 'phone:workfax';
$map['Telefon geschäftlich'] = 'phone:work';
$map['Telefon geschäftlich 2'] = 'phone:work2';
$map['Postleitzahl geschäftlich'] = 'zipcode:work';
$map['Land geschäftlich'] = 'region:work';
$map['Straße geschäftlich'] = 'street:work';
$map['Autotelefon'] = 'phone:car';
$map['Kategorien'] = 'groups';
$map['Firma'] = 'organization';
$map['Abteilung'] = 'department';
$map['E-Mail-Adresse'] = 'email:other';
$map['E-Mail 2: Adresse'] = 'email:other';
$map['E-Mail 3: Adresse'] = 'email:other';
$map['Vorname'] = 'firstname';
$map['Geschlecht'] = 'gender';
$map['Ort privat'] = 'locality:home';
$map['Region privat'] = 'country:home';
$map['Fax privat'] = 'phone:homefax';
$map['Telefon privat'] = 'phone:home';
$map['Telefon privat 2'] = 'phone:home2';
$map['Postleitzahl privat'] = 'zipcode:home';
$map['Land privat'] = 'region:home';
$map['Straße privat'] = 'street:home';
$map['Position'] = 'jobtitle';
$map['Nachname'] = 'surname';
$map['Manager\'s Name'] = 'manager';
$map['Weitere Vornamen'] = 'middlename';
$map['Mobiltelefon'] = 'phone:mobile';
$map['Notizen'] = 'notes';
$map['Weiterer Ort'] = 'locality:other';
$map['Weitere Region'] = 'country:other';
$map['Weiteres Fax'] = 'phone:other';
$map['Weiteres Telefon'] = 'phone:other';
$map['Weitere Postleitzahl'] = 'zipcode:other';
$map['Weiteres Land'] = 'region:other';
$map['Weitere Straße'] = 'street:other';
$map['Pager'] = 'phone:pager';
$map['Haupttelefon'] = 'phone:main';
$map['Spouse'] = 'spouse';
$map['Suffix'] = 'suffix';
$map['Title'] = 'prefix';
$map['Webseite'] = 'website:homepage';
$map['Geburtstag'] = 'birthday-d';
$map['Geburtsmonat'] = 'birthday-m';
$map['Geburtsjahr'] = 'birthday-y';
$map['Anzeigename'] = 'name';
$map['Fax-Nummer'] = 'phone:homefax';
$map['Privat: Adresse'] = 'street:home';
$map['Privat: Land'] = 'country:home';
$map['Privat: PLZ'] = 'zipcode:home';
$map['Mobil-Tel.-Nr.'] = 'phone:mobile';
$map['Spitzname'] = 'nickname';
$map['Organisation'] = 'organization';
$map['Pager-Nummer'] = 'phone:pager';
$map['Primäre E-Mail-Adresse'] = 'email:home';
$map['Sekundäre E-Mail-Adresse'] = 'email:other';
$map['Webseite 1'] = 'website:homepage';
$map['Webseite 2'] = 'website:other';
$map['Tel. dienstlich'] = 'phone:work';
$map['Dienstlich: Adresse'] = 'street:work';
$map['Dienstlich: Land'] = 'country:work';
$map['Dienstlich: PLZ'] = 'zipcode:work';
$map['Date of Birth'] = 'birthday';
$map['Email'] = 'email:home';
$map['Home Mobile'] = 'phone:mobile';
$map['Home Zip'] = 'zipcode:home';
$map['Info'] = 'notes';
$map['User Photo'] = 'photo';
$map['URL'] = 'website:homepage';
$map['Work City'] = 'locality:work';
$map['Work Company'] = 'organization';
$map['Work Dept'] = 'department';
$map['Work Fax'] = 'phone:workfax';
$map['Work Mobile'] = 'phone:other';
$map['Work State'] = 'region:work';
$map['Work Title'] = 'jobtitle';
$map['Work Zip'] = 'zipcode:work';
