<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtry';
$labels['managefilters'] = 'Nastavení filtrů';
$labels['filtername'] = 'Název filtru';
$labels['newfilter'] = 'Nový filtr';
$labels['filteradd'] = 'Přidej filtr';
$labels['filterdel'] = 'Smaž filtr';
$labels['rules'] = 'Pravidla';
$labels['actions'] = 'Akce';
$labels['scope'] = 'Rozsah';
$labels['moveup'] = 'Posunout nahoru';
$labels['movedown'] = 'Posunout dolů';
$labels['filterallof'] = 'Odpovídají všechna pravidla';
$labels['filteranyof'] = 'Odpovídá kterékoliv pravidlo';
$labels['filterany'] = 'Všechny zprávy';
$labels['filtercontains'] = 'obsahuje';
$labels['filternotcontains'] = 'neobsahuje';
$labels['filteris'] = 'odpovídá';
$labels['filterisnot'] = 'neodpovídá';
$labels['filterexists'] = 'existuje';
$labels['filternotexists'] = 'neexistuje';
$labels['filtermatches'] = 'odpovídá výrazu';
$labels['filternotmatches'] = 'neodpovídá výrazu';
$labels['filterregex'] = 'odpovídá regulárnímu výrazu';
$labels['filternotregex'] = 'neodpovídá regulárnímu výrazu';
$labels['filterunder'] = 'pod';
$labels['filterover'] = 'nad';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Část MIME:';
$labels['mime-message'] = 'zpráva';
$labels['mime-anychild'] = 'jakákoli';
$labels['mime-type'] = 'typ';
$labels['mime-subtype'] = 'podtyp';
$labels['mime-contenttype'] = 'typ obsahu';
$labels['mime-param'] = 'parametr';
$labels['addrule'] = 'Přidej pravidlo';
$labels['delrule'] = 'Smaž pravidlo';
$labels['messagemoveto'] = 'Přesuň zprávu do';
$labels['messageredirect'] = 'Přeposlat zprávu na';
$labels['messagecopyto'] = 'Zkopírovat zprávu do';
$labels['messagesendcopy'] = 'Odeslat kopii zprávy na';
$labels['messagereply'] = 'Odpovědět se zprávou';
$labels['messagedelete'] = 'Smazat zprávu';
$labels['messagediscard'] = 'Zahodit a informovat odesilatele';
$labels['messagekeep'] = 'Ponechat zprávu v doručené poště';
$labels['messagesrules'] = 'Pravidla pro příchozí zprávu:';
$labels['messagesactions'] = '...vykonej následující akce:';
$labels['add'] = 'Přidej';
$labels['del'] = 'Smaž';
$labels['sender'] = 'Odesílatel';
$labels['recipient'] = 'Příjemce';
$labels['vacationaddr'] = 'Mé e-mailové adresy:';
$labels['vacationdays'] = 'Počet dnů mezi automatickými odpověďmi:';
$labels['vacationinterval'] = 'Prodleva mezi automatickými odpověďmi:';
$labels['vacationreason'] = 'Zpráva (Důvod nepřítomnosti):';
$labels['vacationfrom'] = 'Adresa odesilatele odpovědi:';
$labels['vacationsubject'] = 'Předmět zprávy:';
$labels['days'] = 'dnů';
$labels['seconds'] = 'sekund';
$labels['rulestop'] = 'Zastavit pravidla';
$labels['enable'] = 'Zapnout/Vypnout';
$labels['filterset'] = 'Sada filtrů';
$labels['filtersets'] = 'Sady filtrů';
$labels['filtersetadd'] = 'Přidat sadu filtrů';
$labels['filtersetdel'] = 'Smazat sadu filtrů';
$labels['filtersetact'] = 'Aktivovat tuto sadu filtrů';
$labels['filtersetdeact'] = 'Vypnout tuto sadu filtrů';
$labels['filterseteditraw'] = 'Upravit sadu pravidel';
$labels['filtersetswitch'] = 'Zapnout/Vypnout sadu filtrů';
$labels['filterdef'] = 'Definice filtru';
$labels['filtersetname'] = 'Název sady filtrů';
$labels['newfilterset'] = 'Nová sada filtrů';
$labels['active'] = 'aktivní';
$labels['none'] = 'nic';
$labels['fromset'] = 'ze sady';
$labels['fromfile'] = 'ze souboru';
$labels['filterdisabled'] = 'Filtr neaktivní';
$labels['filterenabled'] = 'Filtr aktivní';
$labels['countisgreaterthan'] = 'počet je větší než';
$labels['countisgreaterthanequal'] = 'počet je větší nebo roven';
$labels['countislessthan'] = 'počet je nižší než';
$labels['countislessthanequal'] = 'počet je nižší nebo roven';
$labels['countequals'] = 'počet je roven';
$labels['countnotequals'] = 'počet není roven';
$labels['valueisgreaterthan'] = 'hodnota je větší než';
$labels['valueisgreaterthanequal'] = 'hodnota je větší nebo stejná jako';
$labels['valueislessthan'] = 'hodnota je nižší než';
$labels['valueislessthanequal'] = 'hodnota je nižší nebo stejná jako';
$labels['valueequals'] = 'hodnota odpovídá';
$labels['valuenotequals'] = 'hodnota neodpovídá';
$labels['setflags'] = 'Nastavit příznaky u zprávy';
$labels['addflags'] = 'Přidat příznaky ke zprávě';
$labels['removeflags'] = 'Odstranit příznaky ze zprávy';
$labels['flagread'] = 'Přečteno';
$labels['flagdeleted'] = 'Smazáno';
$labels['flaganswered'] = 'Odpovězené';
$labels['flagflagged'] = 'Označeno';
$labels['flagdraft'] = 'Koncept';
$labels['addheader'] = 'Přidat hlavičku do zprávy';
$labels['deleteheader'] = 'Odebrat hlavičku ze zprávy';
$labels['headername'] = 'Název hlavičky';
$labels['headervalue'] = 'Hodnota hlavičky';
$labels['headerpos'] = 'Umístění hlavičky';
$labels['headeratstart'] = 'na začátku';
$labels['headeratend'] = 'na konci';
$labels['headeroccurrence'] = 'Výskyt/Umístění hlavičky';
$labels['headerfromstart'] = 'od začátku';
$labels['headerfromend'] = 'od konce';
$labels['headerpatterns'] = 'Vzory hodnot hlavičky';
$labels['headermatchtype'] = 'odpovídající typ:';
$labels['setvariable'] = 'Nastavit proměnnou';
$labels['setvarname'] = 'Název proměnné:';
$labels['setvarvalue'] = 'Hodnota proměnné:';
$labels['setvarmodifiers'] = 'Modifikátory:';
$labels['varlower'] = 'malá písmena';
$labels['varupper'] = 'velká písmena';
$labels['varlowerfirst'] = 'první písmeno malé';
$labels['varupperfirst'] = 'první písmeno velké';
$labels['varquotewildcard'] = 'uvodit speciální znaky uvozovkama';
$labels['varlength'] = 'délka';
$labels['varencodeurl'] = 'zakódováno pomocí procentového kódování (pro URL)';
$labels['notify'] = 'Odeslat oznámení';
$labels['notifytarget'] = 'Cíl oznámení:';
$labels['notifymessage'] = 'Zpráva oznámení (nepovinné):';
$labels['notifyoptions'] = 'Možnosti oznámení (nepovinné):';
$labels['notifyfrom'] = 'Odesílatel oznámení (nepovinné):';
$labels['notifyimportance'] = 'Důležitost:';
$labels['notifyimportancelow'] = 'nízká';
$labels['notifyimportancenormal'] = 'normální';
$labels['notifyimportancehigh'] = 'vysoká';
$labels['notifymethodmailto'] = 'E-mail';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Vytvořit filtr';
$labels['usedata'] = 'Použít následující údaje ve filtru:';
$labels['nextstep'] = 'Další krok';
$labels['...'] = '...';
$labels['string'] = 'Řetězec';
$labels['currdate'] = 'Aktuální datum';
$labels['datetest'] = 'Datum';
$labels['dateheader'] = 'hlavička:';
$labels['year'] = 'rok';
$labels['month'] = 'měsíc';
$labels['day'] = 'den';
$labels['date'] = 'datum (rrrr-mm-dd)';
$labels['julian'] = 'datum (juliánské)';
$labels['hour'] = 'hodina';
$labels['minute'] = 'minuta';
$labels['second'] = 'sekunda';
$labels['time'] = 'čas (hh:mm:ss)';
$labels['iso8601'] = 'datum (ISO8601)';
$labels['std11'] = 'datum (RFC2822)';
$labels['zone'] = 'časová zóna';
$labels['weekday'] = 'všední den (0-6)';
$labels['advancedopts'] = 'Pokročilá nastavení';
$labels['body'] = 'Tělo';
$labels['address'] = 'adresa';
$labels['envelope'] = 'obálka';
$labels['modifier'] = 'měnič:';
$labels['text'] = 'text';
$labels['undecoded'] = 'nedekódované (surové)';
$labels['contenttype'] = 'typ obsahu';
$labels['modtype'] = 'typ:';
$labels['allparts'] = 'vše';
$labels['domain'] = 'doména';
$labels['localpart'] = 'místní část';
$labels['user'] = 'uživatel';
$labels['detail'] = 'detail';
$labels['comparator'] = 'porovnávač:';
$labels['default'] = 'výchozí';
$labels['octet'] = 'striktní (oktet)';
$labels['asciicasemap'] = 'nerozlišuje velikost písmen (ascii-casemap)';
$labels['asciinumeric'] = 'číslené (ascii-numeric)';
$labels['index'] = 'index:';
$labels['indexlast'] = 'pozpátku';
$labels['spamtest'] = 'Úroveň nevyžádané pošty';
$labels['spamtestisgreaterthan'] = 'je větší než';
$labels['spamtestisgreaterthanequal'] = 'je větší nebo rovno';
$labels['spamtestislessthan'] = 'je menší než';
$labels['spamtestislessthanequal'] = 'je menší nebo rovno';
$labels['spamtestequals'] = 'odpovídá';
$labels['spamtestnotequals'] = 'neodpovídá';
$labels['spamtestisunknown'] = 'je neznámý';
$labels['vacation'] = 'Mimo-kancelář';
$labels['vacation.reply'] = 'Odpověd';
$labels['vacation.advanced'] = 'Pokročilá nastavení';
$labels['vacation.from'] = 'Adresa odesílatele odpovědi';
$labels['vacation.subject'] = 'Předmět';
$labels['vacation.body'] = 'Tělo';
$labels['vacation.start'] = 'Začátek';
$labels['vacation.end'] = 'Konec';
$labels['vacation.status'] = 'Stav';
$labels['vacation.on'] = 'Zapnuto';
$labels['vacation.off'] = 'Vypnuto';
$labels['vacation.addresses'] = 'Mé e-mailové adresy';
$labels['vacation.interval'] = 'Doba mezi odpověďmi';
$labels['vacation.after'] = 'Přidat pravidlo mimo-kancelář za';
$labels['vacation.saving'] = 'Ukládám data...';
$labels['vacation.action'] = 'Akce pro příchozí zprávu';
$labels['vacation.keep'] = 'Zachovat';
$labels['vacation.discard'] = 'Zahodit';
$labels['vacation.redirect'] = 'Přesměrovat na';
$labels['vacation.copy'] = 'Odeslat kopii zprávy na';
$labels['forward'] = 'Přeposílání';
$labels['forward.redirect'] = 'Přesměrovat na';
$labels['forward.copy'] = 'Odeslat kopii zprávy na';
$labels['forward.on'] = 'Zapnuto';
$labels['forward.off'] = 'Vypnuto';
$labels['forward.status'] = 'Stav:';
$labels['forward.action'] = 'Vykonej následující akci pro příchozí e-maily:';
$labels['forward.saving'] = 'Ukládám data...';
$labels['filladdresses'] = 'Vyplnit všemi mými adresami';
$labels['arialabelfiltersetactions'] = 'Nastavit akce filtru';
$labels['arialabelfilteractions'] = 'Akce filtru';
$labels['arialabelfilterform'] = 'Vlastnosti filtru';
$labels['ariasummaryfilterslist'] = 'Seznam filtrů';
$labels['ariasummaryfiltersetslist'] = 'Seznam sad filtrů';
$labels['filterstitle'] = 'Upravit filtry příchozích emailů';
$labels['vacationtitle'] = 'Upravit pravidlo mimo-kancelář';
$labels['forwardtitle'] = 'Upravit pravidlo pro přeposílání emailů';
$labels['message'] = 'Zpráva';
$labels['duplicate'] = 'je duplicitní';
$labels['notduplicate'] = 'není duplicitní';
$labels['duplicate.handle'] = 'popisovač:';
$labels['duplicate.header'] = 'hlavička:';
$labels['duplicate.uniqueid'] = 'Identifikátor:';
$labels['duplicate.seconds'] = 'prodleva (sekundy):';
$labels['duplicate.last'] = 'relativní k poslednímu vykonání';
$messages['filterunknownerror'] = 'Neznámá chyba serveru.';
$messages['filterconnerror'] = 'Nebylo možné se připojit k sieve serveru';
$messages['filterdeleteerror'] = 'Nebylo možné smazat filtr. Došlo k chybě serveru.';
$messages['filterdeleted'] = 'Filtr byl smazán.';
$messages['filtersaved'] = 'Filtr byl uložen.';
$messages['filtersaveerror'] = 'Nebylo možné uložit filtr. Došlo k chybě serveru.';
$messages['filterformerror'] = 'Formulář filtru obsahuje chyby.';
$messages['filterdeleteconfirm'] = 'Opravdu chcete smazat vybraný filtr?';
$messages['ruledeleteconfirm'] = 'Jste si jisti, že chcete smazat vybrané pravidlo?';
$messages['actiondeleteconfirm'] = 'Jste si jisti, že chcete smazat vybranou akci?';
$messages['forbiddenchars'] = 'Zakázané znaky v poli.';
$messages['cannotbeempty'] = 'Pole nemůže být prázdné.';
$messages['ruleexist'] = 'Filtr s uvedeným názvem již existuje.';
$messages['setactivateerror'] = 'Nelze zapnout vybranou sadu filtrů. Došlo k chybě serveru.';
$messages['setdeactivateerror'] = 'Nelze vypnout vybranou sadu filtrů. Došlo k chybě serveru.';
$messages['setdeleteerror'] = 'Nelze odstranit vybranou sadu filtrů. Došlo k chybě serveru.';
$messages['setactivated'] = 'Sada filtrů byla zapnuta.';
$messages['setdeactivated'] = 'Sada filtrů byla vypnuta.';
$messages['setdeleted'] = 'Sada filtrů byla odstraněna.';
$messages['setupdated'] = 'Sada filtrů byla upravena.';
$messages['setdeleteconfirm'] = 'Opravdu si přejete odebrat vybranou sadu filtrů?';
$messages['setcreateerror'] = 'Nelze vytvořit sadu filtrů. Došlo k chybě serveru.';
$messages['setcreated'] = 'Sada filtrů byla vytvořena.';
$messages['activateerror'] = 'Nelze zapnout vybrané filtry. Došlo k chybě serveru.';
$messages['deactivateerror'] = 'Nelze vypnout vybrané filtry. Došlo k chybě serveru.';
$messages['deactivated'] = 'Filtry vypnuty.';
$messages['activated'] = 'Filtry zapnuty.';
$messages['moved'] = 'Filtr byl přesunut.';
$messages['moveerror'] = 'Nelze přesunout vybraný filtr. Došlo k chybě serveru.';
$messages['nametoolong'] = 'Příliš dlouhý název.';
$messages['namereserved'] = 'Vyhrazený název.';
$messages['setexist'] = 'Sada již existuje.';
$messages['nodata'] = 'Musí být vybrána minimálně jedna pozice!';
$messages['invaliddateformat'] = 'Neplatné datum nebo část data';
$messages['saveerror'] = 'Nebylo možné uložit data. Došlo k chybě serveru.';
$messages['vacationsaved'] = 'Data mimo-kancelář byla uložena.';
$messages['forwardsaved'] = 'Data pro přeposlání byla uložena.';
$messages['emptyvacationbody'] = 'Tělo zprávy';
$messages['duplicate.conflict.err'] = 'Hlavička a jedinečný identifikátor zároveň nejsou povoleny.';
$messages['disabledaction'] = 'Akce není povolena';
$messages['lastindexempty'] = 'Při počítání od zadu je vyžadován index.';
$messages['noflagset'] = 'Alespoň jeden příznak musí být vybrán.';
$messages['saving.actionordererror'] = 'Předchozí akce \'$previous\' musí být po akci \'$current\'.';
