<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Markdown редактор';
$labels['editor_button_title'] = 'Състави писмо в Markdown и го изпрати като HTML';
$labels['toolbar_button_quit'] = 'Обратно към редактора на обикновен текст';
$labels['toolbar_button_help'] = 'Отвори ръководство за синтаксис на Markdown в нов прозорец';
$labels['toolbar_button_preview'] = 'Прегледай HTML, както би бил изпратен';
$labels['toolbar_button_bold'] = 'Получер';
$labels['toolbar_button_italic'] = 'Курсив';
$labels['toolbar_button_strike'] = 'Зачеркнат';
$labels['toolbar_button_h1'] = 'Заглавие ниво 1';
$labels['toolbar_button_h2'] = 'Заглавие ниво 2';
$labels['toolbar_button_h3'] = 'Заглавие ниво 3';
$labels['toolbar_button_h4'] = 'Заглавие ниво 4';
$labels['toolbar_button_h5'] = 'Заглавие ниво 5';
$labels['toolbar_button_h6'] = 'Заглавие ниво 6';
$labels['toolbar_button_blockquote'] = 'Блоков цитат';
$labels['toolbar_button_unordered_list'] = 'Неподреден списък';
$labels['toolbar_button_ordered_list'] = 'Подреден списък';
$labels['toolbar_button_link'] = 'Връзка';
$labels['toolbar_button_image'] = 'Картинка';
$labels['toolbar_button_undo'] = 'Отмени';
$labels['toolbar_button_redo'] = 'Върни';
