<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Diell';
$labels['buttontitle'] = 'Diellaouiñ ar gemennadenn-mañ';
$labels['archived'] = 'Diellaouet gant berzh';
$labels['archivedreload'] = 'Diellaouet gant berzh. Adkargit ar bajenn da welet an teuliad dielloù nevez.';
$labels['archiveerror'] = 'Ul lodenn eus ar c\'hemennadennoù n\'hallont ket bezañ diellaouet';
$labels['archivefolder'] = 'Diell';
$labels['settingstitle'] = 'Diell';
$labels['archivetype'] = 'Rannañ an diell dre';
$labels['archivetypeyear'] = 'Bloaz (sk: Diell/2012)';
$labels['archivetypemonth'] = 'Miz (sk: Diell/2012/06)';
$labels['archivetypefolder'] = 'Teuliad orin';
$labels['archivetypesender'] = 'Postel ar c\'haser';
$labels['unkownsender'] = 'dianav';
