<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = 'Африка';
$labels['tz:africa:abidjan'] = 'Абиджан';
$labels['tz:africa:accra'] = 'Аккра';
$labels['tz:africa:addis_ababa'] = 'Аддис-Абеба';
$labels['tz:africa:algiers'] = 'Алжир';
$labels['tz:africa:asmara'] = 'Асмара';
$labels['tz:africa:bamako'] = 'Бамако';
$labels['tz:africa:bangui'] = 'Банги';
$labels['tz:africa:banjul'] = 'Банджул';
$labels['tz:africa:bissau'] = 'Бисау';
$labels['tz:africa:blantyre'] = 'Блантайр';
$labels['tz:africa:brazzaville'] = 'Браззавиль';
$labels['tz:africa:bujumbura'] = 'Бужумбура';
$labels['tz:africa:cairo'] = 'Каир';
$labels['tz:africa:casablanca'] = 'Касабланка';
$labels['tz:africa:ceuta'] = 'Сеута';
$labels['tz:africa:conakry'] = 'Конакри';
$labels['tz:africa:dakar'] = 'Дакар';
$labels['tz:africa:dar_es_salaam'] = 'Дар-эс-Салам';
$labels['tz:africa:djibouti'] = 'Джибути';
$labels['tz:africa:douala'] = 'Дуала';
$labels['tz:africa:el_aaiun'] = 'Эль-Аюн';
$labels['tz:africa:freetown'] = 'Фритаун';
$labels['tz:africa:gaborone'] = 'Габороне';
$labels['tz:africa:harare'] = 'Хараре';
$labels['tz:africa:johannesburg'] = 'Йоханнесбург';
$labels['tz:africa:juba'] = 'Джуба';
$labels['tz:africa:kampala'] = 'Кампала';
$labels['tz:africa:khartoum'] = 'Хартум';
$labels['tz:africa:kigali'] = 'Кигали';
$labels['tz:africa:kinshasa'] = 'Киншаса';
$labels['tz:africa:lagos'] = 'Лагос';
$labels['tz:africa:libreville'] = 'Либревиль';
$labels['tz:africa:lome'] = 'Ломе';
$labels['tz:africa:luanda'] = 'Луанда';
$labels['tz:africa:lubumbashi'] = 'Лубумбаши';
$labels['tz:africa:lusaka'] = 'Лусака';
$labels['tz:africa:malabo'] = 'Малабо';
$labels['tz:africa:maputo'] = 'Мапуту';
$labels['tz:africa:maseru'] = 'Масеру';
$labels['tz:africa:mbabane'] = 'Мбабане';
$labels['tz:africa:mogadishu'] = 'Могадишо';
$labels['tz:africa:monrovia'] = 'Монровия';
$labels['tz:africa:nairobi'] = 'Найроби';
$labels['tz:africa:ndjamena'] = 'Нджамена';
$labels['tz:africa:niamey'] = 'Ниамей';
$labels['tz:africa:nouakchott'] = 'Нуакшот';
$labels['tz:africa:ouagadougou'] = 'Уагадугу';
$labels['tz:africa:porto-novo'] = 'Порто-Ново';
$labels['tz:africa:sao_tome'] = 'Сан-Томе';
$labels['tz:africa:tripoli'] = 'Триполи';
$labels['tz:africa:tunis'] = 'Тунис';
$labels['tz:africa:windhoek'] = 'Виндхук';
$labels['tz:america'] = 'Америка';
$labels['tz:america:adak'] = 'Адак';
$labels['tz:america:anchorage'] = 'Анкоридж';
$labels['tz:america:anguilla'] = 'Ангилья';
$labels['tz:america:antigua'] = 'Антигуа';
$labels['tz:america:araguaina'] = 'Арагуаина';
$labels['tz:america:argentina'] = 'Аргентина';
$labels['tz:america:argentina:buenos_aires'] = 'Буэнос-Айрес';
$labels['tz:america:argentina:catamarca'] = 'Кэйтамарка';
$labels['tz:america:argentina:cordoba'] = 'Кордова';
$labels['tz:america:argentina:jujuy'] = 'Жужуй';
$labels['tz:america:argentina:la_rioja'] = 'Ла-Риоха';
$labels['tz:america:argentina:mendoza'] = 'Мендоса';
$labels['tz:america:argentina:rio_gallegos'] = 'Рио-Гальегос';
$labels['tz:america:argentina:salta'] = 'Сальта';
$labels['tz:america:argentina:san_juan'] = 'Сан-Хуан';
$labels['tz:america:argentina:san_luis'] = 'Сан-Луис';
$labels['tz:america:argentina:tucuman'] = 'Тукуман';
$labels['tz:america:argentina:ushuaia'] = 'Ушуайя';
$labels['tz:america:aruba'] = 'Аруба';
$labels['tz:america:asuncion'] = 'Асунсьон';
$labels['tz:america:atikokan'] = 'Атикокан';
$labels['tz:america:bahia'] = 'Баия';
$labels['tz:america:bahia_banderas'] = 'Баия-де-Бандерас';
$labels['tz:america:barbados'] = 'Барбадос';
$labels['tz:america:belem'] = 'Белен';
$labels['tz:america:belize'] = 'Белиз';
$labels['tz:america:blanc-sablon'] = 'Блан Саблон';
$labels['tz:america:boa_vista'] = 'Боа-Виста';
$labels['tz:america:bogota'] = 'Богота';
$labels['tz:america:boise'] = 'Бойсе';
$labels['tz:america:cambridge_bay'] = 'Кеймбридж-Бей';
$labels['tz:america:campo_grande'] = 'Кампу-Гранди';
$labels['tz:america:cancun'] = 'Канкун';
$labels['tz:america:caracas'] = 'Каракас';
$labels['tz:america:cayenne'] = 'Кайенна';
$labels['tz:america:cayman'] = 'Острова Кайман';
$labels['tz:america:chicago'] = 'Чикаго';
$labels['tz:america:chihuahua'] = 'Чихуахуа';
$labels['tz:america:costa_rica'] = 'Коста-Рика';
$labels['tz:america:creston'] = 'Крестон';
$labels['tz:america:cuiaba'] = 'Куяба';
$labels['tz:america:curacao'] = 'Кюрасао';
$labels['tz:america:danmarkshavn'] = 'Данмарксхавн';
$labels['tz:america:dawson'] = 'Доусон';
$labels['tz:america:dawson_creek'] = 'Доусон-Крик';
$labels['tz:america:denver'] = 'Денвер';
$labels['tz:america:detroit'] = 'Детройт';
$labels['tz:america:dominica'] = 'Доминика';
$labels['tz:america:edmonton'] = 'Эдмонтон';
$labels['tz:america:eirunepe'] = 'Эйрунепе';
$labels['tz:america:el_salvador'] = 'Сальвадор';
$labels['tz:america:fort_nelson'] = 'Форт Нельсон';
$labels['tz:america:fortaleza'] = 'Форталеза';
$labels['tz:america:glace_bay'] = 'Глейс-Бей';
$labels['tz:america:godthab'] = 'Готхоб';
$labels['tz:america:goose_bay'] = 'Гус-Бей';
$labels['tz:america:grand_turk'] = 'Гранд-Терк';
$labels['tz:america:grenada'] = 'Гренада';
$labels['tz:america:guadeloupe'] = 'Гваделупа';
$labels['tz:america:guatemala'] = 'Гватемала';
$labels['tz:america:guayaquil'] = 'Гуаякиль';
$labels['tz:america:guyana'] = 'Гайана';
$labels['tz:america:halifax'] = 'Галифакс';
$labels['tz:america:havana'] = 'Гавана';
$labels['tz:america:hermosillo'] = 'Эрмосильо';
$labels['tz:america:indiana'] = 'Индиана';
$labels['tz:america:indiana:indianapolis'] = 'Индианаполис';
$labels['tz:america:indiana:knox'] = 'Нокс';
$labels['tz:america:indiana:marengo'] = 'Маренго';
$labels['tz:america:indiana:petersburg'] = 'Петербург';
$labels['tz:america:indiana:tell_city'] = 'Телл-Сити';
$labels['tz:america:indiana:vevay'] = 'Вивей';
$labels['tz:america:indiana:vincennes'] = 'Венсен';
$labels['tz:america:indiana:winamac'] = 'Уинамак';
$labels['tz:america:inuvik'] = 'Инувик';
$labels['tz:america:iqaluit'] = 'Икалуит';
$labels['tz:america:jamaica'] = 'Ямайка';
$labels['tz:america:juneau'] = 'Джуно';
$labels['tz:america:kentucky'] = 'Кентукки';
$labels['tz:america:kentucky:louisville'] = 'Луисвилл';
$labels['tz:america:kentucky:monticello'] = 'Монтиселло';
$labels['tz:america:kralendijk'] = 'Кралендейк';
$labels['tz:america:la_paz'] = 'Ла-Пас';
$labels['tz:america:lima'] = 'Лима';
$labels['tz:america:los_angeles'] = 'Лос-Анджелес';
$labels['tz:america:lower_princes'] = 'Лоуэр-Принс';
$labels['tz:america:maceio'] = 'Масейо';
$labels['tz:america:managua'] = 'Манагуа';
$labels['tz:america:manaus'] = 'Манаус';
$labels['tz:america:marigot'] = 'Мариго';
$labels['tz:america:martinique'] = 'Мартиника';
$labels['tz:america:matamoros'] = 'Матаморос';
$labels['tz:america:mazatlan'] = 'Масатлан';
$labels['tz:america:menominee'] = 'Меномини';
$labels['tz:america:merida'] = 'Мерида';
$labels['tz:america:metlakatla'] = 'Метлакатла';
$labels['tz:america:mexico_city'] = 'Мехико';
$labels['tz:america:miquelon'] = 'Микелон';
$labels['tz:america:moncton'] = 'Монктон';
$labels['tz:america:monterrey'] = 'Монтеррей';
$labels['tz:america:montevideo'] = 'Монтевидео';
$labels['tz:america:montserrat'] = 'Монтсеррат';
$labels['tz:america:nassau'] = 'Нассау';
$labels['tz:america:new_york'] = 'Нью-Йорк';
$labels['tz:america:nipigon'] = 'Нипигон';
$labels['tz:america:nome'] = 'Ном';
$labels['tz:america:noronha'] = 'Фернанду-ди-Норонья';
$labels['tz:america:north_dakota'] = 'Северная Дакота';
$labels['tz:america:north_dakota:beulah'] = 'Беула';
$labels['tz:america:north_dakota:center'] = 'Сентр';
$labels['tz:america:north_dakota:new_salem'] = 'Нью Салем';
$labels['tz:america:ojinaga'] = 'Охинага';
$labels['tz:america:panama'] = 'Панама';
$labels['tz:america:pangnirtung'] = 'Пангниртанг';
$labels['tz:america:paramaribo'] = 'Парамарибо';
$labels['tz:america:phoenix'] = 'Феникс';
$labels['tz:america:port-au-prince'] = 'Порт-о-Пренс';
$labels['tz:america:port_of_spain'] = 'Порт-оф-Спейн';
$labels['tz:america:porto_velho'] = 'Порту-Велью';
$labels['tz:america:puerto_rico'] = 'Пуэрто-Рико';
$labels['tz:america:rainy_river'] = 'Рейни-Ривер';
$labels['tz:america:rankin_inlet'] = 'Ранкин-Инлет';
$labels['tz:america:recife'] = 'Ресифи';
$labels['tz:america:regina'] = 'Реджайна';
$labels['tz:america:resolute'] = 'Ризолют';
$labels['tz:america:rio_branco'] = 'Риу-Бранку';
$labels['tz:america:santarem'] = 'Сантарен';
$labels['tz:america:santiago'] = 'Сантьяго';
$labels['tz:america:santo_domingo'] = 'Санто-Доминго';
$labels['tz:america:sao_paulo'] = 'Сан-Паулу';
$labels['tz:america:scoresbysund'] = 'Иллоккортоормиут';
$labels['tz:america:sitka'] = 'Ситка';
$labels['tz:america:st_barthelemy'] = 'Сен-Бартелеми';
$labels['tz:america:st_johns'] = "Сент-Джонс";
$labels['tz:america:st_kitts'] = 'Сент-Китс';
$labels['tz:america:st_lucia'] = 'Сент-Люсия';
$labels['tz:america:st_thomas'] = 'Сент-Томас';
$labels['tz:america:st_vincent'] = 'Сент-Винсент';
$labels['tz:america:swift_current'] = 'Суифт-Карент';
$labels['tz:america:tegucigalpa'] = 'Тегусигальпа';
$labels['tz:america:thule'] = 'Туле';
$labels['tz:america:thunder_bay'] = 'Тандер-Бей';
$labels['tz:america:tijuana'] = 'Тихуана';
$labels['tz:america:toronto'] = 'Торонто';
$labels['tz:america:tortola'] = 'Тортола';
$labels['tz:america:vancouver'] = 'Ванкувер';
$labels['tz:america:whitehorse'] = 'Уайтхорс';
$labels['tz:america:winnipeg'] = 'Виннипег';
$labels['tz:america:yakutat'] = 'Якутат';
$labels['tz:america:yellowknife'] = 'Йеллоунайф';
$labels['tz:antarctica'] = 'Антарктида';
$labels['tz:antarctica:casey'] = 'Кейси';
$labels['tz:antarctica:davis'] = 'Дейвис';
$labels['tz:antarctica:dumontdurville'] = "Дюмон- д' Юрвиль";
$labels['tz:antarctica:macquarie'] = 'Маккуори';
$labels['tz:antarctica:mawson'] = 'Моусон';
$labels['tz:antarctica:mcmurdo'] = 'Мак-Мердо';
$labels['tz:antarctica:palmer'] = 'Палмер';
$labels['tz:antarctica:rothera'] = 'Ротера';
$labels['tz:antarctica:syowa'] = 'Сёва';
$labels['tz:antarctica:troll'] = 'Тролл';
$labels['tz:antarctica:vostok'] = 'Восток';
$labels['tz:arctic'] = 'Арктика';
$labels['tz:arctic:longyearbyen'] = 'Лонгйир';
$labels['tz:asia'] = 'Азия';
$labels['tz:asia:aden'] = 'Аден';
$labels['tz:asia:almaty'] = 'Алма-Ата';
$labels['tz:asia:amman'] = 'Амман';
$labels['tz:asia:anadyr'] = 'Анадырь';
$labels['tz:asia:aqtau'] = 'Актау';
$labels['tz:asia:aqtobe'] = 'Актобе';
$labels['tz:asia:ashgabat'] = 'Ашхабад';
$labels['tz:asia:atyrau'] = 'Атырау';
$labels['tz:asia:baghdad'] = 'Багдад';
$labels['tz:asia:bahrain'] = 'Бахрейн';
$labels['tz:asia:baku'] = 'Баку';
$labels['tz:asia:bangkok'] = 'Бангкок';
$labels['tz:asia:barnaul'] = 'Барнаул';
$labels['tz:asia:beirut'] = 'Бейрут';
$labels['tz:asia:bishkek'] = 'Бишкек';
$labels['tz:asia:brunei'] = 'Бруней';
$labels['tz:asia:chita'] = 'Чита';
$labels['tz:asia:choibalsan'] = 'Чойбалсан';
$labels['tz:asia:colombo'] = 'Коломбо';
$labels['tz:asia:damascus'] = 'Дамаск';
$labels['tz:asia:dhaka'] = 'Дакка';
$labels['tz:asia:dili'] = 'Дили';
$labels['tz:asia:dubai'] = 'Дубай';
$labels['tz:asia:dushanbe'] = 'Душанбе';
$labels['tz:asia:famagusta'] = 'Фамагуста';
$labels['tz:asia:gaza'] = 'Газа';
$labels['tz:asia:hebron'] = 'Хеврон';
$labels['tz:asia:ho_chi_minh'] = 'Хошимин';
$labels['tz:asia:hong_kong'] = 'Гонконг';
$labels['tz:asia:hovd'] = 'Ховд';
$labels['tz:asia:irkutsk'] = 'Иркутск';
$labels['tz:asia:jakarta'] = 'Джакарта';
$labels['tz:asia:jayapura'] = 'Джакарта';
$labels['tz:asia:jerusalem'] = 'Иерусалим';
$labels['tz:asia:kabul'] = 'Кабул';
$labels['tz:asia:kamchatka'] = 'Камчатка';
$labels['tz:asia:karachi'] = 'Карачи';
$labels['tz:asia:kathmandu'] = 'Катманду';
$labels['tz:asia:khandyga'] = 'Хандыга';
$labels['tz:asia:kolkata'] = 'Калькутта';
$labels['tz:asia:krasnoyarsk'] = 'Красноярск';
$labels['tz:asia:kuala_lumpur'] = 'Куала-Лумпур';
$labels['tz:asia:kuching'] = 'Кучинг';
$labels['tz:asia:kuwait'] = 'Кувейт';
$labels['tz:asia:macau'] = 'Макао';
$labels['tz:asia:magadan'] = 'Магадан';
$labels['tz:asia:makassar'] = 'Макассар';
$labels['tz:asia:manila'] = 'Манила';
$labels['tz:asia:muscat'] = 'Маскат';
$labels['tz:asia:nicosia'] = 'Никосия';
$labels['tz:asia:novokuznetsk'] = 'Новокузнецк';
$labels['tz:asia:novosibirsk'] = 'Новосибирск';
$labels['tz:asia:omsk'] = 'Омск';
$labels['tz:asia:oral'] = 'Екатеринбургское время';
$labels['tz:asia:phnom_penh'] = 'Пномпень';
$labels['tz:asia:pontianak'] = 'Понтианак';
$labels['tz:asia:pyongyang'] = 'Пхеньян';
$labels['tz:asia:qatar'] = 'Катар';
$labels['tz:asia:qyzylorda'] = 'Кызылорда';
$labels['tz:asia:riyadh'] = 'Эр-Рияд';
$labels['tz:asia:sakhalin'] = 'Сахалин';
$labels['tz:asia:samarkand'] = 'Самарканд';
$labels['tz:asia:seoul'] = 'Сеул';
$labels['tz:asia:shanghai'] = 'Шанхай';
$labels['tz:asia:singapore'] = 'Сингапур';
$labels['tz:asia:srednekolymsk'] = 'Среднеколымск';
$labels['tz:asia:taipei'] = 'Тайбэй';
$labels['tz:asia:tashkent'] = 'Ташкент';
$labels['tz:asia:tbilisi'] = 'Тбилиси';
$labels['tz:asia:tehran'] = 'Тегеран';
$labels['tz:asia:thimphu'] = 'Тхимпху';
$labels['tz:asia:tokyo'] = 'Токио';
$labels['tz:asia:tomsk'] = 'Томск';
$labels['tz:asia:ulaanbaatar'] = 'Улан-Батор';
$labels['tz:asia:urumqi'] = 'Урумчи';
$labels['tz:asia:ust-nera'] = 'Усть-Нера';
$labels['tz:asia:vientiane'] = 'Вьентьян';
$labels['tz:asia:vladivostok'] = 'Владивосток';
$labels['tz:asia:yakutsk'] = 'Якутск';
$labels['tz:asia:yangon'] = 'Янгон';
$labels['tz:asia:yekaterinburg'] = 'Екатеринбург';
$labels['tz:asia:yerevan'] = 'Ереван';
$labels['tz:atlantic'] = 'Атлантическое время';
$labels['tz:atlantic:azores'] = 'Азорские острова';
$labels['tz:atlantic:bermuda'] = 'Бермудские острова';
$labels['tz:atlantic:canary'] = 'Канарские острова';
$labels['tz:atlantic:cape_verde'] = 'Кабо-Верде';
$labels['tz:atlantic:faroe'] = 'Фареры';
$labels['tz:atlantic:madeira'] = 'Мадейра';
$labels['tz:atlantic:reykjavik'] = 'Рейкьявик';
$labels['tz:atlantic:south_georgia'] = 'Южная Георгия';
$labels['tz:atlantic:st_helena'] = 'Остров Святой Елены';
$labels['tz:atlantic:stanley'] = 'Стэнли';
$labels['tz:australia'] = 'Австралия';
$labels['tz:australia:adelaide'] = 'Аделаида';
$labels['tz:australia:brisbane'] = 'Брисбен';
$labels['tz:australia:broken_hill'] = 'Брокен-Хилл';
$labels['tz:australia:currie'] = 'Карри';
$labels['tz:australia:darwin'] = 'Дарвин';
$labels['tz:australia:eucla'] = 'Эукла';
$labels['tz:australia:hobart'] = 'Хобарт';
$labels['tz:australia:lindeman'] = 'Линдеман';
$labels['tz:australia:lord_howe'] = 'Лорд-Хау';
$labels['tz:australia:melbourne'] = 'Мельбурн';
$labels['tz:australia:perth'] = 'Перт';
$labels['tz:australia:sydney'] = 'Сидней';
$labels['tz:europe'] = 'Европа';
$labels['tz:europe:amsterdam'] = 'Амстердам';
$labels['tz:europe:andorra'] = 'Андорра';
$labels['tz:europe:astrakhan'] = 'Астрахань';
$labels['tz:europe:athens'] = 'Афины';
$labels['tz:europe:belgrade'] = 'Белград';
$labels['tz:europe:berlin'] = 'Берлин';
$labels['tz:europe:bratislava'] = 'Братислава';
$labels['tz:europe:brussels'] = 'Брюссель';
$labels['tz:europe:bucharest'] = 'Бухарест';
$labels['tz:europe:budapest'] = 'Будапешт';
$labels['tz:europe:busingen'] = 'Бюзинген';
$labels['tz:europe:chisinau'] = 'Кишинёв';
$labels['tz:europe:copenhagen'] = 'Копенгаген';
$labels['tz:europe:dublin'] = 'Дублин';
$labels['tz:europe:gibraltar'] = 'Гибралтар';
$labels['tz:europe:guernsey'] = 'Гернси';
$labels['tz:europe:helsinki'] = 'Хельсинки';
$labels['tz:europe:isle_of_man'] = 'Остров Мэн';
$labels['tz:europe:istanbul'] = 'Стамбул';
$labels['tz:europe:jersey'] = 'Джерси';
$labels['tz:europe:kaliningrad'] = 'Калининград';
$labels['tz:europe:kiev'] = 'Киев';
$labels['tz:europe:kirov'] = 'Киров';
$labels['tz:europe:lisbon'] = 'Лиссабон';
$labels['tz:europe:ljubljana'] = 'Любляна';
$labels['tz:europe:london'] = 'Лондон';
$labels['tz:europe:luxembourg'] = 'Люксембург';
$labels['tz:europe:madrid'] = 'Мадрид';
$labels['tz:europe:malta'] = 'Мальта';
$labels['tz:europe:mariehamn'] = 'Мариехамн';
$labels['tz:europe:minsk'] = 'Минск';
$labels['tz:europe:monaco'] = 'Монако';
$labels['tz:europe:moscow'] = 'Москва';
$labels['tz:europe:oslo'] = 'Осло';
$labels['tz:europe:paris'] = 'Париж';
$labels['tz:europe:podgorica'] = 'Подгорица';
$labels['tz:europe:prague'] = 'Прага';
$labels['tz:europe:riga'] = 'Рига';
$labels['tz:europe:rome'] = 'Рим';
$labels['tz:europe:samara'] = 'Самара';
$labels['tz:europe:san_marino'] = 'Сан-Марино';
$labels['tz:europe:sarajevo'] = 'Сараево';
$labels['tz:europe:saratov'] = 'Саратов';
$labels['tz:europe:simferopol'] = 'Симферополь';
$labels['tz:europe:skopje'] = 'Скопье';
$labels['tz:europe:sofia'] = 'София';
$labels['tz:europe:stockholm'] = 'Стокгольм';
$labels['tz:europe:tallinn'] = 'Таллин';
$labels['tz:europe:tirane'] = 'Тирана';
$labels['tz:europe:ulyanovsk'] = 'Ульяновск';
$labels['tz:europe:uzhgorod'] = 'Ужгород';
$labels['tz:europe:vaduz'] = 'Вадуц';
$labels['tz:europe:vatican'] = 'Ватикан';
$labels['tz:europe:vienna'] = 'Вена';
$labels['tz:europe:vilnius'] = 'Вильнюс';
$labels['tz:europe:volgograd'] = 'Волгоград';
$labels['tz:europe:warsaw'] = 'Варшава';
$labels['tz:europe:zagreb'] = 'Загреб';
$labels['tz:europe:zaporozhye'] = 'Запорожье';
$labels['tz:europe:zurich'] = 'Цюрих';
$labels['tz:indian'] = 'Восточноафриканское время';
$labels['tz:indian:antananarivo'] = 'Антананариву';
$labels['tz:indian:chagos'] = 'Чагос';
$labels['tz:indian:christmas'] = 'Остров Рождества';
$labels['tz:indian:cocos'] = 'Остров Кокос';
$labels['tz:indian:comoro'] = 'Коморы';
$labels['tz:indian:kerguelen'] = 'Кергелен';
$labels['tz:indian:mahe'] = 'Маэ';
$labels['tz:indian:maldives'] = 'Мальдивские острова';
$labels['tz:indian:mauritius'] = 'Маврикий';
$labels['tz:indian:mayotte'] = 'Майотта';
$labels['tz:indian:reunion'] = 'Реюньон';
$labels['tz:pacific'] = 'Североамериканское тихоокеанское время';
$labels['tz:pacific:apia'] = 'Апиа';
$labels['tz:pacific:auckland'] = 'Окленд';
$labels['tz:pacific:bougainville'] = 'Бугенвиль';
$labels['tz:pacific:chatham'] = 'Чатем';
$labels['tz:pacific:chuuk'] = 'Чуук';
$labels['tz:pacific:easter'] = 'Остров Пасхи';
$labels['tz:pacific:efate'] = 'Эфате';
$labels['tz:pacific:enderbury'] = 'Эндербери';
$labels['tz:pacific:fakaofo'] = 'Факаофо';
$labels['tz:pacific:fiji'] = 'Фиджи';
$labels['tz:pacific:funafuti'] = 'Фунафути';
$labels['tz:pacific:galapagos'] = 'Галапагос';
$labels['tz:pacific:gambier'] = 'Гамбье';
$labels['tz:pacific:guadalcanal'] = 'Гуадалканал';
$labels['tz:pacific:guam'] = 'Гуам';
$labels['tz:pacific:honolulu'] = 'Гонолулу';
$labels['tz:pacific:johnston'] = 'Джонстон';
$labels['tz:pacific:kiritimati'] = 'Киритимати';
$labels['tz:pacific:kosrae'] = 'Кусаие';
$labels['tz:pacific:kwajalein'] = 'Кваджалейн';
$labels['tz:pacific:majuro'] = 'Маджуро';
$labels['tz:pacific:marquesas'] = 'Маркизские острова';
$labels['tz:pacific:midway'] = 'Мидуэй';
$labels['tz:pacific:nauru'] = 'Науру';
$labels['tz:pacific:niue'] = 'Ниуэ';
$labels['tz:pacific:norfolk'] = 'Норфолк';
$labels['tz:pacific:noumea'] = 'Нумеа';
$labels['tz:pacific:pago_pago'] = 'Паго-Паго';
$labels['tz:pacific:palau'] = 'Палау';
$labels['tz:pacific:pitcairn'] = 'Питкэрн';
$labels['tz:pacific:pohnpei'] = 'Понпеи';
$labels['tz:pacific:port_moresby'] = 'Порт-Морсби';
$labels['tz:pacific:rarotonga'] = 'Раротонга';
$labels['tz:pacific:saipan'] = 'Сайпан';
$labels['tz:pacific:tahiti'] = 'Таити';
$labels['tz:pacific:tarawa'] = 'Тарава';
$labels['tz:pacific:tongatapu'] = 'Тонгатапу';
$labels['tz:pacific:wake'] = 'Уэйк';
$labels['tz:pacific:wallis'] = 'Уоллис и Футуна';
