<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'خطا رخ داد';
$messages['loginfailed']  = 'ورود با شکست همراه بود';
$messages['cookiesdisabled'] = 'جستجوگر شما  cookies را قبول نميکند';
$messages['sessionerror'] = 'جلسه شما وجود ندارد و يا هم از زمان معين آن گذشته است';
$messages['storageerror'] = 'وصل شدن به آیمیپ سرور موفق نشد';
$messages['servererror'] = 'خطای سرور!';
$messages['servererrormsg'] = 'خطای سرور: $msg';
$messages['dberror'] = 'خطای پایگاه داده';
$messages['windowopenerror'] = 'پنجره‌ی پاپ‌آپ مسدود شد!';
$messages['requesttimedout'] = 'عدم پاسخگویی در زمان مقرر';
$messages['errorreadonly'] = 'ناتوان از انجام عملیات. پوشه فقط خواندنی ست.';
$messages['errornoperm'] = 'ناتوان از انجام عملیات. مجوز رد شد.';
$messages['erroroverquota'] = 'ناتوان از انجام عملیات. فضای خالی دیسک کافی نیست.';
$messages['erroroverquotadelete'] = 'فضای خالی دیسک کافی نیست. برای پاک کردن پیام‌ها از SHIFT+DEL استفاده کنید.';
$messages['invalidrequest'] = 'درخواست نامعتبر. هیچ داده‌ای ذخیره نشد.';
$messages['invalidhost'] = 'نام سرور نامعتبر است';
$messages['nomessagesfound'] = 'هيچ پيغامی در اين صندوق پستي دريافت نه شد';
$messages['mailboxempty'] = 'میل باکس خالی است';
$messages['nomessages'] = 'پیامی وجود ندارد';
$messages['refreshing'] = 'دوباره سازی....';
$messages['loading'] = 'در حال بارگزاری...';
$messages['uploading'] = 'در حال بارگزاری فایل...';
$messages['attaching'] = 'ضمیمه کردن پرونده ...';
$messages['uploadingmany'] = 'در حال بارگزاری فایل ها...';
$messages['loadingdata'] = 'در حال بارگزاری داده';
$messages['checkingmail'] = 'پيغام های جديد را بررسي ميکند';
$messages['sendingmessage'] = 'پيغام ها را ارسال ميکند';
$messages['messagesent'] = 'پیام موفقانه ارسال گردید';
$messages['savingmessage'] = 'در حال ذخیره کردن پیام';
$messages['messagesaved'] = 'پيغام را به پیش نويس حفظ کرد';
$messages['successfullysaved'] = 'حفظ پیام موفقانه صورت گرفت';
$messages['savingresponse'] = 'ذخیره کردن متن پاسخ ...';
$messages['deleteresponseconfirm'] = 'آیا واقعاً می‌خواهید این متن پاسخ را حذف کنید؟';
$messages['addedsuccessfully'] = 'آدرس بصورت مکمل در کتاب ادرس علاوه شد';
$messages['contactnameexists'] = 'یک محتوا با نام مشابه وجود دارد.';
$messages['blockedimages'] = 'برای حفظ استقلال پيغام شما، تصاویر اجنبی این پیام بلاک شده اند';
$messages['encryptedmessage'] = 'اين يک پيغام مخفي است و اشکار شده نميتواند   معذرت ميخواهيم';
$messages['externalmessagedecryption'] = 'این یک پیام رمزگذاری شده است و می‌توانید با استفاده از افزونه مرورگر خود آن را رمزگشائی کنید.';
$messages['nopubkeyfor'] = 'کلید عمومی معتبری برای $email پیدا نشد.';
$messages['nocontactsfound'] = 'هيچ آدرسی دريافت نه شد';
$messages['contactnotfound'] = 'آدرس خواسته شده دريافت نه شد';
$messages['sendingfailed'] = 'فرستادن پيغام موفق نه شد';
$messages['senttooquickly'] = 'ثانیه منتظر باشید$secلطفا مدت  قبل از ارسال این پیام';
$messages['errormoving'] = 'پيغام نقل مکان شده نتوانست';
$messages['errorcopying'] = 'امکان کپی پیام (ها) وجود ندارد';
$messages['errordeleting'] = 'پيغام حذف شده نتوانست';
$messages['errormarking'] = 'امکان انتخاب پیام (ها) وجود ندارد';
$messages['deletecontactconfirm']  = 'آيا واقعاً شما ميخواهيد که آدرس های انتخاب شده را حذف کنيد؟';
$messages['deletegroupconfirm']  = 'آیا واقعاً می‌خواهید گروه انتخاب شده حذف شود؟';
$messages['deletemessagesconfirm'] = 'آيا واقعاً شما ميخواهيد که پيغام هاي انتخاب شده را حذف کنيد؟';
$messages['deletefolderconfirm']  = 'آيا واقعاً شما ميخواهيد که اين پوشه را حذف کنيد؟';
$messages['purgefolderconfirm']  = 'آيا واقعاً شما ميخواهيد  تمام پيغام های که  در اين پوشه وجود دارد حذف کنيد؟';
$messages['contactdeleting'] = 'در حال حذف کانتکت(ها)...';
$messages['groupdeleting'] = 'در حال حذف گروه...';
$messages['folderdeleting'] = 'در حال حذف پوشه';
$messages['foldermoving'] = 'در حال انتقال پوشه';
$messages['foldersubscribing'] = 'در حال عضویت در فولدر...';
$messages['folderunsubscribing'] = 'لغو اشتراک پوشه ...';
$messages['formincomplete'] = 'فورمه بصورت مکمل خانه پري نه شده است';
$messages['noemailwarning'] = 'لطفاً يک ايميل ادرس موجود را داخل کنيد';
$messages['nonamewarning']  = 'لطفاً يک نام وارد کنيد';
$messages['nopagesizewarning'] = 'لطفاً اندازه يک صفحه را داخل کنيد';
$messages['norecipientwarning'] = 'لطفاً کم از کم يک آدرس گيرينده را نوشته / داخل کنيد';
$messages['nosubjectwarning']  = 'بخش مضمون خالي است  آیا میخواهید که حالا یکی آنها را درج نمایید؟.';
$messages['nobodywarning'] = 'اين پيغام را بدون متن بفرستیم؟';
$messages['nosearchname'] = 'لطفاً يک نام تماس و يا هم يک ايميل ادرس را داخل کنيد';
$messages['searchsuccessful'] = '$nr پیام یافت شد';
$messages['contactsearchsuccessful'] = '$nr حساب کاربری یافت شد';
$messages['searchnomatch'] = 'جستجو گر موفق به دریافت هیچ گونه اثری نشد';
$messages['searching'] = 'در حال جستجو..';
$messages['checking'] = 'در حال بررسی';
$messages['stillsearching'] = 'در حال جستجو...';
$messages['nospellerrors'] = 'هيچ اشتباه املايي را دريافت نه کرد';
$messages['folderdeleted'] = 'پوشه موفقانه از بين رفت/ حذف گرديد';
$messages['foldersubscribed'] = 'پوشه با موفقیت مشترک شد.';
$messages['folderunsubscribed'] = 'پوشه با موفقیت لغو اشتراک شد.';
$messages['deletedsuccessfully'] = 'با موفقیت حذف شد';
$messages['converting'] = 'در حال پاک کردن ساختار';
$messages['messageopenerror'] = 'پيغام از سرور جريان کرده نتوانست';
$messages['filelinkerror'] = 'ضمیمه کردن پرونده شکست خورد.';
$messages['fileuploaderror'] = 'بارگزاری فايل با خطا مواجه شد.';
$messages['filesizeerror'] = 'تثبیت شده میباشد$size حجم فایل آپلود شده بیشتر از حجم کلی';
$messages['copysuccess'] = 'محتوای $nr با موفقیت کپی شد.';
$messages['sourceisreadonly'] = 'اجازه نمامه کود / منبع این آدرس قفط خواندنی است';
$messages['errorsavingcontact'] = 'ادرس این پیام را حفظکرده نتوانست';
$messages['movingmessage'] = 'ذر حال انتقال پیام...';
$messages['markingmessage'] = 'در حال نشانه گذاری پیغام(ها)...';
$messages['receiptsent'] = 'یک رسید برای ارسال کننده این پیام فرستاده شد.';
$messages['errorsendingreceipt'] = 'رسيد ارسال شده نتوانست';
$messages['nodeletelastidentity'] = 'شما این شناخت نامه را حذف کرده نمیتوانید. این آخرین شناخت نامه شما است.';
$messages['forbiddencharacter'] = 'نام پوشه دارای یک کرکتر ممنوعه است.';
$messages['selectimportfile'] = 'لطفاً یک فایل را برای آپلود کردن انتخاب نمایید.';
$messages['addresswriterror'] = 'کتابچه آدرس انتخاب شده دارای اجازه نامه نوشتاری نیست.';
$messages['importwait'] = 'در حال وارد کردن لطفا صبر کنید.';
$messages['importconfirm'] = '<b>Successfully imported $inserted contacts, $skipped existing entries skipped</b>:<p><em>$names</em></p>';
$messages['opnotpermitted'] = 'اجازه این عملکرد را ندارید';
$messages['smtperror'] = 'خطای SMTP: $msg';
$messages['contactrestored'] = 'دفتر نشانی(ها) با موفقیت بازیابی شد.';
$messages['groupdeleted'] = 'گروه با موفقیت حذف شد.';
$messages['grouprenamed'] = 'تغییر نام گروه با موفقیت انجام شد.';
$messages['groupcreated'] = 'گروه با موفقیت ایجاد شد';
$messages['messagedeleted'] = 'پیام(ها) با موفقیت حذف شدند.';
$messages['messagemoved'] = 'پیام(ها) با موفقیت منتقل شدند.';
$messages['messagecopied'] = 'پیام(ها) با موفقیت کپی شدند.';
$messages['messagemarked'] = 'پیام(ها) با موفقیت نشانه گذاری شدند.';
$messages['namecannotbeempty'] = 'نام نمی تواند خالی باشد.';
$messages['nametoolong'] = 'نام بسیار طولانی است.';
