<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = '마크다운 편집기';
$labels['toolbar_button_quit'] = '텍스트 편집기로 돌아가기';
$labels['toolbar_button_help'] = '새 창으로 마크다운 문법 가이드 열기';
$labels['toolbar_button_preview'] = '전송될 내용을 HTML로 미리보기';
$labels['toolbar_button_bold'] = '굵게';
$labels['toolbar_button_italic'] = '기울임체';
$labels['toolbar_button_strike'] = '취소선';
$labels['toolbar_button_h1'] = '1단계 문단';
$labels['toolbar_button_h2'] = '2단계 문단';
$labels['toolbar_button_h3'] = '3단계 문단';
$labels['toolbar_button_h4'] = '4단계 문단';
$labels['toolbar_button_h5'] = '5단계 문단';
$labels['toolbar_button_h6'] = '6단계 문단';
$labels['toolbar_button_blockquote'] = '인용구';
$labels['toolbar_button_link'] = '링크';
$labels['toolbar_button_image'] = '사진';
$labels['toolbar_button_undo'] = '실행 취소';
$labels['toolbar_button_redo'] = '다시 실행';
